@@ -50,7 +50,7 @@ const G4ChordFinder*(G4FieldManager::*f2_GetChordFinder)() const
   = &G4FieldManager::GetChordFinder;
 
 BOOST_PYTHON_MEMBER_FUNCTION_OVERLOADS(f_SetDetectorField,
-                                       SetDetectorField, 1, 2);
+                                       SetDetectorField, 1, 2)
 
 }
 
