@@ -46,7 +46,6 @@
 
 // constants (detector parameters)
 static const G4double DXYZ_AREA= 30.*cm;
-static const G4double DW= 10.*cm;
 
 //////////////////////////////////////////////
 QDetectorConstruction::QDetectorConstruction()
@@ -70,18 +69,18 @@ G4VPhysicalVolume* QDetectorConstruction::Construct()
   // ==============================================================
   // world volume
   // ==============================================================
-  G4Box* areaSolid= new G4Box("AREA", 
+  G4Box* areaSolid= new G4Box("AREA",
 			      DXYZ_AREA/2., DXYZ_AREA/2., DXYZ_AREA/2.);
 
   G4Material* vacuum= G4Material::GetMaterial("Vacuum");
   G4LogicalVolume* areaLV= new G4LogicalVolume(areaSolid, vacuum, "AREA_LV");
-  G4PVPlacement* area= new G4PVPlacement(0, G4ThreeVector(), "AREA_PV", 
+  G4PVPlacement* area= new G4PVPlacement(0, G4ThreeVector(), "AREA_PV",
 					 areaLV, 0, false, 0);
   // vis. attributes
   va= new G4VisAttributes(G4Color(1.,1.,1.));
   va-> SetForceWireframe(true);
   areaLV-> SetVisAttributes(va);
-  
+
   // ==============================================================
   // detectors
   // ==============================================================
@@ -102,8 +101,7 @@ G4VPhysicalVolume* QDetectorConstruction::Construct()
     for (ix=-7; ix<=7; ix++) {
       G4double x0= (2.*ix)*cm;
       G4double z0= (-13.+2.*iz)*cm;
-      G4PVPlacement* pvoxel= new 
-	G4PVPlacement(0, G4ThreeVector(x0, 0., z0),
+      /*G4PVPlacement* pvoxel=*/ new G4PVPlacement(0, G4ThreeVector(x0, 0., z0),
 		      lvoxel, "voxel", areaLV, false, index);
       index++;
     }
@@ -120,10 +118,9 @@ G4VPhysicalVolume* QDetectorConstruction::Construct()
 
   G4RotationMatrix* rmtube= new G4RotationMatrix;
   rmtube-> rotateX(-90.*deg);
-  G4PVPlacement* ptube= new 
-    G4PVPlacement(rmtube, G4ThreeVector(),
+  /*G4PVPlacement* ptube=*/ new G4PVPlacement(rmtube, G4ThreeVector(),
 		  ltube, "tube", lvoxel, false, 0);
-  
+
   // cal
   const G4double dxycal= 25.*mm;
   const G4double dzcal= 3.*cm;
@@ -137,8 +134,7 @@ G4VPhysicalVolume* QDetectorConstruction::Construct()
   index= 0;
   for (ix=-2; ix<=2; ix++) {
     G4double x0= (5.*ix)*cm;
-    G4PVPlacement* pcal= new 
-      G4PVPlacement(0, G4ThreeVector(x0, 0., 2.*cm),
+    /*G4PVPlacement* pcal=*/ new G4PVPlacement(0, G4ThreeVector(x0, 0., 2.*cm),
 		    lcal, "cal", areaLV, false, index);
     index++;
   }
