@@ -102,15 +102,15 @@ namespace
 }
 
 
-CexmcRunManager::CexmcRunManager( const G4String &  projectId,
-                                  const G4String &  rProject,
+CexmcRunManager::CexmcRunManager( const G4String &  projectId_,
+                                  const G4String &  rProject_,
                                   G4bool  overrideExistingProject ) :
     basePhysicsUsed( CexmcPMFactoryInstance::GetBasePhysics() ),
     productionModelType( CexmcUnknownProductionModel ),
     gdmlFileName( "default.gdml" ), shouldGdmlFileBeValidated( true ),
-    zipGdmlFile( false ), projectsDir( "." ), projectId( projectId ),
-    rProject( rProject ), guiMacroName( "" ), cfFileName( "" ),
-    eventCountPolicy( CexmcCountAllEvents ), areLiveHistogramsEnabled( false ),
+    zipGdmlFile( false ), projectsDir( "." ), projectId( projectId_ ),
+    rProject( rProject_ ), guiMacroName( "" ), cfFileName( "" ),
+    eventCountPolicy( CexmcCountAllEvents ),
     skipInteractionsWithoutEDTonWrite( true ),
     evDataVerboseLevel( CexmcWriteEventDataOnEveryEDT ),
     rEvDataVerboseLevel( CexmcWriteNoEventData ), numberOfEventsProcessed( 0 ),
@@ -127,7 +127,7 @@ CexmcRunManager::CexmcRunManager( const G4String &  projectId,
     if ( rProject != "" && rProject == projectId )
         throw CexmcException( CexmcWeirdException );
 
-    const char *  projectsDirEnv( getenv( "CEXMC_PROJECTS_DIR" ) );
+    const char *  projectsDirEnv( std::getenv( "CEXMC_PROJECTS_DIR" ) );
 
     if ( projectsDirEnv )
         projectsDir = projectsDirEnv;
