@@ -60,57 +60,7 @@
 
 UltraPrimaryGeneratorAction::UltraPrimaryGeneratorAction()
 {
-
   particleGun = new G4GeneralParticleSource();
-
-
-  // Define here the user default properties for the General Particle Source (GPS)
-  // Can be modified through the GPS Messenger (/gps/... commands)
-
-  G4ParticleTable* particleTable = G4ParticleTable::GetParticleTable();
-  G4String particleName;
-
-  G4ParticleDefinition* opticalphoton = particleTable->FindParticle(particleName="opticalphoton");
-
-  //....PARTICLE DEFINITIONS
-  particleGun->SetParticleDefinition(opticalphoton);
-
-  G4ThreeVector Polarization = G4ThreeVector(1.,1.,0.) ;
-  particleGun->SetParticlePolarization(Polarization);
-  
-  // DEFINE A MONO-ENERGETIC SOURCE
-  G4SPSEneDistribution *eneDist = particleGun->GetCurrentSource()->GetEneDist() ;
-  eneDist->SetEnergyDisType("Mono");
-  eneDist->SetMonoEnergy(3.0*eV);
-
-  // SET POSITION DISTRIBUTION 
-  G4SPSPosDistribution *posDist = particleGun->GetCurrentSource()->GetPosDist() ;
-  posDist->SetPosDisType("Plane");
-  posDist->SetPosDisShape("Circle");
-  posDist->SetRadius(20.0*cm);
-
-#ifdef ULTRA_MIRROR_USE
-#define ULTRA_REFLECTION_USE
-#endif
-
-#ifdef ULTRA_GROUND_USE
-#define ULTRA_REFLECTION_USE
-#endif
-
-  G4SPSAngDistribution *angDist = particleGun->GetCurrentSource()->GetAngDist() ;
-
-#ifdef ULTRA_REFLECTION_USE
-  angDist->SetParticleMomentumDirection(G4ThreeVector(0.0,-1.0,0.0)) ;
-  posDist->SetPosRot1(G4ThreeVector(1.,0.,0.));
-  posDist->SetPosRot2(G4ThreeVector(0.,0.,-1.));
-  posDist->SetCentreCoords(G4ThreeVector(0.0*cm,90.0*cm,150.0*cm));
-
-#else
-  angDist->SetParticleMomentumDirection(G4ThreeVector(0.0,0.0,-1.0)) ;
-  posDist->SetCentreCoords(G4ThreeVector(0.0*cm,0.0*cm,150.0*cm));
-
-#endif
-
 }
 
 //....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo....
@@ -134,11 +84,8 @@ void UltraPrimaryGeneratorAction::GeneratePrimaries(G4Event* anEvent)
 
 
 // Check if optical photon wavelength is within limits set for material optical properties tables. 
-
-   
-
-
-}
+  }
+  
   particleGun->GeneratePrimaryVertex(anEvent);
 
     if (particleGun->GetParticleDefinition()->GetParticleName() == "opticalphoton"){
