@@ -23,13 +23,10 @@
 // * acceptance of all terms of the Geant4 Software license.          *
 // ********************************************************************
 //
-// Authors: S. Guatelli , M. G. Pia, INFN Genova and F. Ambroglini INFN Perugia, Italy
+//
+// Previous authors: G. Guerrieri, S. Guatelli and M. G. Pia, INFN Genova, Italy
+// Authors (since 2007): S. Guatelli, University of Wollongong, Australia
 // 
-// Based on code developed by the undergraduate student G. Guerrieri 
-// Note: this is a preliminary beta-version of the code; an improved 
-// version will be distributed in the next Geant4 public release, compliant
-// with the design in a forthcoming publication, and subject to a 
-// design and code review.
 //
 #include "G4MIRDRibCage.hh"
 
@@ -204,7 +201,7 @@ G4VPhysicalVolume* G4MIRDRibCage::Construct(const G4String& volumeName, G4VPhysi
 				0, true);
   
   // Visualization Attributes
-  logicRibCage -> SetVisAttributes(G4VisAttributes::Invisible);
+  logicRibCage -> SetVisAttributes(G4VisAttributes::GetInvisible());
 
   //G4VisAttributes* RibCageVisAtt = new G4VisAttributes(G4Colour(0.46,0.53,0.6));
 
