@@ -23,21 +23,21 @@
 // * acceptance of all terms of the Geant4 Software license.          *
 // ********************************************************************
 //
-// $Id: B1EventAction.cc 75117 2013-10-28 09:38:37Z gcosmo $
 //
 /// \file B1EventAction.cc
 /// \brief Implementation of the B1EventAction class
 
 #include "B1EventAction.hh"
-#include "B1Run.hh"
+#include "B1RunAction.hh"
 
 #include "G4Event.hh"
 #include "G4RunManager.hh"
 
 //....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......
 
-B1EventAction::B1EventAction()
+B1EventAction::B1EventAction(B1RunAction* runAction)
 : G4UserEventAction(),
+  fRunAction(runAction),
   fEdep(0.)
 {} 
 
@@ -57,11 +57,8 @@ void B1EventAction::BeginOfEventAction(const G4Event*)
 
 void B1EventAction::EndOfEventAction(const G4Event*)
 {   
-  // accumulate statistics in B1Run
-  B1Run* run 
-    = static_cast<B1Run*>(
-        G4RunManager::GetRunManager()->GetNonConstCurrentRun());
-  run->AddEdep(fEdep);
+  // accumulate statistics in run action
+  fRunAction->AddEdep(fEdep);
 }
 
 //....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......
