@@ -29,6 +29,7 @@
 
 #include "B4dDetectorConstruction.hh"
 #include "B4dActionInitialization.hh"
+#include "B4Analysis.hh"
 
 #ifdef G4MULTITHREADED
 #include "G4MTRunManager.hh"
@@ -38,12 +39,10 @@
 
 #include "G4UImanager.hh"
 #include "FTFP_BERT.hh"
-
-#include "Randomize.hh"
-
 #include "G4VisExecutive.hh"
-
 #include "G4UIExecutive.hh"
+#include "Randomize.hh"
+#include "G4TScoreNtupleWriter.hh"
 
 //....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......
 
@@ -93,9 +92,9 @@ int main(int argc,char** argv)
     ui = new G4UIExecutive(argc, argv, session);
   }
 
-  // Choose the Random engine
+  // Optionally: choose a different Random engine...
   //
-  G4Random::setTheEngine(new CLHEP::RanecuEngine);
+  // G4Random::setTheEngine(new CLHEP::MTwistEngine);
   
   // Construct the MT run manager
   //
@@ -128,6 +127,14 @@ int main(int argc,char** argv)
   // Get the pointer to the User Interface manager
   auto UImanager = G4UImanager::GetUIpointer();
 
+  // Activate score ntuple writer
+  // The Root output type (Root) is selected in B3Analysis.hh.
+  G4TScoreNtupleWriter<G4AnalysisManager> scoreNtupleWriter;
+  // The verbose level can be set via UI commands
+  // /score/ntuple/writerVerbose level
+  // or via the score ntuple writer function:
+  // scoreNtupleWriter.SetVerboseLevel(1);
+
   // Process macro or start UI session
   //
   if ( macro.size() ) {
