@@ -288,6 +288,10 @@ void B03PhysicsList::ConstructEM()
 #include "G4IonsShenCrossSection.hh"
 #include "G4TripathiCrossSection.hh"
 #include "G4TripathiLightCrossSection.hh"
+#include "G4ComponentGGHadronNucleusXsc.hh"
+#include "G4CrossSectionElastic.hh"
+#include "G4CrossSectionInelastic.hh"
+#include "G4NeutronInelasticXS.hh"
 
 //
 // ConstructHad()
@@ -363,8 +367,13 @@ void B03PhysicsList::ConstructHad()
   G4TripathiCrossSection* tripXS = new G4TripathiCrossSection;
   G4TripathiLightCrossSection* tripLightXS = new G4TripathiLightCrossSection;
 
+  G4ComponentGGHadronNucleusXsc * ggHNXsec = new G4ComponentGGHadronNucleusXsc();
+  G4VCrossSectionDataSet * theGGHNEl = new G4CrossSectionElastic(ggHNXsec);
+  G4VCrossSectionDataSet * theGGHNInel = new G4CrossSectionInelastic(ggHNXsec);
+
   // Elastic process
   G4HadronElasticProcess* theElasticProcess = new G4HadronElasticProcess;
+  theElasticProcess->AddDataSet(theGGHNEl);
   G4HadronElastic* theElasticModel = new G4HadronElastic;
   theElasticProcess->RegisterMe(theElasticModel);
 
@@ -379,6 +388,7 @@ void B03PhysicsList::ConstructHad()
          pmanager->AddDiscreteProcess(theElasticProcess);
          G4PionPlusInelasticProcess* theInelasticProcess = 
                                 new G4PionPlusInelasticProcess("inelastic");
+         theInelasticProcess->AddDataSet(theGGHNInel);
          theInelasticProcess->RegisterMe(bertini);
          theInelasticProcess->RegisterMe(theTheoModel);
          pmanager->AddDiscreteProcess(theInelasticProcess);
@@ -386,6 +396,7 @@ void B03PhysicsList::ConstructHad()
          pmanager->AddDiscreteProcess(theElasticProcess);
          G4PionMinusInelasticProcess* theInelasticProcess = 
                                 new G4PionMinusInelasticProcess("inelastic");
+         theInelasticProcess->AddDataSet(theGGHNInel);
          theInelasticProcess->RegisterMe(bertini);
          theInelasticProcess->RegisterMe(theTheoModel);
          pmanager->AddDiscreteProcess(theInelasticProcess);
@@ -393,6 +404,7 @@ void B03PhysicsList::ConstructHad()
          pmanager->AddDiscreteProcess(theElasticProcess);
          G4KaonPlusInelasticProcess* theInelasticProcess = 
                                   new G4KaonPlusInelasticProcess("inelastic");
+         theInelasticProcess->AddDataSet(theGGHNInel);
          theInelasticProcess->RegisterMe(bertini);
          theInelasticProcess->RegisterMe(theTheoModel);
          pmanager->AddDiscreteProcess(theInelasticProcess);
@@ -401,6 +413,7 @@ void B03PhysicsList::ConstructHad()
          pmanager->AddDiscreteProcess(theElasticProcess);
          G4KaonZeroSInelasticProcess* theInelasticProcess = 
                              new G4KaonZeroSInelasticProcess("inelastic");
+         theInelasticProcess->AddDataSet(theGGHNInel);
          theInelasticProcess->RegisterMe(bertini);
          theInelasticProcess->RegisterMe(theTheoModel);
          pmanager->AddDiscreteProcess(theInelasticProcess);
@@ -409,6 +422,7 @@ void B03PhysicsList::ConstructHad()
          pmanager->AddDiscreteProcess(theElasticProcess);
          G4KaonZeroLInelasticProcess* theInelasticProcess = 
                              new G4KaonZeroLInelasticProcess("inelastic");
+         theInelasticProcess->AddDataSet(theGGHNInel);
          theInelasticProcess->RegisterMe(bertini);
          theInelasticProcess->RegisterMe(theTheoModel);
          pmanager->AddDiscreteProcess(theInelasticProcess);
@@ -417,6 +431,7 @@ void B03PhysicsList::ConstructHad()
          pmanager->AddDiscreteProcess(theElasticProcess);
          G4KaonMinusInelasticProcess* theInelasticProcess = 
                                  new G4KaonMinusInelasticProcess("inelastic");
+         theInelasticProcess->AddDataSet(theGGHNInel);
          theInelasticProcess->RegisterMe(bertini);
          theInelasticProcess->RegisterMe(theTheoModel);
          pmanager->AddDiscreteProcess(theInelasticProcess);
@@ -425,6 +440,7 @@ void B03PhysicsList::ConstructHad()
          pmanager->AddDiscreteProcess(theElasticProcess);
          G4ProtonInelasticProcess* theInelasticProcess = 
                                     new G4ProtonInelasticProcess("inelastic");
+         theInelasticProcess->AddDataSet(theGGHNInel);
          theInelasticProcess->RegisterMe(bertini);
          theInelasticProcess->RegisterMe(theTheoModel);
          pmanager->AddDiscreteProcess(theInelasticProcess);
@@ -433,6 +449,7 @@ void B03PhysicsList::ConstructHad()
          pmanager->AddDiscreteProcess(theElasticProcess);
          G4AntiProtonInelasticProcess* theInelasticProcess = 
                                 new G4AntiProtonInelasticProcess("inelastic");
+         theInelasticProcess->AddDataSet(theGGHNInel);
          theInelasticProcess->RegisterMe(antiBHighEnergyModel);
          pmanager->AddDiscreteProcess(theInelasticProcess);
 
@@ -443,6 +460,7 @@ void B03PhysicsList::ConstructHad()
       // inelastic scattering
       G4NeutronInelasticProcess* theInelasticProcess = 
                                     new G4NeutronInelasticProcess("inelastic");
+      theInelasticProcess->AddDataSet(new G4NeutronInelasticXS());
       theInelasticProcess->RegisterMe(bertini);
       theInelasticProcess->RegisterMe(theTheoModel);
       pmanager->AddDiscreteProcess(theInelasticProcess);
@@ -463,6 +481,7 @@ void B03PhysicsList::ConstructHad()
          pmanager->AddDiscreteProcess(theElasticProcess);
          G4AntiNeutronInelasticProcess* theInelasticProcess = 
                                new G4AntiNeutronInelasticProcess("inelastic");
+         theInelasticProcess->AddDataSet(theGGHNInel);
          theInelasticProcess->RegisterMe(antiBHighEnergyModel);
          pmanager->AddDiscreteProcess(theInelasticProcess);
 
@@ -470,6 +489,7 @@ void B03PhysicsList::ConstructHad()
          pmanager->AddDiscreteProcess(theElasticProcess);
          G4LambdaInelasticProcess* theInelasticProcess = 
                                     new G4LambdaInelasticProcess("inelastic");
+         theInelasticProcess->AddDataSet(theGGHNInel);
          theInelasticProcess->RegisterMe(bertini);
          theInelasticProcess->RegisterMe(theTheoModel);
          pmanager->AddDiscreteProcess(theInelasticProcess);
@@ -478,6 +498,7 @@ void B03PhysicsList::ConstructHad()
          pmanager->AddDiscreteProcess(theElasticProcess);
          G4AntiLambdaInelasticProcess* theInelasticProcess = 
                                 new G4AntiLambdaInelasticProcess("inelastic");
+         theInelasticProcess->AddDataSet(theGGHNInel);
          theInelasticProcess->RegisterMe(antiBHighEnergyModel);
          pmanager->AddDiscreteProcess(theInelasticProcess);
       }
@@ -485,6 +506,7 @@ void B03PhysicsList::ConstructHad()
          pmanager->AddDiscreteProcess(theElasticProcess);
          G4SigmaPlusInelasticProcess* theInelasticProcess = 
                                  new G4SigmaPlusInelasticProcess("inelastic");
+         theInelasticProcess->AddDataSet(theGGHNInel);
          theInelasticProcess->RegisterMe(bertini);
          theInelasticProcess->RegisterMe(theTheoModel);
          pmanager->AddDiscreteProcess(theInelasticProcess);
@@ -493,6 +515,7 @@ void B03PhysicsList::ConstructHad()
          pmanager->AddDiscreteProcess(theElasticProcess);
          G4SigmaMinusInelasticProcess* theInelasticProcess = 
                                  new G4SigmaMinusInelasticProcess("inelastic");
+         theInelasticProcess->AddDataSet(theGGHNInel);
          theInelasticProcess->RegisterMe(bertini);
          theInelasticProcess->RegisterMe(theTheoModel);
          pmanager->AddDiscreteProcess(theInelasticProcess);
@@ -501,6 +524,7 @@ void B03PhysicsList::ConstructHad()
          pmanager->AddDiscreteProcess(theElasticProcess);
          G4AntiSigmaPlusInelasticProcess* theInelasticProcess = 
                              new G4AntiSigmaPlusInelasticProcess("inelastic");
+         theInelasticProcess->AddDataSet(theGGHNInel);
          theInelasticProcess->RegisterMe(antiBHighEnergyModel);
          pmanager->AddDiscreteProcess(theInelasticProcess);
       }
@@ -508,6 +532,7 @@ void B03PhysicsList::ConstructHad()
          pmanager->AddDiscreteProcess(theElasticProcess);
          G4AntiSigmaMinusInelasticProcess* theInelasticProcess = 
                             new G4AntiSigmaMinusInelasticProcess("inelastic");
+         theInelasticProcess->AddDataSet(theGGHNInel);
          theInelasticProcess->RegisterMe(antiBHighEnergyModel);
          pmanager->AddDiscreteProcess(theInelasticProcess);
       }
@@ -515,6 +540,7 @@ void B03PhysicsList::ConstructHad()
          pmanager->AddDiscreteProcess(theElasticProcess);
          G4XiZeroInelasticProcess* theInelasticProcess = 
                             new G4XiZeroInelasticProcess("inelastic");
+         theInelasticProcess->AddDataSet(theGGHNInel);
          theInelasticProcess->RegisterMe(bertini);
          theInelasticProcess->RegisterMe(theTheoModel);
          pmanager->AddDiscreteProcess(theInelasticProcess);
@@ -523,6 +549,7 @@ void B03PhysicsList::ConstructHad()
          pmanager->AddDiscreteProcess(theElasticProcess);
          G4XiMinusInelasticProcess* theInelasticProcess = 
                             new G4XiMinusInelasticProcess("inelastic");
+         theInelasticProcess->AddDataSet(theGGHNInel);
          theInelasticProcess->RegisterMe(bertini);
          theInelasticProcess->RegisterMe(theTheoModel);
          pmanager->AddDiscreteProcess(theInelasticProcess);
@@ -531,6 +558,7 @@ void B03PhysicsList::ConstructHad()
          pmanager->AddDiscreteProcess(theElasticProcess);
          G4AntiXiZeroInelasticProcess* theInelasticProcess = 
                             new G4AntiXiZeroInelasticProcess("inelastic");
+         theInelasticProcess->AddDataSet(theGGHNInel);
          theInelasticProcess->RegisterMe(antiBHighEnergyModel);
          pmanager->AddDiscreteProcess(theInelasticProcess);
       }
@@ -538,6 +566,7 @@ void B03PhysicsList::ConstructHad()
          pmanager->AddDiscreteProcess(theElasticProcess);
          G4AntiXiMinusInelasticProcess* theInelasticProcess = 
                             new G4AntiXiMinusInelasticProcess("inelastic");
+         theInelasticProcess->AddDataSet(theGGHNInel);
          theInelasticProcess->RegisterMe(antiBHighEnergyModel);
          pmanager->AddDiscreteProcess(theInelasticProcess);
       }
@@ -578,6 +607,7 @@ void B03PhysicsList::ConstructHad()
       pmanager->AddDiscreteProcess(theElasticProcess);
       G4OmegaMinusInelasticProcess* theInelasticProcess = 
                             new G4OmegaMinusInelasticProcess("inelastic");
+      theInelasticProcess->AddDataSet(theGGHNInel);
       theInelasticProcess->RegisterMe(bertini);
       theInelasticProcess->RegisterMe(theTheoModel);
       pmanager->AddDiscreteProcess(theInelasticProcess);
@@ -586,6 +616,7 @@ void B03PhysicsList::ConstructHad()
       pmanager->AddDiscreteProcess(theElasticProcess);
       G4AntiOmegaMinusInelasticProcess* theInelasticProcess = 
                             new G4AntiOmegaMinusInelasticProcess("inelastic");
+      theInelasticProcess->AddDataSet(theGGHNInel);
       theInelasticProcess->RegisterMe(antiBHighEnergyModel);
       pmanager->AddDiscreteProcess(theInelasticProcess);
     }
