@@ -26,7 +26,6 @@
 /// \file electromagnetic/TestEm12/src/StepMaxMessenger.cc
 /// \brief Implementation of the StepMaxMessenger class
 //
-// $Id$
 //
 //....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......
 //....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......
@@ -40,7 +39,9 @@
 //....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......
 
 StepMaxMessenger::StepMaxMessenger(StepMax* stepM)
-:fStepMax(stepM)
+:G4UImessenger(),fStepMax(stepM),
+ fStepMax1Cmd(0),    
+ fStepMax2Cmd(0)
 { 
   fStepMax1Cmd = new G4UIcmdWithADoubleAndUnit("/testem/stepMax",this);
   fStepMax1Cmd->SetGuidance("Set max allowed step length");
