@@ -23,16 +23,16 @@
 // * acceptance of all terms of the Geant4 Software license.          *
 // ********************************************************************
 //
-/// \file electromagnetic/TestEm14/src/PhysListEmLivermore.cc
+/// \file PhysListEmLivermore.cc
 /// \brief Implementation of the PhysListEmLivermore class
 //
 //
-// $Id: PhysListEmLivermore.cc 100278 2016-10-17 08:34:03Z gcosmo $
 //
 //....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......
 //....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......
 
 #include "PhysListEmLivermore.hh"
+#include "G4BuilderType.hh"
 #include "G4ParticleDefinition.hh"
 #include "G4ProcessManager.hh"
 
@@ -74,6 +74,8 @@
 #include "G4hIonisation.hh"
 #include "G4ionIonisation.hh"
 
+// deexcitation
+
 #include "G4LossTableManager.hh"
 #include "G4UAtomicDeexcitation.hh"
 
@@ -83,7 +85,17 @@
 
 PhysListEmLivermore::PhysListEmLivermore(const G4String& name)
   :  G4VPhysicsConstructor(name)
-{ }
+{
+    G4EmParameters* param = G4EmParameters::Instance();
+    param->SetDefaults();
+    param->SetMinEnergy(10*eV);
+    param->SetMaxEnergy(10*TeV);
+    param->SetNumberOfBinsPerDecade(10);
+    param->SetBuildCSDARange(true);
+  
+    param->SetVerbose(0);
+    param->Dump();
+ }
 
 //....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......
 
@@ -94,13 +106,13 @@ PhysListEmLivermore::~PhysListEmLivermore()
 
 void PhysListEmLivermore::ConstructProcess()
 {
-  // Add standard EM Processes
-
+  // Add Livermore EM Processes
+  
   auto particleIterator=GetParticleIterator();
   particleIterator->reset();
   while( (*particleIterator)() ){
     G4ParticleDefinition* particle = particleIterator->value();
-    G4ProcessManager* pmanager = particle->GetProcessManager();
+    G4ProcessManager* pmanager = particle->GetProcessManager();    
     G4String particleName = particle->GetParticleName();
 
     //Applicability range for Livermore models
@@ -115,8 +127,9 @@ void PhysListEmLivermore::ConstructProcess()
       photModel = new G4LivermorePhotoElectricModel();
       photModel->SetHighEnergyLimit(highEnergyLimit);
       phot->AddEmModel(0, photModel);
+      ///list->RegisterProcess(phot, particle);
       pmanager->AddDiscreteProcess(phot);
-
+      
       G4ComptonScattering* compt = new G4ComptonScattering();
       G4LivermoreComptonModel* 
       comptModel = new G4LivermoreComptonModel();
@@ -130,7 +143,7 @@ void PhysListEmLivermore::ConstructProcess()
       convModel->SetHighEnergyLimit(highEnergyLimit);
       conv->AddEmModel(0, convModel);
       pmanager->AddDiscreteProcess(conv);
-
+      
       G4RayleighScattering* rayl = new G4RayleighScattering();
       G4LivermoreRayleighModel* 
       raylModel = new G4LivermoreRayleighModel();
@@ -154,7 +167,7 @@ void PhysListEmLivermore::ConstructProcess()
       eBremModel->SetHighEnergyLimit(highEnergyLimit);
       eBrem->AddEmModel(0, eBremModel);
       pmanager->AddProcess(eBrem,                   -1,-1, 2);
-                  
+
     } else if (particleName == "e+") {
       //positron
       pmanager->AddProcess(new G4eIonisation,       -1,-1, 1);
@@ -176,16 +189,13 @@ void PhysListEmLivermore::ConstructProcess()
                (particle->GetParticleName() != "chargedgeantino")) {
       //all others charged particles except geantino
       pmanager->AddProcess(new G4hIonisation,       -1,-1, 1);
-    }
+    }    
   }
   
   // Deexcitation
   //
-  G4VAtomDeexcitation* de = new G4UAtomicDeexcitation();
-  de->SetFluo(true);
-  de->SetAuger(false);  
-  de->SetPIXE(false);  
-  G4LossTableManager::Instance()->SetAtomDeexcitation(de);  
+  G4VAtomDeexcitation* deex = new G4UAtomicDeexcitation();
+  G4LossTableManager::Instance()->SetAtomDeexcitation(deex);
 }
 
 //....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......
