@@ -26,7 +26,6 @@
 /// \file electromagnetic/TestEm5/src/PrimaryGeneratorAction.cc
 /// \brief Implementation of the PrimaryGeneratorAction class
 //
-// $Id$
 //
 //....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......
 //....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......
@@ -44,14 +43,13 @@
 
 //....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......
 
-PrimaryGeneratorAction::PrimaryGeneratorAction(
-                                            DetectorConstruction* DC)
-:fDetector(DC)
+PrimaryGeneratorAction::PrimaryGeneratorAction(DetectorConstruction* DC)
+:G4VUserPrimaryGeneratorAction(),
+ fParticleGun(0),fDetector(DC),fRndmBeam(0),fGunMessenger(0)
 {
   G4int n_particle = 1;
   fParticleGun  = new G4ParticleGun(n_particle);
   SetDefaultKinematic();
-  fRndmBeam = 0.;
   
   //create a messenger for this class
   fGunMessenger = new PrimaryGeneratorMessenger(this);
@@ -78,7 +76,7 @@ void PrimaryGeneratorAction::SetDefaultKinematic()
   fParticleGun->SetParticleMomentumDirection(G4ThreeVector(1.,0.,0.));
   fParticleGun->SetParticleEnergy(30.*MeV);
   G4double x0 = -0.5*(fDetector->GetWorldSizeX());
-  fParticleGun->SetParticlePosition(G4ThreeVector(x0, 0*cm, 0*cm));  
+  fParticleGun->SetParticlePosition(G4ThreeVector(x0, 0.0, 0.0));  
 }
 
 //....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......
