@@ -26,7 +26,6 @@
 /// \file electromagnetic/TestEm5/src/Run.cc
 /// \brief Implementation of the Run class
 //
-// $Id: Run.cc 71376 2013-06-14 07:44:50Z maire $
 // 
 //....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......
 //....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......
@@ -201,7 +200,7 @@ void Run::EndOfRun()
       
   //Stopping Power from input Table.
   //
-  G4Material* material = fDetector->GetAbsorberMaterial();
+  const G4Material* material = fDetector->GetAbsorberMaterial();
   G4double length      = fDetector->GetAbsorberThickness();
   G4double density     = material->GetDensity();   
   G4String partName    = fParticle->GetParticleName();
