@@ -26,7 +26,6 @@
 /// \file electromagnetic/TestEm9/src/RunAction.cc
 /// \brief Implementation of the RunAction class
 //
-// $Id$
 //
 //
 // -------------------------------------------------------------
@@ -41,8 +40,6 @@
 
 #include "RunAction.hh"
 #include "HistoManager.hh"
-#include "G4UImanager.hh"
-#include "G4VVisManager.hh"
 
 //....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo....
 
@@ -62,18 +59,6 @@ void RunAction::BeginOfRunAction(const G4Run* aRun)
   G4int id = aRun->GetRunID();
   G4cout << "### Run " << id << " start" << G4endl;
   (HistoManager::GetPointer())->BeginOfRun();
-
-#ifdef G4VIS_USE
-  G4UImanager* UI = G4UImanager::GetUIpointer();
-
-  G4VVisManager* pVVisManager = G4VVisManager::GetConcreteInstance();
-
-  if(pVVisManager)
-  {
-    UI->ApplyCommand("/vis/scene/notifyHandlers");
-  }
-#endif
-
 }
 
 //....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo....
@@ -83,12 +68,6 @@ void RunAction::EndOfRunAction(const G4Run* run)
 
   G4cout << "RunAction: End of run actions are started" << G4endl;
   (HistoManager::GetPointer())->EndOfRun(run->GetRunID());
-
-#ifdef G4VIS_USE
-  if (G4VVisManager::GetConcreteInstance())
-    G4UImanager::GetUIpointer()->ApplyCommand("/vis/viewer/update");
-#endif
-
 }
 
 //....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo....
