@@ -26,33 +26,44 @@
 /// \file exoticphysics/phonon/XGeBox.cc
 /// \brief Main program of the exoticphysics/phonon example
 //
-// $Id: XGeBox.cc 76246 2013-11-08 11:17:29Z gcosmo $
 //
- 
-#include "G4RunManager.hh"
+
+#include "G4Types.hh"
+
 #include "G4UImanager.hh"
 #include "G4UserSteppingAction.hh"
 
-#ifdef G4VIS_USE
+#ifdef G4MULTITHREADED
+#include "G4MTRunManager.hh"
+#else
+#include "G4RunManager.hh"
+#endif
+
 #include "G4VisExecutive.hh"
-#endif
-
-#ifdef G4UI_USE
 #include "G4UIExecutive.hh"
-#endif
 
+#include "XActionInitialization.hh"
 #include "XDetectorConstruction.hh"
 #include "XPhysicsList.hh"
-#include "XPrimaryGeneratorAction.hh"
-#include "XPhononStackingAction.hh"
 
-int main(int argc,char** argv)
-{
-  
+
+//....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo....
+
+int main(int argc,char** argv) {
+
+ // Instantiate G4UIExecutive if interactive mode
+ G4UIExecutive* ui = nullptr;
+ if ( argc == 1 ) {
+   ui = new G4UIExecutive(argc, argv);
+ }
 
  // Construct the run manager
  //
- G4RunManager * runManager = new G4RunManager;
+#ifdef G4MULTITHREADED
+ G4MTRunManager* runManager = new G4MTRunManager;
+#else
+ G4RunManager* runManager = new G4RunManager;
+#endif
 
  // Set mandatory initialization classes
  //
@@ -65,24 +76,14 @@ int main(int argc,char** argv)
     
  // Set user action classes
  //
+ runManager->SetUserInitialization(new XActionInitialization);
 
- runManager->SetUserAction(new XPhononStackingAction);
- // runManager->SetUserAction(new DriftingElectronStackingAction);
- // runManager->SetUserAction(new XPhononTrackingAction);
- // runManager->SetUserAction(new PhononSteppingAction);
-
- G4VUserPrimaryGeneratorAction* gen_action = new XPrimaryGeneratorAction();
- runManager->SetUserAction(gen_action);
- //
-
-#ifdef G4VIS_USE
  // Visualization manager
  //
  G4VisManager* visManager = new G4VisExecutive;
  visManager->Initialize();
-#endif
-    
- // Initialize G4 kernel
+
+ // Initialize G4 kernel (replaces /run/initialize macro command)
  //
  runManager->Initialize();
   
@@ -90,16 +91,11 @@ int main(int argc,char** argv)
  //
  G4UImanager* UImanager = G4UImanager::GetUIpointer();  
 
- if (argc==1)   // Define UI session for interactive mode
+ if (ui)   // Define UI session for interactive mode
  {
-#ifdef G4UI_USE
-      G4UIExecutive * ui = new G4UIExecutive(argc,argv);
-#ifdef G4VIS_USE
       UImanager->ApplyCommand("/control/execute vis.mac");
-#endif
       ui->SessionStart();
       delete ui;
-#endif
  }
  else           // Batch mode
  {
@@ -108,9 +104,7 @@ int main(int argc,char** argv)
    UImanager->ApplyCommand(command+fileName);
  }
 
-#ifdef G4VIS_USE
  delete visManager;
-#endif
  delete runManager;
 
  return 0;
