@@ -23,6 +23,7 @@
 // * acceptance of all terms of the Geant4 Software license.          *
 // ********************************************************************
 //
+//
 /// \file field/field05/field05.cc
 /// \brief Main program of the field/field05 example
 //
@@ -36,98 +37,96 @@
 #include <unistd.h>
 #endif
 
+#include "G4Types.hh"
+
+#ifdef G4MULTITHREADED
+#include "G4MTRunManager.hh"
+#else
+#include "F05SteppingVerbose.hh"
 #include "G4RunManager.hh"
+#endif
+
+#include "F05PhysicsList.hh"
+#include "F05DetectorConstruction.hh"
+
+#include "F05ActionInitialization.hh"
+
 #include "G4UImanager.hh"
 
 #include "Randomize.hh"
 
-#include "F05PhysicsList.hh"
-#include "F05DetectorConstruction.hh"
-#include "F05PrimaryGeneratorAction.hh"
-
-#include "G4SteppingVerbose.hh"
-#include "F05SteppingAction.hh"
-
-#ifdef G4VIS_USE
 #include "G4VisExecutive.hh"
-#endif
-
-#ifdef G4UI_USE
 #include "G4UIExecutive.hh"
-#endif
 
 //....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......
 
 int main(int argc,char** argv)
 {
-  G4int seed = 1234;
-  if (argc  > 2) seed = atoi(argv[argc-1]);
+  // Instantiate G4UIExecutive if there are no arguments (interactive mode)
+  G4UIExecutive* ui = nullptr;
+  if ( argc == 1 ) {
+    ui = new G4UIExecutive(argc, argv);
+  }
 
   // Choose the Random engine
   //
-  CLHEP::HepRandom::setTheEngine(new CLHEP::RanecuEngine);
-  CLHEP::HepRandom::setTheSeed(seed);
-  
-  // User Verbose output class
-  //
-  G4VSteppingVerbose::SetInstance(new G4SteppingVerbose());
+  G4Random::setTheEngine(new CLHEP::RanecuEngine);
+
+  G4int myseed = 1234;
+  if (argc  > 2) myseed = atoi(argv[argc-1]);
 
   // Construct the default run manager
   //
+#ifdef G4MULTITHREADED
+  G4MTRunManager * runManager = new G4MTRunManager;
+#else
+  G4VSteppingVerbose::SetInstance(new F05SteppingVerbose);
   G4RunManager * runManager = new G4RunManager;
+#endif
+
+  G4Random::setTheSeed(myseed);
 
   // Set mandatory initialization classes
   //
+  // Detector construction
   runManager->SetUserInitialization(new F05DetectorConstruction());
-  //
+  // Physics list
   runManager->SetUserInitialization(new F05PhysicsList());
+  // User action initialization
+  runManager->SetUserInitialization(new F05ActionInitialization());
 
-#ifdef G4VIS_USE
-
-  // visualization manager
-
-  G4VisManager* visManager = new G4VisExecutive();
+  // Initialize visualization
+  //
+  G4VisManager* visManager = new G4VisExecutive;
+  // G4VisExecutive can take a verbosity argument - see /vis/verbose guidance.
+  // G4VisManager* visManager = new G4VisExecutive("Quiet");
   visManager->Initialize();
 
-#endif
-    
-  // Set mandatory user action class
-  //
-  runManager->SetUserAction( new F05PrimaryGeneratorAction() );
-
-  // Set optional user action class
-  //  
-  runManager->SetUserAction(new F05SteppingAction());
-  
-  // Initialize G4 kernel
-  //
-  runManager->Initialize();
-  
   // Get the pointer to the User Interface manager
   //
   G4UImanager* UImanager = G4UImanager::GetUIpointer();
-  
-  if (argc!=1)   // batch mode
-    {
-      G4String command = "/control/execute ";
-      G4String fileName = argv[1];
-      UImanager->ApplyCommand(command+fileName);    
-    }
+
+  if (!ui)   // batch mode
+  {
+     G4String command = "/control/execute ";
+     G4String fileName = argv[1];
+     UImanager->ApplyCommand(command+fileName);
+  }
   else
-    {  // interactive mode : define UI session
-#ifdef G4UI_USE
-      G4UIExecutive* ui = new G4UIExecutive(argc, argv);
-#ifdef G4VIS_USE
-      UImanager->ApplyCommand("/control/execute vis.mac");     
-#endif
-      ui->SessionStart();
-      delete ui;
-#endif
-    }
-  
-#ifdef G4VIS_USE
+  {  // interactive mode : define UI session
+     UImanager->ApplyCommand("/control/execute init_vis.mac");
+     if (ui->IsGUI())
+        UImanager->ApplyCommand("/control/execute gui.mac");
+     ui->SessionStart();
+     delete ui;
+  }
+
+  // Job termination
+  // Free the store: user actions, physics_list and detector_description are
+  //                 owned and deleted by the run manager, so they should not
+  //                 be deleted in the main() program !
+
   delete visManager;
-#endif                
   delete runManager;
 
   return 0;
