@@ -26,7 +26,6 @@
 /// \file medical/GammaTherapy/src/PhysicsList.cc
 /// \brief Implementation of the PhysicsList class
 //
-// $Id: PhysicsList.cc 82277 2014-06-13 14:40:54Z gcosmo $
 //
 //---------------------------------------------------------------------------
 //
@@ -51,6 +50,7 @@
 #include "G4EmStandardPhysics_option1.hh"
 #include "G4EmStandardPhysics_option2.hh"
 #include "G4EmStandardPhysics_option3.hh"
+#include "G4EmStandardPhysics_option4.hh"
 #include "G4EmLivermorePhysics.hh"
 #include "G4EmPenelopePhysics.hh"
 #include "G4EmLowEPPhysics.hh"
@@ -64,7 +64,7 @@
 
 #include "G4UnitsTable.hh"
 #include "G4LossTableManager.hh"
-#include "G4EmProcessOptions.hh"
+#include "G4EmParameters.hh"
 
 #include "G4PhysicalConstants.hh"
 #include "G4SystemOfUnits.hh"
@@ -73,20 +73,21 @@
 
 PhysicsList::PhysicsList(): G4VModularPhysicsList()
 {
-  fEmBuilderIsRegisted = false;
   fHelIsRegisted = false;
   fBicIsRegisted = false;
   fIonIsRegisted = false;
   fGnucIsRegisted = false;
   fStopIsRegisted = false;
   fVerbose = 1;
-  G4LossTableManager::Instance()->SetVerbose(fVerbose);
+
   SetDefaultCutValue(1*mm);
 
   fMessenger = new PhysicsListMessenger(this);
 
   // Add Physics builders
+  RegisterPhysics(new G4EmStandardPhysics());
   RegisterPhysics(new G4DecayPhysics());
+  RegisterPhysics(new StepLimiterBuilder());
 }
 
 //....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......
@@ -113,17 +114,16 @@ void PhysicsList::ConstructProcess()
   if(fVerbose > 0) {
     G4cout << "### PhysicsList Construte Processes" << G4endl;
   }
-  if(!fEmBuilderIsRegisted) { AddPhysicsList("emstandard"); }
-  RegisterPhysics(new StepLimiterBuilder());
+
   G4VModularPhysicsList::ConstructProcess();
 
   // Define energy interval for loss processes
   // from 10 eV to 10 GeV
-  G4EmProcessOptions emOptions;
-  emOptions.SetMinEnergy(0.01*keV);
-  emOptions.SetMaxEnergy(10.*GeV);
-  emOptions.SetDEDXBinning(90);
-  emOptions.SetLambdaBinning(90);
+  G4EmParameters* param = G4EmParameters::Instance();
+  param->SetMinEnergy(0.01*keV);
+  param->SetMaxEnergy(10.*GeV);
+  param->SetNumberOfBinsPerDecade(10);
+  param->SetVerbose(1);
 }
 
 //....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......
@@ -134,57 +134,50 @@ void PhysicsList::AddPhysicsList(const G4String& name)
     G4cout << "### PhysicsList Add Physics <" << name 
            << "> " << G4endl;
   }
-  if ((name == "emstandard") && !fEmBuilderIsRegisted) {
-    RegisterPhysics(new G4EmStandardPhysics());
-    fEmBuilderIsRegisted = true;
+  if (name == "emstandard") {
+    ReplacePhysics(new G4EmStandardPhysics());
 
-  } else if (name == "emstandard_opt1" && !fEmBuilderIsRegisted) {
-    RegisterPhysics(new G4EmStandardPhysics_option1());
-    fEmBuilderIsRegisted = true;
+  } else if (name == "emstandard_opt1") {
+    ReplacePhysics(new G4EmStandardPhysics_option1());
 
-  } else if (name == "emstandard_opt2" && !fEmBuilderIsRegisted) {
-    RegisterPhysics(new G4EmStandardPhysics_option2());
-    fEmBuilderIsRegisted = true;
+  } else if (name == "emstandard_opt2") {
+    ReplacePhysics(new G4EmStandardPhysics_option2());
 
-  } else if (name == "emstandard_opt3" && !fEmBuilderIsRegisted) {
-    RegisterPhysics(new G4EmStandardPhysics_option3());
-    fEmBuilderIsRegisted = true;
+  } else if (name == "emstandard_opt3") {
+    ReplacePhysics(new G4EmStandardPhysics_option3());
 
-  } else if (name == "emlivermore" && !fEmBuilderIsRegisted) {
-    RegisterPhysics(new G4EmLivermorePhysics());
-    fEmBuilderIsRegisted = true;
+  } else if (name == "emstandard_opt4") {
+    ReplacePhysics(new G4EmStandardPhysics_option4());
 
-  } else if (name == "empenelope" && !fEmBuilderIsRegisted) {
-    RegisterPhysics(new G4EmPenelopePhysics());
-    fEmBuilderIsRegisted = true;
+  } else if (name == "emlivermore") {
+    ReplacePhysics(new G4EmLivermorePhysics());
 
-  } else if (name == "emlowenergy" && !fEmBuilderIsRegisted) {
-    RegisterPhysics(new G4EmLowEPPhysics());
-    fEmBuilderIsRegisted = true;
+  } else if (name == "empenelope") {
+    ReplacePhysics(new G4EmPenelopePhysics());
 
-  } else if (name == "elastic" && !fHelIsRegisted && fEmBuilderIsRegisted) {
+  } else if (name == "emlowenergy") {
+    ReplacePhysics(new G4EmLowEPPhysics());
+
+  } else if (name == "elastic" && !fHelIsRegisted) {
     RegisterPhysics(new G4HadronElasticPhysics());
     fHelIsRegisted = true;
     
-  } else if (name == "binary" && !fBicIsRegisted && fEmBuilderIsRegisted) {
+  } else if (name == "binary" && !fBicIsRegisted) {
     RegisterPhysics(new G4HadronInelasticQBBC());
     fBicIsRegisted = true;
     
-  } else if (name == "binary_ion" && !fIonIsRegisted && fEmBuilderIsRegisted) {
+  } else if (name == "binary_ion" && !fIonIsRegisted) {
     RegisterPhysics(new G4IonBinaryCascadePhysics());
     fIonIsRegisted = true;
 
-  } else if (name == "gamma_nuc" && !fGnucIsRegisted && fEmBuilderIsRegisted) {
+  } else if (name == "gamma_nuc" && !fGnucIsRegisted) {
     RegisterPhysics(new G4EmExtraPhysics());
     fGnucIsRegisted = true;
 
-  } else if (name == "stopping" && !fStopIsRegisted && fEmBuilderIsRegisted) {
+  } else if (name == "stopping" && !fStopIsRegisted) {
     RegisterPhysics(new G4StoppingPhysics());
     fStopIsRegisted = true;
     
-  } else if(!fEmBuilderIsRegisted) {
-    G4cout << "PhysicsList::AddPhysicsList <" << name << ">" 
-           << " fail - EM physics should be registered first " << G4endl;
   } else {
     G4cout << "PhysicsList::AddPhysicsList <" << name << ">" 
            << " fail - module is already regitered or is unknown " << G4endl;
