@@ -30,9 +30,8 @@
 // J. Comput. Phys. 274 (2014) 841-882
 // The Geant4-DNA web site is available at http://geant4-dna.org
 //
-// $Id$
 //
-/// \file main.cc
+/// \file chem2.cc
 /// \brief Chem2 example
 
 #include "DetectorConstruction.hh"
@@ -78,13 +77,13 @@ int main(int argc, char** argv)
   //////////
   // Construct the run manager according to whether MT is activated or not
   //
-  Command* commandLine(0);
+  Command* commandLine(nullptr);
 
 #ifdef G4MULTITHREADED
-  G4RunManager* runManager(0);
+  G4RunManager* runManager(nullptr);
   if ((commandLine = parser->GetCommandIfActive("-mt")))
   {
-    runManager = new G4MTRunManager;
+    runManager = new G4MTRunManager();
     int nThreads = 2;
     const G4String& option = commandLine->GetOption();
     if(option == "")
@@ -93,16 +92,15 @@ int main(int argc, char** argv)
     }
     else if(option == "NMAX")
     {
-     nThreads = G4Threading::G4GetNumberOfCores();
+      nThreads = G4Threading::G4GetNumberOfCores();
     }
     else
     {
       nThreads = G4UIcommand::ConvertToInt(option);
     }
 
-    G4cout << "===== Chem2 is started with "
-       << ((G4MTRunManager*) runManager)->GetNumberOfThreads()
-       << " threads =====" << G4endl;
+    G4cout << "===== Chem2 is started with " << nThreads
+           << " threads =====" << G4endl;
 
     ((G4MTRunManager*) runManager)->SetNumberOfThreads(nThreads);
   }
@@ -117,61 +115,60 @@ int main(int argc, char** argv)
   //////////
   // Set mandatory user initialization classes
   //
-  DetectorConstruction* detector = new DetectorConstruction;
+  DetectorConstruction* detector = new DetectorConstruction();
   runManager->SetUserInitialization(new PhysicsList);
   runManager->SetUserInitialization(detector);
   runManager->SetUserInitialization(new ActionInitialization());
 
-  // Initialize G4 kernel
-  runManager->Initialize();
-
   // Initialize visualization
-  G4VisManager* visManager = new G4VisExecutive;
-  // G4VisExecutive can take a verbosity argument - see /vis/verbose guidance.
-  // G4VisManager* visManager = new G4VisExecutive("Quiet");
-  visManager->Initialize();
+  G4VisManager* visManager = nullptr;
 
   // Get the pointer to the User Interface manager
   G4UImanager* UImanager = G4UImanager::GetUIpointer();
-  G4UIExecutive* ui(0);
+  G4UIExecutive* ui(nullptr);
 
   // interactive mode : define UI session
   if ((commandLine = parser->GetCommandIfActive("-gui")))
   {
-    ui = new G4UIExecutive(argc, argv, 
-                           commandLine->GetOption());
+    visManager = new G4VisExecutive;
+    visManager->Initialize();
+
+    ui = new G4UIExecutive(argc, argv, commandLine->GetOption());
 
     if(parser->GetCommandIfActive("-novis") == 0)
-    // visualization is used by default
     {
+      // visualization is used by default
       if((commandLine = parser->GetCommandIfActive("-vis")))
-      // select a visualization driver if needed (e.g. HepFile)
       {
+        // select a visualization driver if needed (e.g. HepFile)
         UImanager->ApplyCommand(G4String("/vis/open ")+
                                 commandLine->GetOption());
       }
       else
-      // by default OGL is used
       {
+        // by default OGL is used
         UImanager->ApplyCommand("/vis/open OGL 800x600-0+0");
       }
       UImanager->ApplyCommand("/control/execute vis.mac");
     }
 
-    if(ui->IsGUI())
-       UImanager->ApplyCommand("/control/execute gui.mac");
-  }
-  else
-  // to be use visualization file (= store the visualization into
-  // an external file:
-  // ASCIITree ;  DAWNFILE ; HepRepFile ; VRML(1,2)FILE ; gMocrenFile ...
-  {
-    if ((commandLine = parser->GetCommandIfActive("-vis")))
+    if(ui->IsGUI()) 
     {
-      UImanager->ApplyCommand(G4String("/vis/open ")+commandLine->GetOption());
-      UImanager->ApplyCommand("/control/execute vis.mac");
+      UImanager->ApplyCommand("/control/execute gui.mac");
     }
   }
+  else if ((commandLine = parser->GetCommandIfActive("-vis")))
+  {
+    // to be use visualization file (= store the visualization into
+    // an external file:
+    // ASCIITree ;  DAWNFILE ; HepRepFile ; VRML(1,2)FILE ; gMocrenFile ...
+    visManager = new G4VisExecutive;
+    visManager->Initialize();
+
+    ui = new G4UIExecutive(argc, argv, commandLine->GetOption());
+    UImanager->ApplyCommand(G4String("/vis/open ")+commandLine->GetOption());
+    UImanager->ApplyCommand("/control/execute vis.mac");
+  }
  
   if ((commandLine = parser->GetCommandIfActive("-mac")))
   {
@@ -183,12 +180,11 @@ int main(int argc, char** argv)
     UImanager->ApplyCommand("/control/execute beam.in");
   }
 
-  if ((commandLine = parser->GetCommandIfActive("-gui")))
+  if(ui)
   {
     ui->SessionStart();
     delete ui;
   }
-
   // Job termination
   // Free the store: user actions, physics_list and detector_description are
   // owned and deleted by the run manager, so they should not be deleted
