@@ -36,8 +36,7 @@
 // November 2016
 // -------------------------------------------------------------------
 //
-// $ID$
-/// \file Runc.cc 
+/// \file Run.cc 
 /// \brief Implementation of the Run class
 
 #include "Run.hh"
@@ -54,7 +53,7 @@
 #include "G4H2O.hh"
 #include <G4Scheduler.hh>
 #include "G4MoleculeTable.hh"
-#include "math.h"
+#include <cmath>
 #include "G4EmCalculator.hh"
 #include <iomanip>
 
