@@ -23,6 +23,13 @@
 // * acceptance of all terms of the Geant4 Software license.          *
 // ********************************************************************
 //
+// This example is provided by the Geant4-DNA collaboration
+// Any report or published results obtained using the Geant4-DNA software 
+// shall cite the following Geant4-DNA collaboration publications:
+// Med. Phys. 37 (2010) 4692-4708
+// Phys. Med. 31 (2015) 861-874
+// The Geant4-DNA web site is available at http://geant4-dna.org
+//
 /// \file medical/dna/svalue/src/DetectorMessenger.cc
 /// \brief Implementation of the DetectorMessenger class
 
@@ -40,9 +47,12 @@ DetectorMessenger::DetectorMessenger(DetectorConstruction * Det)
 :G4UImessenger(),fDetector(Det),
  fTestemDir(0),
  fDetDir(0),    
- fMaterCmd(0),
- fRadiusCmd(0),
- fTrackingCutCmd(0)
+ fMaterWorldCmd(0),
+ fMaterCytoCmd(0),
+ fMaterNuclCmd(0),
+ fNuclRadiusCmd(0),
+ fCytoThicknessCmd(0),
+ fTrackingCutCmd(0) 
 { 
   fTestemDir = new G4UIdirectory("/svalue/");
   fTestemDir->SetGuidance(" detector control.");
@@ -50,20 +60,40 @@ DetectorMessenger::DetectorMessenger(DetectorConstruction * Det)
   fDetDir = new G4UIdirectory("/svalue/det/");
   fDetDir->SetGuidance("detector construction commands");
       
-  fMaterCmd = new G4UIcmdWithAString("/svalue/det/setMat",this);
-  fMaterCmd->SetGuidance("Select material of the box.");
-  fMaterCmd->SetParameterName("choice",false);
-  fMaterCmd->AvailableForStates(G4State_PreInit,G4State_Idle);
-  fMaterCmd->SetToBeBroadcasted(false);  
+  fMaterWorldCmd = new G4UIcmdWithAString("/svalue/det/setWorldMat",this);
+  fMaterWorldCmd->SetGuidance("Select material of the World");
+  fMaterWorldCmd->SetParameterName("choice",false);
+  fMaterWorldCmd->AvailableForStates(G4State_PreInit,G4State_Idle);
+  fMaterWorldCmd->SetToBeBroadcasted(false);  
   
-  fRadiusCmd = new G4UIcmdWithADoubleAndUnit("/svalue/det/setRadius",this);
-  fRadiusCmd->SetGuidance("Set radius of the absorber");
-  fRadiusCmd->SetParameterName("Radius",false);
-  fRadiusCmd->SetRange("Radius>0.");
-  fRadiusCmd->SetUnitCategory("Length");
-  fRadiusCmd->AvailableForStates(G4State_PreInit,G4State_Idle);
-  fRadiusCmd->SetToBeBroadcasted(false);
+  fMaterNuclCmd = new G4UIcmdWithAString("/svalue/det/setNuclMat",this);
+  fMaterNuclCmd->SetGuidance("Select material of the nucleus");
+  fMaterNuclCmd->SetParameterName("choice",false);
+  fMaterNuclCmd->AvailableForStates(G4State_PreInit,G4State_Idle);
+  fMaterNuclCmd->SetToBeBroadcasted(false);  
+  
+  fMaterCytoCmd = new G4UIcmdWithAString("/svalue/det/setCytoMat",this);
+  fMaterCytoCmd->SetGuidance("Select material of the cytoplasm");
+  fMaterCytoCmd->SetParameterName("choice",false);
+  fMaterCytoCmd->AvailableForStates(G4State_PreInit,G4State_Idle);
+  fMaterCytoCmd->SetToBeBroadcasted(false);  
+  
+  fNuclRadiusCmd = new G4UIcmdWithADoubleAndUnit("/svalue/det/setNuclRadius",this);
+  fNuclRadiusCmd->SetGuidance("Set radius of the nucleus");
+  fNuclRadiusCmd->SetParameterName("Radius",false);
+  fNuclRadiusCmd->SetRange("Radius>0.");
+  fNuclRadiusCmd->SetUnitCategory("Length");
+  fNuclRadiusCmd->AvailableForStates(G4State_PreInit,G4State_Idle);
+  fNuclRadiusCmd->SetToBeBroadcasted(false);
       
+  fCytoThicknessCmd = new G4UIcmdWithADoubleAndUnit("/svalue/det/setCytoThickness",this);
+  fCytoThicknessCmd->SetGuidance("Set thickness of the cytoplasm");
+  fCytoThicknessCmd->SetParameterName("Thickness",false);
+  fCytoThicknessCmd->SetRange("Thickness>0.");
+  fCytoThicknessCmd->SetUnitCategory("Length");
+  fCytoThicknessCmd->AvailableForStates(G4State_PreInit,G4State_Idle);
+  fCytoThicknessCmd->SetToBeBroadcasted(false);
+ 
   fTrackingCutCmd = 
     new G4UIcmdWithADoubleAndUnit("/svalue/det/setTrackingCut",this);
   fTrackingCutCmd->SetGuidance("Set tracking cut in the absorber");
@@ -78,8 +108,11 @@ DetectorMessenger::DetectorMessenger(DetectorConstruction * Det)
 
 DetectorMessenger::~DetectorMessenger()
 {
-  delete fMaterCmd;
-  delete fRadiusCmd;
+  delete fMaterWorldCmd;
+  delete fMaterCytoCmd;
+  delete fMaterNuclCmd;
+  delete fNuclRadiusCmd;
+  delete fCytoThicknessCmd;
   delete fTrackingCutCmd;
   delete fDetDir;  
   delete fTestemDir;
@@ -89,11 +122,20 @@ DetectorMessenger::~DetectorMessenger()
 
 void DetectorMessenger::SetNewValue(G4UIcommand* command,G4String newValue)
 { 
-  if( command == fMaterCmd )
-   { fDetector->SetMaterial(newValue);}
+  if( command == fMaterWorldCmd )
+   { fDetector->SetWorldMaterial(newValue);}
    
-  if( command == fRadiusCmd )
-   { fDetector->SetRadius(fRadiusCmd->GetNewDoubleValue(newValue));}
+  if( command == fMaterCytoCmd )
+   { fDetector->SetCytoMaterial(newValue);}
+   
+  if( command == fMaterNuclCmd )
+   { fDetector->SetNuclMaterial(newValue);}
+   
+  if( command == fNuclRadiusCmd )
+   { fDetector->SetNuclRadius(fNuclRadiusCmd->GetNewDoubleValue(newValue));}
+   
+  if( command == fCytoThicknessCmd )
+   { fDetector->SetCytoThickness(fCytoThicknessCmd->GetNewDoubleValue(newValue));}
    
   if( command == fTrackingCutCmd )
    { fDetector->SetTrackingCut(fTrackingCutCmd->GetNewDoubleValue(newValue));}
