@@ -26,7 +26,6 @@
 /// \file medical/fanoCavity/src/PhysListEmStandard_option3.cc
 /// \brief Implementation of the PhysListEmStandard_option3 class
 //
-// $Id: PhysListEmStandard_option3.cc 103180 2017-03-21 10:33:40Z gcosmo $
 //
 //....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......
 //....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......
@@ -41,6 +40,7 @@
 #include "MyKleinNishinaCompton.hh"
 #include "G4GammaConversion.hh"
 #include "G4PhotoElectricEffect.hh"
+#include "G4RayleighScattering.hh"
 
 #include "G4eMultipleScattering.hh"
 
@@ -73,13 +73,15 @@ PhysListEmStandard_option3::PhysListEmStandard_option3(const G4String& name,
   G4EmParameters* param = G4EmParameters::Instance();
   param->SetDefaults();
   param->SetVerbose(1);
-  param->SetMinEnergy(100*eV);
+  param->SetMinEnergy(10*eV);
   param->SetMaxEnergy(10*GeV);
   param->SetNumberOfBinsPerDecade(20);
-  param->SetLowestElectronEnergy(10*eV);
+  param->SetLowestElectronEnergy(100*eV);
+  param->SetStepFunction(0.2, 100*um);
   param->SetBuildCSDARange(true);
   param->SetMaxEnergyForCSDARange(10*GeV);
   param->SetMscStepLimitType(fUseDistanceToBoundary);
+  param->SetLateralDisplacementAlg96(true);
   SetPhysicsType(bElectromagnetic);
 }
 
@@ -121,10 +123,9 @@ void PhysListEmStandard_option3::ConstructProcess()
             
       G4eIonisation* eIoni = new G4eIonisation();
       eIoni->SetEmModel(new MyMollerBhabhaModel);
-      eIoni->SetStepFunction(0.2, 100*um, false);
                          
-      pmanager->AddProcess(msc,                       -1, 1, 1);
-      pmanager->AddProcess(eIoni,                     -1, 2, 2);
+      pmanager->AddProcess(msc,                       -1, 1,-1);
+      pmanager->AddProcess(eIoni,                     -1, 2, 1);
             
     } else if (particleName == "e+") {
       //positron
@@ -133,13 +134,13 @@ void PhysListEmStandard_option3::ConstructProcess()
       G4eIonisation* pIoni = new G4eIonisation();
       pIoni->SetEmModel(new MyMollerBhabhaModel);
                                
-      pmanager->AddProcess(msc,                       -1, 1, 1);
-      pmanager->AddProcess(pIoni,                     -1, 2, 2);
-      pmanager->AddProcess(new G4eplusAnnihilation,    0,-1, 3);
+      pmanager->AddProcess(msc,                       -1, 1,-1);
+      pmanager->AddProcess(pIoni,                     -1, 2, 1);
+      pmanager->AddProcess(new G4eplusAnnihilation,    0,-1, 2);
              
     } else if( particleName == "proton" ) {
       //proton  
-      pmanager->AddProcess(new G4hMultipleScattering, -1, 1, 1);
+      pmanager->AddProcess(new G4hMultipleScattering, -1, 1,-1);
       pmanager->AddProcess(new G4hIonisation,         -1, 2, 2);
     }
   }
