@@ -26,10 +26,10 @@
 /// \file medical/fanoCavity2/fanoCavity2.cc
 /// \brief Main program of the medical/fanoCavity2 example
 //
-// $Id: fanoCavity2.cc 103507 2017-04-11 14:15:33Z gcosmo $
 //
 //....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......
 //....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......
+#include "G4Types.hh"
 
 #ifdef G4MULTITHREADED
 #include "G4MTRunManager.hh"
@@ -51,89 +51,66 @@
 #include "SteppingAction.hh"
 #include "SteppingVerbose.hh"
 
-#ifdef G4VIS_USE
- #include "G4VisExecutive.hh"
-#endif
-
-#ifdef G4UI_USE
- #include "G4UIExecutive.hh"
-#endif
+#include "G4UIExecutive.hh"
+#include "G4VisExecutive.hh"
 
 //....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......
- 
+
 int main(int argc,char** argv) {
- 
+
+  //detect interactive mode (if no arguments) and define UI session
+  G4UIExecutive* ui = nullptr;
+  if (argc == 1) ui = new G4UIExecutive(argc,argv);
+
   //choose the Random engine
   CLHEP::HepRandom::setTheEngine(new CLHEP::RanecuEngine);
- 
 
 #ifdef G4MULTITHREADED
   G4MTRunManager* runManager = new G4MTRunManager;
   G4int nThreads = std::min(G4Threading::G4GetNumberOfCores(),2);
   if (argc==3) nThreads = G4UIcommand::ConvertToInt(argv[2]);
   runManager->SetNumberOfThreads(nThreads);
-  G4cout << "===== fanoCavity2 is started with " 
+  G4cout << "===== fanoCavity2 is started with "
          <<  runManager->GetNumberOfThreads() << " threads =====" << G4endl;
 #else
     G4VSteppingVerbose::SetInstance(new SteppingVerbose);
     G4RunManager* runManager = new G4RunManager;
 #endif
 
-
-  //my Verbose output class
-  //G4VSteppingVerbose::SetInstance(new SteppingVerbose);
-
-  //Construct the default run manager
-  //G4RunManager * runManager = new G4RunManager;
-
   //set mandatory initialization classes
   DetectorConstruction* det;
   PhysicsList* phys;
 
-
   runManager->SetUserInitialization(det  = new DetectorConstruction);
   runManager->SetUserInitialization(phys = new PhysicsList());
 
-  // set user action classes
+  //set user action classes
   runManager->SetUserInitialization(new ActionInitialization(det));
 
+  //initialize visualization
+  G4VisManager* visManager = nullptr;
 
   //get the pointer to the User Interface manager
   G4UImanager* UImanager = G4UImanager::GetUIpointer();
 
-#ifdef G4VIS_USE
-      G4VisManager* visManager = new G4VisExecutive;
-      visManager->Initialize();
-#endif
-
-  if (argc!=1)   // batch mode
-    {
-     G4String command = "/control/execute ";
-     G4String fileName = argv[1];
-     UImanager->ApplyCommand(command+fileName);
-    }
- 
-  else           // interactive mode :define visualization and UI terminal
-    {
-#ifdef G4UI_USE
-     G4UIExecutive* ui = new G4UIExecutive(argc, argv);
-#ifdef G4VIS_USE
-     UImanager->ApplyCommand("/control/execute vis.mac");
-#endif
-     ui->SessionStart();
-     delete ui;
-#endif
-
-#ifdef G4VIS_USE
-     delete visManager;
-#endif
-    }
+  if (ui)  {
+   //interactive mode
+   visManager = new G4VisExecutive;
+   visManager->Initialize();
+   UImanager->ApplyCommand("/control/execute vis.mac");
+   ui->SessionStart();
+   delete ui;
+  }
+  else  {
+  //batch mode
+   G4String command = "/control/execute ";
+   G4String fileName = argv[1];
+   UImanager->ApplyCommand(command+fileName);
+  }
 
   //job termination
-  //
+  delete visManager;
   delete runManager;
-
-  return 0;
 }
 
 //....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......
