@@ -26,7 +26,6 @@
 /// \file medical/fanoCavity2/src/PhysListEmStandard_GS.cc
 /// \brief Implementation of the PhysListEmStandard_GS class
 //
-// $Id$
 //
 //....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......
 //....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......
@@ -67,11 +66,9 @@ PhysListEmStandard_GS::PhysListEmStandard_GS(const G4String& name)
   param->SetVerbose(1);
   param->SetMinEnergy(100*eV);
   param->SetMaxEnergy(10*GeV);
-  param->SetNumberOfBinsPerDecade(20);
-  param->SetLowestElectronEnergy(1*eV);
   param->SetBuildCSDARange(true);
   param->SetMaxEnergyForCSDARange(10*GeV);
-  param->SetMscStepLimitType(fUseDistanceToBoundary);
+  param->SetMscRangeFactor(0.06);
   SetPhysicsType(bElectromagnetic);
 }
 
@@ -105,14 +102,13 @@ void PhysListEmStandard_GS::ConstructProcess()
       //electron
 
       G4eMultipleScattering* eMsc = new G4eMultipleScattering();
-      eMsc->AddEmModel(1, new G4GoudsmitSaundersonMscModel);
+      eMsc->SetEmModel(new G4GoudsmitSaundersonMscModel);
             
       G4eIonisation* eIoni = new G4eIonisation();
       eIoni->SetEmModel(new MyMollerBhabhaModel);
-      eIoni->SetStepFunction(0.2, 10*um);
                          
-      pmanager->AddProcess(eMsc,                      -1, 1, 1);
-      pmanager->AddProcess(eIoni,                     -1, 2, 2);
+      pmanager->AddProcess(eMsc,                      -1, 1,-1);
+      pmanager->AddProcess(eIoni,                     -1, 2, 1);
             
     } else if (particleName == "e+") {
       //positron
@@ -123,14 +119,14 @@ void PhysListEmStandard_GS::ConstructProcess()
       G4eIonisation* pIoni = new G4eIonisation();
       pIoni->SetEmModel(new MyMollerBhabhaModel);
                                
-      pmanager->AddProcess(pMsc,                      -1, 1, 1);
-      pmanager->AddProcess(pIoni,                     -1, 2, 2);
-      pmanager->AddProcess(new G4eplusAnnihilation,    0,-1, 3);
+      pmanager->AddProcess(pMsc,                      -1, 1,-1);
+      pmanager->AddProcess(pIoni,                     -1, 2, 1);
+      pmanager->AddProcess(new G4eplusAnnihilation,    0,-1, 2);
              
     } else if( particleName == "proton" ) {
       //proton  
-      pmanager->AddProcess(new G4hMultipleScattering, -1, 1, 1);
-      pmanager->AddProcess(new G4hIonisation,         -1, 2, 2);
+      pmanager->AddProcess(new G4hMultipleScattering, -1, 1,-1);
+      pmanager->AddProcess(new G4hIonisation,         -1, 2, 1);
     }
   }
 }
