@@ -26,7 +26,6 @@
 /// \file medical/fanoCavity2/src/PhysListEmStandard_SS.cc
 /// \brief Implementation of the PhysListEmStandard_SS class
 //
-// $Id$
 //
 //....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......
 //....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......
@@ -64,10 +63,9 @@ PhysListEmStandard_SS::PhysListEmStandard_SS(const G4String& name)
   G4EmParameters* param = G4EmParameters::Instance();
   param->SetDefaults();
   param->SetVerbose(1);
-  param->SetMinEnergy(100*eV);
+  param->SetMinEnergy(10*eV);
   param->SetMaxEnergy(10*GeV);
-  param->SetNumberOfBinsPerDecade(20);
-  param->SetLowestElectronEnergy(1*eV);
+  param->SetLowestElectronEnergy(10*eV);
   param->SetBuildCSDARange(true);
   param->SetMaxEnergyForCSDARange(10*GeV);
   param->SetMscThetaLimit(0.0);
@@ -105,7 +103,6 @@ void PhysListEmStandard_SS::ConstructProcess()
       
       G4eIonisation* eIoni = new G4eIonisation();
       eIoni->SetEmModel(new MyMollerBhabhaModel);
-      eIoni->SetStepFunction(0.2, 10*um);
                          
       G4CoulombScattering* cs = new G4CoulombScattering();
       G4eCoulombScatteringModel* csmod = new G4eCoulombScatteringModel();
