@@ -26,7 +26,6 @@
 /// \file medical/fanoCavity2/src/PhysListEmStandard_option0.cc
 /// \brief Implementation of the PhysListEmStandard_option0 class
 //
-// $Id: PhysListEmStandard_option0.cc 91599 2015-07-27 13:31:32Z gcosmo $
 //
 //....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......
 //....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......
@@ -67,7 +66,7 @@ PhysListEmStandard_option0::PhysListEmStandard_option0(const G4String& name)
   param->SetVerbose(1);
   param->SetMinEnergy(100*eV);
   param->SetMaxEnergy(10*GeV);
-  param->SetLowestElectronEnergy(10*eV);
+  param->SetLowestElectronEnergy(1*keV);
   param->SetBuildCSDARange(true);
   param->SetMaxEnergyForCSDARange(10*GeV);
   SetPhysicsType(bElectromagnetic);
@@ -85,9 +84,10 @@ void PhysListEmStandard_option0::ConstructProcess()
   // Add standard EM Processes
   //
 
-  aParticleIterator->reset();
-  while( (*aParticleIterator)() ){
-    G4ParticleDefinition* particle = aParticleIterator->value();
+  auto particleIterator=GetParticleIterator();
+  particleIterator->reset();
+  while( (*particleIterator)() ){
+    G4ParticleDefinition* particle = particleIterator->value();
     G4ProcessManager* pmanager = particle->GetProcessManager();
     G4String particleName = particle->GetParticleName();
      
@@ -104,8 +104,8 @@ void PhysListEmStandard_option0::ConstructProcess()
       G4eIonisation* eIoni = new G4eIonisation();
       eIoni->SetEmModel(new MyMollerBhabhaModel);
                          
-      pmanager->AddProcess(new G4eMultipleScattering, -1, 1, 1);
-      pmanager->AddProcess(eIoni,                     -1, 2, 2);
+      pmanager->AddProcess(new G4eMultipleScattering, -1, 1,-1);
+      pmanager->AddProcess(eIoni,                     -1, 2, 1);
             
     } else if (particleName == "e+") {
       //positron
@@ -113,14 +113,14 @@ void PhysListEmStandard_option0::ConstructProcess()
       G4eIonisation* pIoni = new G4eIonisation();
       pIoni->SetEmModel(new MyMollerBhabhaModel);
                                
-      pmanager->AddProcess(new G4eMultipleScattering, -1, 1, 1);
-      pmanager->AddProcess(pIoni,                     -1, 2, 2);
-      pmanager->AddProcess(new G4eplusAnnihilation,    0,-1, 3);
+      pmanager->AddProcess(new G4eMultipleScattering, -1, 1,-1);
+      pmanager->AddProcess(pIoni,                     -1, 2, 1);
+      pmanager->AddProcess(new G4eplusAnnihilation,    0,-1, 2);
              
     } else if( particleName == "proton" ) {
       //proton  
-      pmanager->AddProcess(new G4hMultipleScattering, -1, 1, 1);
-      pmanager->AddProcess(new G4hIonisation,         -1, 2, 2);
+      pmanager->AddProcess(new G4hMultipleScattering, -1, 1,-1);
+      pmanager->AddProcess(new G4hIonisation,         -1, 2, 1);
     }
   }
 }
