@@ -26,7 +26,6 @@
 /// \file persistency/P02/src/ExP02GeoTree.cc
 /// \brief Implementation of the ExP02GeoTree class
 //
-// $Id$
 // Include files
 
 // local
@@ -41,16 +40,16 @@
 
 //....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......
 
-ExP02GeoTree::ExP02GeoTree(  ): fTopV(0)
+ExP02GeoTree::ExP02GeoTree(  )
+ : fTopV(0), fEltab(0)
 {
   fEltab = G4Element::GetElementTable();
-  fMattab = G4Material::GetMaterialTable();
 }
 
 //....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......
 
-ExP02GeoTree::ExP02GeoTree(G4VPhysicalVolume* vol, const G4ElementTable* et, const G4MaterialTable* mt): 
-  fTopV(vol), fEltab(et), fMattab(mt)
+ExP02GeoTree::ExP02GeoTree(G4VPhysicalVolume* vol, const G4ElementTable* et)
+  : fTopV(vol), fEltab(et)
 {}
 
 //....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......
