@@ -89,7 +89,7 @@ void ExTGRCRegionCutsMgr::AddRegionCuts( const std::vector<G4String>& rc )
   }
 
   // Find region
-  std::vector<ExTGRCRegionData*>::const_iterator iter;
+  // std::vector<ExTGRCRegionData*>::const_iterator iter;
   std::vector<ExTGRCRegionData*> regs = FindRegionData(rc[0]);
 
   if( regs.size() == 0 )
@@ -125,7 +125,7 @@ void ExTGRCRegionCutsMgr::BuildRegions()
 {
   std::vector<ExTGRCRegionData*>::const_iterator iter;
   std::vector<G4String>::const_iterator ites;
-  std::vector<G4LogicalVolume*>::const_iterator itelv;
+  // std::vector<G4LogicalVolume*>::const_iterator itelv;
   for( iter = fRegionDatae.begin(); iter != fRegionDatae.end(); iter++ )
   {
     G4Region* reg = new G4Region( (*iter)->GetRegionName() );
