@@ -68,9 +68,9 @@ const ExTGTrackerHit& ExTGTrackerHit::operator=(const ExTGTrackerHit& right)
 }
 
 //....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......
-G4int ExTGTrackerHit::operator==(const ExTGTrackerHit& right) const
+G4bool ExTGTrackerHit::operator==(const ExTGTrackerHit& right) const
 {
-  return (this==&right) ? 1 : 0;
+  return (this==&right) ? true : false;
 }
 
 //....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......
