@@ -94,6 +94,11 @@ void G4CsvNtupleManager::FinishTNtuple(
   G4TNtupleDescription<tools::wcsv::ntuple>* ntupleDescription,
   G4bool /*fromBooking*/)
 {
+
+  // Do nothing if the base file name was not yet defined
+  if ( ! fFileManager->GetFileName().size() ) return;
+
+  // Create ntuple from booking
   if ( ! ntupleDescription->fNtuple ) {
     CreateTNtupleFromBooking(ntupleDescription);
   }
