@@ -27,10 +27,16 @@
 //
 // G4VSensitiveDetector
 #include "G4VSDFilter.hh"
+#include "G4SDManager.hh"
 
 G4VSDFilter::G4VSDFilter(G4String name)
 :filterName(name)
-{;}
+{
+  G4SDManager::GetSDMpointer()->RegisterSDFilter(this);
+}
 
 G4VSDFilter::~G4VSDFilter()
-{;}
+{
+  G4SDManager::GetSDMpointer()->DeRegisterSDFilter(this);
+}
+
