@@ -33,7 +33,8 @@
 // 29-Mar-2013 T.Aso Support weighted options in the nOfTrack command.
 //                   Support a boundary flag option in the nOfStep command
 //                  for skipping stepLength=0 steps.
-// 
+// 13-Feb-2020 T.Aso Change SetDefaultUnit() in trackLength scorer to
+//                   SetDefaultValue() to support various unit category.
 // ---------------------------------------------------------------------
 
 #include "G4ScoreQuantityMessenger.hh"
@@ -76,6 +77,7 @@
 #include "G4UIcmdWithADoubleAndUnit.hh"
 #include "G4UIcmdWith3VectorAndUnit.hh"
 #include "G4UIcommand.hh"
+#include "G4UIparameter.hh"
 #include "G4Tokenizer.hh"
 #include "G4UnitsTable.hh"
 
@@ -103,31 +105,31 @@ void G4ScoreQuantityMessenger::QuantityCommands()
   qeDepCmd = new G4UIcommand("/score/quantity/energyDeposit",this);
   qeDepCmd->SetGuidance("Energy deposit scorer.");
   qeDepCmd->
-  SetGuidance("[usage] /score/quantiy/energyDeposit qname unit");
+  SetGuidance("[usage] /score/quantity/energyDeposit qname unit");
   qeDepCmd->SetGuidance("  qname  :(String) scorer name");
   qeDepCmd->SetGuidance("  unit   :(String) unit");
   param = new G4UIparameter("qname",'s',false);
   qeDepCmd->SetParameter(param);
   param = new G4UIparameter("unit",'s',true);
-  param->SetDefaultValue("MeV");
+  param->SetDefaultUnit("MeV");
   qeDepCmd->SetParameter(param);
   //
   qCellChgCmd  = new G4UIcommand("/score/quantity/cellCharge",this);
   qCellChgCmd->SetGuidance("Cell charge scorer.");
   qCellChgCmd->
-  SetGuidance("[usage] /score/quantiy/cellCharge qname unit");
+  SetGuidance("[usage] /score/quantity/cellCharge qname unit");
   qCellChgCmd->SetGuidance("  qname  :(String) scorer name");
   qCellChgCmd->SetGuidance("  unit   :(String) unit");
   param = new G4UIparameter("qname",'s',false);
   qCellChgCmd->SetParameter(param);
   param = new G4UIparameter("unit",'s',true);
-  param->SetDefaultValue("e+");
+  param->SetDefaultUnit("e+");
   qCellChgCmd->SetParameter(param);
   //
   qCellFluxCmd = new G4UIcommand("/score/quantity/cellFlux",this);
   qCellFluxCmd->SetGuidance("Cell flux scorer.");
   qCellFluxCmd->
-  SetGuidance("[usage] /score/quantiy/cellFlux qname unit");
+  SetGuidance("[usage] /score/quantity/cellFlux qname unit");
   qCellFluxCmd->SetGuidance("  qname  :(String) scorer name");
   qCellFluxCmd->SetGuidance("  unit   :(String) unit");
   param = new G4UIparameter("qname",'s',false);
@@ -139,7 +141,7 @@ void G4ScoreQuantityMessenger::QuantityCommands()
   qPassCellFluxCmd = new G4UIcommand("/score/quantity/passageCellFlux",this);
   qPassCellFluxCmd->SetGuidance("Passage cell flux scorer");
   qPassCellFluxCmd->
-  SetGuidance("[usage] /score/quantiy/passageCellFlux qname unit");
+  SetGuidance("[usage] /score/quantity/passageCellFlux qname unit");
   qPassCellFluxCmd->SetGuidance("  qname  :(String) scorer name");
   qPassCellFluxCmd->SetGuidance("  unit   :(String) unit");
   param = new G4UIparameter("qname",'s',false);
@@ -151,21 +153,21 @@ void G4ScoreQuantityMessenger::QuantityCommands()
   qdoseDepCmd = new G4UIcommand("/score/quantity/doseDeposit",this);
   qdoseDepCmd->SetGuidance("Dose deposit scorer.");
   qdoseDepCmd->
-  SetGuidance("[usage] /score/quantiy/doseDeposit qname unit");
+  SetGuidance("[usage] /score/quantity/doseDeposit qname unit");
   qdoseDepCmd->SetGuidance("  qname  :(String) scorer name");
   qdoseDepCmd->SetGuidance("  unit   :(String) unit");
   param = new G4UIparameter("qname",'s',false);
   qdoseDepCmd->SetParameter(param);
   param = new G4UIparameter("unit",'s',true);
-  param->SetDefaultValue("Gy");
+  param->SetDefaultUnit("Gy");
   qdoseDepCmd->SetParameter(param);
   //
   qnOfStepCmd = new G4UIcommand("/score/quantity/nOfStep",this);
   qnOfStepCmd->SetGuidance("Number of step scorer.");
   qnOfStepCmd->
-  SetGuidance("[usage] /score/quantiy/nOfStep qname");
+  SetGuidance("[usage] /score/quantity/nOfStep qname");
   qnOfStepCmd->
-  SetGuidance("[usage] /score/quantiy/nOfStep qname  bflag"); 
+  SetGuidance("[usage] /score/quantity/nOfStep qname  bflag"); 
   qnOfStepCmd->SetGuidance("  qname  :(String) scorer name");
   qnOfStepCmd->SetGuidance("  bflag  :(Bool) Skip zero step ");
   qnOfStepCmd->SetGuidance("          at geometry boundary if true");
@@ -178,7 +180,7 @@ void G4ScoreQuantityMessenger::QuantityCommands()
   qnOfSecondaryCmd = new G4UIcommand("/score/quantity/nOfSecondary",this);
   qnOfSecondaryCmd->SetGuidance("Number of secondary scorer.");
   qnOfSecondaryCmd->
-  SetGuidance("[usage] /score/quantiy/nOfSecondary qname"); 
+  SetGuidance("[usage] /score/quantity/nOfSecondary qname"); 
   qnOfSecondaryCmd->SetGuidance("  qname  :(String) scorer name");
   param = new G4UIparameter("qname",'s',false);
   qnOfSecondaryCmd->SetParameter(param);
@@ -186,7 +188,7 @@ void G4ScoreQuantityMessenger::QuantityCommands()
   qTrackLengthCmd = new G4UIcommand("/score/quantity/trackLength",this);
   qTrackLengthCmd->SetGuidance("Track length scorer.");
   qTrackLengthCmd->
-  SetGuidance("[usage] /score/quantiy/trackLength qname wflag kflag vflag unit");
+  SetGuidance("[usage] /score/quantity/trackLength qname wflag kflag vflag unit");
   qTrackLengthCmd->SetGuidance("  qname  :(String) scorer name");
   qTrackLengthCmd->SetGuidance("  wflag  :(Bool) weighted");
   qTrackLengthCmd->SetGuidance("  kflag  :(Bool) multiply kinetic energy");
@@ -210,7 +212,7 @@ void G4ScoreQuantityMessenger::QuantityCommands()
   qPassCellCurrCmd = new G4UIcommand("/score/quantity/passageCellCurrent",this);
   qPassCellCurrCmd->SetGuidance("Passage cell current scorer.");
   qPassCellCurrCmd->
-  SetGuidance("[usage] /score/quantiy/passageCellCurrent qname wflag");
+  SetGuidance("[usage] /score/quantity/passageCellCurrent qname wflag");
   qPassCellCurrCmd->SetGuidance("  qname  :(String) scorer name");
   qPassCellCurrCmd->SetGuidance("  wflag  :(Bool) weighted");
   param = new G4UIparameter("qname",'s',false);
@@ -222,7 +224,7 @@ void G4ScoreQuantityMessenger::QuantityCommands()
   qPassTrackLengthCmd = new G4UIcommand("/score/quantity/passageTrackLength",this);
   qPassTrackLengthCmd->SetGuidance("Passage track length scorer.");
   qPassTrackLengthCmd->
-  SetGuidance("[usage] /score/quantiy/passageTrackLength qname wflag unit");
+  SetGuidance("[usage] /score/quantity/passageTrackLength qname wflag unit");
   qPassTrackLengthCmd->SetGuidance("  qname  :(String) scorer name");
   qPassTrackLengthCmd->SetGuidance("  wflag  :(Bool) weighted");
   qPassTrackLengthCmd->SetGuidance("  unit   :(Bool) unit");
@@ -232,13 +234,13 @@ void G4ScoreQuantityMessenger::QuantityCommands()
   param->SetDefaultValue("true");
   qPassTrackLengthCmd->SetParameter(param);
   param = new G4UIparameter("unit",'s',true);
-  param->SetDefaultValue("mm");
+  param->SetDefaultUnit("mm");
   qPassTrackLengthCmd->SetParameter(param);
   //
   qFlatSurfCurrCmd = new G4UIcommand("/score/quantity/flatSurfaceCurrent",this);
   qFlatSurfCurrCmd->SetGuidance("Flat surface current Scorer.");
   qFlatSurfCurrCmd->
-  SetGuidance("[usage] /score/quantiy/flatSurfaceCurrent qname dflag wflag aflag unit");
+  SetGuidance("[usage] /score/quantity/flatSurfaceCurrent qname dflag wflag aflag unit");
   qFlatSurfCurrCmd->SetGuidance("  qname  :(String) scorer name");
   qFlatSurfCurrCmd->SetGuidance("  dflag  :(Int) direction flag");
   qFlatSurfCurrCmd->SetGuidance("         : 0 = Both In and Out");
@@ -246,7 +248,7 @@ void G4ScoreQuantityMessenger::QuantityCommands()
   qFlatSurfCurrCmd->SetGuidance("         : 2 = Out only");
   qFlatSurfCurrCmd->SetGuidance("  wflag  :(Bool) weighted");
   qFlatSurfCurrCmd->SetGuidance("  aflag  :(Bool) divide by area");
-  qFlatSurfCurrCmd->SetGuidance("  unit   :(Bool) unit");
+  qFlatSurfCurrCmd->SetGuidance("  unit   :(String) unit");
   param = new G4UIparameter("qname",'s',false);
   qFlatSurfCurrCmd->SetParameter(param);
   param = new G4UIparameter("dflag",'i',true);
@@ -265,7 +267,7 @@ void G4ScoreQuantityMessenger::QuantityCommands()
   qFlatSurfFluxCmd = new G4UIcommand("/score/quantity/flatSurfaceFlux",this);
   qFlatSurfFluxCmd->SetGuidance("Flat surface flux scorer.");
   qFlatSurfFluxCmd->
-  SetGuidance("[usage] /score/quantiy/flatSurfaceFlux qname dflag unit");
+  SetGuidance("[usage] /score/quantity/flatSurfaceFlux qname dflag unit");
   qFlatSurfFluxCmd->SetGuidance("  qname  :(String) scorer name");
   qFlatSurfFluxCmd->SetGuidance("  dflag  :(Int) direction flag");
   qFlatSurfFluxCmd->SetGuidance("         : 0 = Both In and Out");
@@ -292,7 +294,7 @@ void G4ScoreQuantityMessenger::QuantityCommands()
 //  qSphereSurfCurrCmd = new G4UIcommand("/score/quantity/sphereSurfaceCurrent",this);
 //  qSphereSurfCurrCmd->SetGuidance("Sphere surface current Scorer.");
 //  qSphereSurfCurrCmd->
-//      SetGuidance("[usage] /score/quantiy/sphereSurfaceCurrent qname dflag wflag aflag unit");
+//      SetGuidance("[usage] /score/quantity/sphereSurfaceCurrent qname dflag wflag aflag unit");
 //  qSphereSurfCurrCmd->SetGuidance("  qname  :(String) scorer name");
 //  qSphereSurfCurrCmd->SetGuidance("  dflag  :(Int) direction flag");
 //  qSphereSurfCurrCmd->SetGuidance("         : 0 = Both In and Out");
@@ -320,7 +322,7 @@ void G4ScoreQuantityMessenger::QuantityCommands()
 //  qSphereSurfFluxCmd = new G4UIcommand("/score/quantity/sphereSurfaceFlux",this);
 //  qSphereSurfFluxCmd->SetGuidance("Sphere surface Flux Scorer.");
 //  qSphereSurfFluxCmd->
-//  SetGuidance("[usage] /score/quantiy/sphereSurfaceFlux qname dflag unit");
+//  SetGuidance("[usage] /score/quantity/sphereSurfaceFlux qname dflag unit");
 //  qSphereSurfFluxCmd->SetGuidance("  qname  :(String) scorer name");
 //  qSphereSurfFluxCmd->SetGuidance("  dflag  :(Int) direction flag");
 //  qSphereSurfFluxCmd->SetGuidance("         : 0 = Both In and Out");
@@ -348,7 +350,7 @@ void G4ScoreQuantityMessenger::QuantityCommands()
 //  qCylSurfCurrCmd = new G4UIcommand("/score/quantity/cylinderSurfaceCurrent",this);
 //  qCylSurfCurrCmd->SetGuidance("Cylinder surface current Scorer.");
 //  qCylSurfCurrCmd->
-//  SetGuidance("[usage] /score/quantiy/cylinderSurfaceCurrent qname dflag wflag aflag unit");
+//  SetGuidance("[usage] /score/quantity/cylinderSurfaceCurrent qname dflag wflag aflag unit");
 //  qCylSurfCurrCmd->SetGuidance("  qname  :(String) scorer name");
 //  qCylSurfCurrCmd->SetGuidance("  dflag  :(Int) direction flag");
 //  qCylSurfCurrCmd->SetGuidance("         : 0 = Both In and Out");
@@ -375,7 +377,7 @@ void G4ScoreQuantityMessenger::QuantityCommands()
 //  qCylSurfFluxCmd = new G4UIcommand("/score/quantity/cylinderSurfaceFlux",this);
 //  qCylSurfFluxCmd->SetGuidance("Cylinder surface Flux Scorer.");
 //  qCylSurfFluxCmd->
-//  SetGuidance("[usage] /score/quantiy/cylinderSurfaceFlux qname dflag unit");
+//  SetGuidance("[usage] /score/quantity/cylinderSurfaceFlux qname dflag unit");
 //  qCylSurfFluxCmd->SetGuidance("  qname  :(String) scorer name");
 //  qCylSurfFluxCmd->SetGuidance("  dflag  :(Int) direction flag");
 //  qCylSurfFluxCmd->SetGuidance("         : 0 = Both In and Out");
@@ -403,7 +405,7 @@ void G4ScoreQuantityMessenger::QuantityCommands()
   qNofCollisionCmd = new G4UIcommand("/score/quantity/nOfCollision",this);
   qNofCollisionCmd->SetGuidance("Number of collision scorer.");
   qNofCollisionCmd->
-  SetGuidance("[usage] /score/quantiy/nOfCollision qname wflag");
+  SetGuidance("[usage] /score/quantity/nOfCollision qname wflag");
   qNofCollisionCmd->SetGuidance("  qname  :(String) scorer name");
   param = new G4UIparameter("qname",'s',false);
   qNofCollisionCmd->SetParameter(param);
@@ -414,7 +416,7 @@ void G4ScoreQuantityMessenger::QuantityCommands()
   qPopulationCmd = new G4UIcommand("/score/quantity/population",this);
   qPopulationCmd->SetGuidance("Population scorer.");
   qPopulationCmd->
-   SetGuidance("[usage] /score/quantiy/population qname wflag");
+   SetGuidance("[usage] /score/quantity/population qname wflag");
   qPopulationCmd->SetGuidance("  qname  :(String) scorer name");
   qPopulationCmd->SetGuidance("  wflag  :(Bool) weighted");
   param = new G4UIparameter("qname",'s',false);
@@ -427,7 +429,7 @@ void G4ScoreQuantityMessenger::QuantityCommands()
   qTrackCountCmd = new G4UIcommand("/score/quantity/nOfTrack",this);
   qTrackCountCmd->SetGuidance("Number of track scorer.");
   qTrackCountCmd->
-  SetGuidance("[usage] /score/quantiy/nOfTrack qname dflag wflag");
+  SetGuidance("[usage] /score/quantity/nOfTrack qname dflag wflag");
   qTrackCountCmd->SetGuidance("  qname  :(String) scorer name");
   qTrackCountCmd->SetGuidance("  dflag  :(Int) direction");
   qTrackCountCmd->SetGuidance("         : 0 = Both In and Out");
@@ -447,7 +449,7 @@ void G4ScoreQuantityMessenger::QuantityCommands()
   qTerminationCmd = new G4UIcommand("/score/quantity/nOfTerminatedTrack",this);
   qTerminationCmd->SetGuidance("Number of terminated tracks scorer.");
   qTerminationCmd->
-      SetGuidance("[usage] /score/quantiy/nOfTerminatedTrack qname wflag");
+      SetGuidance("[usage] /score/quantity/nOfTerminatedTrack qname wflag");
   qTerminationCmd->SetGuidance("  qname  :(String) scorer name");
   qTerminationCmd->SetGuidance("  wflag  :(Bool) weighted");
   param = new G4UIparameter("qname",'s',false);
@@ -460,19 +462,19 @@ void G4ScoreQuantityMessenger::QuantityCommands()
   qMinKinEAtGeneCmd = new G4UIcommand("/score/quantity/minKinEAtGeneration",this);
   qMinKinEAtGeneCmd->SetGuidance("Min Kinetic Energy at Generation");
   qMinKinEAtGeneCmd->
-  SetGuidance("[usage] /score/quantiy/minKinEAtGeneration qname unit");
+  SetGuidance("[usage] /score/quantity/minKinEAtGeneration qname unit");
   qMinKinEAtGeneCmd->SetGuidance("  qname  :(String) scorer name");
   qMinKinEAtGeneCmd->SetGuidance("  unit   :(String) unit name");
   param = new G4UIparameter("qname",'s',false);
   qMinKinEAtGeneCmd->SetParameter(param);
   param = new G4UIparameter("unit",'s',true);
-  param->SetDefaultValue("MeV");
+  param->SetDefaultUnit("MeV");
   qMinKinEAtGeneCmd->SetParameter(param);
   //
   qStepCheckerCmd = new G4UIcommand("/score/quantity/stepChecker",this);
   qStepCheckerCmd->SetGuidance("Display a comment when this PS is invoked");
   qStepCheckerCmd->
-  SetGuidance("[usage] /score/quantiy/stepChecker qname");
+  SetGuidance("[usage] /score/quantity/stepChecker qname");
   qStepCheckerCmd->SetGuidance("  qname  :(String) scorer name");
   param = new G4UIparameter("qname",'s',false);
   qStepCheckerCmd->SetParameter(param);
