@@ -32,6 +32,7 @@
 #include "G4VScoringMesh.hh"
 #include "G4ScoringBox.hh"
 #include "G4ScoringCylinder.hh"
+#include "G4ScoringRealWorld.hh"
 
 #include "G4UIdirectory.hh"
 #include "G4UIcmdWithoutParameter.hh"
@@ -41,6 +42,7 @@
 #include "G4UIcmdWithADoubleAndUnit.hh"
 #include "G4UIcmdWith3VectorAndUnit.hh"
 #include "G4UIcommand.hh"
+#include "G4UIparameter.hh"
 #include "G4Tokenizer.hh"
 #include "G4UnitsTable.hh"
 #include "G4VScoreColorMap.hh"
@@ -48,7 +50,7 @@
 G4ScoringMessenger::G4ScoringMessenger(G4ScoringManager* SManager)
 :fSMan(SManager)
 {
-  G4UIparameter* param;
+  G4UIparameter* param = nullptr;
 
   scoreDir = new G4UIdirectory("/score/");
   scoreDir->SetGuidance("Interactive scoring commands.");
@@ -82,6 +84,19 @@ G4ScoringMessenger::G4ScoringMessenger(G4ScoringManager* SManager)
 //  meshSphereCreateCmd = new G4UIcmdWithAString("/score/create/sphereMesh",this);
 //  meshSphereCreateCmd->SetGuidance("Create scoring mesh.");
 //  meshSphereCreateCmd->SetParameterName("MeshName",false);
+  //
+  meshRWLogVolCreateCmd = new G4UIcommand("/score/create/realWorldLogVol",this);
+  meshRWLogVolCreateCmd->SetGuidance("Define scorers to a logical volume defined in the real world.");
+  meshRWLogVolCreateCmd->SetGuidance("  - Name of the specified logical volume is used as the mesh name.");
+  meshRWLogVolCreateCmd->SetGuidance("  - /score/mesh commands do not affect for this mesh.");
+  meshRWLogVolCreateCmd->SetGuidance("  - If copyNumberLevel is set, the copy number of that-level higher");
+  meshRWLogVolCreateCmd->SetGuidance("    in the geometrical hierarchy is used as the index.");
+  param = new G4UIparameter("logVol",'s',false);
+  meshRWLogVolCreateCmd->SetParameter(param);
+  param = new G4UIparameter("copyNumberLevel",'i',true);
+  param->SetParameterRange("copyNumberLevel>=0");
+  param->SetDefaultValue(0);
+  meshRWLogVolCreateCmd->SetParameter(param);
   //
   meshOpnCmd = new G4UIcmdWithAString("/score/open",this);
   meshOpnCmd->SetGuidance("Open scoring mesh.");
@@ -111,7 +126,7 @@ G4ScoringMessenger::G4ScoringMessenger(G4ScoringManager* SManager)
   param->SetParameterRange("Dz>0");
   mCylinderSizeCmd->SetParameter(param);
   param = new G4UIparameter("unit",'s',true);
-  param->SetDefaultValue("mm");
+  param->SetDefaultUnit("mm");
   mCylinderSizeCmd->SetParameter(param);
   //
   //   Division command
@@ -159,8 +174,8 @@ G4ScoringMessenger::G4ScoringMessenger(G4ScoringManager* SManager)
   mRotDir = new G4UIdirectory("/score/mesh/rotate/");
   mRotDir->SetGuidance("Mesh rotation commands.");
   //
-  mRResetCmd = new G4UIcmdWithoutParameter("/score/mesh/rotate/reset",this);
-  mRResetCmd->SetGuidance("Reset rotation angles of the scoring mesh.");
+  //mRResetCmd = new G4UIcmdWithoutParameter("/score/mesh/rotate/reset",this);
+  //mRResetCmd->SetGuidance("Reset rotation angles of the scoring mesh.");
   //
   mRotXCmd = new G4UIcmdWithADoubleAndUnit("/score/mesh/rotate/rotateX",this);
   mRotXCmd->SetGuidance("Rotate the scoring mesh in X axis.");
@@ -223,7 +238,7 @@ G4ScoringMessenger::G4ScoringMessenger(G4ScoringManager* SManager)
   listColorMapCmd->SetToBeBroadcasted(false);
 
   floatMinMaxCmd = new G4UIcmdWithAString("/score/colorMap/floatMinMax",this);
-  floatMinMaxCmd->SetGuidance("Min/Max of the color map is calculated accorging to the actual scores.");
+  floatMinMaxCmd->SetGuidance("Min/Max of the color map is calculated according to the actual scores.");
   floatMinMaxCmd->SetParameterName("colorMapName",true,false);
   floatMinMaxCmd->SetDefaultValue("defaultLinearColorMap");
   floatMinMaxCmd->SetToBeBroadcasted(false);
@@ -272,6 +287,22 @@ G4ScoringMessenger::G4ScoringMessenger(G4ScoringManager* SManager)
   dumpQtyToFileCmd->SetParameter(param);
   dumpQtyToFileCmd->SetToBeBroadcasted(false);
 
+  dumpQtyWithFactorCmd = new G4UIcommand("/score/dumpQuantityWithFactor", this);
+  dumpQtyWithFactorCmd->SetGuidance("Dump one scored quantity to file.");
+  dumpQtyWithFactorCmd->SetGuidance("Each value is multiplied by the specified factor.");
+  param = new G4UIparameter("meshName", 's', false);
+  dumpQtyWithFactorCmd->SetParameter(param);
+  param = new G4UIparameter("psName", 's', false);
+  dumpQtyWithFactorCmd->SetParameter(param);
+  param = new G4UIparameter("fileName", 's', false);
+  dumpQtyWithFactorCmd->SetParameter(param);
+  param = new G4UIparameter("factor", 'd', false);
+  param->SetParameterRange("factor>0.");
+  dumpQtyWithFactorCmd->SetParameter(param);
+  param = new G4UIparameter("option", 's', true);
+  dumpQtyWithFactorCmd->SetParameter(param);
+  dumpQtyWithFactorCmd->SetToBeBroadcasted(false);
+
   // Dump all scored quantities
   dumpAllQtsToFileCmd = new G4UIcommand("/score/dumpAllQuantitiesToFile", this);
   dumpAllQtsToFileCmd->SetGuidance("Dump all quantities of the mesh to file.");
@@ -283,6 +314,20 @@ G4ScoringMessenger::G4ScoringMessenger(G4ScoringManager* SManager)
   dumpAllQtsToFileCmd->SetParameter(param);
   dumpAllQtsToFileCmd->SetToBeBroadcasted(false);
 
+  dumpAllQtsWithFactorCmd = new G4UIcommand("/score/dumpAllQuantitiesWithFactor", this);
+  dumpAllQtsWithFactorCmd->SetGuidance("Dump all quantities of the mesh to file.");
+  dumpAllQtsWithFactorCmd->SetGuidance("Each value is multiplied by the specified factor.");
+  param = new G4UIparameter("meshName", 's', false);
+  dumpAllQtsWithFactorCmd->SetParameter(param);
+  param = new G4UIparameter("fileName", 's', false);
+  dumpAllQtsWithFactorCmd->SetParameter(param);
+  param = new G4UIparameter("factor", 'd', false);
+  param->SetParameterRange("factor>0.");
+  dumpAllQtsWithFactorCmd->SetParameter(param);
+  param = new G4UIparameter("option", 's', true);
+  dumpAllQtsWithFactorCmd->SetParameter(param);
+  dumpAllQtsWithFactorCmd->SetToBeBroadcasted(false);
+
 }
 
 G4ScoringMessenger::~G4ScoringMessenger()
@@ -293,6 +338,7 @@ G4ScoringMessenger::~G4ScoringMessenger()
     delete           meshCreateDir;
     delete           meshBoxCreateCmd;
     delete           meshCylinderCreateCmd;
+    delete           meshRWLogVolCreateCmd;
 //    delete           meshSphereCreateCmd;
     //
     delete          meshOpnCmd;
@@ -310,7 +356,7 @@ G4ScoringMessenger::~G4ScoringMessenger()
     delete   mTResetCmd;
     delete   mTXyzCmd;
     delete   mTransDir;
-    delete   mRResetCmd;
+//    delete   mRResetCmd;
     delete   mRotXCmd;
     delete   mRotYCmd;
     delete   mRotZCmd;
@@ -324,14 +370,18 @@ G4ScoringMessenger::~G4ScoringMessenger()
     delete     floatMinMaxCmd;
     delete     colorMapMinMaxCmd;
     delete     colorMapDir;
-    delete     dumpQtyToFileCmd;
+    delete     dumpQtyWithFactorCmd;
+    delete dumpQtyWithFactorCmd;
     delete     dumpAllQtsToFileCmd;
+    delete dumpAllQtsWithFactorCmd;
     //
     delete scoreDir;
 }
 
 void G4ScoringMessenger::SetNewValue(G4UIcommand * command,G4String newVal)
 {
+  using MeshShape = G4VScoringMesh::MeshShape;
+
   if(command==listCmd) { 
       fSMan->List(); 
   } else if(command==dumpCmd) { 
@@ -365,13 +415,64 @@ void G4ScoringMessenger::SetNewValue(G4UIcommand * command,G4String newVal)
       G4String psName = next();
       G4String fileName = next();
       G4String option = next("\n");
+      auto mesh = fSMan->FindMesh(meshName);
+      if(!mesh)
+      {
+        G4ExceptionDescription ed;
+        ed << "Mesh name <" << meshName << "> is not found. Command ignored.";
+        command->CommandFailed(ed);
+        return;
+      }
       fSMan->DumpQuantityToFile(meshName, psName, fileName, option);
+  } else if(command==dumpQtyWithFactorCmd) {
+      G4Tokenizer next(newVal);
+      G4String meshName = next();
+      G4String psName = next();
+      G4String fileName = next();
+      G4double fac = StoD(next());
+      G4String option = next("\n");
+      auto mesh = fSMan->FindMesh(meshName);
+      if(!mesh)
+      {
+        G4ExceptionDescription ed;
+        ed << "Mesh name <" << meshName << "> is not found. Command ignored.";
+        command->CommandFailed(ed);
+        return;
+      }
+      fSMan->SetFactor(fac);
+      fSMan->DumpQuantityToFile(meshName, psName, fileName, option);
+      fSMan->SetFactor(1.0);
   } else if(command==dumpAllQtsToFileCmd) { 
       G4Tokenizer next(newVal);
       G4String meshName = next();
       G4String fileName = next();
       G4String option = next("\n");
+      auto mesh = fSMan->FindMesh(meshName);
+      if(!mesh)
+      {
+        G4ExceptionDescription ed;
+        ed << "Mesh name <" << meshName << "> is not found. Command ignored.";
+        command->CommandFailed(ed);
+        return;
+      }
       fSMan->DumpAllQuantitiesToFile(meshName, fileName, option);
+  } else if(command==dumpAllQtsWithFactorCmd) {
+      G4Tokenizer next(newVal);
+      G4String meshName = next();
+      G4String fileName = next();
+      G4double fac = StoD(next());
+      G4String option = next("\n");
+      auto mesh = fSMan->FindMesh(meshName);
+      if(!mesh)
+      {
+        G4ExceptionDescription ed;
+        ed << "Mesh name <" << meshName << "> is not found. Command ignored.";
+        command->CommandFailed(ed);
+        return;
+      }
+      fSMan->SetFactor(fac);
+      fSMan->DumpAllQuantitiesToFile(meshName, fileName, option);
+      fSMan->SetFactor(1.0);
   } else if(command==verboseCmd) { 
       fSMan->SetVerboseLevel(verboseCmd->GetNewIntValue(newVal)); 
   } else if(command==meshBoxCreateCmd) {
@@ -418,6 +519,33 @@ void G4ScoringMessenger::SetNewValue(G4UIcommand * command,G4String newVal)
           command->CommandFailed(ed);
 	}
       }
+  } else if(command==meshRWLogVolCreateCmd) {
+      auto mesh = fSMan->GetCurrentMesh();
+      if ( mesh ){
+        G4ExceptionDescription ed;
+        ed << "ERROR[" << meshRWLogVolCreateCmd->GetCommandPath()
+           << "] : Mesh <" << mesh->GetWorldName()
+               << "> is still open. Close it first. Command ignored.";
+        command->CommandFailed(ed);
+      }
+      else
+      {
+        G4Tokenizer next(newVal);
+        G4String meshName = next();
+        G4int idx = StoI(next());
+        mesh = fSMan->FindMesh(meshName);
+        if ( !mesh ){
+          mesh = new G4ScoringRealWorld(meshName);
+          mesh->SetCopyNumberLevel(idx);
+          fSMan->RegisterScoringMesh(mesh);
+        }else{
+          G4ExceptionDescription ed;
+          ed << "ERROR[" << meshRWLogVolCreateCmd->GetCommandPath()
+             << "] : Scoring mesh <" << meshName << "> already exists. Command ignored.";
+          command->CommandFailed(ed);
+        }
+      }
+
   } else if(command==listColorMapCmd) {
       fSMan->ListScoreColorMaps();
   } else if(command==floatMinMaxCmd) {
@@ -477,6 +605,14 @@ void G4ScoringMessenger::SetNewValue(G4UIcommand * command,G4String newVal)
       //
       // Commands for Current Mesh
       if ( mesh ){
+        MeshShape shape = mesh->GetShape();
+        if ( shape == MeshShape::realWorldLogVol ) {
+          G4ExceptionDescription ed;
+	  ed << "ERROR[" << mBinCmd->GetCommandPath()
+             << "] : Number of mesh command cannot be set for this type of mesh. Command ignored.";
+          command->CommandFailed(ed);
+        } else {
+
           // Tokens
           G4TokenVec token;
           FillTokenVec(newVal,token);
@@ -487,8 +623,7 @@ void G4ScoringMessenger::SetNewValue(G4UIcommand * command,G4String newVal)
 //	      mesh->Activate(meshActCmd->GetNewBoolValue(newVal)); 
 //	  } else
           if(command==mBoxSizeCmd) {
-	      MeshShape shape = mesh->GetShape();
-	      if ( shape == boxMesh ){
+	      if ( shape == MeshShape::box){
 		  G4ThreeVector size = mBoxSizeCmd->GetNew3VectorValue(newVal);
 		  G4double vsize[3];
 		  vsize[0] = size.x();
@@ -502,8 +637,7 @@ void G4ScoringMessenger::SetNewValue(G4UIcommand * command,G4String newVal)
                  command->CommandFailed(ed);
 	      }
 	  }else if(command==mCylinderSizeCmd) {
-	      MeshShape shape = mesh->GetShape();
-	      if ( shape == cylinderMesh ){
+	      if ( shape == MeshShape::cylinder ){
 		  G4double vsize[3];
 		  vsize[0]     = StoD(token[0]);
 		  vsize[1]     = StoD(token[1]);
@@ -519,7 +653,7 @@ void G4ScoringMessenger::SetNewValue(G4UIcommand * command,G4String newVal)
                  command->CommandFailed(ed);
 	      }
 	  } else if(command==mBinCmd) {
-	      MeshBinCommand(mesh,token);
+              MeshBinCommand(mesh,token);
 	  } else if(command==mTResetCmd) {
 	      G4double centerPosition[3] ={ 0., 0., 0.};
 	      mesh->SetCenterPosition(centerPosition);
@@ -530,7 +664,7 @@ void G4ScoringMessenger::SetNewValue(G4UIcommand * command,G4String newVal)
 	      centerPosition[1] = xyz.y();
 	      centerPosition[2] = xyz.z();
 	      mesh->SetCenterPosition(centerPosition);
-	  } else if(command==mRResetCmd) {
+//	  } else if(command==mRResetCmd) {
 	  } else if(command==mRotXCmd) {
 	      G4double value = mRotXCmd->GetNewDoubleValue(newVal);
 	      mesh->RotateX(value);
@@ -541,11 +675,12 @@ void G4ScoringMessenger::SetNewValue(G4UIcommand * command,G4String newVal)
 	      G4double value = mRotZCmd->GetNewDoubleValue(newVal);
 	      mesh->RotateZ(value);
 	  }
-      }else{
-        G4ExceptionDescription ed;
-        ed << "ERROR: No mesh is currently open. Open/create a mesh first. Command ignored.";
-        command->CommandFailed(ed);
       }
+    }else{
+      G4ExceptionDescription ed;
+      ed << "ERROR: No mesh is currently open. Open/create a mesh first. Command ignored.";
+      command->CommandFailed(ed);
+    }
   }
 }
 
