@@ -1,5 +1,4 @@
 // -*- C++ -*-
-// $Id:$
 // -----------------------------------------------------------------------
 //                             HEP Random
 //                          --- DoubConv ---
@@ -31,10 +30,6 @@ void DoubConv::fill_byte_order () {
     z *= 256;
   }
   // x, in IEEE format, would now be 0x4330060504030201
-  union DB8 {
-    unsigned char b[8];
-    double d;
-  };
   DB8 xb;
   xb.d = x;
   int n;
