@@ -23,24 +23,19 @@
 // * acceptance of all terms of the Geant4 Software license.          *
 // ********************************************************************
 //
+// G4GeometryCellStep implementation
 //
-//
-// ----------------------------------------------------------------------
-// GEANT 4 class source file
-//
-// G4GeometryCellStep.cc
-//
+// Author: Michael Dressel (CERN), 2002
 // ----------------------------------------------------------------------
 
 #include "G4GeometryCellStep.hh"
 
-G4GeometryCellStep::G4GeometryCellStep(const G4GeometryCell &preCell, 
-		 const G4GeometryCell &postCell)
-  : 
-  fPreGeometryCell(preCell), 
-  fPostGeometryCell(postCell), 
-  fCrossBoundary(false) 
-{}
+G4GeometryCellStep::G4GeometryCellStep(const G4GeometryCell& preCell, 
+                                       const G4GeometryCell& postCell)
+  : fPreGeometryCell(preCell), fPostGeometryCell(postCell)
+{
+}
 
 G4GeometryCellStep::~G4GeometryCellStep()
-{}
+{
+}
