@@ -23,9 +23,7 @@
 // * acceptance of all terms of the Geant4 Software license.          *
 // ********************************************************************
 //
-//
-//
-// class G4ParameterisationPolycone Implementation file
+// G4ParameterisationPolycone[Rho/Phi/Z] implementation
 //
 // 26.05.03 - P.Arce, Initial version
 // 08.04.04 - I.Hrivnacova, Implemented reflection
@@ -58,20 +56,23 @@ G4VParameterisationPolycone( EAxis axis, G4int nDiv, G4double width,
   G4Polycone* msol = (G4Polycone*)(msolid);
   if (msolid->GetEntityType() == "G4ReflectedSolid")
   {
-    // Get constituent solid  
+    // Get constituent solid
+    //
     G4VSolid* mConstituentSolid 
        = ((G4ReflectedSolid*)msolid)->GetConstituentMovedSolid();
     msol = (G4Polycone*)(mConstituentSolid);
   
     // Get parameters
+    //
     G4int   nofZplanes = msol->GetOriginalParameters()->Num_z_planes;
     G4double* zValues  = msol->GetOriginalParameters()->Z_values;
     G4double* rminValues  = msol->GetOriginalParameters()->Rmin;
     G4double* rmaxValues  = msol->GetOriginalParameters()->Rmax;
 
     // Invert z values
-    G4double* zValuesRefl = new double[nofZplanes];
-    for (G4int i=0; i<nofZplanes; i++) zValuesRefl[i] = - zValues[i];
+    //
+    G4double* zValuesRefl = new G4double[nofZplanes];
+    for (G4int i=0; i<nofZplanes; ++i)  { zValuesRefl[i] = - zValues[i]; }
     
     G4Polycone* newSolid
       = new G4Polycone(msol->GetName(),
@@ -219,7 +220,7 @@ ComputeDimensions( G4Polycone& pcone, const G4int copyNo,
   G4int nZplanes = origparamMother->Num_z_planes;
 
   G4double width = 0.;
-  for( G4int ii = 0; ii < nZplanes; ii++ )
+  for( G4int ii = 0; ii < nZplanes; ++ii )
   {
     width = CalculateWidth( origparamMother->Rmax[ii]
                           - origparamMother->Rmin[ii], fnDiv, foffset );
@@ -288,7 +289,7 @@ G4double G4ParameterisationPolyconePhi::GetMaxParameter() const
 //---------------------------------------------------------------------
 void
 G4ParameterisationPolyconePhi::
-ComputeTransformation( const G4int copyNo, G4VPhysicalVolume *physVol ) const
+ComputeTransformation( const G4int copyNo, G4VPhysicalVolume* physVol ) const
 {
   //----- translation 
   G4ThreeVector origin(0.,0.,0.); 
@@ -352,7 +353,6 @@ G4ParameterisationPolyconeZ( EAxis axis, G4int nDiv,
                              G4double width, G4double offset,
                              G4VSolid* msolid, DivisionType divType)
   : G4VParameterisationPolycone( axis, nDiv, width, offset, msolid, divType ),
-    fNSegment(0),
     fOrigParamMother(((G4Polycone*)fmotherSolid)->GetOriginalParameters())
 {
 
@@ -429,7 +429,7 @@ G4double G4ParameterisationPolyconeZ::GetRmax(G4double z, G4int nseg) const
 G4double G4ParameterisationPolyconeZ::GetMaxParameter() const
 {
   return std::abs (fOrigParamMother->Z_values[fOrigParamMother->Num_z_planes-1]
-             -fOrigParamMother->Z_values[0]);
+                  -fOrigParamMother->Z_values[0]);
 }
 
 //---------------------------------------------------------------------
@@ -438,8 +438,11 @@ void G4ParameterisationPolyconeZ::CheckParametersValidity()
   G4VDivisionParameterisation::CheckParametersValidity();
   
   // Division will be following the mother polycone segments
-  if( fDivisionType == DivNDIV ) {
-    if( fnDiv > fOrigParamMother->Num_z_planes-1 ) { 
+  //
+  if( fDivisionType == DivNDIV )
+  {
+    if( fnDiv > fOrigParamMother->Num_z_planes-1 )
+    { 
       std::ostringstream error;
       error  << "Configuration not supported." << G4endl
              << "Division along Z will be done by splitting in the defined"
@@ -454,52 +457,64 @@ void G4ParameterisationPolyconeZ::CheckParametersValidity()
      
   // Division will be done within one polycone segment
   // with applying given width and offset
-  if( fDivisionType == DivNDIVandWIDTH || fDivisionType == DivWIDTH ) {
+  //
+  if( fDivisionType == DivNDIVandWIDTH || fDivisionType == DivWIDTH )
+  {
     // Check if divided region does not span over more
     // than one z segment
   
     G4int isegstart = -1;  // number of the segment containing start position
     G4int isegend = -1;    // number of the segment containing end position
 
-    if ( ! fReflectedSolid ) {
+    if ( !fReflectedSolid )
+    {
       // The start/end position of the divided region
+      //
       G4double zstart 
         = fOrigParamMother->Z_values[0] + foffset;
       G4double zend 
         = fOrigParamMother->Z_values[0] + foffset + fnDiv* fwidth;
    
       G4int counter = 0;
-      while ( isegend < 0 && counter < fOrigParamMother->Num_z_planes-1 ) {
+      while ( isegend < 0 && counter < fOrigParamMother->Num_z_planes-1 )
+      {
         // first segment
         if ( zstart >= fOrigParamMother->Z_values[counter]  &&
-             zstart  < fOrigParamMother->Z_values[counter+1] ) {
+             zstart  < fOrigParamMother->Z_values[counter+1] )
+        {
            isegstart = counter;
         }     
         // last segment
         if ( zend  > fOrigParamMother->Z_values[counter] &&
-             zend <= fOrigParamMother->Z_values[counter+1] ) {
+             zend <= fOrigParamMother->Z_values[counter+1] )
+        {
           isegend = counter;
         }   
         ++counter;   
       }  // Loop checking, 06.08.2015, G.Cosmo
     }
-    else  {
+    else
+    {
       // The start/end position of the divided region
+      //
       G4double zstart 
         = fOrigParamMother->Z_values[0] - foffset;
       G4double zend 
         = fOrigParamMother->Z_values[0] - ( foffset + fnDiv* fwidth);
    
       G4int counter = 0;
-      while ( isegend < 0 && counter < fOrigParamMother->Num_z_planes-1 ) {
+      while ( isegend < 0 && counter < fOrigParamMother->Num_z_planes-1 )
+      {
         // first segment
         if ( zstart <= fOrigParamMother->Z_values[counter]  &&
-             zstart  > fOrigParamMother->Z_values[counter+1] ) {
+             zstart  > fOrigParamMother->Z_values[counter+1] )
+        {
            isegstart = counter;
         }     
         // last segment
         if ( zend  < fOrigParamMother->Z_values[counter] &&
-             zend >= fOrigParamMother->Z_values[counter+1] ) {
+             zend >= fOrigParamMother->Z_values[counter+1] )
+        {
            isegend = counter;
         }   
         ++counter;   
@@ -507,7 +522,8 @@ void G4ParameterisationPolyconeZ::CheckParametersValidity()
     }
       
   
-    if ( isegstart != isegend ) {
+    if ( isegstart != isegend )
+    {
       std::ostringstream message;
       message << "Condiguration not supported." << G4endl
               << "Division with user defined width." << G4endl
@@ -526,19 +542,22 @@ void
 G4ParameterisationPolyconeZ::
 ComputeTransformation( const G4int copyNo, G4VPhysicalVolume* physVol) const
 {
-  if ( fDivisionType == DivNDIV ) {
+  if ( fDivisionType == DivNDIV )
+  {
     // The position of the centre of copyNo-th mother polycone segment
-    G4double posi 
-      = ( fOrigParamMother->Z_values[copyNo]
-        + fOrigParamMother->Z_values[copyNo+1])/2;
+    //
+    G4double posi = ( fOrigParamMother->Z_values[copyNo]
+                    + fOrigParamMother->Z_values[copyNo+1])/2;
     physVol->SetTranslation( G4ThreeVector(0, 0, posi) );
   }
   
-  if ( fDivisionType == DivNDIVandWIDTH || fDivisionType == DivWIDTH ) {
+  if ( fDivisionType == DivNDIVandWIDTH || fDivisionType == DivWIDTH )
+  {
     // The position of the centre of copyNo-th division
+    //
     G4double posi = fOrigParamMother->Z_values[0];
       
-    if ( ! fReflectedSolid )  
+    if ( !fReflectedSolid )  
       posi += foffset + (2*copyNo + 1) * fwidth/2.;
     else
       posi -= foffset + (2*copyNo + 1) * fwidth/2.;
@@ -578,6 +597,7 @@ ComputeDimensions( G4Polycone& pcone, const G4int copyNo,
 {
 
   // Define division solid
+  //
   G4PolyconeHistorical origparam;
   G4int nz = 2; 
   origparam.Num_z_planes = nz;
@@ -585,11 +605,13 @@ ComputeDimensions( G4Polycone& pcone, const G4int copyNo,
   origparam.Opening_angle = fOrigParamMother->Opening_angle;
 
   // Define division solid z sections
+  //
   origparam.Z_values = new G4double[nz];
   origparam.Rmin = new G4double[nz];
   origparam.Rmax = new G4double[nz];
 
-  if ( fDivisionType == DivNDIV ) {
+  if ( fDivisionType == DivNDIV )
+  {
     // The position of the centre of copyNo-th mother polycone segment
     G4double posi = (fOrigParamMother->Z_values[copyNo]
                    + fOrigParamMother->Z_values[copyNo+1])/2;
@@ -602,16 +624,20 @@ ComputeDimensions( G4Polycone& pcone, const G4int copyNo,
     origparam.Rmax[1] = fOrigParamMother->Rmax[copyNo+1];
   }
   
-  if ( fDivisionType == DivNDIVandWIDTH || fDivisionType == DivWIDTH ) {
-    if ( ! fReflectedSolid ) {
+  if ( fDivisionType == DivNDIVandWIDTH || fDivisionType == DivWIDTH )
+  {
+    if ( !fReflectedSolid )
+    {
       origparam.Z_values[0] = - fwidth/2.;
       origparam.Z_values[1] = fwidth/2.;
 
       // The position of the centre of copyNo-th division
-      G4double posi 
-        = fOrigParamMother->Z_values[0] + foffset + (2*copyNo + 1) * fwidth/2.;
+      //
+      G4double posi = fOrigParamMother->Z_values[0]
+                    + foffset + (2*copyNo + 1) * fwidth/2.;
     
       // The first and last z sides z values
+      //
       G4double zstart = posi - fwidth/2.;
       G4double zend = posi + fwidth/2.;
       origparam.Rmin[0] = GetRmin(zstart, fNSegment); 
@@ -619,15 +645,18 @@ ComputeDimensions( G4Polycone& pcone, const G4int copyNo,
       origparam.Rmin[1] = GetRmin(zend, fNSegment); 
       origparam.Rmax[1] = GetRmax(zend, fNSegment);  
     }
-    else {
+    else
+    {
       origparam.Z_values[0] = fwidth/2.;
       origparam.Z_values[1] = - fwidth/2.;
 
       // The position of the centre of copyNo-th division
-      G4double posi 
-        = fOrigParamMother->Z_values[0] - ( foffset + (2*copyNo + 1) * fwidth/2.);
+      //
+      G4double posi = fOrigParamMother->Z_values[0]
+                    - ( foffset + (2*copyNo + 1) * fwidth/2.);
     
       // The first and last z sides z values
+      //
       G4double zstart = posi + fwidth/2.;
       G4double zend = posi - fwidth/2.;
       origparam.Rmin[0] = GetRmin(zstart, fNSegment); 
@@ -637,6 +666,7 @@ ComputeDimensions( G4Polycone& pcone, const G4int copyNo,
     }
 
     // It can happen due to rounding errors
+    //
     if ( origparam.Rmin[0]    < 0.0 ) origparam.Rmin[0] = 0.0;
     if ( origparam.Rmin[nz-1] < 0.0 ) origparam.Rmin[1] = 0.0;
   }  
