@@ -23,7 +23,9 @@
 // * acceptance of all terms of the Geant4 Software license.          *
 // ********************************************************************
 //
+// G4DELPHIMagField implementation
 //
+// Created: V.Grichine - 03.02.1997
 // -------------------------------------------------------------------
 
 #include "G4DELPHIMagField.hh"
@@ -34,10 +36,6 @@ G4DELPHIMagField::G4DELPHIMagField()
 {
 }
 
-G4Field* G4DELPHIMagField::Clone() const
-{
-   return new G4DELPHIMagField;
-}
 ////////////////////////////////////////////////////////////////////////
 
 G4DELPHIMagField::~G4DELPHIMagField()
@@ -46,6 +44,12 @@ G4DELPHIMagField::~G4DELPHIMagField()
 
 ///////////////////////////////////////////////////////////////////////
 
+G4Field* G4DELPHIMagField::Clone() const
+{
+   return new G4DELPHIMagField;
+}
+
+///////////////////////////////////////////////////////////////////////
 
 void G4DELPHIMagField::GetFieldValue( const G4double yTrack[7],
                                             G4double B[3]     ) const 
@@ -59,7 +63,8 @@ void G4DELPHIMagField::GetFieldValue( const G4double yTrack[7],
    G4double rz = z*std::sqrt(r2), r = std::sqrt(r2+a*a) ;
    G4double Br ;
    G4double P[8], Q[8] ; 
-   static G4ThreadLocal G4double c[8] = {
+   static G4ThreadLocal G4double c[8] =
+                          {
                             -9.26e-5, -3.51e-5, 2.94e-6, -1.10e-6, 
                              6.25e-8, -1.77e-8, -6.88e-10, -7.52e-11 
                           } ;
@@ -85,7 +90,7 @@ void G4DELPHIMagField::GetFieldValue( const G4double yTrack[7],
    
    Br = 0 ;
    B[2] = 1.2*tesla  ;    //  the principal Bz value of DELPHI detector
-   for(i=0;i<n;i++)
+   for(i=0; i<n; ++i)
    {
       Br += c[i]*P[i] ;
       B[2] += c[i]*Q[i] ;
