@@ -23,55 +23,67 @@
 // * acceptance of all terms of the Geant4 Software license.          *
 // ********************************************************************
 //
-//
-//
+// G4HelixExplicitEuler implementation
 //
 //  Helix Explicit Euler: x_1 = x_0 + helix(h)
-//  with helix(h) being a helix piece of length h
-//  most simple approach for solving linear differential equations.
+//  with helix(h) being a helix piece of length h.
+//  Most simple approach for solving linear differential equations.
 //  Take the current derivative and add it to the current position.
 //
-//  W.Wander <wwc@mit.edu> 12/09/97 
+// Author: W.Wander <wwc@mit.edu>, 12.09.1997
 // -------------------------------------------------------------------
 
 #include "G4HelixExplicitEuler.hh"
 #include "G4PhysicalConstants.hh"
 #include "G4ThreeVector.hh"
 
-
-void G4HelixExplicitEuler::Stepper(  const G4double  yInput[7],
-                               const G4double*,
-                                     G4double Step,
-                                     G4double yOut[7],
-                                     G4double yErr[])
-
+G4HelixExplicitEuler::G4HelixExplicitEuler(G4Mag_EqRhs* EqRhs)
+  : G4MagHelicalStepper(EqRhs)
 {
+}
+ 
+G4HelixExplicitEuler::~G4HelixExplicitEuler()
+{
+}
 
- //Estimation of the Stepping Angle
-
+void G4HelixExplicitEuler::Stepper( const G4double  yInput[7],
+                                    const G4double*,
+                                          G4double Step,
+                                          G4double yOut[7],
+                                          G4double yErr[] )
+{
+  // Estimation of the Stepping Angle
+  //
   G4ThreeVector Bfld;
   MagFieldEvaluate(yInput, Bfld); 
   
   const G4int nvar = 6 ;
-  G4int i;
-  G4double      yTemp[8], yIn[8] ;
+  G4double yTemp[8], yIn[8] ;
   G4ThreeVector  Bfld_midpoint;
-  //  Saving yInput because yInput and yOut can be aliases for same array
-        for(i=0;i<nvar;i++) yIn[i]=yInput[i];
+
+  // Saving yInput because yInput and yOut can be aliases for same array
+  //
+  for(G4int i=0; i<nvar; ++i)
+  {
+    yIn[i] = yInput[i];
+  }
      
-        G4double h = Step * 0.5;
+  G4double h = Step * 0.5;
  
-     // Do full step and two half steps
-        G4double yTemp2[7];
-        AdvanceHelix(yIn,   Bfld,  h, yTemp2,yTemp);
-        MagFieldEvaluate(yTemp2, Bfld_midpoint) ;     
-        AdvanceHelix(yTemp2, Bfld_midpoint, h, yOut);
-    
-     // Error estimation
-        for(i=0;i<nvar;i++) {
-         yErr[i] = yOut[i] - yTemp[i] ;
-       }
+  // Do full step and two half steps
+  //
+  G4double yTemp2[7];
+  AdvanceHelix(yIn, Bfld, h, yTemp2,yTemp);
+  MagFieldEvaluate(yTemp2, Bfld_midpoint) ;     
+  AdvanceHelix(yTemp2, Bfld_midpoint, h, yOut);
+  SetAngCurve(GetAngCurve() * 2);
     
+  // Error estimation
+  //
+  for(G4int i=0; i<nvar; ++i)
+  {
+    yErr[i] = yOut[i] - yTemp[i];
+  }
 }
 
 G4double G4HelixExplicitEuler::DistChord()   const 
@@ -83,28 +95,27 @@ G4double G4HelixExplicitEuler::DistChord()   const
   G4double distChord;
   G4double Ang_curve=GetAngCurve();
 
-      
-	 if(Ang_curve<=pi){
-	   distChord=GetRadHelix()*(1-std::cos(0.5*Ang_curve));
-	 }
-         else 
-         if(Ang_curve<twopi){
-           distChord=GetRadHelix()*(1+std::cos(0.5*(twopi-Ang_curve)));
-         }
-         else{
-          distChord=2.*GetRadHelix();  
-         }
+
+  if(Ang_curve<=pi)
+  {
+    distChord=GetRadHelix()*(1-std::cos(0.5*Ang_curve));
+  }
+  else if(Ang_curve<twopi)
+  {
+    distChord=GetRadHelix()*(1+std::cos(0.5*(twopi-Ang_curve)));
+  }
+  else
+  {
+    distChord=2.*GetRadHelix();  
+  }
 
   return distChord;
-  
 }
-void
-G4HelixExplicitEuler::DumbStepper( const G4double  yIn[],
-				   G4ThreeVector   Bfld,
-				   G4double        h,
-				   G4double        yOut[])
+
+void G4HelixExplicitEuler::DumbStepper( const G4double      yIn[],
+                                              G4ThreeVector Bfld,
+                                              G4double      h,
+                                              G4double      yOut[] )
 {
-    
-       AdvanceHelix(yIn, Bfld, h, yOut);
-               
+   AdvanceHelix(yIn, Bfld, h, yOut);
 }  
