@@ -23,8 +23,7 @@
 // * acceptance of all terms of the Geant4 Software license.          *
 // ********************************************************************
 //
-//
-//
+// G4HelixImplicitEuler implementation
 //
 //  Helix Implicit Euler:
 //        x_1 = x_0 + 1/2 * ( helix(h,t_0,x_0)
@@ -34,37 +33,49 @@
 //  Take the output and its derivative. Add the mean of both derivatives
 //  to form the final output
 //
-//  W.Wander <wwc@mit.edu> 12/09/97 
-//
+// Author: W.Wander <wwc@mit.edu>, 03/11/1998
 // -------------------------------------------------------------------------
 
 #include "G4HelixImplicitEuler.hh"
 #include "G4ThreeVector.hh"
 
+G4HelixImplicitEuler::G4HelixImplicitEuler(G4Mag_EqRhs *EqRhs)
+  : G4MagHelicalStepper(EqRhs)
+{
+}
+
+G4HelixImplicitEuler::~G4HelixImplicitEuler()
+{
+}
+  
 void
-G4HelixImplicitEuler::DumbStepper( const G4double  yIn[],
-				   G4ThreeVector   Bfld,
-				   G4double        h,
-				   G4double        yOut[])
+G4HelixImplicitEuler::DumbStepper( const G4double yIn[],
+                                   G4ThreeVector  Bfld,
+                                   G4double       h,
+                                   G4double       yOut[])
 {
   const G4int nvar = 6 ;
   G4double yTemp[6], yTemp2[6];
   G4ThreeVector Bfld_endpoint;
 
-  G4int i;
-
   // Step forward like in the explicit euler case
+  //
   AdvanceHelix( yIn, Bfld, h, yTemp);
 
   // now obtain the new field value at the new point
+  //
   MagFieldEvaluate(yTemp, Bfld_endpoint);      
 
   // and also advance along a helix for this field value
+  //
   AdvanceHelix( yIn, Bfld_endpoint, h, yTemp2);
 
-  // we take the average 
-  for( i = 0; i < nvar; i++ ) 
+  // we take the average
+  //
+  for( G4int i = 0; i < nvar; ++i )
+  {
     yOut[i] = 0.5 * ( yTemp[i] + yTemp2[i] );
+  }
 
   // NormaliseTangentVector( yOut );           
 }  
