@@ -33,9 +33,7 @@
 //        use Stepper for small step(ClassicalRK4 by default)
 // Else use  HelixExplicitEuler Stepper
 //
-// History: 
-// Derived from ExactHelicalStepper 18/05/07
-//
+// Created: T.Nikitina, CERN - 18.05.2007, derived from G4ExactHelicalStepper
 // -------------------------------------------------------------------------
 
 #include "G4HelixMixedStepper.hh"
@@ -52,7 +50,8 @@
 #include "G4SimpleHeum.hh"
 #include "G4RKG3_Stepper.hh"
 #include "G4NystromRK4.hh"
-// Additional potential stepper 
+
+// Additional potential steppers
 #include "G4DormandPrince745.hh"
 #include "G4BogackiShampine23.hh"
 #include "G4BogackiShampine45.hh"
@@ -61,105 +60,122 @@
 #include "G4ThreeVector.hh"
 #include "G4LineSection.hh"
 
+// ---------------------------------------------------------------------------
 G4HelixMixedStepper::
-G4HelixMixedStepper(G4Mag_EqRhs *EqRhs,
+G4HelixMixedStepper(G4Mag_EqRhs* EqRhs,
                     G4int        stepperNumber,
                     G4double     angleThreshold)
-  : G4MagHelicalStepper(EqRhs), fNumCallsRK4(0), fNumCallsHelix(0)
+  : G4MagHelicalStepper(EqRhs)
 {
-   SetVerbose(1);
-   if( angleThreshold < 0.0 ){
-     fAngle_threshold= (1.0/3.0)*pi;
-   }else{
-     fAngle_threshold= angleThreshold;
+   if( angleThreshold < 0.0 )
+   {
+     fAngle_threshold = (1.0/3.0)*pi;
+   }
+   else
+   {
+     fAngle_threshold = angleThreshold;
    }
 
    if(stepperNumber<0)
-     stepperNumber=4;  // Default is RK4   (original)      
-     // stepperNumber=745;   // Default is DormandPrince745 (ie DoPri5)
-     // stepperNumber=8;  // Default is CashKarp
+   {
+     // stepperNumber = 4;  // Default is RK4   (original)      
+     stepperNumber = 745;   // Default is DormandPrince745 (ie DoPri5)
+     // stepperNumber = 8;  // Default is CashKarp
+   }
 
    fStepperNumber = stepperNumber; // Store the choice
    fRK4Stepper =  SetupStepper(EqRhs, fStepperNumber);
 }
 
+// ---------------------------------------------------------------------------
 G4HelixMixedStepper::~G4HelixMixedStepper()
 {  
-  delete(fRK4Stepper);
-  if (fVerbose>0){ PrintCalls();};
+  delete fRK4Stepper;
+  if (fVerbose>0) { PrintCalls(); }
 }
 
-void G4HelixMixedStepper::Stepper(  const G4double  yInput[7],
-                               const G4double dydx[7],
-                                     G4double Step,
-                                     G4double yOut[7],
-                                     G4double yErr[])
+// ---------------------------------------------------------------------------
+void G4HelixMixedStepper::Stepper(  const G4double yInput[7],
+                                    const G4double dydx[7],
+                                          G4double Step,
+                                          G4double yOut[7],
+                                          G4double yErr[])
 {
-  //Estimation of the Stepping Angle
+  // Estimation of the Stepping Angle
+  //
   G4ThreeVector Bfld;
   MagFieldEvaluate(yInput, Bfld);
   
   G4double Bmag = Bfld.mag();
-  const G4double *pIn = yInput+3;
-  G4ThreeVector initVelocity= G4ThreeVector( pIn[0], pIn[1], pIn[2]);
-  G4double      velocityVal = initVelocity.mag();
+  const G4double* pIn = yInput+3;
+  G4ThreeVector initVelocity = G4ThreeVector( pIn[0], pIn[1], pIn[2] );
+  G4double velocityVal = initVelocity.mag();
 
-  const G4double R_1=std::abs(GetInverseCurve(velocityVal,Bmag));  // curv= inverse Radius
-  G4double Ang_curve= R_1 * Step;
+  const G4double R_1 = std::abs(GetInverseCurve(velocityVal,Bmag));
+    // curv = inverse Radius
+  G4double Ang_curve = R_1 * Step;
   // SetAngCurve(Ang_curve);
-  // SetCurve(std::abs(1/R_1)); // Move below, to avoid un-needed division if RK used
-  
-  if(Ang_curve< fAngle_threshold)
+  // SetCurve(std::abs(1/R_1));
+
+  if(Ang_curve < fAngle_threshold)
   {
-    fNumCallsRK4++;
+    ++fNumCallsRK4;
     fRK4Stepper->Stepper(yInput,dydx,Step,yOut,yErr);
   }
   else
   {
-    constexpr G4int  nvar    = 6 ;
-    constexpr G4int  nvarMax = 8 ;
-    G4double       yTemp[nvarMax], yIn[nvarMax], yTemp2[nvarMax];
-    G4ThreeVector  Bfld_midpoint;
+    constexpr G4int nvar    = 6 ;
+    constexpr G4int nvarMax = 8 ;
+    G4double      yTemp[nvarMax], yIn[nvarMax], yTemp2[nvarMax];
+    G4ThreeVector Bfld_midpoint;
     
     SetAngCurve(Ang_curve);
     SetCurve(std::abs(1.0/R_1));
-    fNumCallsHelix++;
+    ++fNumCallsHelix;
     
-    //  Saving yInput because yInput and yOut can be aliases for same array
-    for(G4int i=0;i<nvar;i++) yIn[i]=yInput[i];
+    // Saving yInput because yInput and yOut can be aliases for same array
+    //
+    for(G4int i=0; i<nvar; ++i)
+    {
+      yIn[i]=yInput[i];
+    }
     
     G4double halfS = Step * 0.5;
+
     // 1. Do first half step and full step
+    //
     AdvanceHelix(yIn, Bfld, halfS, yTemp, yTemp2); // yTemp2 for s=2*h (halfS)
-    //**********
 
     MagFieldEvaluate(yTemp, Bfld_midpoint) ;
 
     // 2. Do second half step - with revised field
     // NOTE: Could avoid this call if  'Bfld_midpoint == Bfld'
     //       or diff 'almost' zero
+    //
     AdvanceHelix(yTemp, Bfld_midpoint, halfS, yOut);
-    // Not requesting y at s=2*h (halfS)
-    //**********
+      // Not requesting y at s=2*h (halfS)
     
     // 3. Estimate the integration error
     //    should be (nearly) zero if Bfield= constant
-    for(G4int i=0;i<nvar;i++) {
-      yErr[i] = yOut[i] - yTemp2[i] ;
+    //
+    for(G4int i=0; i<nvar; ++i)
+    {
+      yErr[i] = yOut[i] - yTemp2[i];
     }
   }
 }
 
-void
-G4HelixMixedStepper::DumbStepper( const G4double  yIn[],
-				   G4ThreeVector   Bfld,
-				   G4double        h,
-				   G4double        yOut[])
+// ---------------------------------------------------------------------------
+void G4HelixMixedStepper::DumbStepper( const G4double      yIn[],
+                                             G4ThreeVector Bfld,
+                                             G4double      h,
+                                             G4double      yOut[] )
 {
   AdvanceHelix(yIn, Bfld, h, yOut);
 }
 
-G4double G4HelixMixedStepper::DistChord()   const
+// ---------------------------------------------------------------------------
+G4double G4HelixMixedStepper::DistChord() const
 {
   // Implementation : must check whether h/R > 2 pi  !!
   //   If( h/R <  pi) use G4LineSection::DistLine
@@ -168,15 +184,18 @@ G4double G4HelixMixedStepper::DistChord()   const
   G4double distChord;
   G4double Ang_curve=GetAngCurve();
   
-  if(Ang_curve<=pi){
+  if(Ang_curve<=pi)
+  {
     distChord=GetRadHelix()*(1-std::cos(0.5*Ang_curve));
   }
   else
   {
-    if(Ang_curve<twopi){
+    if(Ang_curve<twopi)
+    {
       distChord=GetRadHelix()*(1+std::cos(0.5*(twopi-Ang_curve)));
     }
-    else{
+    else
+    {
       distChord=2.*GetRadHelix();
     }
   }
@@ -192,13 +211,14 @@ void G4HelixMixedStepper::PrintCalls()
          << "  and Number of calls to Helix = " << fNumCallsHelix << G4endl;
 }
 
+// ---------------------------------------------------------------------------
 G4MagIntegratorStepper*
 G4HelixMixedStepper::SetupStepper(G4Mag_EqRhs* pE, G4int StepperNumber)
 {
   G4MagIntegratorStepper* pStepper;
   if (fVerbose>0) G4cout << " G4HelixMixedStepper: ";
   switch ( StepperNumber )
-    {
+  {
       // Robust, classic method
       case 4:
         pStepper = new G4ClassicalRK4( pE );
@@ -292,10 +312,13 @@ G4HelixMixedStepper::SetupStepper(G4Mag_EqRhs* pE, G4int StepperNumber)
          pStepper = new G4DormandPrince745( pE ); // Was G4ClassicalRK4( pE );
         if (fVerbose>0) G4cout << "G4DormandPrince745 (Default)";
         break;
-    }
+  }
+
   if(fVerbose>0)
+  {
     G4cout << " chosen as stepper for small steps in G4HelixMixedStepper."
            << G4endl;
+  }
 
   return pStepper;
 }
