@@ -23,79 +23,73 @@
 // * acceptance of all terms of the Geant4 Software license.          *
 // ********************************************************************
 //
+// G4UniformGravityField implementation
 //
-// Class for creation of Uniform Gravitation Field.
-//
+// Created: P.Gumplinger, 14.06.2011 - Adapted from G4UniformElectricField
+//          Thanks to P.Fierlinger (PSI), A.Capra and A.Fontana (INFN Pavia)
+// -------------------------------------------------------------------
 
-// History:
-// - 14.06.11 P.Gumplinger, Created.
-// -------------------------------------------------------------------
-// Adopted from G4UniformElectricField.hh
-//
-// Thanks to Peter Fierlinger (PSI) and
-// A. Capra and A. Fontana (INFN Pavia)
-// -------------------------------------------------------------------
-//
 #include "G4UniformGravityField.hh"
 #include "G4PhysicalConstants.hh"
 #include "G4SystemOfUnits.hh"
 
 // Construct from a 3-vector
-G4UniformGravityField::G4UniformGravityField(const G4ThreeVector FieldVector)
+//
+G4UniformGravityField::G4UniformGravityField(const G4ThreeVector& FieldVector)
   : G4Field ( true ) //  Gravity flag *on*
 {
-      fFieldComponents[0] = FieldVector.x();
-      fFieldComponents[1] = FieldVector.y();
-      fFieldComponents[2] = FieldVector.z();
+  fFieldComponents[0] = FieldVector.x();
+  fFieldComponents[1] = FieldVector.y();
+  fFieldComponents[2] = FieldVector.z();
 }
 
 // Construct from a double > default = -9.81 m*s^-2
-G4UniformGravityField::G4UniformGravityField(const G4double gy )
+G4UniformGravityField::G4UniformGravityField(const G4double gy)
   : G4Field ( true ) 
 {
-      fFieldComponents[0] = 0.0;
-      fFieldComponents[1] = gy;
-      fFieldComponents[2] = 0.0;
-}
-
-G4Field* G4UniformGravityField::Clone() const
-{
-    return new G4UniformGravityField( G4ThreeVector(fFieldComponents[0],
-                                                    fFieldComponents[1],
-                                                    fFieldComponents[2]) );
+  fFieldComponents[0] = 0.0;
+  fFieldComponents[1] = gy;
+  fFieldComponents[2] = 0.0;
 }
 
 G4UniformGravityField::~G4UniformGravityField()
 {
 }
 
-G4UniformGravityField::G4UniformGravityField (const G4UniformGravityField &p)
-   : G4Field(p)
+G4UniformGravityField::G4UniformGravityField (const G4UniformGravityField& p)
+  : G4Field(p)
 {
-   for (G4int i=0; i<3; i++)
-   {
-     fFieldComponents[i] = p.fFieldComponents[i];
-   }
+  for (auto i=0; i<3; ++i)
+  {
+    fFieldComponents[i] = p.fFieldComponents[i];
+  }
 }
 
 G4UniformGravityField&
-G4UniformGravityField::operator = (const G4UniformGravityField &p)
+G4UniformGravityField::operator = (const G4UniformGravityField& p)
 {
   if (&p == this) return *this; 
   G4Field::operator=(p); 
-  for (G4int i=0; i<3; i++)
+  for (auto i=0; i<3; ++i)
   {
     fFieldComponents[i] = p.fFieldComponents[i];
   }
   return *this;
 }
 
+G4Field* G4UniformGravityField::Clone() const
+{
+  return new G4UniformGravityField( G4ThreeVector(fFieldComponents[0],
+                                                  fFieldComponents[1],
+                                                  fFieldComponents[2]) );
+}
+
 // -------------------------------------------------------------------
 
 void G4UniformGravityField::GetFieldValue (const G4double [4],
-                                                 G4double *G ) const
+                                                 G4double* G ) const
 {
-   G[0]= fFieldComponents[0] ;
-   G[1]= fFieldComponents[1] ;
-   G[2]= fFieldComponents[2] ;
+   G[0]= fFieldComponents[0];
+   G[1]= fFieldComponents[1];
+   G[2]= fFieldComponents[2];
 }
