@@ -23,13 +23,9 @@
 // * acceptance of all terms of the Geant4 Software license.          *
 // ********************************************************************
 //
+// G4UniformMagField implementation
 //
-//
-//
-// Class for creation of uniform Magnetic Field
-//
-// 30.1.97 V.Grichine
-//
+// Created: V.Grichine, 30.01.1997
 // -------------------------------------------------------------------
 
 #include "G4UniformMagField.hh"
@@ -37,34 +33,58 @@
 
 G4UniformMagField::G4UniformMagField(const G4ThreeVector& FieldVector )
 {
-      fFieldComponents[0] = FieldVector.x();
-      fFieldComponents[1] = FieldVector.y();
-      fFieldComponents[2] = FieldVector.z();
+   fFieldComponents[0] = FieldVector.x();
+   fFieldComponents[1] = FieldVector.y();
+   fFieldComponents[2] = FieldVector.z();
+}
+
+G4UniformMagField::~G4UniformMagField()
+{
+}
+
+G4UniformMagField::G4UniformMagField (const G4UniformMagField& p)
+   : G4MagneticField(p)
+{
+   for (auto i=0; i<3; ++i)
+   {
+     fFieldComponents[i] = p.fFieldComponents[i];
+   }
+}
+
+G4UniformMagField& G4UniformMagField::operator = (const G4UniformMagField& p)
+{
+   if (&p == this) return *this;
+   G4MagneticField::operator=(p); 
+   for (auto i=0; i<3; ++i)
+   {
+     fFieldComponents[i] = p.fFieldComponents[i];
+   }
+   return *this;
 }
 
 G4Field* G4UniformMagField::Clone() const
 {
-    return new G4UniformMagField( G4ThreeVector(fFieldComponents[0],
-                                                fFieldComponents[1],
-                                                fFieldComponents[2]) );
+   return new G4UniformMagField( G4ThreeVector(fFieldComponents[0],
+                                               fFieldComponents[1],
+                                               fFieldComponents[2]) );
 }
 
 void
 G4UniformMagField::SetFieldValue(const G4ThreeVector& newFieldVector )
 {
-      fFieldComponents[0] = newFieldVector.x();
-      fFieldComponents[1] = newFieldVector.y();
-      fFieldComponents[2] = newFieldVector.z();
+   fFieldComponents[0] = newFieldVector.x();
+   fFieldComponents[1] = newFieldVector.y();
+   fFieldComponents[2] = newFieldVector.z();
 }
    
 G4UniformMagField::G4UniformMagField(G4double vField,
                                      G4double vTheta,
-                                     G4double vPhi    )
+                                     G4double vPhi)
 {
    if ( (vField<0) || (vTheta<0) || (vTheta>pi) || (vPhi<0) || (vPhi>twopi) )
    {
       std::ostringstream msg;
-      msg << "ERROR in G4UniformMagField::G4UniformMagField(double, double, double) : "
+      msg << "ERROR in G4UniformMagField::G4UniformMagField() : "
           << "Invalid parameter(s). " << std::endl;
       msg << " Expected " << std::endl;
       
@@ -83,45 +103,21 @@ G4UniformMagField::G4UniformMagField(G4double vField,
       if ( (vPhi<0) || (vPhi>twopi) ) { msg << " <------ Erroneous "; }
       
       G4Exception("G4UniformMagField::G4UniformMagField()",
-                  "GeomField0002", FatalException, msg ); // "Invalid parameters.") ;
+                  "GeomField0002", FatalException, msg );
    }
    fFieldComponents[0] = vField*std::sin(vTheta)*std::cos(vPhi) ;
    fFieldComponents[1] = vField*std::sin(vTheta)*std::sin(vPhi) ;
    fFieldComponents[2] = vField*std::cos(vTheta) ;
 }
 
-G4UniformMagField::~G4UniformMagField()
-{
-}
-
-G4UniformMagField::G4UniformMagField (const G4UniformMagField &p)
-   : G4MagneticField(p)
-{
-   for (G4int i=0; i<3; i++)
-   {
-     fFieldComponents[i] = p.fFieldComponents[i];
-   }
-}
-
-G4UniformMagField& G4UniformMagField::operator = (const G4UniformMagField &p)
-{
-   if (&p == this) return *this;
-   G4MagneticField::operator=(p); 
-   for (G4int i=0; i<3; i++)
-   {
-     fFieldComponents[i] = p.fFieldComponents[i];
-   }
-   return *this;
-}
-
 // ------------------------------------------------------------------------
 
 void G4UniformMagField::GetFieldValue (const G4double [4],
-                                             G4double *B  ) const 
+                                             G4double* B) const 
 {
-   B[0]= fFieldComponents[0] ;
-   B[1]= fFieldComponents[1] ;
-   B[2]= fFieldComponents[2] ;
+   B[0]= fFieldComponents[0];
+   B[1]= fFieldComponents[1];
+   B[2]= fFieldComponents[2];
 }
 
 G4ThreeVector G4UniformMagField::GetConstantFieldValue() const
@@ -129,5 +125,5 @@ G4ThreeVector G4UniformMagField::GetConstantFieldValue() const
    G4ThreeVector B(fFieldComponents[0],
                    fFieldComponents[1],
                    fFieldComponents[2]);
-  return B;
+   return B;
 }
