@@ -23,9 +23,6 @@
 // * acceptance of all terms of the Geant4 Software license.          *
 // ********************************************************************
 //
-//
-//
-//
 // class G4BlockingList Implementation
 //
 // --------------------------------------------------------------------
@@ -33,7 +30,7 @@
 #include "G4BlockingList.hh"
 
 G4BlockingList::G4BlockingList(G4int maxDefault, G4int stride)
-  : fBlockTagNo(1), fStride(stride), fBlockingList(maxDefault,0)
+  : fStride(stride), fBlockingList(maxDefault,0)
 {
 }
 
@@ -48,7 +45,7 @@ G4BlockingList::~G4BlockingList()
 void G4BlockingList::FullyReset()
 {
   fBlockTagNo = 1;
-  for ( G4int i=fBlockingList.size()-1; i>=0; i-- )
+  for ( G4long i=G4long(fBlockingList.size()-1); i>=0; --i )
   {
     fBlockingList[i] = 0;
   }  
