@@ -23,17 +23,14 @@
 // * acceptance of all terms of the Geant4 Software license.          *
 // ********************************************************************
 //
+// G4ErrorTarget class implementation
 //
-//
-//
-// --------------------------------------------------------------------
-//      GEANT 4 class implementation file
+// Created: P.Arce, September 2004
 // --------------------------------------------------------------------
 
 #include "G4ErrorTarget.hh"
 
-G4ErrorTarget::G4ErrorTarget()
- : theType(G4ErrorTarget_GeomVolume) {}
+G4ErrorTarget::G4ErrorTarget() : theType(G4ErrorTarget_GeomVolume) {}
 
 G4ErrorTarget::~G4ErrorTarget() {}
 
@@ -50,5 +47,5 @@ G4double G4ErrorTarget::GetDistanceFromPoint( const G4ThreeVector& ) const
 
 G4bool G4ErrorTarget::TargetReached(const G4Step*)
 {
-  return 0;
+  return false;
 }
