@@ -23,10 +23,10 @@
 // * acceptance of all terms of the Geant4 Software license.          *
 // ********************************************************************
 //
-//
-//
 // Default implementations for Parameterisations that do not
 // parameterise solid and/or material.
+//
+// 25.07.96, P.Kent - Initial stub version
 // --------------------------------------------------------------------
 
 #include "G4VPVParameterisation.hh"
@@ -44,14 +44,14 @@ G4VPVParameterisation::~G4VPVParameterisation()
 
 G4VSolid*
 G4VPVParameterisation::ComputeSolid(const G4int,
-                                    G4VPhysicalVolume *pPhysicalVol) 
+                                    G4VPhysicalVolume* pPhysicalVol) 
 {
   return pPhysicalVol->GetLogicalVolume()->GetSolid();
 }
        
 G4Material*
 G4VPVParameterisation::ComputeMaterial(const G4int,
-                                       G4VPhysicalVolume *pPhysicalVol,
+                                       G4VPhysicalVolume* pPhysicalVol,
 				       const G4VTouchable *) 
 {
   return pPhysicalVol->GetLogicalVolume()->GetMaterial();
@@ -66,6 +66,6 @@ G4bool G4VPVParameterisation::IsNested() const
 G4VVolumeMaterialScanner* 
 G4VPVParameterisation::GetMaterialScanner()
 {
-  return 0;
+  return nullptr;
 }
 //   These enable material scan for nested parameterisations
