@@ -23,42 +23,14 @@
 // * acceptance of all terms of the Geant4 Software license.          *
 // ********************************************************************
 //
+// G4Tubs implementation
 //
-//
-// 
-// class G4Tubs
-//
-// History:
-//
-// 24.08.16 E.Tcherniaev: reimplemented CalculateExtent() to make use
-//                      of G4BoundingEnvelope  
-// 05.04.12 M.Kelsey:   Use sqrt(r) in GetPointOnSurface() for uniform points
-// 02.08.07 T.Nikitina: bug fixed in DistanceToOut(p,v,..) for negative value under sqrt
-//                      for the case: p on the surface and v is tangent to the surface
-// 11.05.07 T.Nikitina: bug fixed in DistanceToOut(p,v,..) for phi < 2pi
-// 03.05.05 V.Grichine: SurfaceNormal(p) according to J. Apostolakis proposal
-// 16.03.05 V.Grichine: SurfaceNormal(p) with edges/corners for boolean
-// 20.07.01 V.Grichine: bug fixed in Inside(p)
-// 20.02.01 V.Grichine: bug fixed in Inside(p) and CalculateExtent was 
-//                      simplified base on G4Box::CalculateExtent
-// 07.12.00 V.Grichine: phi-section algorithm was changed in Inside(p)
-// 28.11.00 V.Grichine: bug fixed in Inside(p)
-// 31.10.00 V.Grichine: assign srd, sphi in Distance ToOut(p,v,...)
+// 1994-95 P.Kent: first implementation
 // 08.08.00 V.Grichine: more stable roots of 2-equation in DistanceToOut(p,v,..)
-// 02.08.00 V.Grichine: point is outside check in Distance ToOut(p)
-// 17.05.00 V.Grichine: bugs (#76,#91) fixed in Distance ToOut(p,v,...)
-// 31.03.00 V.Grichine: bug fixed in Inside(p)
-// 19.11.99 V.Grichine: side = kNull in DistanceToOut(p,v,...)
-// 13.10.99 V.Grichine: bugs fixed in DistanceToIn(p,v) 
-// 28.05.99 V.Grichine: bugs fixed in DistanceToOut(p,v,...)
-// 25.05.99 V.Grichine: bugs fixed in DistanceToIn(p,v) 
-// 23.03.99 V.Grichine: bug fixed in DistanceToIn(p,v) 
-// 09.10.98 V.Grichine: modifications in DistanceToOut(p,v,...)
-// 18.06.98 V.Grichine: n-normalisation in DistanceToOut(p,v)
-// 
-// 1994-95  P.Kent:     implementation
-//
-/////////////////////////////////////////////////////////////////////////
+// 07.12.00 V.Grichine: phi-section algorithm was changed in Inside(p)
+// 03.05.05 V.Grichine: SurfaceNormal(p) according to J.Apostolakis proposal
+// 24.08.16 E.Tcherniaev: reimplemented CalculateExtent().
+// --------------------------------------------------------------------
 
 #include "G4Tubs.hh"
 
@@ -89,9 +61,11 @@ G4Tubs::G4Tubs( const G4String &pName,
                       G4double pRMin, G4double pRMax,
                       G4double pDz,
                       G4double pSPhi, G4double pDPhi )
-  : G4CSGSolid(pName), fRMin(pRMin), fRMax(pRMax), fDz(pDz), fSPhi(0), fDPhi(0)
+   : G4CSGSolid(pName), fRMin(pRMin), fRMax(pRMax), fDz(pDz),
+     fSPhi(0), fDPhi(0),
+     fInvRmax( pRMax > 0.0 ? 1.0/pRMax : 0.0 ),
+     fInvRmin( pRMin > 0.0 ? 1.0/pRMin : 0.0 )
 {
-
   kRadTolerance = G4GeometryTolerance::GetInstance()->GetRadialTolerance();
   kAngTolerance = G4GeometryTolerance::GetInstance()->GetAngularTolerance();
 
@@ -127,9 +101,10 @@ G4Tubs::G4Tubs( const G4String &pName,
 G4Tubs::G4Tubs( __void__& a )
   : G4CSGSolid(a), kRadTolerance(0.), kAngTolerance(0.),
     fRMin(0.), fRMax(0.), fDz(0.), fSPhi(0.), fDPhi(0.),
-    sinCPhi(0.), cosCPhi(0.), cosHDPhiOT(0.), cosHDPhiIT(0.),
+    sinCPhi(0.), cosCPhi(0.), cosHDPhi(0.), cosHDPhiOT(0.), cosHDPhiIT(0.),
     sinSPhi(0.), cosSPhi(0.), sinEPhi(0.), cosEPhi(0.),
-    fPhiFullTube(false), halfCarTolerance(0.), halfRadTolerance(0.),
+    fPhiFullTube(false), fInvRmax(0.), fInvRmin(0.),    
+    halfCarTolerance(0.), halfRadTolerance(0.),
     halfAngTolerance(0.)
 {
 }
@@ -151,10 +126,11 @@ G4Tubs::G4Tubs(const G4Tubs& rhs)
     kRadTolerance(rhs.kRadTolerance), kAngTolerance(rhs.kAngTolerance),
     fRMin(rhs.fRMin), fRMax(rhs.fRMax), fDz(rhs.fDz),
     fSPhi(rhs.fSPhi), fDPhi(rhs.fDPhi),
-    sinCPhi(rhs.sinCPhi), cosCPhi(rhs.cosCPhi),
+    sinCPhi(rhs.sinCPhi), cosCPhi(rhs.cosCPhi), cosHDPhi(rhs.cosHDPhi),
     cosHDPhiOT(rhs.cosHDPhiOT), cosHDPhiIT(rhs.cosHDPhiIT),
     sinSPhi(rhs.sinSPhi), cosSPhi(rhs.cosSPhi),
     sinEPhi(rhs.sinEPhi), cosEPhi(rhs.cosEPhi), fPhiFullTube(rhs.fPhiFullTube),
+    fInvRmax(rhs.fInvRmax), fInvRmin(rhs.fInvRmin),
     halfCarTolerance(rhs.halfCarTolerance),
     halfRadTolerance(rhs.halfRadTolerance),
     halfAngTolerance(rhs.halfAngTolerance)
@@ -180,11 +156,13 @@ G4Tubs& G4Tubs::operator = (const G4Tubs& rhs)
    kRadTolerance = rhs.kRadTolerance; kAngTolerance = rhs.kAngTolerance;
    fRMin = rhs.fRMin; fRMax = rhs.fRMax; fDz = rhs.fDz;
    fSPhi = rhs.fSPhi; fDPhi = rhs.fDPhi;
-   sinCPhi = rhs.sinCPhi; cosCPhi = rhs.cosCPhi;
+   sinCPhi = rhs.sinCPhi; cosCPhi = rhs.cosCPhi; cosHDPhi = rhs.cosHDPhi;
    cosHDPhiOT = rhs.cosHDPhiOT; cosHDPhiIT = rhs.cosHDPhiIT;
    sinSPhi = rhs.sinSPhi; cosSPhi = rhs.cosSPhi;
    sinEPhi = rhs.sinEPhi; cosEPhi = rhs.cosEPhi;
    fPhiFullTube = rhs.fPhiFullTube;
+   fInvRmax = rhs.fInvRmax;
+   fInvRmin = rhs.fInvRmin;
    halfCarTolerance = rhs.halfCarTolerance;
    halfRadTolerance = rhs.halfRadTolerance;
    halfAngTolerance = rhs.halfAngTolerance;
@@ -266,7 +244,7 @@ G4bool G4Tubs::CalculateExtent( const EAxis              pAxis,
   // Check bounding box
   G4BoundingEnvelope bbox(bmin,bmax);
 #ifdef G4BBOX_EXTENT
-  if (true) return bbox.CalculateExtent(pAxis,pVoxelLimit,pTransform,pMin,pMax);
+  return bbox.CalculateExtent(pAxis,pVoxelLimit,pTransform,pMin,pMax);
 #endif
   if (bbox.BoundingBoxVsVoxelLimits(pAxis,pVoxelLimit,pTransform,pMin,pMax))
   {
@@ -551,48 +529,48 @@ G4ThreeVector G4Tubs::SurfaceNormal( const G4ThreeVector& p ) const
     {
       pPhi = std::atan2(p.y(),p.x());
     
-      if(pPhi  < fSPhi- halfCarTolerance)           { pPhi += twopi; }
-      else if(pPhi > fSPhi+fDPhi+ halfCarTolerance) { pPhi -= twopi; }
+      if (pPhi  < fSPhi-halfCarTolerance)            { pPhi += twopi; }
+      else if (pPhi > fSPhi+fDPhi+halfCarTolerance)  { pPhi -= twopi; }
 
-      distSPhi = std::fabs(pPhi - fSPhi);       
-      distEPhi = std::fabs(pPhi - fSPhi - fDPhi); 
+      distSPhi = std::fabs( pPhi - fSPhi );       
+      distEPhi = std::fabs( pPhi - fSPhi - fDPhi ); 
     }
-    else if( !fRMin )
+    else if ( !fRMin )
     {
       distSPhi = 0.; 
       distEPhi = 0.; 
     }
-    nPs = G4ThreeVector(std::sin(fSPhi),-std::cos(fSPhi),0);
-    nPe = G4ThreeVector(-std::sin(fSPhi+fDPhi),std::cos(fSPhi+fDPhi),0);
+    nPs = G4ThreeVector( sinSPhi, -cosSPhi, 0 );
+    nPe = G4ThreeVector( -sinEPhi, cosEPhi, 0 );
   }
   if ( rho > halfCarTolerance ) { nR = G4ThreeVector(p.x()/rho,p.y()/rho,0); }
 
   if( distRMax <= halfCarTolerance )
   {
-    noSurfaces ++;
+    ++noSurfaces;
     sumnorm += nR;
   }
   if( fRMin && (distRMin <= halfCarTolerance) )
   {
-    noSurfaces ++;
+    ++noSurfaces;
     sumnorm -= nR;
   }
   if( fDPhi < twopi )   
   {
     if (distSPhi <= halfAngTolerance)  
     {
-      noSurfaces ++;
+      ++noSurfaces;
       sumnorm += nPs;
     }
     if (distEPhi <= halfAngTolerance)  
     {
-      noSurfaces ++;
+      ++noSurfaces;
       sumnorm += nPe;
     }
   }
   if (distZ <= halfCarTolerance)  
   {
-    noSurfaces ++;
+    ++noSurfaces;
     if ( p.z() >= 0.)  { sumnorm += nZ; }
     else               { sumnorm -= nZ; }
   }
@@ -709,12 +687,12 @@ G4ThreeVector G4Tubs::ApproxSurfaceNormal( const G4ThreeVector& p ) const
     }
     case kNSPhi:
     {
-      norm = G4ThreeVector(std::sin(fSPhi), -std::cos(fSPhi), 0) ;
+      norm = G4ThreeVector(sinSPhi, -cosSPhi, 0) ;
       break ;
     }
     case kNEPhi:
     {
-      norm = G4ThreeVector(-std::sin(fSPhi+fDPhi), std::cos(fSPhi+fDPhi), 0) ;
+      norm = G4ThreeVector(-sinEPhi, cosEPhi, 0) ;
       break;
     }
     default:      // Should never reach this case ...
@@ -992,7 +970,7 @@ G4double G4Tubs::DistanceToIn( const G4ThreeVector& p,
             {
               xi     = p.x() + sd*v.x() ;
               yi     = p.y() + sd*v.y() ;
-              cosPsi = (xi*cosCPhi + yi*sinCPhi)/fRMin ;
+              cosPsi = (xi*cosCPhi + yi*sinCPhi)*fInvRmin;
               if (cosPsi >= cosHDPhiIT)
               {
                 // Good inner radius isect
@@ -1147,7 +1125,7 @@ G4double G4Tubs::DistanceToIn( const G4ThreeVector& p ) const
     //
     cosPsi = (p.x()*cosCPhi + p.y()*sinCPhi)/rho ;
     
-    if ( cosPsi < std::cos(fDPhi*0.5) )
+    if ( cosPsi < cosHDPhi )
     {
       // Point lies outside phi range
 
@@ -1174,13 +1152,13 @@ G4double G4Tubs::DistanceToIn( const G4ThreeVector& p ) const
 G4double G4Tubs::DistanceToOut( const G4ThreeVector& p,
                                 const G4ThreeVector& v,
                                 const G4bool calcNorm,
-                                      G4bool *validNorm,
-                                      G4ThreeVector *n    ) const
-{  
+                                      G4bool* validNorm,
+                                      G4ThreeVector* n ) const
+{
   ESide side=kNull , sider=kNull, sidephi=kNull ;
   G4double snxt, srd=kInfinity, sphi=kInfinity, pdist ;
   G4double deltaR, t1, t2, t3, b, c, d2, roMin2 ;
-
+  
   // Vars for phi intersection:
 
   G4double pDistS, compS, pDistE, compE, sphi2, xi, yi, vphi, roi2 ;
@@ -1277,7 +1255,8 @@ G4double G4Tubs::DistanceToOut( const G4ThreeVector& p,
 
         if ( calcNorm ) 
         {
-          *n         = G4ThreeVector(p.x()/fRMax,p.y()/fRMax,0) ;
+          G4double invRho = FastInverseRxy( p, fInvRmax, kNormTolerance );
+          *n         = G4ThreeVector(p.x()*invRho,p.y()*invRho,0) ;
           *validNorm = true ;
         }
         return snxt = 0 ; // Leaving by rmax immediately
@@ -1306,7 +1285,9 @@ G4double G4Tubs::DistanceToOut( const G4ThreeVector& p,
           }
           else
           {
-            if ( calcNorm ) { *validNorm = false; }  // Concave side
+            if ( calcNorm ) {
+               *validNorm = false;
+            }  // Concave side
             return snxt = 0.0;
           }
         }
@@ -1325,7 +1306,8 @@ G4double G4Tubs::DistanceToOut( const G4ThreeVector& p,
           {
             if (calcNorm)
             {
-              *n = G4ThreeVector(p.x()/fRMax,p.y()/fRMax,0) ;
+              G4double invRho = FastInverseRxy( p, fInvRmax, kNormTolerance );
+              *n = G4ThreeVector(p.x()*invRho,p.y()*invRho,0) ;               
               *validNorm = true ;
             }
             return snxt = 0.0;
@@ -1349,7 +1331,8 @@ G4double G4Tubs::DistanceToOut( const G4ThreeVector& p,
         {
           if (calcNorm)
           {
-            *n = G4ThreeVector(p.x()/fRMax,p.y()/fRMax,0) ;
+            G4double invRho = FastInverseRxy( p, fInvRmax, kNormTolerance );
+            *n = G4ThreeVector(p.x()*invRho,p.y()*invRho,0) ;
             *validNorm = true ;
           }
           return snxt = 0.0;
@@ -1379,8 +1362,8 @@ G4double G4Tubs::DistanceToOut( const G4ThreeVector& p,
 
         // Comp -ve when in direction of outwards normal
 
-        compS   = -sinSPhi*v.x() + cosSPhi*v.y() ;
-        compE   =  sinEPhi*v.x() - cosEPhi*v.y() ;
+        compS = -sinSPhi*v.x() + cosSPhi*v.y() ;
+        compE =  sinEPhi*v.x() - cosEPhi*v.y() ;
        
         sidephi = kNull;
         
@@ -1741,15 +1724,15 @@ G4ThreeVector G4Tubs::GetPointOnSurface() const
   else if( (chose >= aOne + aTwo + 2.*aThr)
         && (chose < aOne + aTwo + 2.*aThr + aFou) )
   {
-    xRand = rRand*std::cos(fSPhi);
-    yRand = rRand*std::sin(fSPhi);
+    xRand = rRand*cosSPhi;
+    yRand = rRand*sinSPhi;
     zRand = G4RandFlat::shoot(-1.*fDz,fDz);
     return G4ThreeVector  (xRand, yRand, zRand);
   }
   else
   {
-    xRand = rRand*std::cos(fSPhi+fDPhi);
-    yRand = rRand*std::sin(fSPhi+fDPhi);
+    xRand = rRand*cosEPhi;
+    yRand = rRand*sinEPhi;
     zRand = G4RandFlat::shoot(-1.*fDz,fDz);
     return G4ThreeVector  (xRand, yRand, zRand);
   }
@@ -1768,4 +1751,5 @@ G4Polyhedron* G4Tubs::CreatePolyhedron () const
 {
   return new G4PolyhedronTubs (fRMin, fRMax, fDz, fSPhi, fDPhi) ;
 }
+
 #endif
