@@ -23,25 +23,11 @@
 // * acceptance of all terms of the Geant4 Software license.          *
 // ********************************************************************
 //
-//
-//
-//
-// --------------------------------------------------------------------
-// GEANT 4 class source file
-//
-// G4GenericTrap.cc
+// G4GenericTrap implementation
 //
 // Authors:
 //   Tatiana Nikitina, CERN; Ivana Hrivnacova, IPN Orsay
 //   Adapted from Root Arb8 implementation by Andrei Gheata, CERN 
-//
-// History:
-// 04.08.2011 T.Nikitina - Added SetReferences() and InvertFacets()
-//            to CreatePolyhedron() for Visualisation of Boolean
-// 03.02.2016 E.Tcherniaev - Revised GetSurfaceArea() and GetCubicVolume(),
-//            rewritten GetFaceSurfaceArea(), added GetFaceCubicVolume()      
-// 25.09.2016 E.Tcherniaev - Use G4BoundingEnvelope for CalculateExtent(),
-//            removed CreateRotatedVertices()
 // --------------------------------------------------------------------
 
 #include "G4GenericTrap.hh"
@@ -52,7 +38,6 @@
 
 #include "G4PhysicalConstants.hh"
 #include "G4SystemOfUnits.hh"
-#include "G4TessellatedSolid.hh"
 #include "G4TriangularFacet.hh"
 #include "G4QuadrangularFacet.hh"
 #include "G4VoxelLimits.hh"
@@ -79,19 +64,8 @@ const G4double G4GenericTrap::fgkTolerance = 1E-3;
 
 G4GenericTrap::G4GenericTrap( const G4String& name, G4double halfZ,
                               const std::vector<G4TwoVector>&  vertices )
-  : G4VSolid(name),
-    fRebuildPolyhedron(false),
-    fpPolyhedron(0),
-    fDz(halfZ),
-    fVertices(),
-    fIsTwisted(false),
-    fTessellatedSolid(0),
-    fMinBBoxVector(G4ThreeVector(0,0,0)),
-    fMaxBBoxVector(G4ThreeVector(0,0,0)),
-    fVisSubdivisions(0),
-    fSurfaceArea(0.),
-    fCubicVolume(0.)
-   
+  : G4VSolid(name), fDz(halfZ), fVertices(),
+    fMinBBoxVector(G4ThreeVector(0,0,0)), fMaxBBoxVector(G4ThreeVector(0,0,0))
 {
   // General constructor
   const G4double min_length=5*1.e-6;
@@ -127,15 +101,15 @@ G4GenericTrap::G4GenericTrap( const G4String& name, G4double halfZ,
   }
   else
   { 
-    for (G4int i=0; i <4; ++i) {fVertices.push_back(vertices[3-i]);}
-    for (G4int i=0; i <4; ++i) {fVertices.push_back(vertices[7-i]);}
+    for (auto i=0; i <4; ++i) {fVertices.push_back(vertices[3-i]);}
+    for (auto i=0; i <4; ++i) {fVertices.push_back(vertices[7-i]);}
   }
 
    // Check length of segments and Adjust
   // 
-  for (G4int j=0; j < 2; j++)
+  for (auto j=0; j<2; ++j)
   {
-    for (G4int i=1; i<4; ++i)
+    for (auto i=1; i<4; ++i)
     {
       k = j*4+i;
       length = (fVertices[k]-fVertices[k-1]).mag();
@@ -154,7 +128,7 @@ G4GenericTrap::G4GenericTrap( const G4String& name, G4double halfZ,
 
   // Compute Twist
   //
-  for( G4int i=0; i<4; i++) { fTwist[i]=0.; }
+  for( auto i=0; i<4; ++i) { fTwist[i]=0.; }
   fIsTwisted = ComputeIsTwisted();
 
   // Compute Bounding Box 
@@ -172,19 +146,8 @@ G4GenericTrap::G4GenericTrap( const G4String& name, G4double halfZ,
 // --------------------------------------------------------------------
 
 G4GenericTrap::G4GenericTrap( __void__& a )
-  : G4VSolid(a),
-    fRebuildPolyhedron(false),
-    fpPolyhedron(0),
-    halfCarTolerance(0.),
-    fDz(0.),
-    fVertices(),
-    fIsTwisted(false),
-    fTessellatedSolid(0),
-    fMinBBoxVector(G4ThreeVector(0,0,0)),
-    fMaxBBoxVector(G4ThreeVector(0,0,0)),
-    fVisSubdivisions(0),
-    fSurfaceArea(0.),
-    fCubicVolume(0.)
+  : G4VSolid(a), halfCarTolerance(0.), fDz(0.), fVertices(),
+    fMinBBoxVector(G4ThreeVector(0,0,0)), fMaxBBoxVector(G4ThreeVector(0,0,0))
 {
   // Fake default constructor - sets only member data and allocates memory
   //                            for usage restricted to object persistency.
@@ -194,7 +157,6 @@ G4GenericTrap::G4GenericTrap( __void__& a )
 
 G4GenericTrap::~G4GenericTrap()
 {
-  // Destructor
   delete fTessellatedSolid;
 }
 
@@ -202,15 +164,14 @@ G4GenericTrap::~G4GenericTrap()
 
 G4GenericTrap::G4GenericTrap(const G4GenericTrap& rhs)
   : G4VSolid(rhs),
-    fRebuildPolyhedron(false), fpPolyhedron(0),
     halfCarTolerance(rhs.halfCarTolerance),
     fDz(rhs.fDz), fVertices(rhs.fVertices),
-    fIsTwisted(rhs.fIsTwisted), fTessellatedSolid(0),
+    fIsTwisted(rhs.fIsTwisted),
     fMinBBoxVector(rhs.fMinBBoxVector), fMaxBBoxVector(rhs.fMaxBBoxVector),
     fVisSubdivisions(rhs.fVisSubdivisions),
     fSurfaceArea(rhs.fSurfaceArea), fCubicVolume(rhs.fCubicVolume) 
 {
-   for (size_t i=0; i<4; ++i)  { fTwist[i] = rhs.fTwist[i]; }
+   for (auto i=0; i<4; ++i)  { fTwist[i] = rhs.fTwist[i]; }
 #ifdef G4TESS_TEST
    if (rhs.fTessellatedSolid && !fIsTwisted )
    { fTessellatedSolid = CreateTessellatedSolid(); } 
@@ -233,18 +194,18 @@ G4GenericTrap& G4GenericTrap::operator = (const G4GenericTrap& rhs)
    //
    halfCarTolerance = rhs.halfCarTolerance;
    fDz = rhs.fDz; fVertices = rhs.fVertices;
-   fIsTwisted = rhs.fIsTwisted; fTessellatedSolid = 0;
+   fIsTwisted = rhs.fIsTwisted; fTessellatedSolid = nullptr;
    fMinBBoxVector = rhs.fMinBBoxVector; fMaxBBoxVector = rhs.fMaxBBoxVector;
    fVisSubdivisions = rhs.fVisSubdivisions;
    fSurfaceArea = rhs.fSurfaceArea; fCubicVolume = rhs.fCubicVolume;
 
-   for (size_t i=0; i<4; ++i)  { fTwist[i] = rhs.fTwist[i]; }
+   for (auto i=0; i<4; ++i)  { fTwist[i] = rhs.fTwist[i]; }
 #ifdef G4TESS_TEST
    if (rhs.fTessellatedSolid && !fIsTwisted )
    { delete fTessellatedSolid; fTessellatedSolid = CreateTessellatedSolid(); } 
 #endif
    fRebuildPolyhedron = false;
-   delete fpPolyhedron; fpPolyhedron = 0;
+   delete fpPolyhedron; fpPolyhedron = nullptr;
 
    return *this;
 }
@@ -259,7 +220,7 @@ G4GenericTrap::InsidePolygone(const G4ThreeVector& p,
   G4double cross, len2;
   G4int count=0;
 
-  for (G4int i = 0; i < 4; i++)
+  for (G4int i=0; i<4; ++i)
   {
     G4int j = (i+1) % 4;
 
@@ -335,7 +296,7 @@ G4GenericTrap::InsidePolygone(const G4ThreeVector& p,
     }
     else
     {
-      count++;
+      ++count;
     }
   }
 
@@ -343,9 +304,10 @@ G4GenericTrap::InsidePolygone(const G4ThreeVector& p,
   //
   if(count==4)
   { 
-    if ( (std::fabs(p.x()-poly[0].x())+std::fabs(p.y()-poly[0].y())) > halfCarTolerance )
+    if ( (std::fabs(p.x()-poly[0].x())
+         +std::fabs(p.y()-poly[0].y())) > halfCarTolerance )
     {
-      in=kOutside;
+      in = kOutside;
     }
   }
   return in;
@@ -372,7 +334,7 @@ EInside G4GenericTrap::Inside(const G4ThreeVector& p) const
     // Compute intersection between Z plane containing point and the shape
     //
     G4double cf = 0.5*(fDz-p.z())/fDz;
-    for (G4int i=0; i<4; i++)
+    for (auto i=0; i<4; ++i)
     {
       xy.push_back(fVertices[i+4]+cf*( fVertices[i]-fVertices[i+4]));
     }
@@ -419,21 +381,21 @@ G4ThreeVector G4GenericTrap::SurfaceNormal( const G4ThreeVector& p ) const
     {
       sumnorm=G4ThreeVector(0,0,-1);
     }
-    noSurfaces ++;
+    ++noSurfaces;
   } 
 
   // Check lateral planes
   //
   std:: vector<G4TwoVector> vertices;  
   G4double cf = 0.5*(fDz-p.z())/fDz;
-  for (G4int i=0; i<4; i++)
+  for (auto i=0; i<4; ++i)
   {
     vertices.push_back(fVertices[i+4]+cf*(fVertices[i]-fVertices[i+4]));
   }
 
   // Compute distance for lateral planes
   //
-  for (G4int q=0; q<4; q++)
+  for (G4int q=0; q<4; ++q)
   {
     p0=G4ThreeVector(vertices[q].x(),vertices[q].y(),p.z());
     if(zPlusSide)
@@ -489,7 +451,7 @@ G4ThreeVector G4GenericTrap::SurfaceNormal( const G4ThreeVector& p ) const
     distxy=std::fabs((p0-p).dot(lnorm));
     if ( distxy<halfCarTolerance )
     {
-      noSurfaces ++;
+      ++noSurfaces;
 
       // Negative sign for Normal is taken for Outside Normal
       //
@@ -783,7 +745,7 @@ G4double G4GenericTrap::DistanceToIn(const G4ThreeVector& p,
   // Check lateral faces
   //
   G4int i;
-  for (i=0; i<4; i++)
+  for (i=0; i<4; ++i)
   {
     dist[i]=DistToPlane(p, v, i);  
   }
@@ -823,7 +785,7 @@ G4double G4GenericTrap::DistanceToIn(const G4ThreeVector& p,
     }
   }   
   G4double distmin = dist[0];
-  for (i=1;i<5;i++)
+  for (i=1; i<5 ; ++i)
   {
     if (dist[i] < distmin)  { distmin = dist[i]; }
   }
@@ -853,7 +815,7 @@ G4double G4GenericTrap::DistanceToIn(const G4ThreeVector& p) const
   G4double safe  = safz;
   G4double safxy = safz;
  
-  for (iseg=0; iseg<4; iseg++)
+  for (iseg=0; iseg<4; ++iseg)
   { 
     safxy = SafetyToFace(p,iseg);
     if (safxy>safe)  { safe=safxy; }
@@ -954,9 +916,9 @@ G4double G4GenericTrap::DistanceToOut(const G4ThreeVector& p,
 
   G4double distmin;
   G4bool lateral_cross = false;
-  ESide side = kUndefined;
+  ESide side = kUndef;
  
-  if (calcNorm)  { *validNorm=true; } // All normals are valid
+  if (calcNorm)  { *validNorm = true; } // All normals are valid
 
   if (v.z() < 0)
   {
@@ -977,7 +939,7 @@ G4double G4GenericTrap::DistanceToOut(const G4ThreeVector& p,
   G4double xa,xb,xc,xd;
   G4double ya,yb,yc,yd;
 
-  for (G4int ipl=0; ipl<4; ipl++)
+  for (G4int ipl=0; ipl<4; ++ipl)
   {
     G4int j = (ipl+1)%4;
     xa=fVertices[ipl].x();
@@ -1200,7 +1162,7 @@ G4double G4GenericTrap::DistanceToOut(const G4ThreeVector& p) const
   G4double safe  = safz;
   G4double safxy = safz;
  
-  for (G4int iseg=0; iseg<4; iseg++)
+  for (G4int iseg=0; iseg<4; ++iseg)
   { 
     safxy = std::fabs(SafetyToFace(p,iseg));
     if (safxy < safe)  { safe = safxy; }
@@ -1248,7 +1210,7 @@ G4GenericTrap::CalculateExtent(const EAxis pAxis,
   BoundingLimits(bmin,bmax);
   G4BoundingEnvelope bbox(bmin,bmax);
 #ifdef G4BBOX_EXTENT
-  if (true) return bbox.CalculateExtent(pAxis,pVoxelLimit,pTransform,pMin,pMax);
+  return bbox.CalculateExtent(pAxis,pVoxelLimit,pTransform,pMin,pMax);
 #endif
   if (bbox.BoundingBoxVsVoxelLimits(pAxis,pVoxelLimit,pTransform,pMin,pMax))
   {
@@ -1347,11 +1309,11 @@ G4ThreeVector G4GenericTrap::GetPointOnSurface() const
   G4int ipl,j;
  
   std::vector<G4ThreeVector> vertices;
-  for (G4int i=0; i<4;i++)
+  for (auto i=0; i<4; ++i)
   {
     vertices.push_back(G4ThreeVector(fVertices[i].x(),fVertices[i].y(),-fDz));
   }
-  for (G4int i=4; i<8;i++)
+  for (auto i=4; i<8; ++i)
   {
     vertices.push_back(G4ThreeVector(fVertices[i].x(),fVertices[i].y(),fDz));
   }
@@ -1421,10 +1383,14 @@ G4ThreeVector G4GenericTrap::GetPointOnSurface() const
 
 G4double G4GenericTrap::GetSurfaceArea()
 {
-  if (fSurfaceArea == 0.0) {
-    if(fIsTwisted) {
+  if (fSurfaceArea == 0.0)
+  {
+    if(fIsTwisted)
+    {
       fSurfaceArea = G4VSolid::GetSurfaceArea();
-    } else {
+    }
+     else
+    {
       // Set vertices
       G4ThreeVector vertix0(fVertices[0].x(),fVertices[0].y(),-fDz);
       G4ThreeVector vertix1(fVertices[1].x(),fVertices[1].y(),-fDz);
@@ -1451,10 +1417,14 @@ G4double G4GenericTrap::GetSurfaceArea()
 
 G4double G4GenericTrap::GetCubicVolume()
 {
-  if (fCubicVolume == 0.0) {
-    if(fIsTwisted) {
+  if (fCubicVolume == 0.0)
+  {
+    if(fIsTwisted)
+    {
       fCubicVolume = G4VSolid::GetCubicVolume();
-    } else {
+    }
+    else
+    {
       // Set vertices
       G4ThreeVector vertix0(fVertices[0].x(),fVertices[0].y(),-fDz);
       G4ThreeVector vertix1(fVertices[1].x(),fVertices[1].y(),-fDz);
@@ -1511,7 +1481,7 @@ G4bool G4GenericTrap::ComputeIsTwisted()
   G4double dx1, dy1, dx2, dy2;
   G4int nv = fgkNofVertices/2;
 
-  for ( G4int i=0; i<4; i++ )
+  for ( G4int i=0; i<4; ++i )
   {
     dx1 = fVertices[(i+1)%nv].x()-fVertices[i].x();
     dy1 = fVertices[(i+1)%nv].y()-fVertices[i].y();
@@ -1560,7 +1530,7 @@ G4bool G4GenericTrap::CheckOrder(const std::vector<G4TwoVector>& vertices) const
   G4double sum2 = 0.;
   G4int j;
 
-  for (G4int i=0; i<4; i++)
+  for (G4int i=0; i<4; ++i)
   {
     j = (i+1)%4;
     sum1 += vertices[i].x()*vertices[j].y() - vertices[j].x()*vertices[i].y();
@@ -1637,7 +1607,7 @@ void G4GenericTrap::ReorderVertices(std::vector<G4ThreeVector>& vertices) const
 
   std::vector<G4ThreeVector> oldVertices(vertices);
 
-  for ( G4int i=0; i < G4int(oldVertices.size()); ++i )
+  for ( size_t i=0; i<oldVertices.size(); ++i )
   {
     vertices[i] = oldVertices[oldVertices.size()-1-i];
   }  
@@ -1832,7 +1802,7 @@ G4GenericTrap::MakeUpFacet(const std::vector<G4ThreeVector>& fromVertices,
   //
   if ( (fromVertices[ind1] == fromVertices[ind2]) ||
        (fromVertices[ind2] == fromVertices[ind3]) ||
-       (fromVertices[ind1] == fromVertices[ind3]) )  { return 0; }
+       (fromVertices[ind1] == fromVertices[ind3]) )  { return nullptr; }
 
   std::vector<G4ThreeVector> vertices;
   vertices.push_back(fromVertices[ind1]);
@@ -1869,7 +1839,7 @@ G4GenericTrap::MakeSideFacet(const G4ThreeVector& downVertex0,
 
   if ( (downVertex0 == downVertex1) && (upVertex0 == upVertex1) )
   {
-    return 0;
+    return nullptr;
   }
 
   if ( downVertex0 == downVertex1 )
@@ -1894,14 +1864,14 @@ G4TessellatedSolid* G4GenericTrap::CreateTessellatedSolid() const
   //
   G4int nv = fgkNofVertices/2;
   std::vector<G4ThreeVector> downVertices;
-  for ( G4int i=0; i<nv; i++ )
+  for ( G4int i=0; i<nv; ++i )
   { 
     downVertices.push_back(G4ThreeVector(fVertices[i].x(),
                                          fVertices[i].y(), -fDz));
   }
 
   std::vector<G4ThreeVector> upVertices;
-  for ( G4int i=nv; i<2*nv; i++ )
+  for ( G4int i=nv; i<2*nv; ++i )
   { 
     upVertices.push_back(G4ThreeVector(fVertices[i].x(),
                                        fVertices[i].y(), fDz));
@@ -1980,7 +1950,7 @@ G4Polyhedron* G4GenericTrap::GetPolyhedron () const
   }
 #endif  
   
-  if ( (!fpPolyhedron)
+  if ( (fpPolyhedron == nullptr)
     || fRebuildPolyhedron
     || (fpPolyhedron->GetNumberOfRotationStepsAtTimeOfCreation() !=
         fpPolyhedron->GetNumberOfRotationSteps()) )
@@ -2016,7 +1986,7 @@ G4VisExtent G4GenericTrap::GetExtent() const
   // Computes bounding vectors for the shape
 
 #ifdef G4TESS_TEST
-  if ( fTessellatedSolid )
+  if ( fTessellatedSolid != nullptr )
   { 
     return fTessellatedSolid->GetExtent();
   } 
@@ -2035,7 +2005,7 @@ G4Polyhedron* G4GenericTrap::CreatePolyhedron() const
 {
 
 #ifdef G4TESS_TEST
-  if ( fTessellatedSolid )
+  if ( fTessellatedSolid != nullptr )
   { 
     return fTessellatedSolid->CreatePolyhedron();
   }  
@@ -2060,7 +2030,7 @@ G4Polyhedron* G4GenericTrap::CreatePolyhedron() const
       // Estimation of Number of Subdivisions for smooth visualisation
       //
       G4double maxTwist=0.;
-      for(i=0; i<4; i++)
+      for(i=0; i<4; ++i)
       {
         if(GetTwistAngle(i)>maxTwist) { maxTwist=GetTwistAngle(i); }
       }
@@ -2087,12 +2057,12 @@ G4Polyhedron* G4GenericTrap::CreatePolyhedron() const
 
   // Add Vertex
   //
-  for (i=0;i<4;i++)
+  for (i=0; i<4; ++i)
   {
     polyhedron->AddVertex(G4ThreeVector(fVertices[i].x(),
                                         fVertices[i].y(),-fDz));
   }
-  for( i=0;i<subdivisions;i++)
+  for( i=0; i<subdivisions; ++i)
   {
     for(G4int j=0;j<4;j++)
     {
@@ -2100,7 +2070,7 @@ G4Polyhedron* G4GenericTrap::CreatePolyhedron() const
       polyhedron->AddVertex(G4ThreeVector(u.x(),u.y(),-fDz+cf*2*fDz*(i+1)));
     }    
   }
-  for (i=4;i<8;i++)
+  for (i=4; i<8; ++i)
   {
     polyhedron->AddVertex(G4ThreeVector(fVertices[i].x(),
                                         fVertices[i].y(),fDz));
@@ -2109,7 +2079,7 @@ G4Polyhedron* G4GenericTrap::CreatePolyhedron() const
   // Add Facets
   //
   polyhedron->AddFacet(1,4,3,2);  //Z-plane
-  for (i=0;i<subdivisions+1;i++)
+  for (i=0; i<subdivisions+1; ++i)
   {
     G4int is=i*4;
     polyhedron->AddFacet(5+is,8+is,4+is,1+is);
