@@ -24,36 +24,10 @@
 // * acceptance of all terms of the Geant4 Software license.          *
 // ********************************************************************
 //
+// G4TessellatedSolid implementation
 //
-// %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
-//
-// CHANGE HISTORY
-// --------------
-// 23 October 2016,   E Tcherniaev, reimplemented CalculateExtent() to make
-//                    use of G4BoundingEnvelope.
-//
-// 12 October 2012,   M Gayer, CERN, complete rewrite reducing memory
-//                    requirements more than 50% and speedup by a factor of
-//                    tens or more depending on the number of facets, thanks
-//                    to voxelization of surface and improvements. 
-//                    Speedup factor of thousands for solids with number of
-//                    facets in hundreds of thousands.
-//
-// 22 August 2011,    I Hrivnacova, Orsay, fix in DistanceToOut(p) and
-//                    DistanceToIn(p) to exactly compute distance from facet
-//                    avoiding use of 'outgoing' flag shortcut variant.
-//
-// 04 August 2011,    T Nikitina, CERN, added SetReferences() to
-//                    CreatePolyhedron() for Visualization of Boolean Operations  
-//
-// 12 April 2010,     P R Truscott, QinetiQ, bug fixes to treat optical
-//                    photon transport, in particular internal reflection
-//                    at surface.
-//
-// 14 November 2007,  P R Truscott, QinetiQ & Stan Seibert, U Texas
-//                    Bug fixes to CalculateExtent
-//
-// 17 September 2007, P R Truscott, QinetiQ Ltd & Richard Holmberg
+// 31.10.2004, P R Truscott, QinetiQ Ltd, UK - Created.
+// 17.09.2007, P R Truscott, QinetiQ Ltd & Richard Holmberg
 //                    Updated extensively prior to this date to deal with
 //                    concaved tessellated surfaces, based on the algorithm
 //                    of Richard Holmberg.  This had been slightly modified
@@ -61,15 +35,15 @@
 //                    random rays from the point provided.  Now random rays
 //                    are predefined rather than making use of random
 //                    number generator at run-time.
-//
-// 22 November 2005, F Lei
-//  - Changed ::DescribeYourselfTo(), line 464
-//  - added GetPolyHedron()
-// 
-// 31 October 2004, P R Truscott, QinetiQ Ltd, UK
-//  - Created.
-//
-// %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+// 12.10.2012, M Gayer, CERN, complete rewrite reducing memory
+//                    requirements more than 50% and speedup by a factor of
+//                    tens or more depending on the number of facets, thanks
+//                    to voxelization of surface and improvements. 
+//                    Speedup factor of thousands for solids with number of
+//                    facets in hundreds of thousands.
+// 23.10.2016, E Tcherniaev, reimplemented CalculateExtent() to make
+//                    use of G4BoundingEnvelope.
+// --------------------------------------------------------------------
 
 #include "G4TessellatedSolid.hh"
 
@@ -88,7 +62,6 @@
 #include "G4SystemOfUnits.hh"
 #include "G4PhysicalConstants.hh"
 #include "G4GeometryTolerance.hh"
-#include "G4VFacet.hh"
 #include "G4VoxelLimits.hh"
 #include "G4AffineTransform.hh"
 #include "G4BoundingEnvelope.hh"
@@ -120,7 +93,7 @@ G4TessellatedSolid::G4TessellatedSolid () : G4VSolid("dummy")
 // Alternative constructor. Simple define name and geometry type - no fFacets
 // to detine.
 //
-G4TessellatedSolid::G4TessellatedSolid (const G4String &name)
+G4TessellatedSolid::G4TessellatedSolid (const G4String& name)
   : G4VSolid(name)
 {
   Initialize();
@@ -140,17 +113,17 @@ G4TessellatedSolid::G4TessellatedSolid( __void__& a) : G4VSolid(a)
 
 
 ///////////////////////////////////////////////////////////////////////////////
-G4TessellatedSolid::~G4TessellatedSolid ()
+G4TessellatedSolid::~G4TessellatedSolid()
 {
-  DeleteObjects ();
+  DeleteObjects();
 }
 
 ///////////////////////////////////////////////////////////////////////////////
 //
 // Copy constructor.
 //
-G4TessellatedSolid::G4TessellatedSolid (const G4TessellatedSolid &ts)
-  : G4VSolid(ts), fpPolyhedron(0)
+G4TessellatedSolid::G4TessellatedSolid (const G4TessellatedSolid& ts)
+  : G4VSolid(ts)
 {
   Initialize();
 
@@ -184,7 +157,7 @@ void G4TessellatedSolid::Initialize()
 {
   kCarToleranceHalf = 0.5*kCarTolerance;
 
-  fRebuildPolyhedron = false; fpPolyhedron = 0;
+  fRebuildPolyhedron = false; fpPolyhedron = nullptr;
   fCubicVolume = 0.; fSurfaceArea = 0.;
 
   fGeometryType = "G4TessellatedSolid";
@@ -198,12 +171,12 @@ void G4TessellatedSolid::Initialize()
 
 ///////////////////////////////////////////////////////////////////////////////
 //
-void G4TessellatedSolid::DeleteObjects ()
+void G4TessellatedSolid::DeleteObjects()
 {
   G4int size = fFacets.size();
   for (G4int i = 0; i < size; ++i)  { delete fFacets[i]; }
   fFacets.clear();
-  delete fpPolyhedron; fpPolyhedron = 0;
+  delete fpPolyhedron; fpPolyhedron = nullptr;
 }
 
 ///////////////////////////////////////////////////////////////////////////////
@@ -231,7 +204,7 @@ void G4TessellatedSolid::CopyObjects (const G4TessellatedSolid &ts)
 // Add a facet to the facet list.
 // Note that you can add, but you cannot delete.
 //
-G4bool G4TessellatedSolid::AddFacet (G4VFacet *aFacet)
+G4bool G4TessellatedSolid::AddFacet (G4VFacet* aFacet)
 {
   // Add the facet to the vector.
   //
@@ -290,7 +263,6 @@ G4bool G4TessellatedSolid::AddFacet (G4VFacet *aFacet)
       fFacets.push_back(aFacet);
       fFacetList.insert(value);
     }
-
     return true;
   }
   else
@@ -304,9 +276,9 @@ G4bool G4TessellatedSolid::AddFacet (G4VFacet *aFacet)
 
 ///////////////////////////////////////////////////////////////////////////////
 //
-G4int G4TessellatedSolid::SetAllUsingStack(const std::vector<G4int> &voxel,
-                                           const std::vector<G4int> &max,
-                                           G4bool status, G4SurfBits &checked)
+G4int G4TessellatedSolid::SetAllUsingStack(const std::vector<G4int>& voxel,
+                                           const std::vector<G4int>& max,
+                                           G4bool status, G4SurfBits& checked)
 {
   vector<G4int> xyz = voxel;
   stack<vector<G4int> > pos;
@@ -324,15 +296,15 @@ G4int G4TessellatedSolid::SetAllUsingStack(const std::vector<G4int> &voxel,
     if (!checked[index])
     {
       checked.SetBitNumber(index, true);
-      cc++;
+      ++cc;
 
       if (fVoxels.IsEmpty(index))
       {
-        filled++;
+        ++filled;
 
         fInsides.SetBitNumber(index, status);
 
-        for (G4int i = 0; i <= 2; ++i)
+        for (auto i = 0; i <= 2; ++i)
         {
           if (xyz[i] < max[i] - 1)
           {
@@ -351,7 +323,7 @@ G4int G4TessellatedSolid::SetAllUsingStack(const std::vector<G4int> &voxel,
       }
       else
       {
-        nz++;
+        ++nz;
       }
     }
   }
@@ -363,7 +335,7 @@ G4int G4TessellatedSolid::SetAllUsingStack(const std::vector<G4int> &voxel,
 void G4TessellatedSolid::PrecalculateInsides()
 {
   vector<G4int> voxel(3), maxVoxels(3);
-  for (G4int i = 0; i <= 2; ++i) maxVoxels[i] = fVoxels.GetBoundary(i).size();
+  for (auto i = 0; i <= 2; ++i) maxVoxels[i] = fVoxels.GetBoundary(i).size();
   G4int size = maxVoxels[0] * maxVoxels[1] * maxVoxels[2];
 
   G4SurfBits checked(size-1);
@@ -380,7 +352,7 @@ void G4TessellatedSolid::PrecalculateInsides()
         G4int index = fVoxels.GetVoxelsIndex(voxel);
         if (!checked[index] && fVoxels.IsEmpty(index))
         {
-          for (G4int i = 0; i <= 2; ++i)
+          for (auto i = 0; i <= 2; ++i)
           {
             point[i] = fVoxels.GetBoundary(i)[voxel[i]];
           }
@@ -511,7 +483,7 @@ void G4TessellatedSolid::CreateVertexList()
             G4double dif = (q-p).mag2();
             found = (dif < kCarTolerance24);
             if (found) break;
-        dif = value.mag2 - (q.x() + q.y() + q.z());
+            dif = value.mag2 - (q.x() + q.y() + q.z());
             if (dif > kCarTolerance3) break;
           }
         }
@@ -558,15 +530,14 @@ void G4TessellatedSolid::CreateVertexList()
     // only now it is possible to change vertices pointer
     //
     facet.SetVertices(&fVertexList);
-    for (G4int i = 0; i < max; i++)
-        facet.SetVertexIndex(i,newIndex[i]);
+    for (G4int i = 0; i < max; ++i)
+      facet.SetVertexIndex(i,newIndex[i]);
   }
   vector<G4ThreeVector>(fVertexList).swap(fVertexList);
   
 #ifdef G4SPECSDEBUG
-  G4double previousValue = 0;
-  for (set<G4VertexInfo,G4VertexComparator>::iterator res=
-       vertexListSorted.begin(); res!=vertexListSorted.end(); ++res)
+  G4double previousValue = 0.;
+  for (auto res=vertexListSorted.cbegin(); res!=vertexListSorted.cend(); ++res)
   {
     G4int id = (*res).id;
     G4ThreeVector vec = fVertexList[id];
@@ -639,8 +610,8 @@ G4bool G4TessellatedSolid::GetSolidClosed () const
 // on the right.  Note that copies of the facets are generated, rather than
 // using the original facet set of the solid on the right.
 //
-G4TessellatedSolid &
-G4TessellatedSolid::operator+=(const G4TessellatedSolid &right)
+G4TessellatedSolid&
+G4TessellatedSolid::operator+=(const G4TessellatedSolid& right)
 {
   G4int size = right.GetNumberOfFacets();
   for (G4int i = 0; i < size; ++i)
@@ -653,14 +624,14 @@ G4TessellatedSolid::operator+=(const G4TessellatedSolid &right)
 //
 // GetNumberOfFacets
 //
-G4int G4TessellatedSolid::GetNumberOfFacets () const
+G4int G4TessellatedSolid::GetNumberOfFacets() const
 {
   return fFacets.size();
 }
 
 ///////////////////////////////////////////////////////////////////////////////
 //
-EInside G4TessellatedSolid::InsideVoxels(const G4ThreeVector &p) const
+EInside G4TessellatedSolid::InsideVoxels(const G4ThreeVector& p) const
 {
   //
   // First the simple test - check if we're outside of the X-Y-Z extremes
@@ -727,8 +698,8 @@ EInside G4TessellatedSolid::InsideVoxels(const G4ThreeVector &p) const
     // are 20 random directions to select from - hopefully sufficient.
     //
     distOut = distIn = kInfinity;
-    const G4ThreeVector &v = fRandir[sm];
-    sm++;
+    const G4ThreeVector& v = fRandir[sm];
+    ++sm;
     //
     // This code could be voxelized by the same algorithm, which is used for
     // DistanceToOut(). We will traverse through fVoxels. we will call
@@ -756,7 +727,7 @@ EInside G4TessellatedSolid::InsideVoxels(const G4ThreeVector &p) const
         {
           G4int candidate = candidates[i];
           // bits.SetBitNumber(candidate);
-          G4VFacet &facet = *fFacets[candidate];
+          G4VFacet& facet = *fFacets[candidate];
 
           crossingO = facet.Intersect(p,v,true,distO,distFromSurfaceO,normalO);
           crossingI = facet.Intersect(p,v,false,distI,distFromSurfaceI,normalI);
@@ -799,7 +770,7 @@ EInside G4TessellatedSolid::InsideVoxels(const G4ThreeVector &p) const
     while (fVoxels.UpdateCurrentVoxel(currentPoint, direction, curVoxel));
 
   }
-  while (nearParallel && sm!=fMaxTries);
+  while (nearParallel && sm != fMaxTries);
   //
   // Here we loop through the facets to find out if there is an intersection
   // between the ray and that facet.  The test if performed separately whether
@@ -869,7 +840,7 @@ EInside G4TessellatedSolid::InsideNoVoxels (const G4ThreeVector &p) const
   G4int size = fFacets.size();
   for (G4int i = 0; i < size; ++i)
   {
-    G4VFacet &facet = *fFacets[i];
+    G4VFacet& facet = *fFacets[i];
     G4double dist = facet.Distance(p,minDist);
     if (dist < minDist) minDist = dist;
     if (dist <= kCarToleranceHalf)
@@ -918,7 +889,7 @@ EInside G4TessellatedSolid::InsideNoVoxels (const G4ThreeVector &p) const
       // case is that the angles should be sufficiently different, but there
       // are 20 random directions to select from - hopefully sufficient.
       //
-      distOut =  distIn = kInfinity;
+      distOut = distIn = kInfinity;
       G4ThreeVector v = fRandir[sm];
       sm++;
       vector<G4VFacet*>::const_iterator f = fFacets.begin();
@@ -942,8 +913,8 @@ EInside G4TessellatedSolid::InsideNoVoxels (const G4ThreeVector &p) const
             if (crossingI && distI > 0.0 && distI < distIn)  distIn  = distI;
           }
         }
-      } while (!nearParallel && ++f!=fFacets.end());
-    } while (nearParallel && sm!=fMaxTries);
+      } while (!nearParallel && ++f != fFacets.end());
+    } while (nearParallel && sm != fMaxTries);
 
 #ifdef G4VERBOSE
     if (sm == fMaxTries)
@@ -997,11 +968,11 @@ EInside G4TessellatedSolid::InsideNoVoxels (const G4ThreeVector &p) const
 // Return the outwards pointing unit normal of the shape for the
 // surface closest to the point at offset p.
 //
-G4bool G4TessellatedSolid::Normal (const G4ThreeVector &p,
-                                         G4ThreeVector &aNormal) const
+G4bool G4TessellatedSolid::Normal (const G4ThreeVector& p,
+                                         G4ThreeVector& aNormal) const
 {
   G4double minDist;
-  G4VFacet *facet = 0;
+  G4VFacet* facet = nullptr;
 
   if (fVoxels.GetCountOfVoxels() > 1)
   {
@@ -1034,7 +1005,7 @@ G4bool G4TessellatedSolid::Normal (const G4ThreeVector &p,
     G4int size = fFacets.size();
     for (G4int i = 0; i < size; ++i)
     {
-      G4VFacet &f = *fFacets[i];
+      G4VFacet& f = *fFacets[i];
       G4double dist = f.Distance(p, minDist);
       if (dist < minDist)
       {
@@ -1076,8 +1047,8 @@ G4bool G4TessellatedSolid::Normal (const G4ThreeVector &p,
 // surface of shape.
 //
 G4double
-G4TessellatedSolid::DistanceToInNoVoxels (const G4ThreeVector &p,
-                                          const G4ThreeVector &v,
+G4TessellatedSolid::DistanceToInNoVoxels (const G4ThreeVector& p,
+                                          const G4ThreeVector& v,
                                                 G4double /*aPstep*/) const
 {
   G4double minDist         = kInfinity;
@@ -1105,7 +1076,7 @@ G4TessellatedSolid::DistanceToInNoVoxels (const G4ThreeVector &p,
   G4int size = fFacets.size();
   for (G4int i = 0; i < size; ++i)
   {
-    G4VFacet &facet = *fFacets[i];
+    G4VFacet& facet = *fFacets[i];
     if (facet.Intersect(p,v,false,dist,distFromSurface,normal))
     {
       //
@@ -1142,10 +1113,10 @@ G4TessellatedSolid::DistanceToInNoVoxels (const G4ThreeVector &p,
 ///////////////////////////////////////////////////////////////////////////////
 //
 G4double
-G4TessellatedSolid::DistanceToOutNoVoxels (const G4ThreeVector &p,
-                                           const G4ThreeVector &v,
-                                                 G4ThreeVector &aNormalVector,
-                                                 G4bool &aConvex,
+G4TessellatedSolid::DistanceToOutNoVoxels (const G4ThreeVector& p,
+                                           const G4ThreeVector& v,
+                                                 G4ThreeVector& aNormalVector,
+                                                 G4bool& aConvex,
                                                  G4double /*aPstep*/) const
 {
   G4double minDist         = kInfinity;
@@ -1174,11 +1145,11 @@ G4TessellatedSolid::DistanceToOutNoVoxels (const G4ThreeVector &p,
   G4int size = fFacets.size();
   for (G4int i = 0; i < size; ++i)
   {
-    G4VFacet &facet = *fFacets[i];
+    G4VFacet& facet = *fFacets[i];
     if (facet.Intersect(p,v,true,dist,distFromSurface,normal))
     {
-      if (distFromSurface > 0.0 && distFromSurface <= kCarToleranceHalf &&
-        facet.Distance(p,kCarTolerance) <= kCarToleranceHalf)
+      if (distFromSurface > 0.0 && distFromSurface <= kCarToleranceHalf
+        && facet.Distance(p,kCarTolerance) <= kCarToleranceHalf)
       {
         // We are on a surface. Return zero.
         aConvex = (fExtremeFacets.find(&facet) != fExtremeFacets.end());
@@ -1213,11 +1184,11 @@ G4TessellatedSolid::DistanceToOutNoVoxels (const G4ThreeVector &p,
 ///////////////////////////////////////////////////////////////////////////////
 //
 void G4TessellatedSolid::
-DistanceToOutCandidates(const std::vector<G4int> &candidates,
-                        const G4ThreeVector &aPoint,
-                        const G4ThreeVector &direction,
-                              G4double &minDist, G4ThreeVector &minNormal,
-                              G4int &minCandidate ) const
+DistanceToOutCandidates(const std::vector<G4int>& candidates,
+                        const G4ThreeVector& aPoint,
+                        const G4ThreeVector& direction,
+                              G4double& minDist, G4ThreeVector& minNormal,
+                              G4int& minCandidate ) const
 {
   G4int candidatesCount = candidates.size();
   G4double dist            = 0.0;
@@ -1227,7 +1198,7 @@ DistanceToOutCandidates(const std::vector<G4int> &candidates,
   for (G4int i = 0 ; i < candidatesCount; ++i)
   {
     G4int candidate = candidates[i];
-    G4VFacet &facet = *fFacets[candidate];
+    G4VFacet& facet = *fFacets[candidate];
     if (facet.Intersect(aPoint,direction,true,dist,distFromSurface,normal))
     {
       if (distFromSurface > 0.0 && distFromSurface <= kCarToleranceHalf
@@ -1253,9 +1224,9 @@ DistanceToOutCandidates(const std::vector<G4int> &candidates,
 ///////////////////////////////////////////////////////////////////////////////
 //
 G4double
-G4TessellatedSolid::DistanceToOutCore(const G4ThreeVector &aPoint,
-                                      const G4ThreeVector &aDirection,
-                                            G4ThreeVector &aNormalVector,
+G4TessellatedSolid::DistanceToOutCore(const G4ThreeVector& aPoint,
+                                      const G4ThreeVector& aDirection,
+                                            G4ThreeVector& aNormalVector,
                                             G4bool &aConvex,
                                             G4double aPstep) const
 {
@@ -1267,22 +1238,22 @@ G4TessellatedSolid::DistanceToOutCore(const G4ThreeVector &aPoint,
 
     G4ThreeVector currentPoint = aPoint;
     G4ThreeVector direction = aDirection.unit();
-    G4double totalShift = 0;
+    G4double totalShift = 0.;
     vector<G4int> curVoxel(3);
-    if (!fVoxels.Contains(aPoint)) return 0;
+    if (!fVoxels.Contains(aPoint)) return 0.;
 
     fVoxels.GetVoxel(curVoxel, currentPoint);
 
     G4double shiftBonus = kCarTolerance;
 
-    const vector<G4int> *old = 0;
+    const vector<G4int>* old = nullptr;
 
     G4int minCandidate = -1;
     do    // Loop checking, 13.08.2015, G.Cosmo
     {
-      const vector<G4int> &candidates = fVoxels.GetCandidates(curVoxel);
+      const vector<G4int>& candidates = fVoxels.GetCandidates(curVoxel);
       if (old == &candidates)
-        old++;
+        ++old;
       if (old != &candidates && candidates.size())
       {
         DistanceToOutCandidates(candidates, aPoint, direction, minDistance,
@@ -1305,7 +1276,7 @@ G4TessellatedSolid::DistanceToOutCore(const G4ThreeVector &aPoint,
     if (minCandidate < 0)
     {
       // No intersection found
-      minDistance = 0;
+      minDistance = 0.;
       aConvex = false;
       Normal(aPoint, aNormalVector);
     }
@@ -1326,9 +1297,9 @@ G4TessellatedSolid::DistanceToOutCore(const G4ThreeVector &aPoint,
 ///////////////////////////////////////////////////////////////////////////////
 //
 G4double G4TessellatedSolid::
-DistanceToInCandidates(const std::vector<G4int> &candidates,
-                       const G4ThreeVector &aPoint,
-                       const G4ThreeVector &direction) const
+DistanceToInCandidates(const std::vector<G4int>& candidates,
+                       const G4ThreeVector& aPoint,
+                       const G4ThreeVector& direction) const
 {
   G4int candidatesCount = candidates.size();
   G4double dist            = 0.0;
@@ -1339,7 +1310,7 @@ DistanceToInCandidates(const std::vector<G4int> &candidates,
   for (G4int i = 0 ; i < candidatesCount; ++i)
   {
     G4int candidate = candidates[i];
-    G4VFacet &facet = *fFacets[candidate];
+    G4VFacet& facet = *fFacets[candidate];
     if (facet.Intersect(aPoint,direction,false,dist,distFromSurface,normal))
     {
       //
@@ -1374,8 +1345,8 @@ DistanceToInCandidates(const std::vector<G4int> &candidates,
 ///////////////////////////////////////////////////////////////////////////////
 //
 G4double
-G4TessellatedSolid::DistanceToInCore(const G4ThreeVector &aPoint,
-                                     const G4ThreeVector &aDirection,
+G4TessellatedSolid::DistanceToInCore(const G4ThreeVector& aPoint,
+                                     const G4ThreeVector& aDirection,
                                            G4double aPstep) const
 {
   G4double minDistance;
@@ -1399,7 +1370,7 @@ G4TessellatedSolid::DistanceToInCore(const G4ThreeVector &aPoint,
     fVoxels.GetVoxel(curVoxel, currentPoint);
     do    // Loop checking, 13.08.2015, G.Cosmo
     {
-      const vector<G4int> &candidates = fVoxels.GetCandidates(curVoxel);
+      const vector<G4int>& candidates = fVoxels.GetCandidates(curVoxel);
       if (candidates.size())
       {
         G4double distance=DistanceToInCandidates(candidates, aPoint, direction);
@@ -1428,8 +1399,8 @@ G4TessellatedSolid::DistanceToInCore(const G4ThreeVector &aPoint,
 ///////////////////////////////////////////////////////////////////////////////
 //
 G4bool
-G4TessellatedSolid::CompareSortedVoxel(const std::pair<G4int, G4double> &l,
-                                       const std::pair<G4int, G4double> &r)
+G4TessellatedSolid::CompareSortedVoxel(const std::pair<G4int, G4double>& l,
+                                       const std::pair<G4int, G4double>& r)
 {
   return l.second < r.second;
 }
@@ -1437,9 +1408,9 @@ G4TessellatedSolid::CompareSortedVoxel(const std::pair<G4int, G4double> &l,
 ///////////////////////////////////////////////////////////////////////////////
 //
 G4double
-G4TessellatedSolid::MinDistanceFacet(const G4ThreeVector &p,
+G4TessellatedSolid::MinDistanceFacet(const G4ThreeVector& p,
                                            G4bool simple,
-                                           G4VFacet * &minFacet) const
+                                           G4VFacet* &minFacet) const
 {
   G4double minDist = kInfinity;
 
@@ -1450,7 +1421,7 @@ G4TessellatedSolid::MinDistanceFacet(const G4ThreeVector &p,
 
   for (G4int i = 0; i < size; ++i)
   {
-    const G4VoxelBox &voxelBox = fVoxels.GetVoxelBox(i);
+    const G4VoxelBox& voxelBox = fVoxels.GetVoxelBox(i);
 
     G4ThreeVector pointShifted = p - voxelBox.pos;
     G4double safety = fVoxels.MinDistanceToBox(pointShifted, voxelBox.hlen);
@@ -1464,16 +1435,16 @@ G4TessellatedSolid::MinDistanceFacet(const G4ThreeVector &p,
 
   for (G4int i = 0; i < size; ++i)
   {
-    const pair<G4int,G4double> &inf = voxelsSorted[i];
+    const pair<G4int,G4double>& inf = voxelsSorted[i];
     G4double dist = inf.second;
     if (dist > minDist) break;
 
-    const vector<G4int> &candidates = fVoxels.GetVoxelBoxCandidates(inf.first);
+    const vector<G4int>& candidates = fVoxels.GetVoxelBoxCandidates(inf.first);
     G4int csize = candidates.size();
     for (G4int j = 0; j < csize; ++j)
     {
       G4int candidate = candidates[j];
-      G4VFacet &facet = *fFacets[candidate];
+      G4VFacet& facet = *fFacets[candidate];
       dist = simple ? facet.Distance(p,minDist)
                     : facet.Distance(p,minDist,false);
       if (dist < minDist)
@@ -1488,7 +1459,7 @@ G4TessellatedSolid::MinDistanceFacet(const G4ThreeVector &p,
 
 ///////////////////////////////////////////////////////////////////////////////
 //
-G4double G4TessellatedSolid::SafetyFromOutside (const G4ThreeVector &p,
+G4double G4TessellatedSolid::SafetyFromOutside (const G4ThreeVector& p,
                                                       G4bool aAccurate) const
 {
 #if G4SPECSDEBUG
@@ -1527,7 +1498,7 @@ G4double G4TessellatedSolid::SafetyFromOutside (const G4ThreeVector &p,
       }
     }
 
-    G4VFacet *facet;
+    G4VFacet* facet;
     minDist = MinDistanceFacet(p, true, facet);
   }
   else
@@ -1536,9 +1507,9 @@ G4double G4TessellatedSolid::SafetyFromOutside (const G4ThreeVector &p,
     G4int size = fFacets.size();
     for (G4int i = 0; i < size; ++i)
     {
-      G4VFacet &facet = *fFacets[i];
+      G4VFacet& facet = *fFacets[i];
       G4double dist = facet.Distance(p,minDist);
-      if (dist < minDist) minDist  = dist;
+      if (dist < minDist) minDist = dist;
     }
   }
   return minDist;
@@ -1547,7 +1518,7 @@ G4double G4TessellatedSolid::SafetyFromOutside (const G4ThreeVector &p,
 ///////////////////////////////////////////////////////////////////////////////
 //
 G4double
-G4TessellatedSolid::SafetyFromInside (const G4ThreeVector &p, G4bool) const
+G4TessellatedSolid::SafetyFromInside (const G4ThreeVector& p, G4bool) const
 {  
 #if G4SPECSDEBUG
   if ( Inside(p) == kOutside )
@@ -1572,7 +1543,7 @@ G4TessellatedSolid::SafetyFromInside (const G4ThreeVector &p, G4bool) const
 
   if (fVoxels.GetCountOfVoxels() > 1)
   {
-    G4VFacet *facet;
+    G4VFacet* facet;
     minDist = MinDistanceFacet(p, true, facet);
   }
   else
@@ -1582,7 +1553,7 @@ G4TessellatedSolid::SafetyFromInside (const G4ThreeVector &p, G4bool) const
     G4int size = fFacets.size();
     for (G4int i = 0; i < size; ++i)
     {
-      G4VFacet &facet = *fFacets[i];
+      G4VFacet& facet = *fFacets[i];
       dist = facet.Distance(p,minDist);
       if (dist < minDist) minDist  = dist;
     }
@@ -1641,7 +1612,7 @@ G4VSolid* G4TessellatedSolid::Clone() const
 //    * kSurface if the point is <= kCarTolerance/2 from a surface, or
 //    * kInside otherwise.
 //
-EInside G4TessellatedSolid::Inside (const G4ThreeVector &aPoint) const
+EInside G4TessellatedSolid::Inside (const G4ThreeVector& aPoint) const
 {
   EInside location;
 
@@ -1674,7 +1645,7 @@ G4ThreeVector G4TessellatedSolid::SurfaceNormal(const G4ThreeVector& p) const
 //
 G4double G4TessellatedSolid::DistanceToIn(const G4ThreeVector& p) const
 {
-  return SafetyFromOutside(p,false);
+  return SafetyFromOutside(p, false);
 }
 
 ///////////////////////////////////////////////////////////////////////////////
@@ -1709,7 +1680,7 @@ G4double G4TessellatedSolid::DistanceToIn(const G4ThreeVector& p,
 //
 G4double G4TessellatedSolid::DistanceToOut(const G4ThreeVector& p) const
 {
-  return SafetyFromInside(p,false);
+  return SafetyFromInside(p, false);
 }
 
 ///////////////////////////////////////////////////////////////////////////////
@@ -1733,8 +1704,8 @@ G4double G4TessellatedSolid::DistanceToOut(const G4ThreeVector& p) const
 G4double G4TessellatedSolid::DistanceToOut(const G4ThreeVector& p,
                                            const G4ThreeVector& v,
                                            const G4bool calcNorm,
-                                                 G4bool *validNorm,
-                                                 G4ThreeVector *norm) const
+                                                 G4bool* validNorm,
+                                                 G4ThreeVector* norm) const
 {
   G4ThreeVector n;
   G4bool valid;
@@ -1775,10 +1746,9 @@ G4Polyhedron *G4TessellatedSolid::CreatePolyhedron () const
 {
   G4int nVertices = fVertexList.size();
   G4int nFacets   = fFacets.size();
-  G4PolyhedronArbitrary *polyhedron =
+  G4PolyhedronArbitrary* polyhedron =
     new G4PolyhedronArbitrary (nVertices, nFacets);
-  for (G4ThreeVectorList::const_iterator v= fVertexList.begin();
-                                         v!=fVertexList.end(); ++v)
+  for (auto v= fVertexList.cbegin(); v!=fVertexList.cend(); ++v)
   {
     polyhedron->AddVertex(*v);
   }
@@ -1787,10 +1757,9 @@ G4Polyhedron *G4TessellatedSolid::CreatePolyhedron () const
   for (G4int i = 0; i < size; ++i)
   {
     G4VFacet* facet = fFacets[i];
-    G4int v[4];
+    G4int v[4] = {0};
     G4int n = facet->GetNumberOfVertices();
     if (n > 4) n = 4;
-    else if (n == 3) v[3] = 0;
     for (G4int j=0; j<n; ++j)
     {
       G4int k = facet->GetVertexIndex(j);
@@ -1807,9 +1776,9 @@ G4Polyhedron *G4TessellatedSolid::CreatePolyhedron () const
 //
 // GetPolyhedron
 //
-G4Polyhedron* G4TessellatedSolid::GetPolyhedron () const
+G4Polyhedron* G4TessellatedSolid::GetPolyhedron() const
 {
-  if (!fpPolyhedron ||
+  if (fpPolyhedron == nullptr ||
       fRebuildPolyhedron ||
       fpPolyhedron->GetNumberOfRotationStepsAtTimeOfCreation() !=
       fpPolyhedron->GetNumberOfRotationSteps())
@@ -1859,18 +1828,22 @@ G4TessellatedSolid::CalculateExtent(const EAxis pAxis,
                                           G4double& pMin, G4double& pMax) const
 {
   G4ThreeVector bmin, bmax;
-  G4bool exist;
 
   // Check bounding box (bbox)
   //
   BoundingLimits(bmin,bmax);
   G4BoundingEnvelope bbox(bmin,bmax);
-#ifdef G4BBOX_EXTENT
-  if (true) return bbox.CalculateExtent(pAxis,pVoxelLimit,pTransform,pMin,pMax);
-#endif
+
+  // Use simple bounding-box to help in the case of complex meshes
+  //
+  return bbox.CalculateExtent(pAxis,pVoxelLimit,pTransform,pMin,pMax);
+
+#if 0
+  // Precise extent computation (disabled by default for this shape)
+  //
   if (bbox.BoundingBoxVsVoxelLimits(pAxis,pVoxelLimit,pTransform,pMin,pMax))
   {
-    return exist = (pMin < pMax) ? true : false;
+    return (pMin < pMax) ? true : false;
   }
 
   // The extent is calculated as cumulative extent of the pyramids
@@ -1907,6 +1880,7 @@ G4TessellatedSolid::CalculateExtent(const EAxis pAxis,
     if (eminlim > pMin && emaxlim < pMax) break; // max possible extent
   }
   return (pMin < pMax);
+#endif
 }
 
 ///////////////////////////////////////////////////////////////////////////////
@@ -2072,16 +2046,13 @@ G4int G4TessellatedSolid::AllocatedMemoryWithoutVoxels()
   base += fRandir.capacity() * sizeof(G4ThreeVector);
 
   G4int limit = fFacets.size();
-  for (G4int i = 0; i < limit; i++)
+  for (G4int i = 0; i < limit; ++i)
   {
-    G4VFacet &facet = *fFacets[i];
+    G4VFacet& facet = *fFacets[i];
     base += facet.AllocatedMemory();
   }
 
-  std::set<G4VFacet *>::const_iterator beg, end, it;
-  beg = fExtremeFacets.begin();
-  end = fExtremeFacets.end();
-  for (it = beg; it != end; it++)
+  for (auto it = fExtremeFacets.cbegin(); it != fExtremeFacets.cend(); ++it)
   {
     G4VFacet &facet = *(*it);
     base += facet.AllocatedMemory();
