@@ -23,21 +23,11 @@
 // * acceptance of all terms of the Geant4 Software license.          *
 // ********************************************************************
 //
+// G4TwistTubsFlatSide implementation
 //
-//
-// 
-// --------------------------------------------------------------------
-// GEANT 4 class source file
-//
-//
-// G4TwistTubsFlatSide.cc
-//
-// Author: 
-//   01-Aug-2002 - Kotoyo Hoshina (hoshina@hepburn.s.chiba-u.ac.jp)
-//
-// History:
-//   13-Nov-2003 - O.Link (Oliver.Link@cern.ch), Integration in Geant4
-//                 from original version in Jupiter-2.5.02 application.
+// 01-Aug-2002 - Kotoyo Hoshina (hoshina@hepburn.s.chiba-u.ac.jp), created.
+// 13-Nov-2003 - O.Link (Oliver.Link@cern.ch), Integration in Geant4
+//               from original version in Jupiter-2.5.02 application.
 // --------------------------------------------------------------------
 
 #include "G4TwistTubsFlatSide.hh"
@@ -46,10 +36,10 @@
 //=====================================================================
 //* constructors ------------------------------------------------------
 
-G4TwistTubsFlatSide::G4TwistTubsFlatSide(const G4String         &name,
-                             const G4RotationMatrix &rot,
-                             const G4ThreeVector    &tlate,
-                             const G4ThreeVector    &n,
+G4TwistTubsFlatSide::G4TwistTubsFlatSide(const G4String& name,
+                             const G4RotationMatrix& rot,
+                             const G4ThreeVector&    tlate,
+                             const G4ThreeVector&    n,
                              const EAxis             axis0 ,
                              const EAxis             axis1 ,
                                    G4double          axis0min,
@@ -57,9 +47,10 @@ G4TwistTubsFlatSide::G4TwistTubsFlatSide(const G4String         &name,
                                    G4double          axis0max,
                                    G4double          axis1max )
   : G4VTwistSurface(name, rot, tlate, 0, axis0, axis1,
-               axis0min, axis1min, axis0max, axis1max)
+                    axis0min, axis1min, axis0max, axis1max)
 {   
-   if (axis0 == kPhi && axis1 == kRho) {
+   if (axis0 == kPhi && axis1 == kRho)
+   {
       G4Exception("G4TwistTubsFlatSide::G4TwistTubsFlatSide()",
                   "GeomSolids0002", FatalErrorInArgument,
                   "Should swap axis0 and axis1!");
@@ -72,19 +63,16 @@ G4TwistTubsFlatSide::G4TwistTubsFlatSide(const G4String         &name,
    SetCorners();
    SetBoundaries();
 
-   fSurfaceArea = 1 ;  // not yet implemented. This is NOT a problem for tracking
-
+   fSurfaceArea = 1. ;  // NOTE: not yet implemented!
 }
 
-
-
-G4TwistTubsFlatSide::G4TwistTubsFlatSide( const G4String        &name,
-                                    G4double         EndInnerRadius[2],
-                                    G4double         EndOuterRadius[2],
-                                    G4double         DPhi,
-                                    G4double         EndPhi[2],
-                                    G4double         EndZ[2], 
-                                    G4int            handedness ) 
+G4TwistTubsFlatSide::G4TwistTubsFlatSide( const G4String& name,
+                                                G4double EndInnerRadius[2],
+                                                G4double EndOuterRadius[2],
+                                                G4double DPhi,
+                                                G4double EndPhi[2],
+                                                G4double EndZ[2], 
+                                                G4int    handedness ) 
   : G4VTwistSurface(name)
 {
    fHandedness = handedness;   // +z = +ve, -z = -ve
@@ -105,20 +93,17 @@ G4TwistTubsFlatSide::G4TwistTubsFlatSide( const G4String        &name,
    SetBoundaries();
 
    fSurfaceArea =  0.5*DPhi * (EndOuterRadius[i]*EndOuterRadius[i]  
-                               - EndInnerRadius[i]*EndInnerRadius[i] ) ; 
-
+                             - EndInnerRadius[i]*EndInnerRadius[i] ) ;
 }
 
-
 //=====================================================================
 //* Fake default constructor ------------------------------------------
 
 G4TwistTubsFlatSide::G4TwistTubsFlatSide( __void__& a )
-  : G4VTwistSurface(a), fSurfaceArea(0.)
+  : G4VTwistSurface(a)
 {
 }
 
-
 //=====================================================================
 //* destructor --------------------------------------------------------
 
@@ -129,12 +114,15 @@ G4TwistTubsFlatSide::~G4TwistTubsFlatSide()
 //=====================================================================
 //* GetNormal ---------------------------------------------------------
 
-G4ThreeVector G4TwistTubsFlatSide::GetNormal(const G4ThreeVector & /* xx */ , 
-                                             G4bool isGlobal)
+G4ThreeVector G4TwistTubsFlatSide::GetNormal(const G4ThreeVector& /* xx */ , 
+                                                   G4bool isGlobal)
 {
-   if (isGlobal) {
+   if (isGlobal)
+   {
       return ComputeGlobalDirection(fCurrentNormal.normal);
-   } else {
+   }
+   else
+   {
       return fCurrentNormal.normal;
    }
 }
@@ -142,29 +130,31 @@ G4ThreeVector G4TwistTubsFlatSide::GetNormal(const G4ThreeVector & /* xx */ ,
 //=====================================================================
 //* DistanceToSurface(p, v) -------------------------------------------
 
-G4int G4TwistTubsFlatSide::DistanceToSurface(const G4ThreeVector &gp,
-                                       const G4ThreeVector &gv,
-                                             G4ThreeVector  gxx[],
-                                             G4double       distance[],
-                                             G4int          areacode[],
-                                             G4bool         isvalid[],
-                                             EValidate      validate) 
+G4int G4TwistTubsFlatSide::DistanceToSurface(const G4ThreeVector& gp,
+                                             const G4ThreeVector& gv,
+                                                   G4ThreeVector  gxx[],
+                                                   G4double       distance[],
+                                                   G4int          areacode[],
+                                                   G4bool         isvalid[],
+                                                   EValidate      validate) 
 {
    fCurStatWithV.ResetfDone(validate, &gp, &gv);
    
-   if (fCurStatWithV.IsDone()) {
-      G4int i;
-      for (i=0; i<fCurStatWithV.GetNXX(); i++) {
+   if (fCurStatWithV.IsDone())
+   {
+      for (G4int i=0; i<fCurStatWithV.GetNXX(); ++i)
+      {
          gxx[i] = fCurStatWithV.GetXX(i);
          distance[i] = fCurStatWithV.GetDistance(i);
          areacode[i] = fCurStatWithV.GetAreacode(i);
          isvalid[i]  = fCurStatWithV.IsValid(i);
       }
       return fCurStatWithV.GetNXX();
-   } else {
-      // initialize
-      G4int i;
-      for (i=0; i<2; i++) {
+   }
+   else  // initialize
+   {
+      for (G4int i=0; i<2; ++i)
+      {
          distance[i] = kInfinity;
          areacode[i] = sOutside;
          isvalid[i]  = false;
@@ -180,34 +170,41 @@ G4int G4TwistTubsFlatSide::DistanceToSurface(const G4ThreeVector &gp,
    // if p is on surface, distance = 0. 
    //
 
-   if (std::fabs(p.z()) == 0.) {   // if p is on the plane
+   if (std::fabs(p.z()) == 0.)    // if p is on the plane
+   {
       distance[0] = 0;
       G4ThreeVector xx = p;
       gxx[0] = ComputeGlobalPoint(xx);
       
-      if (validate == kValidateWithTol) {
+      if (validate == kValidateWithTol)
+      {
          areacode[0] = GetAreaCode(xx);
-         if (!IsOutside(areacode[0])) {
+         if (!IsOutside(areacode[0]))
+         {
             isvalid[0] = true;
          }
-      } else if (validate == kValidateWithoutTol) {
+      }
+      else if (validate == kValidateWithoutTol)
+      {
          areacode[0] = GetAreaCode(xx, false);
-         if (IsInside(areacode[0])) {
+         if (IsInside(areacode[0]))
+         {
             isvalid[0] = true;
          }
-      } else { // kDontValidate
+      }
+      else  // kDontValidate
+      {
          areacode[0] = sInside;
          isvalid[0] = true;
       }
-
       return 1;
    }
    //
    // special case end
    //
    
-   if (v.z() == 0) { 
-
+   if (v.z() == 0)
+   { 
       fCurStatWithV.SetCurrentStatus(0, gxx[0], distance[0], areacode[0], 
                                      isvalid[0], 0, validate, &gp, &gv);
       return 0;
@@ -218,17 +215,24 @@ G4int G4TwistTubsFlatSide::DistanceToSurface(const G4ThreeVector &gp,
    G4ThreeVector xx = p + distance[0]*v;
    gxx[0] = ComputeGlobalPoint(xx);
 
-   if (validate == kValidateWithTol) {
+   if (validate == kValidateWithTol)
+   {
       areacode[0] = GetAreaCode(xx);
-      if (!IsOutside(areacode[0])) {
+      if (!IsOutside(areacode[0]))
+      {
          if (distance[0] >= 0) isvalid[0] = true;
       }
-   } else if (validate == kValidateWithoutTol) {
+   }
+   else if (validate == kValidateWithoutTol)
+   {
       areacode[0] = GetAreaCode(xx, false);
-      if (IsInside(areacode[0])) {
+      if (IsInside(areacode[0]))
+      {
          if (distance[0] >= 0) isvalid[0] = true;
       }
-   } else { // kDontValidate
+   }
+   else  // kDontValidate
+   {
       areacode[0] = sInside;
          if (distance[0] >= 0) isvalid[0] = true;
    }
@@ -251,7 +255,7 @@ G4int G4TwistTubsFlatSide::DistanceToSurface(const G4ThreeVector &gp,
 //=====================================================================
 //* DistanceToSurface(p) ----------------------------------------------
 
-G4int G4TwistTubsFlatSide::DistanceToSurface(const G4ThreeVector &gp,
+G4int G4TwistTubsFlatSide::DistanceToSurface(const G4ThreeVector& gp,
                                              G4ThreeVector  gxx[],
                                              G4double       distance[],
                                              G4int          areacode[])
@@ -262,18 +266,20 @@ G4int G4TwistTubsFlatSide::DistanceToSurface(const G4ThreeVector &gp,
 
    fCurStat.ResetfDone(kDontValidate, &gp);
 
-   if (fCurStat.IsDone()) {
-      G4int i;
-      for (i=0; i<fCurStat.GetNXX(); i++) {
+   if (fCurStat.IsDone())
+   {
+      for (G4int i=0; i<fCurStat.GetNXX(); ++i)
+      {
          gxx[i] = fCurStat.GetXX(i);
          distance[i] = fCurStat.GetDistance(i);
          areacode[i] = fCurStat.GetAreacode(i);
       }
       return fCurStat.GetNXX();
-   } else {
-      // initialize
-      G4int i;
-      for (i=0; i<2; i++) {
+   }
+   else   // initialize
+   {
+      for (auto i=0; i<2; ++i)
+      {
          distance[i] = kInfinity;
          areacode[i] = sOutside;
          gxx[i].set(kInfinity, kInfinity, kInfinity);
@@ -285,10 +291,13 @@ G4int G4TwistTubsFlatSide::DistanceToSurface(const G4ThreeVector &gp,
 
    // The plane is placed on origin with making its normal 
    // parallel to z-axis. 
-   if (std::fabs(p.z()) <= 0.5 * kCarTolerance) {   // if p is on the plane, return 1
-      distance[0] = 0;
+   if (std::fabs(p.z()) <= 0.5 * kCarTolerance) // if p is on plane, return 1
+   {
+     distance[0] = 0;
       xx = p;
-   } else {
+   }
+   else
+   {
       distance[0] = std::fabs(p.z());
       xx.set(p.x(), p.y(), 0);  
    }
@@ -299,98 +308,107 @@ G4int G4TwistTubsFlatSide::DistanceToSurface(const G4ThreeVector &gp,
    fCurStat.SetCurrentStatus(0, gxx[0], distance[0], areacode[0],
                              isvalid, 1, kDontValidate, &gp);
    return 1;
-
 }
 
 //=====================================================================
 //* GetAreaCode -------------------------------------------------------
 
 G4int G4TwistTubsFlatSide::GetAreaCode(const G4ThreeVector &xx, 
-                                       G4bool withTol)
+                                             G4bool withTol)
 {
    const G4double rtol
      = 0.5*G4GeometryTolerance::GetInstance()->GetRadialTolerance();
    
    G4int areacode = sInside;
 
-   if (fAxis[0] == kRho && fAxis[1] == kPhi) {
+   if (fAxis[0] == kRho && fAxis[1] == kPhi)
+   {
       G4int rhoaxis = 0;
-     // G4int phiaxis = 0;
 
       G4ThreeVector dphimin;   // direction of phi-minimum boundary
       G4ThreeVector dphimax;   // direction of phi-maximum boundary
       dphimin = GetCorner(sC0Max1Min);
       dphimax = GetCorner(sC0Max1Max);   
       
-      if (withTol) {
-
+      if (withTol)
+      {
          G4bool isoutside = false;
 
          // test boundary of rho-axis
 
-         if (xx.getRho() <= fAxisMin[rhoaxis] + rtol) {
-
-            areacode |= (sAxis0 & (sAxisRho | sAxisMin)) | sBoundary; // rho-min
+         if (xx.getRho() <= fAxisMin[rhoaxis] + rtol)
+         {
+            areacode |= (sAxis0 & (sAxisRho|sAxisMin)) | sBoundary; // rho-min
             if (xx.getRho() < fAxisMin[rhoaxis] - rtol) isoutside = true; 
             
-         } else if (xx.getRho() >= fAxisMax[rhoaxis] - rtol) {
-
-            areacode |= (sAxis0 & (sAxisRho | sAxisMax)) | sBoundary; // rho-max
-            if (xx.getRho() > fAxisMax[rhoaxis] + rtol) isoutside = true; 
-
+         }
+         else if (xx.getRho() >= fAxisMax[rhoaxis] - rtol)
+         {
+            areacode |= (sAxis0 & (sAxisRho|sAxisMax)) | sBoundary; // rho-max
+            if (xx.getRho() > fAxisMax[rhoaxis] + rtol) isoutside = true;
          }         
          
          // test boundary of phi-axis
 
-         if (AmIOnLeftSide(xx, dphimin) >= 0) {           // xx is on dphimin
-
+         if (AmIOnLeftSide(xx, dphimin) >= 0)            // xx is on dphimin
+         {
             areacode |= (sAxis1 & (sAxisPhi | sAxisMin)); 
-            if   (areacode & sBoundary) areacode |= sCorner;  // xx is on the corner.
+            if   (areacode & sBoundary) areacode |= sCorner;  // xx is on corner.
             else                        areacode |= sBoundary;
 
             if (AmIOnLeftSide(xx, dphimin) > 0) isoutside = true; 
 
-         } else if (AmIOnLeftSide(xx, dphimax) <= 0) {    // xx is on dphimax
-
+         }
+         else if (AmIOnLeftSide(xx, dphimax) <= 0)       // xx is on dphimax
+         {
             areacode |= (sAxis1 & (sAxisPhi | sAxisMax)); 
-            if   (areacode & sBoundary) areacode |= sCorner;  // xx is on the corner.
+            if   (areacode & sBoundary) areacode |= sCorner;  // xx is on corner.
             else                        areacode |= sBoundary;
 
-            if (AmIOnLeftSide(xx, dphimax) < 0) isoutside = true; 
-
+            if (AmIOnLeftSide(xx, dphimax) < 0) isoutside = true;
          }
          
          // if isoutside = true, clear inside bit.
          // if not on boundary, add axis information. 
 
-         if (isoutside) {
+         if (isoutside)
+         {
             G4int tmpareacode = areacode & (~sInside);
             areacode = tmpareacode;
-         } else if ((areacode & sBoundary) != sBoundary) {
+         }
+         else if ((areacode & sBoundary) != sBoundary)
+         {
             areacode |= (sAxis0 & sAxisRho) | (sAxis1 & sAxisPhi);
          }
 
-      } else {
-
+      }
+      else
+      {
          // out of boundary of rho-axis
 
-         if (xx.getRho() < fAxisMin[rhoaxis]) {
+         if (xx.getRho() < fAxisMin[rhoaxis])
+         {
             areacode |= (sAxis0 & (sAxisRho | sAxisMin)) | sBoundary;
-         } else if (xx.getRho() > fAxisMax[rhoaxis]) {
+         }
+         else if (xx.getRho() > fAxisMax[rhoaxis])
+         {
             areacode |= (sAxis0 & (sAxisRho | sAxisMax)) | sBoundary;
          }
          
          // out of boundary of phi-axis
 
-         if (AmIOnLeftSide(xx, dphimin, false) >= 0) {       // xx is leftside or
-            areacode |= (sAxis1 & (sAxisPhi | sAxisMin)) ;   // boundary of dphimin
-            if   (areacode & sBoundary) areacode |= sCorner; // xx is on the corner.
-            else                        areacode |= sBoundary;
+         if (AmIOnLeftSide(xx, dphimin, false) >= 0)  // xx is leftside or
+         {
+           areacode |= (sAxis1 & (sAxisPhi | sAxisMin)) ; // boundary of dphimin
+           if   (areacode & sBoundary) areacode |= sCorner; // xx is on corner
+           else                        areacode |= sBoundary;
 
-         } else if (AmIOnLeftSide(xx, dphimax, false) <= 0) { // xx is rightside or
-            areacode |= (sAxis1 & (sAxisPhi | sAxisMax)) ;    // boundary of dphimax
-            if   (areacode & sBoundary) areacode |= sCorner;  // xx is on the corner.
-            else                        areacode |= sBoundary;
+         }
+         else if (AmIOnLeftSide(xx, dphimax, false) <= 0) // xx is rightside or
+         {
+           areacode |= (sAxis1 & (sAxisPhi | sAxisMax)); // boundary of dphimax
+           if   (areacode & sBoundary) areacode |= sCorner;  // xx is on corner
+           else                        areacode |= sBoundary;
            
          }
 
@@ -400,8 +418,9 @@ G4int G4TwistTubsFlatSide::GetAreaCode(const G4ThreeVector &xx,
 
       }
       return areacode;
-   } else {
-
+   }
+   else
+   {
       std::ostringstream message;
       message << "Feature NOT implemented !" << G4endl
               << "        fAxis[0] = " << fAxis[0] << G4endl
@@ -411,8 +430,7 @@ G4int G4TwistTubsFlatSide::GetAreaCode(const G4ThreeVector &xx,
    }
    return areacode;
 }
-                                      
-                                           
+
 //=====================================================================
 //* SetCorners --------------------------------------------------------
 
@@ -420,8 +438,8 @@ void G4TwistTubsFlatSide::SetCorners()
 {
    // Set Corner points in local coodinate.
    
-   if (fAxis[0] == kRho && fAxis[1] == kPhi) {
-       
+   if (fAxis[0] == kRho && fAxis[1] == kPhi)
+   {
       G4int rhoaxis = 0;  // kRho
       G4int phiaxis = 1;  // kPhi
       
@@ -447,7 +465,9 @@ void G4TwistTubsFlatSide::SetCorners()
          z = 0;
          SetCorner(sC0Min1Max, x, y, z);
        
-   } else {
+   }
+   else
+   {
       std::ostringstream message;
       message << "Feature NOT implemented !" << G4endl
               << "        fAxis[0] = " << fAxis[0] << G4endl
@@ -465,8 +485,8 @@ void G4TwistTubsFlatSide::SetBoundaries()
    // Set direction-unit vector of phi-boundary-lines in local coodinate.
    // Don't call the function twice.
    
-   if (fAxis[0] == kRho && fAxis[1] == kPhi) {
-   
+   if (fAxis[0] == kRho && fAxis[1] == kPhi)
+   {
       G4ThreeVector direction;
       // sAxis0 & sAxisMin
       direction = GetCorner(sC0Min1Max) - GetCorner(sC0Min1Min);
@@ -491,7 +511,9 @@ void G4TwistTubsFlatSide::SetBoundaries()
       direction = direction.unit();
       SetBoundary(sAxis1 & (sAxisRho | sAxisMax), direction,
                   GetCorner(sC0Min1Max), sAxisPhi);
-   } else {
+   }
+   else
+   {
       std::ostringstream message;
       message << "Feature NOT implemented !" << G4endl
               << "        fAxis[0] = " << fAxis[0] << G4endl
@@ -507,7 +529,6 @@ void G4TwistTubsFlatSide::SetBoundaries()
 void G4TwistTubsFlatSide::GetFacets( G4int k, G4int n, G4double xyz[][3],
                                      G4int faces[][4], G4int iside ) 
 {
-
   G4ThreeVector p ;
 
   G4double rmin = fAxisMin[0] ;
@@ -515,19 +536,16 @@ void G4TwistTubsFlatSide::GetFacets( G4int k, G4int n, G4double xyz[][3],
   G4double phimin, phimax ;
 
   G4double r,phi ;
-
-  G4int i,j ;
-
   G4int nnode,nface ;
 
-  for ( i = 0 ; i<n ; i++ ) {
-
+  for ( G4int i = 0 ; i<n ; ++i )
+  {
     r = rmin + i*(rmax-rmin)/(n-1) ;
 
     phimin = GetBoundaryMin(r) ; 
     phimax = GetBoundaryMax(r) ;
 
-    for ( j = 0 ; j<k ; j++ )
+    for ( G4int j = 0 ; j<k ; ++j )
     {
       phi = phimin + j*(phimax-phimin)/(k-1) ;
 
@@ -538,25 +556,32 @@ void G4TwistTubsFlatSide::GetFacets( G4int k, G4int n, G4double xyz[][3],
       xyz[nnode][1] = p.y() ;
       xyz[nnode][2] = p.z() ;
 
-      if ( i<n-1 && j<k-1 ) {   // conterclock wise filling
-        
+      if ( i<n-1 && j<k-1 )    // conterclock wise filling
+      {
         nface = GetFace(i,j,k,n,iside) ;
 
-        if (fHandedness < 0) {  // lower side 
-          faces[nface][0] = GetEdgeVisibility(i,j,k,n,0,-1) * ( GetNode(i  ,j  ,k,n,iside)+1) ;  
-          faces[nface][1] = GetEdgeVisibility(i,j,k,n,1,-1) * ( GetNode(i  ,j+1,k,n,iside)+1) ;
-          faces[nface][2] = GetEdgeVisibility(i,j,k,n,2,-1) * ( GetNode(i+1,j+1,k,n,iside)+1) ;
-          faces[nface][3] = GetEdgeVisibility(i,j,k,n,3,-1) * ( GetNode(i+1,j  ,k,n,iside)+1) ;
-        } else {                // upper side
-          faces[nface][0] = GetEdgeVisibility(i,j,k,n,0,1) * ( GetNode(i  ,j  ,k,n,iside)+1) ;  
-          faces[nface][1] = GetEdgeVisibility(i,j,k,n,1,1) * ( GetNode(i+1,j  ,k,n,iside)+1) ;
-          faces[nface][2] = GetEdgeVisibility(i,j,k,n,2,1) * ( GetNode(i+1,j+1,k,n,iside)+1) ;
-          faces[nface][3] = GetEdgeVisibility(i,j,k,n,3,1) * ( GetNode(i  ,j+1,k,n,iside)+1) ;
-
+        if (fHandedness < 0)   // lower side
+        {
+          faces[nface][0] = GetEdgeVisibility(i,j,k,n,0,-1)
+                          * ( GetNode(i  ,j  ,k,n,iside)+1) ;  
+          faces[nface][1] = GetEdgeVisibility(i,j,k,n,1,-1)
+                          * ( GetNode(i  ,j+1,k,n,iside)+1) ;
+          faces[nface][2] = GetEdgeVisibility(i,j,k,n,2,-1)
+                          * ( GetNode(i+1,j+1,k,n,iside)+1) ;
+          faces[nface][3] = GetEdgeVisibility(i,j,k,n,3,-1)
+                          * ( GetNode(i+1,j  ,k,n,iside)+1) ;
+        }
+        else                   // upper side
+        {
+          faces[nface][0] = GetEdgeVisibility(i,j,k,n,0,1)
+                          * ( GetNode(i  ,j  ,k,n,iside)+1) ;  
+          faces[nface][1] = GetEdgeVisibility(i,j,k,n,1,1)
+                          * ( GetNode(i+1,j  ,k,n,iside)+1) ;
+          faces[nface][2] = GetEdgeVisibility(i,j,k,n,2,1)
+                          * ( GetNode(i+1,j+1,k,n,iside)+1) ;
+          faces[nface][3] = GetEdgeVisibility(i,j,k,n,3,1)
+                          * ( GetNode(i  ,j+1,k,n,iside)+1) ;
         }
-
-
-
       }
     }
   }
