@@ -23,21 +23,11 @@
 // * acceptance of all terms of the Geant4 Software license.          *
 // ********************************************************************
 //
+// G4VTwistSurface implementation
 //
-//
-// 
-// --------------------------------------------------------------------
-// GEANT 4 class source file
-//
-//
-// G4VTwistSurface.cc
-//
-// Author: 
-//   01-Aug-2002 - Kotoyo Hoshina (hoshina@hepburn.s.chiba-u.ac.jp)
-//
-// History:
-//   13-Nov-2003 - O.Link (Oliver.Link@cern.ch), Integration in Geant4
-//                 from original version in Jupiter-2.5.02 application.
+// 01-Aug-2002 - Kotoyo Hoshina (hoshina@hepburn.s.chiba-u.ac.jp), created.
+// 13-Nov-2003 - O.Link (Oliver.Link@cern.ch), Integration in Geant4
+//               from original version in Jupiter-2.5.02 application.
 // --------------------------------------------------------------------
 
 #include <iomanip>
@@ -83,10 +73,10 @@ G4VTwistSurface::G4VTwistSurface(const G4String &name)
    fAxisMax[1] = kInfinity;
    fHandedness = 1;
 
-   for (G4int i=0; i<4; i++)
+   for (auto i=0; i<4; ++i)
    {
       fCorners[i].set(kInfinity, kInfinity, kInfinity);
-      fNeighbours[i] = 0;
+      fNeighbours[i] = nullptr;
    }
 
    fCurrentNormal.p.set(kInfinity, kInfinity, kInfinity);
@@ -96,9 +86,9 @@ G4VTwistSurface::G4VTwistSurface(const G4String &name)
    kCarTolerance = G4GeometryTolerance::GetInstance()->GetSurfaceTolerance();
 }
 
-G4VTwistSurface::G4VTwistSurface(const G4String         &name,
-                       const G4RotationMatrix &rot,
-                       const G4ThreeVector    &tlate,
+G4VTwistSurface::G4VTwistSurface(const G4String& name,
+                       const G4RotationMatrix& rot,
+                       const G4ThreeVector&    tlate,
                              G4int             handedness,
                        const EAxis             axis0 ,
                        const EAxis             axis1 ,
@@ -118,10 +108,10 @@ G4VTwistSurface::G4VTwistSurface(const G4String         &name,
    fRot        = rot;
    fTrans      = tlate;
 
-   for (G4int i=0; i<4; i++)
+   for (auto i=0; i<4; ++i)
    {
       fCorners[i].set(kInfinity, kInfinity, kInfinity);
-      fNeighbours[i] = 0;
+      fNeighbours[i] = nullptr;
    }
 
    fCurrentNormal.p.set(kInfinity, kInfinity, kInfinity);
@@ -141,7 +131,7 @@ G4VTwistSurface::G4VTwistSurface( __void__& )
    fAxis[0] = fAxis[1] = kXAxis;
    fAxisMin[0] = fAxisMin[1] = 0.;
    fAxisMax[0] = fAxisMax[1] = 0.;
-   fNeighbours[0] = fNeighbours[1] = fNeighbours[2] = fNeighbours[3] = 0;
+   fNeighbours[0] = fNeighbours[1] = fNeighbours[2] = fNeighbours[3] = nullptr;
 }
 
 //=====================================================================
@@ -154,9 +144,9 @@ G4VTwistSurface::~G4VTwistSurface()
 //=====================================================================
 //* AmIOnLeftSide -----------------------------------------------------
 
-G4int G4VTwistSurface::AmIOnLeftSide(const G4ThreeVector &me, 
-                                     const G4ThreeVector &vec,
-                                     G4bool        withtol) 
+G4int G4VTwistSurface::AmIOnLeftSide(const G4ThreeVector& me, 
+                                     const G4ThreeVector& vec,
+                                           G4bool withtol) 
 {
    // AmIOnLeftSide returns phi-location of "me"
    // (phi relation between me and vec projected on z=0 plane).
@@ -176,7 +166,8 @@ G4int G4VTwistSurface::AmIOnLeftSide(const G4ThreeVector &me,
 
    if (fAmIOnLeftSide.me == me 
        && fAmIOnLeftSide.vec == vec
-       && fAmIOnLeftSide.withTol == withtol) {
+       && fAmIOnLeftSide.withTol == withtol)
+   {
       return fAmIOnLeftSide.amIOnLeftSide;
    }
    
@@ -192,7 +183,8 @@ G4int G4VTwistSurface::AmIOnLeftSide(const G4ThreeVector &me,
 
    G4double metcrossvect = met.x() * vect.y() - met.y() * vect.x();
    
-   if (withtol) {
+   if (withtol)
+   {
       if (met.x() * ivect.y() - met.y() * ivect.x() > 0 && 
           metcrossvect >= 0)  {
          fAmIOnLeftSide.amIOnLeftSide = 1;
@@ -202,7 +194,9 @@ G4int G4VTwistSurface::AmIOnLeftSide(const G4ThreeVector &me,
       } else {
          fAmIOnLeftSide.amIOnLeftSide = 0;
       }
-   } else {
+   }
+   else
+   {
       if (metcrossvect > 0) {    
          fAmIOnLeftSide.amIOnLeftSide = 1;
       } else if (metcrossvect < 0 ) {
@@ -235,8 +229,8 @@ G4int G4VTwistSurface::AmIOnLeftSide(const G4ThreeVector &me,
 //* DistanceToBoundary ------------------------------------------------
 
 G4double G4VTwistSurface::DistanceToBoundary(G4int areacode,
-                                        G4ThreeVector &xx,
-                                        const G4ThreeVector &p) 
+                                             G4ThreeVector& xx,
+                                       const G4ThreeVector& p) 
 {
    // DistanceToBoundary 
    //
@@ -252,7 +246,8 @@ G4double G4VTwistSurface::DistanceToBoundary(G4int areacode,
    G4double      dist = kInfinity;
    G4int         boundarytype;
 
-   if (IsAxis0(areacode) && IsAxis1(areacode)) {
+   if (IsAxis0(areacode) && IsAxis1(areacode))
+   {
       std::ostringstream message;
       message << "Point is in the corner area." << G4endl
               << "        Point is in the corner area. This function returns"
@@ -261,18 +256,25 @@ G4double G4VTwistSurface::DistanceToBoundary(G4int areacode,
               << "        areacode = " << areacode;
       G4Exception("G4VTwistSurface::DistanceToBoundary()", "GeomSolids0003",
                   FatalException, message);
-   } else if (IsAxis0(areacode) || IsAxis1(areacode)) {
+   }
+   else if (IsAxis0(areacode) || IsAxis1(areacode))
+   {
       GetBoundaryParameters(areacode, d, x0, boundarytype);
-      if (boundarytype == sAxisPhi) {
+      if (boundarytype == sAxisPhi)
+      {
          G4double t = x0.getRho() / p.getRho();
          xx.set(t*p.x(), t*p.y(), x0.z());
          dist = (xx - p).mag();
-      } else { 
+      }
+      else
+      { 
          // linear boundary
          // sAxisX, sAxisY, sAxisZ, sAxisRho
          dist = DistanceToLine(p, x0, d, xx);
       }
-   } else {
+   }
+   else
+   {
       std::ostringstream message;
       message << "Bad areacode of boundary." << G4endl
               << "        areacode = " << areacode;
@@ -285,12 +287,12 @@ G4double G4VTwistSurface::DistanceToBoundary(G4int areacode,
 //=====================================================================
 //* DistanceToIn ------------------------------------------------------
 
-G4double G4VTwistSurface::DistanceToIn(const G4ThreeVector &gp,
-                                  const G4ThreeVector &gv,
-                                        G4ThreeVector &gxxbest)
+G4double G4VTwistSurface::DistanceToIn(const G4ThreeVector& gp,
+                                       const G4ThreeVector& gv,
+                                             G4ThreeVector& gxxbest)
 {
 #ifdef G4TWISTDEBUG
-   G4cout << " ~~~~~ G4VTwistSurface::DistanceToIn(p,v) - Start ~~~~~" << G4endl;
+   G4cout << " ~~~~ G4VTwistSurface::DistanceToIn(p,v) - Start ~~~~" << G4endl;
    G4cout << "      Name : " << fName << G4endl;
    G4cout << "      gp   : " << gp << G4endl;
    G4cout << "      gv   : " <<  gv << G4endl;
@@ -302,7 +304,8 @@ G4double G4VTwistSurface::DistanceToIn(const G4ThreeVector &gp,
    G4int         areacode[G4VSURFACENXX]  ;
    G4bool        isvalid[G4VSURFACENXX]   ; 
    
-   for (G4int i = 0 ; i<G4VSURFACENXX ; i++ ) {
+   for (G4int i = 0 ; i<G4VSURFACENXX ; ++i )
+   {
      distance[i] = kInfinity ;
      areacode[i] = sOutside ;
      isvalid[i] = false ;
@@ -317,20 +320,23 @@ G4double G4VTwistSurface::DistanceToIn(const G4ThreeVector &gp,
    G4int         nxx = DistanceToSurface(gp, gv, gxx, distance, areacode, 
                                          isvalid, kValidateWithTol);
 
-   for (G4int i=0; i< nxx; i++) {
+   for (G4int i=0; i<nxx; ++i)
+   {
 
       // skip this intersection if:
       //   - invalid intersection
       //   - particle goes outword the surface
 
-      if (!isvalid[i]) {
+      if (!isvalid[i])
+      {
          // xx[i] is sOutside or distance[i] < 0
          continue;      
       }
 
       G4ThreeVector normal = GetNormal(gxx[i], true);
 
-      if ((normal * gv) >= 0) {
+      if ((normal * gv) >= 0)
+      {
 
 #ifdef G4TWISTDEBUG
          G4cout << "   G4VTwistSurface::DistanceToIn(p,v): "
@@ -343,8 +349,10 @@ G4double G4VTwistSurface::DistanceToIn(const G4ThreeVector &gp,
       // accept this intersection if the intersection is inside.
       //
 
-      if (IsInside(areacode[i])) {
-         if (distance[i] < bestdistance) {
+      if (IsInside(areacode[i]))
+      {
+         if (distance[i] < bestdistance)
+         {
             bestdistance = distance[i];
             bestgxx = gxx[i];
 #ifdef G4TWISTDEBUG
@@ -359,13 +367,15 @@ G4double G4VTwistSurface::DistanceToIn(const G4ThreeVector &gp,
       // else, the intersection is on boundary or corner.
       //
 
-      } else {
-
-         G4VTwistSurface *neighbours[2];
+      }
+      else
+      {
+         G4VTwistSurface* neighbours[2];
          G4bool      isaccepted[2] = {false, false};
          G4int       nneighbours   = GetNeighbours(areacode[i], neighbours);
             
-         for (G4int j=0; j< nneighbours; j++) {
+         for (G4int j=0; j<nneighbours; ++j)
+         {
             // if on corner, nneighbours = 2.
             // if on boundary, nneighbours = 1.
 
@@ -374,7 +384,8 @@ G4double G4VTwistSurface::DistanceToIn(const G4ThreeVector &gp,
             G4int         tmpareacode[G4VSURFACENXX] ;
             G4bool        tmpisvalid[G4VSURFACENXX] ;
 
-            for (G4int l = 0 ; l<G4VSURFACENXX ; l++ ) {
+            for (G4int l = 0 ; l<G4VSURFACENXX ; ++l )
+            {
               tmpdist[l] = kInfinity ;
               tmpareacode[l] = sOutside ;
               tmpisvalid[l] = false ;
@@ -386,22 +397,22 @@ G4double G4VTwistSurface::DistanceToIn(const G4ThreeVector &gp,
                                           kValidateWithTol);
             G4ThreeVector neighbournormal;
 
-            for (G4int k=0; k< tmpnxx; k++) {
-
+            for (G4int k=0; k< tmpnxx; ++k)
+            {
                //  
                // if tmpxx[k] is valid && sInside, the final winner must
                // be neighbour surface. return kInfinity. 
                // else , choose tmpxx on same boundary of xx, then check normal 
                //  
 
-               if (IsInside(tmpareacode[k])) {
-
+               if (IsInside(tmpareacode[k]))
+               {
 #ifdef G4TWISTDEBUG
                   G4cout << "   G4VTwistSurface:DistanceToIn(p,v): "
                          << " intersection "<< tmpgxx[k] << G4endl
                          << "   is inside of neighbour surface of " << fName 
                          << " . returning kInfinity." << G4endl;
-                  G4cout << "~~~~~ G4VTwistSurface::DistanceToIn(p,v) - return ~~~~"
+                  G4cout << "~~ G4VTwistSurface::DistanceToIn(p,v) - return ~~"
                          << G4endl;
                   G4cout << "      No intersections " << G4endl; 
                   G4cout << "      Name : " << fName << G4endl; 
@@ -416,8 +427,10 @@ G4double G4VTwistSurface::DistanceToIn(const G4ThreeVector &gp,
                // be neighbour surface. return .  
                //
 
-               } else if (IsSameBoundary(this,areacode[i],
-                                         neighbours[j], tmpareacode[k])) { 
+               }
+               else if (IsSameBoundary(this,areacode[i],
+                                       neighbours[j], tmpareacode[k]))
+               { 
                   // tmpxx[k] is same boundary (or corner) of xx.
                  
                   neighbournormal = neighbours[j]->GetNormal(tmpgxx[k], true);
@@ -434,32 +447,36 @@ G4double G4VTwistSurface::DistanceToIn(const G4ThreeVector &gp,
 
          // now, we can accept xx intersection
 
-         if (isaccepted[0] == true && isaccepted[1] == true) {
-            if (distance[i] < bestdistance) {
+         if (isaccepted[0] == true && isaccepted[1] == true)
+         {
+            if (distance[i] < bestdistance)
+            {
                bestdistance = distance[i];
                gxxbest = gxx[i];
 #ifdef G4TWISTDEBUG
-               besti   = i;
+               besti = i;
                G4cout << "   G4VTwistSurface::DistanceToIn(p,v): "
                       << " areacode sBoundary & sBoundary distance = "
                       << fName  << " " << distance[i] << G4endl;
 #endif 
             }
          }
-
       } // else end
    } // intersection loop end
 
    gxxbest = bestgxx;
 
 #ifdef G4TWISTDEBUG
-   if (besti < 0) {
-      G4cout << "~~~~~ G4VTwistSurface::DistanceToIn(p,v) - return ~~~~" << G4endl;
+   if (besti < 0)
+   {
+      G4cout << "~~~ G4VTwistSurface::DistanceToIn(p,v) - return ~~~" << G4endl;
       G4cout << "      No intersections " << G4endl; 
       G4cout << "      Name : " << fName << G4endl; 
       G4cout << "~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~" << G4endl;
-   } else {
-      G4cout << "~~~~~ G4VTwistSurface::DistanceToIn(p,v) : return ~~~~" << G4endl;
+   }
+   else
+   {
+      G4cout << "~~~ G4VTwistSurface::DistanceToIn(p,v) : return ~~~" << G4endl;
       G4cout << "      Name, i  : " << fName << " , " << besti << G4endl; 
       G4cout << "      gxx[i]   : " << gxxbest << G4endl; 
       G4cout << "      bestdist : " << bestdistance << G4endl;
@@ -474,9 +491,9 @@ G4double G4VTwistSurface::DistanceToIn(const G4ThreeVector &gp,
 //=====================================================================
 //* DistanceToOut(p, v) -----------------------------------------------
 
-G4double G4VTwistSurface::DistanceToOut(const G4ThreeVector &gp,
-                                   const G4ThreeVector &gv,
-                                         G4ThreeVector &gxxbest)
+G4double G4VTwistSurface::DistanceToOut(const G4ThreeVector& gp,
+                                        const G4ThreeVector& gv,
+                                              G4ThreeVector& gxxbest)
 {
 #ifdef G4TWISTDEBUG
    G4cout << "~~~~~ G4VTwistSurface::DistanceToOut(p,v) - Start ~~~~" << G4endl;
@@ -487,12 +504,11 @@ G4double G4VTwistSurface::DistanceToOut(const G4ThreeVector &gp,
 #endif
 
    G4ThreeVector gxx[G4VSURFACENXX];
-   G4double      distance[G4VSURFACENXX]  ; 
-   G4int         areacode[G4VSURFACENXX]  ;
-   G4bool        isvalid[G4VSURFACENXX]   ; 
-   G4int         i;
+   G4double      distance[G4VSURFACENXX]; 
+   G4int         areacode[G4VSURFACENXX];
+   G4bool        isvalid[G4VSURFACENXX]; 
    
-   for ( i = 0 ; i<G4VSURFACENXX ; i++ )
+   for ( G4int i = 0 ; i<G4VSURFACENXX ; ++i )
    {
      distance[i] = kInfinity ;
      areacode[i] = sOutside ;
@@ -505,22 +521,28 @@ G4double G4VTwistSurface::DistanceToOut(const G4ThreeVector &gp,
    nxx = DistanceToSurface(gp, gv, gxx, distance, areacode,
                            isvalid, kValidateWithTol);
 
-   for (i=0; i<nxx; i++) {
-      if (!(isvalid[i])) {
+   for (G4int i=0; i<nxx; ++i)
+   {
+      if (!(isvalid[i]))
+      {
          continue;
       }
 
       G4ThreeVector normal = GetNormal(gxx[i], true);
-      if (normal * gv <= 0) {
+      if (normal * gv <= 0)
+      {
          // particle goes toword inside of solid, return kInfinity
 #ifdef G4TWISTDEBUG
-          G4cout << "   G4VTwistSurface::DistanceToOut(p,v): normal*gv < 0, normal " 
+          G4cout << "   G4VTwistSurface::DistanceToOut(p,v): normal*gv < 0 " 
                  << fName << " " << normal 
                  << G4endl;
 #endif 
-      } else {
+      }
+      else
+      {
          // gxx[i] is accepted.
-         if (distance[i] < bestdistance) {
+         if (distance[i] < bestdistance)
+         {
             bestdistance = distance[i];
             gxxbest = gxx[i];
          }
@@ -528,14 +550,17 @@ G4double G4VTwistSurface::DistanceToOut(const G4ThreeVector &gp,
    }
 
 #ifdef G4TWISTDEBUG
-   if (besti < 0) {
-      G4cout << "~~~~~ G4VTwistSurface::DistanceToOut(p,v) - return ~~~" << G4endl;
+   if (besti < 0)
+   {
+      G4cout << "~~ G4VTwistSurface::DistanceToOut(p,v) - return ~~" << G4endl;
       G4cout << "      No intersections   " << G4endl; 
       G4cout << "      Name     : " << fName << G4endl; 
       G4cout << "      bestdist : " << bestdistance << G4endl;
       G4cout << "~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~" << G4endl;
-   } else {
-      G4cout << "~~~~~ G4VTwistSurface::DistanceToOut(p,v) : return ~~~" << G4endl;
+   }
+   else
+   {
+      G4cout << "~~ G4VTwistSurface::DistanceToOut(p,v) : return ~~" << G4endl;
       G4cout << "      Name, i  : " << fName << " , " << i << G4endl; 
       G4cout << "      gxx[i]   : " << gxxbest << G4endl; 
       G4cout << "      bestdist : " << bestdistance << G4endl;
@@ -549,8 +574,8 @@ G4double G4VTwistSurface::DistanceToOut(const G4ThreeVector &gp,
 //=====================================================================
 //* DistanceTo(p) -----------------------------------------------------
 
-G4double G4VTwistSurface::DistanceTo(const G4ThreeVector &gp,
-                                      G4ThreeVector &gxxbest)
+G4double G4VTwistSurface::DistanceTo(const G4ThreeVector& gp,
+                                           G4ThreeVector& gxxbest)
 {
 #ifdef G4TWISTDEBUG
    G4cout << "~~~~~ G4VTwistSurface::DistanceTo(p) - Start ~~~~~~~~~" << G4endl;
@@ -564,12 +589,12 @@ G4double G4VTwistSurface::DistanceTo(const G4ThreeVector &gp,
    G4double      distance[G4VSURFACENXX]  ; 
    G4int         areacode[G4VSURFACENXX]  ;
    
-   for (G4int i = 0 ; i<G4VSURFACENXX ; i++ ) {
+   for (G4int i = 0 ; i<G4VSURFACENXX ; ++i )
+   {
      distance[i] = kInfinity ;
      areacode[i] = sOutside ;
    }
 
-
    DistanceToSurface(gp, gxx, distance, areacode);
    gxxbest = gxx[0];
 
@@ -587,8 +612,9 @@ G4double G4VTwistSurface::DistanceTo(const G4ThreeVector &gp,
 //=====================================================================
 //* IsSameBoundary ----------------------------------------------------
 
-G4bool G4VTwistSurface::IsSameBoundary(G4VTwistSurface *surface1, G4int areacode1,
-                                  G4VTwistSurface *surface2, G4int areacode2 ) const
+G4bool
+G4VTwistSurface::IsSameBoundary(G4VTwistSurface* surf1, G4int areacode1,
+                                G4VTwistSurface* surf2, G4int areacode2 ) const
 {
    //
    // IsSameBoundary
@@ -600,41 +626,38 @@ G4bool G4VTwistSurface::IsSameBoundary(G4VTwistSurface *surface1, G4int areacode
    G4bool iscorner[2] = {IsCorner(areacode1, testbitmode), 
                          IsCorner(areacode2, testbitmode)};
 
-   if (iscorner[0] && iscorner[1]) {
+   if (iscorner[0] && iscorner[1])
+   {
       // on corner 
       G4ThreeVector corner1 = 
-           surface1->ComputeGlobalPoint(surface1->GetCorner(areacode1));
+           surf1->ComputeGlobalPoint(surf1->GetCorner(areacode1));
       G4ThreeVector corner2 = 
-           surface2->ComputeGlobalPoint(surface2->GetCorner(areacode2));
+           surf2->ComputeGlobalPoint(surf2->GetCorner(areacode2));
 
-      if ((corner1 - corner2).mag() < kCarTolerance) {
-         return true;
-      } else {
-         return false;
-      }
-    
-   } else if ((IsBoundary(areacode1, testbitmode) && (!iscorner[0])) &&
-              (IsBoundary(areacode2, testbitmode) && (!iscorner[1]))) {
+      if ((corner1 - corner2).mag() < kCarTolerance) { return true; }
+      else                                           { return false; }
+   }
+   else if ((IsBoundary(areacode1, testbitmode) && (!iscorner[0])) &&
+            (IsBoundary(areacode2, testbitmode) && (!iscorner[1])))
+   {
       // on boundary  
       G4ThreeVector d1, d2, ld1, ld2;
       G4ThreeVector x01, x02, lx01, lx02;
       G4int         type1, type2;
-      surface1->GetBoundaryParameters(areacode1, ld1, lx01, type1);
-      surface2->GetBoundaryParameters(areacode2, ld2, lx02, type2);
+      surf1->GetBoundaryParameters(areacode1, ld1, lx01, type1);
+      surf2->GetBoundaryParameters(areacode2, ld2, lx02, type2);
 
-      x01 = surface1->ComputeGlobalPoint(lx01);
-      x02 = surface2->ComputeGlobalPoint(lx02);
-      d1  = surface1->ComputeGlobalDirection(ld1);
-      d2  = surface2->ComputeGlobalDirection(ld2);
+      x01 = surf1->ComputeGlobalPoint(lx01);
+      x02 = surf2->ComputeGlobalPoint(lx02);
+      d1  = surf1->ComputeGlobalDirection(ld1);
+      d2  = surf2->ComputeGlobalDirection(ld2);
 
       if ((x01 - x02).mag() < kCarTolerance &&
-          (d1 - d2).mag() < kCarTolerance) {
-        return true;
-      } else {
-        return false;
-      }
-
-   } else {
+          (d1 - d2).mag() < kCarTolerance) { return true; }
+      else                                 { return false; }
+   }
+   else
+   {
       return false;
    }
 }
@@ -642,19 +665,20 @@ G4bool G4VTwistSurface::IsSameBoundary(G4VTwistSurface *surface1, G4int areacode
 //=====================================================================
 //* GetBoundaryParameters ---------------------------------------------
 
-void G4VTwistSurface::GetBoundaryParameters(const G4int         &areacode,
-                                             G4ThreeVector &d,
-                                             G4ThreeVector &x0,
-                                             G4int         &boundarytype) const
+void G4VTwistSurface::GetBoundaryParameters(const G4int& areacode,
+                                             G4ThreeVector& d,
+                                             G4ThreeVector& x0,
+                                             G4int& boundarytype) const
 {
    // areacode must be one of them:
    // sAxis0 & sAxisMin, sAxis0 & sAxisMax,
    // sAxis1 & sAxisMin, sAxis1 & sAxisMax.
    
-   G4int i;
-   for (i=0; i<4; i++) {
+   for (G4int i=0; i<4; ++i)
+   {
       if (fBoundaries[i].GetBoundaryParameters(areacode, d, x0,
-                                               boundarytype)) {
+                                               boundarytype))
+      {
          return;
       }
    }
@@ -672,13 +696,14 @@ void G4VTwistSurface::GetBoundaryParameters(const G4int         &areacode,
 //* GetBoundaryAtPZ ---------------------------------------------------
 
 G4ThreeVector G4VTwistSurface::GetBoundaryAtPZ(G4int areacode,
-                                          const G4ThreeVector &p) const
+                                               const G4ThreeVector& p) const
 {
    // areacode must be one of them:
    // sAxis0 & sAxisMin, sAxis0 & sAxisMax,
    // sAxis1 & sAxisMin, sAxis1 & sAxisMax.
 
-   if (areacode & sAxis0 && areacode & sAxis1) {
+   if (areacode & sAxis0 && areacode & sAxis1)
+   {
      std::ostringstream message;
      message << "Point is in the corner area." << G4endl
              << "        This function returns "
@@ -693,15 +718,18 @@ G4ThreeVector G4VTwistSurface::GetBoundaryAtPZ(G4int areacode,
    G4int         boundarytype;
    G4bool        found = false;
    
-   for (G4int i=0; i<4; i++) {
+   for (G4int i=0; i<4; ++i)
+   {
       if (fBoundaries[i].GetBoundaryParameters(areacode, d, x0, 
-                                                boundarytype)){
+                                               boundarytype))
+      {
          found = true;
          continue;
       }
    }
 
-   if (!found) {
+   if (!found)
+   {
      std::ostringstream message;
      message << "Not registered boundary." << G4endl
              << "        Boundary at areacode " << areacode << G4endl
@@ -711,7 +739,8 @@ G4ThreeVector G4VTwistSurface::GetBoundaryAtPZ(G4int areacode,
    }
 
    if (((boundarytype & sAxisPhi) == sAxisPhi) ||
-       ((boundarytype & sAxisRho) == sAxisRho)) {
+       ((boundarytype & sAxisRho) == sAxisRho))
+   {
      std::ostringstream message;
      message << "Not a z-depended line boundary." << G4endl
              << "        Boundary at areacode " << areacode << G4endl
@@ -725,9 +754,11 @@ G4ThreeVector G4VTwistSurface::GetBoundaryAtPZ(G4int areacode,
 //=====================================================================
 //* SetCorner ---------------------------------------------------------
 
-void G4VTwistSurface::SetCorner(G4int areacode, G4double x, G4double y, G4double z)
+void G4VTwistSurface::SetCorner(G4int areacode,
+                                G4double x, G4double y, G4double z)
 {
-   if ((areacode & sCorner) != sCorner){
+   if ((areacode & sCorner) != sCorner)
+   {
      std::ostringstream message;
      message << "Area code must represents corner." << G4endl
              << "        areacode " << areacode;
@@ -755,9 +786,8 @@ void G4VTwistSurface::GetBoundaryAxis(G4int areacode, EAxis axis[]) const
      G4Exception("G4VTwistSurface::GetBoundaryAxis()", "GeomSolids0003",
                  FatalException, "Not located on a boundary!");
    }
-   G4int i;
-   for (i=0; i<2; i++) {
-
+   for (G4int i=0; i<2; ++i)
+   {
       G4int whichaxis = 0 ;
       if (i == 0) {
          whichaxis = sAxis0;
@@ -830,21 +860,22 @@ void G4VTwistSurface::GetBoundaryLimit(G4int areacode, G4double limit[]) const
 //=====================================================================
 //* SetBoundary -------------------------------------------------------
 
-void G4VTwistSurface::SetBoundary(const G4int         &axiscode,
-                             const G4ThreeVector &direction,
-                             const G4ThreeVector &x0,
-                             const G4int         &boundarytype)
+void G4VTwistSurface::SetBoundary(const G4int& axiscode,
+                                  const G4ThreeVector& direction,
+                                  const G4ThreeVector& x0,
+                                  const G4int& boundarytype)
 {
    G4int code = (~sAxisMask) & axiscode;
    if ((code == (sAxis0 & sAxisMin)) ||
        (code == (sAxis0 & sAxisMax)) ||
        (code == (sAxis1 & sAxisMin)) ||
-       (code == (sAxis1 & sAxisMax))) {
-
-      G4int i;
+       (code == (sAxis1 & sAxisMax)))
+   {
       G4bool done = false;
-      for (i=0; i<4; i++) {
-         if (fBoundaries[i].IsEmpty()) {
+      for (auto i=0; i<4; ++i)
+      {
+         if (fBoundaries[i].IsEmpty())
+         {
             fBoundaries[i].SetFields(axiscode, direction,
                                      x0, boundarytype);
             done = true;
@@ -852,11 +883,14 @@ void G4VTwistSurface::SetBoundary(const G4int         &axiscode,
          }
       }
 
-      if (!done) {
+      if (!done)
+      {
          G4Exception("G4VTwistSurface::SetBoundary()", "GeomSolids0003",
                       FatalException, "Number of boundary exceeding 4!");
       }
-   } else {
+   }
+   else
+   {
       std::ostringstream message;
       message << "Invalid axis-code." << G4endl
               << "        axiscode = "
@@ -900,7 +934,6 @@ G4int G4VTwistSurface::GetFace( G4int i, G4int j, G4int k,
   }
 
   else {
-
     std::ostringstream message;
     message << "Not correct side number: "
             << GetName() << G4endl
@@ -908,8 +941,6 @@ G4int G4VTwistSurface::GetFace( G4int i, G4int j, G4int k,
             << "0,1,2,3,4 or 5" << ".";
     G4Exception("G4TwistSurface::G4GetFace()", "GeomSolids0002",
                 FatalException, message);
-
-
   }
 
   return -1 ;  // wrong face
@@ -925,50 +956,64 @@ G4int G4VTwistSurface::GetNode( G4int i, G4int j, G4int k,
   // (i,j) -> node number
   // Depends on the side iside and the used meshing of the surface
 
-  if ( iside == 0 ) {
+  if ( iside == 0 )
+  {
     // lower endcap is kxk squared. 
     // n = k 
     return i * k + j ;
   }
 
-  if ( iside == 1 ) {
+  if ( iside == 1 )
+  {
     // upper endcap is kxk squared. Shift by k*k
     // n = k 
     return  k*k + i*k + j ;
   }
 
-  else if ( iside == 2 ) {
+  else if ( iside == 2 )
+  {
     // front side.
-    if      ( i == 0 )     {   return       j ;  }
-    else if ( i == n-1 )   {   return k*k + j ;  } 
-    else                   {   return 2*k*k + 4*(i-1)*(k-1) + j ; }
+    if      ( i == 0 )   { return       j ;  }
+    else if ( i == n-1 ) { return k*k + j ;  } 
+    else                 { return 2*k*k + 4*(i-1)*(k-1) + j ; }
   }
 
-  else if ( iside == 3 ) {
+  else if ( iside == 3 )
+  {
     // right side
-    if      ( i == 0 )     {   return       (j+1)*k - 1 ; } 
-    else if ( i == n-1 )   {   return k*k + (j+1)*k - 1 ; }
-    else                   {   return 2*k*k + 4*(i-1)*(k-1) + (k-1) + j ; }
-  }
-  else if ( iside == 4 ) {
-    // back side.
-    if      ( i == 0 )     {   return   k*k - 1 - j ; }               // reversed order
-    else if ( i == n-1 )   {   return 2*k*k - 1 - j ; }               // reversed order 
-    else                   {   return 2*k*k + 4*(i-1)*(k-1) + 2*(k-1) + j ; // normal order
+    if      ( i == 0 )   { return       (j+1)*k - 1 ; } 
+    else if ( i == n-1 ) { return k*k + (j+1)*k - 1 ; }
+    else
+    {
+      return 2*k*k + 4*(i-1)*(k-1) + (k-1) + j ;
     }
   }
-  else if ( iside == 5 ) {
-    // left side 
-    if      ( i == 0 )     {   return k*k   - (j+1)*k ; }             // reversed order
-    else if ( i == n-1)    {   return 2*k*k - (j+1)*k ; }             // reverded order
-    else {
-      if ( j == k-1 )      {   return 2*k*k + 4*(i-1)*(k-1) ; }       // special case
-      else                 {   return 2*k*k + 4*(i-1)*(k-1) + 3*(k-1) + j ; }  // normal order
-    }  
+  else if ( iside == 4 )
+  {
+    // back side
+    if      ( i == 0 )   { return   k*k - 1 - j ; }    // reversed order
+    else if ( i == n-1 ) { return 2*k*k - 1 - j ; }    // reversed order 
+    else
+    {
+      return 2*k*k + 4*(i-1)*(k-1) + 2*(k-1) + j ; // normal order
+    }
   }
-
-  else {
-
+  else if ( iside == 5 )
+  {
+    // left side 
+    if      ( i == 0 )   { return k*k   - (j+1)*k ; }  // reversed order
+    else if ( i == n-1)  { return 2*k*k - (j+1)*k ; }  // reverded order
+    else
+    {
+      if ( j == k-1 ) { return 2*k*k + 4*(i-1)*(k-1) ; } // special case
+      else
+      {
+        return 2*k*k + 4*(i-1)*(k-1) + 3*(k-1) + j ; // normal order
+      }
+    }
+  }
+  else
+  {
     std::ostringstream message;
     message << "Not correct side number: "
             << GetName() << G4endl
@@ -983,9 +1028,9 @@ G4int G4VTwistSurface::GetNode( G4int i, G4int j, G4int k,
 //=====================================================================
 //* GetEdgeVisiblility ------------------------------------------------
 
-G4int G4VTwistSurface::GetEdgeVisibility( G4int i, G4int j, G4int k, G4int n, G4int number, G4int orientation) 
+G4int G4VTwistSurface::GetEdgeVisibility( G4int i, G4int j, G4int k, G4int n,
+                                          G4int number, G4int orientation ) 
 {
-
   // clockwise filling         -> positive orientation
   // counter clockwise filling -> negative orientation 
 
@@ -1010,7 +1055,8 @@ G4int G4VTwistSurface::GetEdgeVisibility( G4int i, G4int j, G4int k, G4int n, G4
 
   // check first invisible faces
 
-  if ( ( i>0 && i<n-2 ) && ( j>0 && j<k-2 ) ) {
+  if ( ( i>0 && i<n-2 ) && ( j>0 && j<k-2 ) )
+  {
     return -1 ;   // always invisible, signs:   ----
   }
   
@@ -1019,8 +1065,8 @@ G4int G4VTwistSurface::GetEdgeVisibility( G4int i, G4int j, G4int k, G4int n, G4
   if ( orientation < 0 ) { number = ( 3 - number ) ;  }
   
   // check true edges
-  if ( ( j>=1 && j<=k-3 ) ) {
-
+  if ( ( j>=1 && j<=k-3 ) )
+  {
     if ( i == 0 )  {        // signs (A):  ---+  
       return ( number == 3 ) ? 1 : -1 ;
     }
@@ -1029,7 +1075,8 @@ G4int G4VTwistSurface::GetEdgeVisibility( G4int i, G4int j, G4int k, G4int n, G4
       return  ( number == 1 ) ? 1 : -1 ; 
     }
     
-    else {
+    else
+    {
       std::ostringstream message;
       message << "Not correct face number: " << GetName() << " !";
       G4Exception("G4TwistSurface::G4GetEdgeVisibility()",
@@ -1037,8 +1084,8 @@ G4int G4VTwistSurface::GetEdgeVisibility( G4int i, G4int j, G4int k, G4int n, G4
     }
   }
   
-  if ( ( i>=1 && i<=n-3 ) ) {
-
+  if ( ( i>=1 && i<=n-3 ) )
+  {
     if ( j == 0 )  {        // signs (D):  +---
       return ( number == 0 ) ? 1 : -1 ;
     }
@@ -1047,7 +1094,8 @@ G4int G4VTwistSurface::GetEdgeVisibility( G4int i, G4int j, G4int k, G4int n, G4
       return  ( number == 2 ) ? 1 : -1 ; 
     }
 
-    else {
+    else
+    {
       std::ostringstream message;
       message << "Not correct face number: " << GetName() << " !";
       G4Exception("G4TwistSurface::G4GetEdgeVisibility()",
@@ -1068,7 +1116,8 @@ G4int G4VTwistSurface::GetEdgeVisibility( G4int i, G4int j, G4int k, G4int n, G4
   else if ( i == n-2 && j == 0 ) {   // signs (d) : ++--
     return ( number == 0 || number == 1 ) ? 1 : -1 ;
   }
-  else {
+  else
+  {
     std::ostringstream message;
     message << "Not correct face number: " << GetName() << " !";
     G4Exception("G4TwistSurface::G4GetEdgeVisibility()",
@@ -1094,7 +1143,7 @@ void G4VTwistSurface::DebugPrint() const
    G4ThreeVector C = fRot * GetCorner(sC0Max1Max) + fTrans;
    G4ThreeVector D = fRot * GetCorner(sC0Min1Max) + fTrans;
   
-   G4cout << "/* G4VTwistSurface::DebugPrint():-------------------------------"
+   G4cout << "/* G4VTwistSurface::DebugPrint():--------------------------"
           << G4endl;
    G4cout << "/* Name = " << fName << G4endl;
    G4cout << "/* Axis = " << std::hex << fAxis[0] << " "
@@ -1122,7 +1171,7 @@ void G4VTwistSurface::DebugPrint() const
 
 G4VTwistSurface::CurrentStatus::CurrentStatus() 
 {
-  for (size_t i=0; i<G4VSURFACENXX; i++)
+  for (size_t i=0; i<G4VSURFACENXX; ++i)
   {
     fDistance[i] = kInfinity;
     fAreacode[i] = sOutside;
@@ -1147,15 +1196,15 @@ G4VTwistSurface::CurrentStatus::~CurrentStatus()
 //* CurrentStatus::SetCurrentStatus -----------------------------------
 
 void
-G4VTwistSurface::CurrentStatus::SetCurrentStatus(G4int                i, 
-                                            G4ThreeVector       &xx, 
-                                            G4double            &dist, 
-                                            G4int               &areacode, 
-                                            G4bool              &isvalid,
-                                            G4int                nxx,
-                                            EValidate            validate,
-                                      const G4ThreeVector *p, 
-                                      const G4ThreeVector *v)
+G4VTwistSurface::CurrentStatus::SetCurrentStatus(G4int i, 
+                                                 G4ThreeVector& xx, 
+                                                 G4double& dist, 
+                                                 G4int& areacode, 
+                                                 G4bool& isvalid,
+                                                 G4int nxx,
+                                                 EValidate validate,
+                                           const G4ThreeVector* p, 
+                                           const G4ThreeVector* v)
 {
   fDistance[i]  = dist;
   fAreacode[i]  = areacode;
@@ -1163,7 +1212,7 @@ G4VTwistSurface::CurrentStatus::SetCurrentStatus(G4int                i,
   fXX[i]        = xx;
   fNXX          = nxx;
   fLastValidate = validate;
-  if (p)
+  if (p != nullptr)
   {
     fLastp = *p;
   }
@@ -1172,7 +1221,7 @@ G4VTwistSurface::CurrentStatus::SetCurrentStatus(G4int                i,
     G4Exception("G4VTwistSurface::CurrentStatus::SetCurrentStatus()",
                 "GeomSolids0003", FatalException, "SetCurrentStatus: p = 0!");
   }
-  if (v) 
+  if (v != nullptr) 
   {
     fLastv = *v;
   }
@@ -1187,24 +1236,24 @@ G4VTwistSurface::CurrentStatus::SetCurrentStatus(G4int                i,
 //* CurrentStatus::ResetfDone -----------------------------------------
 
 void
-G4VTwistSurface::CurrentStatus::ResetfDone(EValidate     validate,
-                                const G4ThreeVector *p, 
-                                const G4ThreeVector *v)
+G4VTwistSurface::CurrentStatus::ResetfDone(EValidate validate,
+                                     const G4ThreeVector* p, 
+                                     const G4ThreeVector* v)
 
 {
-  if (validate == fLastValidate && p && *p == fLastp)
+  if (validate == fLastValidate && p != nullptr && *p == fLastp)
   {
-     if (!v || (*v == fLastv)) return;
+     if (v == nullptr || (*v == fLastv)) return;
   }         
   G4ThreeVector xx(kInfinity, kInfinity, kInfinity);
-  for (size_t i=0; i<G4VSURFACENXX; i++)
+  for (size_t i=0; i<G4VSURFACENXX; ++i)
   {
     fDistance[i] = kInfinity;
     fAreacode[i] = sOutside;
     fIsValid[i]  = false;
     fXX[i] = xx;   // bug in old code ( was fXX[i] =  xx[i]  )
   }
-  fNXX   = 0;
+  fNXX = 0;
   fLastp.set(kInfinity, kInfinity, kInfinity);
   fLastv.set(kInfinity, kInfinity, kInfinity);
   fLastValidate = kUninitialized;
@@ -1245,10 +1294,10 @@ G4VTwistSurface::Boundary::~Boundary()
 //* Boundary::SetFields -----------------------------------------------
 
 void
-G4VTwistSurface::Boundary::SetFields(const G4int         &areacode, 
-                                const G4ThreeVector &d, 
-                                const G4ThreeVector &x0, 
-                                const G4int         &boundarytype)
+G4VTwistSurface::Boundary::SetFields(const G4int& areacode, 
+                                const G4ThreeVector& d, 
+                                const G4ThreeVector& x0, 
+                                const G4int& boundarytype)
 {
   fBoundaryAcode     = areacode;
   fBoundaryDirection = d;
@@ -1269,14 +1318,15 @@ G4bool G4VTwistSurface::Boundary::IsEmpty() const
 //* Boundary::GetBoundaryParameters -----------------------------------
 
 G4bool
-G4VTwistSurface::Boundary::GetBoundaryParameters(const G4int         &areacode, 
-                                                  G4ThreeVector &d,
-                                                  G4ThreeVector &x0, 
-                                                  G4int  &boundarytype) const 
+G4VTwistSurface::Boundary::GetBoundaryParameters(const G4int& areacode, 
+                                                  G4ThreeVector& d,
+                                                  G4ThreeVector& x0, 
+                                                  G4int& boundarytype) const 
 {  
   // areacode must be one of them:
   // sAxis0 & sAxisMin, sAxis0 & sAxisMax,
   // sAxis1 & sAxisMin, sAxis1 & sAxisMax
+  //
   if ((areacode & sAxis0) && (areacode & sAxis1))
   {
     std::ostringstream message;
