@@ -23,15 +23,11 @@
 // * acceptance of all terms of the Geant4 Software license.          *
 // ********************************************************************
 //
-//
-//
-// G.Barrand
-
-//#define DEBUG
+// Author: G.Barrand
+// --------------------------------------------------------------------
 
 #ifdef G4UI_BUILD_WIN32_SESSION
 
-// this :
 #include "G4UIWin32.hh"
 
 #include <string.h>
@@ -40,8 +36,6 @@
 #include <windowsx.h>
 #include <wingdi.h>
 
-#include <strstream>
-
 #include "G4UImanager.hh"
 #include "G4StateManager.hh"
 #include "G4UIcommandTree.hh"
