@@ -73,7 +73,7 @@ G4UItcsh::G4UItcsh(const G4String& prompt, G4int maxhist)
   tcgetattr(0, &tios);
 
   // read a shell history file
-  const char* path = getenv("HOME");
+  const char* path = std::getenv("HOME");
   if( path == NULL ) return;
 
   G4String homedir= path;
@@ -99,7 +99,7 @@ G4UItcsh::~G4UItcsh()
 /////////////////////
 {
   // store a shell history
-  const char* path = getenv("HOME");
+  const char* path = std::getenv("HOME");
   if( path == NULL ) return;
 
   G4String homedir= path;
