@@ -61,12 +61,9 @@
 //--------------------------------------------------------------
 
 #include "G4DynamicParticle.hh"
-#include "G4PhysicalConstants.hh"
-#include "G4SystemOfUnits.hh"
 #include "G4DecayProducts.hh"
 #include "G4LorentzVector.hh"
 #include "G4ParticleDefinition.hh"
-#include "G4ParticleTable.hh"
 #include "G4IonTable.hh"
 #include "G4PrimaryParticle.hh"
 
@@ -76,23 +73,27 @@ G4Allocator<G4DynamicParticle>*& pDynamicParticleAllocator()
     return _instance;
 }
 
-static const G4double EnergyMomentumRelationAllowance = 1.0e-2*keV;
+static const G4double EnergyMomentumRelationAllowance = 1.0e-2*CLHEP::keV;
+static const G4double EnergyMRA2 = 
+  EnergyMomentumRelationAllowance*EnergyMomentumRelationAllowance;
 
 ////////////////////
 G4DynamicParticle::G4DynamicParticle():
 		   theMomentumDirection(0.0,0.0,1.0),
+		   thePolarization(0.0,0.0,0.0),
 		   theParticleDefinition(nullptr),
+		   theElectronOccupancy(nullptr),
+                   thePreAssignedDecayProducts(nullptr),
+		   primaryParticle(nullptr),
 		   theKineticEnergy(0.0),
+                   theLogKineticEnergy(DBL_MAX),
  		   theProperTime(0.0),
 		   theDynamicalMass(0.0),
 		   theDynamicalCharge(0.0),
 		   theDynamicalSpin(0.0),
 		   theDynamicalMagneticMoment(0.0),
-		   theElectronOccupancy(nullptr),
-                   thePreAssignedDecayProducts(nullptr),
                    thePreAssignedDecayTime(-1.0),
 		   verboseLevel(1),
-		   primaryParticle(nullptr),
                    thePDGcode(0)
 {
 }
@@ -104,18 +105,20 @@ G4DynamicParticle::G4DynamicParticle(const G4ParticleDefinition * aParticleDefin
 				     const G4ThreeVector& aMomentumDirection,
 				     G4double aKineticEnergy):
 		   theMomentumDirection(aMomentumDirection),
+		   thePolarization(0.0,0.0,0.0),
 		   theParticleDefinition(aParticleDefinition),
+		   theElectronOccupancy(nullptr),
+                   thePreAssignedDecayProducts(nullptr),
+		   primaryParticle(nullptr),
 		   theKineticEnergy(aKineticEnergy),
+		   theLogKineticEnergy(DBL_MAX),
  		   theProperTime(0.0),
 		   theDynamicalMass(aParticleDefinition->GetPDGMass()),
 		   theDynamicalCharge(aParticleDefinition->GetPDGCharge()),
 		   theDynamicalSpin(aParticleDefinition->GetPDGSpin()),
 		   theDynamicalMagneticMoment(aParticleDefinition->GetPDGMagneticMoment()),
-		   theElectronOccupancy(0),
-                   thePreAssignedDecayProducts(nullptr),
                    thePreAssignedDecayTime(-1.0),
 		   verboseLevel(1),
-		   primaryParticle(0),
                    thePDGcode(0)
 {
 }
@@ -126,18 +129,20 @@ G4DynamicParticle::G4DynamicParticle(const G4ParticleDefinition * aParticleDefin
 				     G4double aKineticEnergy,
                                      const G4double dynamicalMass):
 		   theMomentumDirection(aMomentumDirection),
+		   thePolarization(0.0,0.0,0.0),
 		   theParticleDefinition(aParticleDefinition),
+		   theElectronOccupancy(nullptr),
+                   thePreAssignedDecayProducts(nullptr),
+		   primaryParticle(nullptr),
 		   theKineticEnergy(aKineticEnergy),
+                   theLogKineticEnergy(DBL_MAX),
  		   theProperTime(0.0),
 		   theDynamicalMass(aParticleDefinition->GetPDGMass()),
 		   theDynamicalCharge(aParticleDefinition->GetPDGCharge()),
 		   theDynamicalSpin(aParticleDefinition->GetPDGSpin()),
 		   theDynamicalMagneticMoment(aParticleDefinition->GetPDGMagneticMoment()),
-		   theElectronOccupancy(nullptr),
-                   thePreAssignedDecayProducts(nullptr),
                    thePreAssignedDecayTime(-1.0),
 		   verboseLevel(1),
-		   primaryParticle(nullptr),
                    thePDGcode(0)
 {
   if (std::abs(theDynamicalMass-dynamicalMass)> EnergyMomentumRelationAllowance) {
@@ -149,74 +154,80 @@ G4DynamicParticle::G4DynamicParticle(const G4ParticleDefinition * aParticleDefin
 ////////////////////
 G4DynamicParticle::G4DynamicParticle(const G4ParticleDefinition * aParticleDefinition,
                                      const G4ThreeVector& aParticleMomentum):
+		   thePolarization(0.0,0.0,0.0),
 		   theParticleDefinition(aParticleDefinition),
+		   theElectronOccupancy(nullptr),
+                   thePreAssignedDecayProducts(nullptr),
+		   primaryParticle(nullptr),
 		   theKineticEnergy(0.0),
+                   theLogKineticEnergy(DBL_MAX),
        		   theProperTime(0.0),
 		   theDynamicalMass(aParticleDefinition->GetPDGMass()),
 		   theDynamicalCharge(aParticleDefinition->GetPDGCharge()),
 		   theDynamicalSpin(aParticleDefinition->GetPDGSpin()),
 		   theDynamicalMagneticMoment(aParticleDefinition->GetPDGMagneticMoment()),
-		   theElectronOccupancy(nullptr),
-                   thePreAssignedDecayProducts(nullptr),
                    thePreAssignedDecayTime(-1.0),
 		   verboseLevel(1),
-		   primaryParticle(nullptr),
                    thePDGcode(0)
 {
   SetMomentum(aParticleMomentum);  // 3-dim momentum is given
 }
 
-
 ////////////////////
 G4DynamicParticle::G4DynamicParticle(const G4ParticleDefinition * aParticleDefinition,
 				     const G4LorentzVector   &aParticleMomentum):
+		   thePolarization(0.0,0.0,0.0),
 		   theParticleDefinition(aParticleDefinition),
+		   theElectronOccupancy(nullptr),
+                   thePreAssignedDecayProducts(nullptr),
+		   primaryParticle(nullptr),
 		   theKineticEnergy(0.0),
+                   theLogKineticEnergy(DBL_MAX),
  		   theProperTime(0.0),
 		   theDynamicalMass(aParticleDefinition->GetPDGMass()),
 		   theDynamicalCharge(aParticleDefinition->GetPDGCharge()),
 		   theDynamicalSpin(aParticleDefinition->GetPDGSpin()),
 		   theDynamicalMagneticMoment(aParticleDefinition->GetPDGMagneticMoment()),
-		   theElectronOccupancy(nullptr),
-                   thePreAssignedDecayProducts(nullptr),
                    thePreAssignedDecayTime(-1.0),
 		   verboseLevel(1),
-		   primaryParticle(nullptr),
                    thePDGcode(0)
 {
   Set4Momentum(aParticleMomentum);  // 4-momentum vector (Lorentz vector) is given
 }
 
+////////////////////
 G4DynamicParticle::G4DynamicParticle(const G4ParticleDefinition * aParticleDefinition,
                                      G4double totalEnergy,
 				     const G4ThreeVector &aParticleMomentum):
+		   thePolarization(0.0,0.0,0.0),
                    theParticleDefinition(aParticleDefinition),
+		   theElectronOccupancy(nullptr),
+                   thePreAssignedDecayProducts(nullptr),
+		   primaryParticle(nullptr),
 		   theKineticEnergy(0.0),
+                   theLogKineticEnergy(DBL_MAX),
                    theProperTime(0.0),
 		   theDynamicalMass(aParticleDefinition->GetPDGMass()),
 		   theDynamicalCharge(aParticleDefinition->GetPDGCharge()),
 		   theDynamicalSpin(aParticleDefinition->GetPDGSpin()),
 		   theDynamicalMagneticMoment(aParticleDefinition->GetPDGMagneticMoment()),
-		   theElectronOccupancy(nullptr),
-                   thePreAssignedDecayProducts(nullptr),
                    thePreAssignedDecayTime(-1.0),
 		   verboseLevel(1),
-		   primaryParticle(nullptr),
                    thePDGcode(0)
 {
   // total energy and 3-dim momentum are given
   G4double pModule2 = aParticleMomentum.mag2();
-  if (pModule2>0.0) {
+  if (pModule2 > 0.0) {
     G4double mass2 = totalEnergy*totalEnergy - pModule2;
     G4double PDGmass2 = (aParticleDefinition->GetPDGMass())*(aParticleDefinition->GetPDGMass());
     SetMomentumDirection(aParticleMomentum.unit());
-    if (mass2 < EnergyMomentumRelationAllowance*EnergyMomentumRelationAllowance) {
+    if (mass2 < EnergyMRA2) {
       theDynamicalMass = 0.;
       SetKineticEnergy(totalEnergy);
     } else {
-      if (std::abs(PDGmass2-mass2)>EnergyMomentumRelationAllowance*EnergyMomentumRelationAllowance){
-      theDynamicalMass = std::sqrt(mass2);
-      SetKineticEnergy(totalEnergy-theDynamicalMass);
+      if (std::abs(PDGmass2-mass2)>EnergyMRA2){
+        theDynamicalMass = std::sqrt(mass2);
+        SetKineticEnergy(totalEnergy-theDynamicalMass);
       } else {
 	SetKineticEnergy(totalEnergy-theDynamicalMass);
       }
@@ -230,19 +241,20 @@ G4DynamicParticle::G4DynamicParticle(const G4ParticleDefinition * aParticleDefin
 ////////////////////
 G4DynamicParticle::G4DynamicParticle(const G4DynamicParticle &right):
   theMomentumDirection(right.theMomentumDirection),
-  theParticleDefinition(right.theParticleDefinition),
   thePolarization(right.thePolarization),
+  theParticleDefinition(right.theParticleDefinition),
+  theElectronOccupancy(nullptr),
+  thePreAssignedDecayProducts(nullptr),	// Do not copy preassignedDecayProducts
+  primaryParticle(right.primaryParticle),
   theKineticEnergy(right.theKineticEnergy),
-  theProperTime(0.0),
+  theLogKineticEnergy(right.theLogKineticEnergy),
+  theProperTime(right.theProperTime),
   theDynamicalMass(right.theDynamicalMass),
   theDynamicalCharge(right.theDynamicalCharge),
   theDynamicalSpin(right.theDynamicalSpin),
   theDynamicalMagneticMoment(right.theDynamicalMagneticMoment),
-  theElectronOccupancy(nullptr),
-  thePreAssignedDecayProducts(nullptr),	// Do not copy preassignedDecayProducts
   thePreAssignedDecayTime(-1.0),
   verboseLevel(right.verboseLevel),
-  primaryParticle(right.primaryParticle),
   thePDGcode(right.thePDGcode)
 {
   if (right.theElectronOccupancy != nullptr) {
@@ -264,7 +276,6 @@ G4DynamicParticle::~G4DynamicParticle()
   theElectronOccupancy =nullptr;
 }
 
-
 ////////////////////
 // -- operators ----
 ////////////////////
@@ -291,7 +302,7 @@ G4DynamicParticle & G4DynamicParticle::operator=(const G4DynamicParticle &right)
     }
 
     // thePreAssignedDecayProducts must not be copied.
-    thePreAssignedDecayProducts = 0;
+    thePreAssignedDecayProducts = nullptr;
     thePreAssignedDecayTime = -1.0;
 
     verboseLevel = right.verboseLevel;
@@ -324,40 +335,37 @@ void G4DynamicParticle::SetDefinition(const G4ParticleDefinition * aParticleDefi
 
   theParticleDefinition = aParticleDefinition;
 
-  // set Dynamic mass/chrge
+  // set Dynamic mass/charge
   theDynamicalMass = theParticleDefinition->GetPDGMass();
   theDynamicalCharge = theParticleDefinition->GetPDGCharge();
   theDynamicalSpin = theParticleDefinition->GetPDGSpin();
   theDynamicalMagneticMoment = theParticleDefinition->GetPDGMagneticMoment();
 
   // Set electron orbits
-  if (theElectronOccupancy != nullptr) delete theElectronOccupancy;
-  theElectronOccupancy = nullptr;
-
+  if (theElectronOccupancy != nullptr) {
+    delete theElectronOccupancy;
+    theElectronOccupancy = nullptr;
+  }
 }
 
 ////////////////////
-G4int G4DynamicParticle::operator==(const G4DynamicParticle &right) const
+G4bool G4DynamicParticle::operator==(const G4DynamicParticle &right) const
 {
   return (this == (G4DynamicParticle *) &right);
 }
 
 ////////////////////
-G4int G4DynamicParticle::operator!=(const G4DynamicParticle &right) const
+G4bool G4DynamicParticle::operator!=(const G4DynamicParticle &right) const
 {
   return (this != (G4DynamicParticle *) &right);
 }
 
-
-
 ////////////////////
 // -- AllocateElectronOccupancy --
 ////////////////////
 void  G4DynamicParticle::AllocateElectronOccupancy()
 {
-  const G4ParticleDefinition* particle = GetDefinition();
-
-  if (G4IonTable::IsIon(particle)) {
+  if (G4IonTable::IsIon(theParticleDefinition)) {
     // Only ions can have ElectronOccupancy
     theElectronOccupancy = new G4ElectronOccupancy();
 
@@ -376,7 +384,7 @@ void G4DynamicParticle::SetMomentum(const G4ThreeVector &momentum)
   if (pModule2>0.0) {
     G4double mass = theDynamicalMass;
     SetMomentumDirection(momentum.unit());
-    SetKineticEnergy(std::sqrt(pModule2 + mass*mass)-mass);
+    SetKineticEnergy(pModule2/(std::sqrt(pModule2 + mass*mass)+mass));
   } else {
     SetMomentumDirection(1.0,0.0,0.0);
     SetKineticEnergy(0.0);
@@ -392,9 +400,9 @@ void G4DynamicParticle::Set4Momentum(const G4LorentzVector &momentum )
     G4double totalenergy = momentum.t();
     G4double mass2 = totalenergy*totalenergy - pModule2;
     G4double PDGmass2 = (theParticleDefinition->GetPDGMass())*(theParticleDefinition->GetPDGMass());
-    if (mass2 < EnergyMomentumRelationAllowance*EnergyMomentumRelationAllowance) {
+    if (mass2 < EnergyMRA2) {
       theDynamicalMass = 0.;
-    } else if (std::abs(PDGmass2-mass2)>EnergyMomentumRelationAllowance*EnergyMomentumRelationAllowance){
+    } else if (std::abs(PDGmass2-mass2)>EnergyMRA2){
       theDynamicalMass = std::sqrt(mass2);
     }
     SetKineticEnergy(totalenergy-theDynamicalMass);
@@ -404,7 +412,6 @@ void G4DynamicParticle::Set4Momentum(const G4LorentzVector &momentum )
   }
 }
 
-
 ////////////////////
 //  --- Dump Information --
 ////////////////////
@@ -415,19 +422,19 @@ void G4DynamicParticle::DumpInfo(G4int mode) const
     G4cout << " G4DynamicParticle::DumpInfo():: !!!Particle type not defined !!!! " << G4endl;
   } else {
     G4cout << " Particle type - " << theParticleDefinition->GetParticleName() << G4endl
-         << "   mass:        " << GetMass()/GeV <<  "[GeV]" <<G4endl
-         << "   charge:      " << GetCharge()/eplus <<  "[e]" <<G4endl
+         << "   mass:        " << GetMass()/CLHEP::GeV <<  "[GeV]" <<G4endl
+	   << "   charge:      " << GetCharge()/CLHEP::eplus <<  "[e]" <<G4endl
          << "   Direction x: " << GetMomentumDirection().x() << ", y: "
 	 << GetMomentumDirection().y() << ", z: "
                              << GetMomentumDirection().z() << G4endl
-         << "   Total Momentum = " << GetTotalMomentum() /GeV << "[GeV]" << G4endl
-         << "   Momentum: "    << GetMomentum().x() /GeV << "[GeV]" << ", y: "
-                               << GetMomentum().y() /GeV << "[GeV]" << ", z: "
-                               << GetMomentum().z() /GeV << "[GeV]" << G4endl
-         << "   Total Energy   = " << GetTotalEnergy()/GeV << "[GeV]"  << G4endl
-         << "   Kinetic Energy = " << GetKineticEnergy() /GeV << "[GeV]" << G4endl
-	 << " MagneticMoment  [MeV/T]: " << GetMagneticMoment()/MeV*tesla << G4endl
-         << "   ProperTime     = " << GetProperTime() /ns <<  "[ns]" << G4endl;
+         << "   Total Momentum = " << GetTotalMomentum()/CLHEP::GeV << "[GeV]" << G4endl
+         << "   Momentum: "    << GetMomentum().x() /CLHEP::GeV << "[GeV]" << ", y: "
+                               << GetMomentum().y() /CLHEP::GeV << "[GeV]" << ", z: "
+                               << GetMomentum().z() /CLHEP::GeV << "[GeV]" << G4endl
+         << "   Total Energy   = " << GetTotalEnergy()/CLHEP::GeV << "[GeV]"  << G4endl
+         << "   Kinetic Energy = " << GetKineticEnergy() /CLHEP::GeV << "[GeV]" << G4endl
+	 << " MagneticMoment  [MeV/T]: " << GetMagneticMoment()/CLHEP::MeV*CLHEP::tesla << G4endl
+         << "   ProperTime     = " << GetProperTime() /CLHEP::ns <<  "[ns]" << G4endl;
 
     if (mode>0) {
       if( theElectronOccupancy != nullptr) {
@@ -442,28 +449,9 @@ void G4DynamicParticle::DumpInfo(G4int) const
   return;
 }
 #endif
-///////////////////////
-//
-void G4DynamicParticle::SetMass(G4double newMass)
-{
-  if(std::abs(newMass-theParticleDefinition->GetPDGMass())>EnergyMomentumRelationAllowance*0.1) {
-    theDynamicalMass = newMass;
-  }
-}
+
 ////////////////////////
-G4double  G4DynamicParticle::GetElectronMass() const
+G4double G4DynamicParticle::GetElectronMass() const
 {
-  static G4ThreadLocal G4double electronMass = 0.0;
-
-  // check if electron exits and get the mass
-  if (electronMass<=0.0) {
-    G4ParticleDefinition* electron = G4ParticleTable::GetParticleTable()->FindParticle("e-");
-    if (electron == nullptr) {
-      G4Exception("G4DynamicParticle::GetElectronMass()","PART021",
- 		  FatalException,"G4DynamicParticle: G4Electron is not defined !!");
-    }
-    electronMass = electron->GetPDGMass();
-  }
-
-  return electronMass;
+  return CLHEP::electron_mass_c2;
 }
