@@ -104,7 +104,7 @@ G4ElectronOccupancy& G4ElectronOccupancy::operator=(const G4ElectronOccupancy& r
   return *this;
 }
 
-G4int G4ElectronOccupancy::operator==(const G4ElectronOccupancy& right) const
+G4bool G4ElectronOccupancy::operator==(const G4ElectronOccupancy& right) const
 {
   G4int index;
   G4bool value = true;
@@ -113,15 +113,15 @@ G4int G4ElectronOccupancy::operator==(const G4ElectronOccupancy& right) const
       value = value && 
          (theOccupancies[index] == right.theOccupancies[index]) ;
     } else if ((index < theSizeOfOrbit ) && ( index >= right.theSizeOfOrbit)) {
-      value = value && (theOccupancies[index] == 0);
+      value = value && (theOccupancies[index] == false);
     } else if ((index >= theSizeOfOrbit ) && ( index <right.theSizeOfOrbit)) {
-      value = value && (right.theOccupancies[index] == 0);
+      value = value && (right.theOccupancies[index] == false);
     }
   }
   return value;
 }
 
-G4int G4ElectronOccupancy::operator!=(const G4ElectronOccupancy& right) const
+G4bool G4ElectronOccupancy::operator!=(const G4ElectronOccupancy& right) const
 {
   return !(*this == right);
 }
