@@ -61,12 +61,12 @@ G4VShortLivedParticle::G4VShortLivedParticle(const G4String&  aName,
 
 G4VShortLivedParticle::~G4VShortLivedParticle() {}
 
-G4int G4VShortLivedParticle::operator==(const G4VShortLivedParticle &right) const
+G4bool G4VShortLivedParticle::operator==(const G4VShortLivedParticle &right) const
 {
   return (this->GetParticleName() == right.GetParticleName());
 }
 
-G4int G4VShortLivedParticle::operator!=(const G4VShortLivedParticle &right) const
+G4bool G4VShortLivedParticle::operator!=(const G4VShortLivedParticle &right) const
 {
   return (this->GetParticleName() != right.GetParticleName());
 }
