@@ -41,12 +41,14 @@
 #include "G4ParticleDefinition.hh"
 #include "G4ParticleTable.hh"
 #include "G4ProcessManager.hh"
+#include "G4HadronicParameters.hh"
+
 
 G4BertiniNeutronBuilder::
 G4BertiniNeutronBuilder() 
 {
-  theMin = 0;
-  theMax = 9.9*GeV;
+  theMin = 0.0;
+  theMax = G4HadronicParameters::Instance()->GetMaxEnergyTransitionFTF_Cascade();
   theModel = new G4CascadeInterface;
 }
 
@@ -58,5 +60,3 @@ Build(G4NeutronInelasticProcess * aP)
   aP->RegisterMe(theModel);
 }
 
-
-// 2002 by J.P. Wellisch
