@@ -49,7 +49,7 @@
 G4FTFBinaryPionBuilder::
 G4FTFBinaryPionBuilder(G4bool quasiElastic)
 {
-  theMin = 4*GeV;
+  theMin = G4HadronicParameters::Instance()->GetMinEnergyTransitionFTF_Cascade();
   theMax = G4HadronicParameters::Instance()->GetMaxEnergy();
   theModel = new G4TheoFSGenerator("FTFB");
 
