@@ -38,10 +38,11 @@
 #include "G4ProcessManager.hh"
 #include "G4HadronicParameters.hh"
 
+
 G4FTFPKaonBuilder::
 G4FTFPKaonBuilder(G4bool quasiElastic) 
 {
-  theMin = 4*GeV;
+  theMin = G4HadronicParameters::Instance()->GetMinEnergyTransitionFTF_Cascade();
   theMax = G4HadronicParameters::Instance()->GetMaxEnergy();
   theModel = new G4TheoFSGenerator("FTFP");
 
