@@ -46,10 +46,11 @@
 #include "G4BGGNucleonInelasticXS.hh"
 #include "G4HadronicParameters.hh"
 
+
 G4FTFPNeutronBuilder::
 G4FTFPNeutronBuilder(G4bool quasiElastic) 
 {
-  theMin =   4*GeV;
+  theMin = G4HadronicParameters::Instance()->GetMinEnergyTransitionFTF_Cascade();
   theMax = G4HadronicParameters::Instance()->GetMaxEnergy();
   theModel = new G4TheoFSGenerator("FTFP");
 
@@ -92,4 +93,3 @@ Build(G4NeutronInelasticProcess * aP)
     
 }
 
- // 2002 by J.P. Wellisch
