@@ -47,7 +47,7 @@
 G4QGSBinaryProtonBuilder::
 G4QGSBinaryProtonBuilder(G4bool quasiElastic) 
  {
-   theMin = 12*GeV;
+   theMin = G4HadronicParameters::Instance()->GetMinEnergyTransitionQGS_FTF();
    theModel = new G4TheoFSGenerator("QGSB");
 
    theStringModel = new G4QGSModel< G4QGSParticipants >;
