@@ -42,18 +42,14 @@
 #include "G4ParticleDefinition.hh"
 #include "G4ParticleTable.hh"
 #include "G4ProcessManager.hh"
-#include "G4ChipsKaonMinusInelasticXS.hh"
-#include "G4ChipsKaonPlusInelasticXS.hh"
-#include "G4ChipsKaonZeroInelasticXS.hh"
 #include "G4BGGPionInelasticXS.hh"
-#include "G4CrossSectionDataSetRegistry.hh"
 #include "G4HadronicParameters.hh"
 
 
 G4QGSPPiKBuilder::
 G4QGSPPiKBuilder(G4bool quasiElastic) 
 {    
-  theMin = 12*GeV;
+  theMin = G4HadronicParameters::Instance()->GetMinEnergyTransitionQGS_FTF();
   theModel = new G4TheoFSGenerator("QGSP");
 
   theStringModel = new G4QGSModel< G4QGSParticipants >;
@@ -105,8 +101,7 @@ Build(G4KaonPlusInelasticProcess * aP)
 {
   theModel->SetMinEnergy(theMin);
   theModel->SetMaxEnergy( G4HadronicParameters::Instance()->GetMaxEnergy() );
-    aP->RegisterMe(theModel);
-    aP->AddDataSet(G4CrossSectionDataSetRegistry::Instance()->GetCrossSectionDataSet(G4ChipsKaonPlusInelasticXS::Default_Name()));
+  aP->RegisterMe(theModel);
 }
 
 void G4QGSPPiKBuilder::
@@ -115,7 +110,6 @@ Build(G4KaonMinusInelasticProcess * aP)
   theModel->SetMinEnergy(theMin);
   theModel->SetMaxEnergy( G4HadronicParameters::Instance()->GetMaxEnergy() );
   aP->RegisterMe(theModel);
-  aP->AddDataSet(G4CrossSectionDataSetRegistry::Instance()->GetCrossSectionDataSet(G4ChipsKaonMinusInelasticXS::Default_Name()));
 }
 
 void G4QGSPPiKBuilder::
@@ -124,7 +118,6 @@ Build(G4KaonZeroLInelasticProcess * aP)
   theModel->SetMinEnergy(theMin);
   theModel->SetMaxEnergy( G4HadronicParameters::Instance()->GetMaxEnergy() );
   aP->RegisterMe(theModel);
-  aP->AddDataSet(G4CrossSectionDataSetRegistry::Instance()->GetCrossSectionDataSet(G4ChipsKaonZeroInelasticXS::Default_Name()));
 }
 
 void G4QGSPPiKBuilder::
@@ -135,4 +128,3 @@ Build(G4KaonZeroSInelasticProcess * aP)
   aP->RegisterMe(theModel);
 }
 
-// 2002 by J.P. Wellisch
