@@ -51,7 +51,7 @@
 G4QGSPPionBuilder::
 G4QGSPPionBuilder(G4bool quasiElastic) 
 {
-  theMin = 12*GeV;
+  theMin = G4HadronicParameters::Instance()->GetMinEnergyTransitionQGS_FTF();
   theModel = new G4TheoFSGenerator("QGSP");
 
   theStringModel = new G4QGSModel< G4QGSParticipants >;
@@ -98,5 +98,3 @@ Build(G4PionMinusInelasticProcess * aP)
   aP->RegisterMe(theModel);
 }
 
-
-// 2002 by J.P. Wellisch
