@@ -100,6 +100,7 @@ G4EmDNAPhysics_option7::G4EmDNAPhysics_option7(G4int ver, const G4String&) :
   param->SetAuger(true);  
   param->SetAugerCascade(true);  
   param->SetDeexcitationIgnoreCut(true);
+  param->ActivateDNA();
 
   SetPhysicsType(bElectromagnetic);
 }
@@ -161,8 +162,7 @@ void G4EmDNAPhysics_option7::ConstructProcess()
       
       G4DNAElectronSolvation* solvation =
         new G4DNAElectronSolvation("e-_G4DNAElectronSolvation");
-      G4DNAOneStepThermalizationModel* therm =
-        new G4DNAOneStepThermalizationModel();
+      auto therm = G4DNASolvationModelFactory::GetMacroDefinedModel();
       therm->SetHighEnergyLimit(10.*eV); // limit of the Uehara's model
       solvation->SetEmModel(therm);
       ph->RegisterProcess(solvation, particle);
