@@ -69,6 +69,7 @@ G4EmLEPTSPhysics::G4EmLEPTSPhysics( const G4String& name)
  : G4VPhysicsConstructor(name)
 {
   G4EmParameters::Instance()->SetDefaults();
+  SetPhysicsType(bElectromagnetic);
 }
 
 //....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......
@@ -100,10 +101,11 @@ void G4EmLEPTSPhysics::ConstructParticle()
 void G4EmLEPTSPhysics::ConstructProcess()
 {
 
-  aParticleIterator->reset();
+	auto myParticleIterator=GetParticleIterator();
+	myParticleIterator->reset();
 
-  while( (*aParticleIterator)() ){
-    G4ParticleDefinition * particle = aParticleIterator->value();
+  while( (*myParticleIterator)() ){
+    G4ParticleDefinition * particle = myParticleIterator->value();
     G4String               particleName = particle->GetParticleName();
     G4ProcessManager     * manager = particle->GetProcessManager();
     G4cout << " particle " << particle->GetParticleName() << " manager " << manager << G4endl; //GDEB    
