@@ -148,10 +148,10 @@ G4EmPenelopePhysics::G4EmPenelopePhysics(G4int ver, const G4String&)
   param->SetUseMottCorrection(true);  
   param->SetMscStepLimitType(fUseSafetyPlus);
   param->SetMscSkin(3);            
-  param->SetMscRangeFactor(0.2);   
+  param->SetMscRangeFactor(0.08);
   param->SetMuHadLateralDisplacement(true);
   param->SetFluo(true);
-  //param->SetAugerCascade(true);
+  param->SetMaxNIELEnergy(1*MeV);
   param->SetPIXEElectronCrossSectionModel("Penelope");
   SetPhysicsType(bElectromagnetic);
 }
@@ -232,8 +232,9 @@ void G4EmPenelopePhysics::ConstructProcess()
   G4double highEnergyLimit = G4EmParameters::Instance()->MscEnergyLimit();
 
   // nuclear stopping
+  G4double nielEnergyLimit = G4EmParameters::Instance()->MaxNIELEnergy();
   G4NuclearStopping* pnuc = new G4NuclearStopping();
-  G4NuclearStopping* inuc = new G4NuclearStopping();
+  pnuc->SetMaxKinEnergy(nielEnergyLimit);
 
   //Applicability range for Penelope models
   //for higher energies, the Standard models are used   
@@ -395,7 +396,7 @@ void G4EmPenelopePhysics::ConstructProcess()
 
       ph->RegisterProcess(hmsc, particle);
       ph->RegisterProcess(ionIoni, particle);
-      ph->RegisterProcess(inuc, particle);
+      ph->RegisterProcess(pnuc, particle);
 
     } else if (particleName == "pi+" ||
                particleName == "pi-" ) {
@@ -423,6 +424,7 @@ void G4EmPenelopePhysics::ConstructProcess()
 	       particleName == "anti_proton") {
 
       G4hMultipleScattering* pmsc = new G4hMultipleScattering();
+      pmsc->SetEmModel(new G4WentzelVIModel());
       G4hIonisation* hIoni = new G4hIonisation();
 
       ph->RegisterProcess(pmsc, particle);
@@ -430,7 +432,6 @@ void G4EmPenelopePhysics::ConstructProcess()
       ph->RegisterProcess(pb, particle);
       ph->RegisterProcess(pp, particle);
       ph->RegisterProcess(new G4CoulombScattering(), particle);
-      ph->RegisterProcess(pnuc, particle);
 
     } else if (particleName == "B+" ||
 	       particleName == "B-" ||
@@ -471,7 +472,6 @@ void G4EmPenelopePhysics::ConstructProcess()
     
   // Nuclear stopping
   pnuc->SetMaxKinEnergy(MeV);
-  inuc->SetMaxKinEnergy(MeV);
   
   // Deexcitation
   //
