@@ -107,6 +107,7 @@
 #include "G4PhysicsListHelper.hh"
 #include "G4BuilderType.hh"
 #include "G4EmModelActivator.hh"
+#include "G4GammaGeneralProcess.hh"
 
 // factory
 #include "G4PhysicsConstructorFactory.hh"
@@ -134,6 +135,7 @@ G4EmStandardPhysics_option3::G4EmStandardPhysics_option3(G4int ver,
   param->SetLateralDisplacementAlg96(true);
   //param->SetUseICRU90Data(true);
   param->SetFluo(true);
+  param->SetMaxNIELEnergy(1*MeV);
   SetPhysicsType(bElectromagnetic);
 }
 
@@ -181,6 +183,7 @@ void G4EmStandardPhysics_option3::ConstructProcess()
     G4cout << "### " << GetPhysicsName() << " Construct Processes " << G4endl;
   }
   G4PhysicsListHelper* ph = G4PhysicsListHelper::GetPhysicsListHelper();
+  G4LossTableManager* man = G4LossTableManager::Instance();
 
   // muon & hadron bremsstrahlung and pair production
   G4MuBremsstrahlung* mub = new G4MuBremsstrahlung();
@@ -196,8 +199,9 @@ void G4EmStandardPhysics_option3::ConstructProcess()
   G4hMultipleScattering* hmsc = new G4hMultipleScattering("ionmsc");
 
   // nuclear stopping
+  G4double nielEnergyLimit = G4EmParameters::Instance()->MaxNIELEnergy();
   G4NuclearStopping* pnuc = new G4NuclearStopping();
-  pnuc->SetMaxKinEnergy(MeV);
+  pnuc->SetMaxKinEnergy(nielEnergyLimit);
 
   // Add standard EM Processes
   G4ParticleTable* table = G4ParticleTable::GetParticleTable();
@@ -208,14 +212,24 @@ void G4EmStandardPhysics_option3::ConstructProcess()
 
       G4PhotoElectricEffect* pee = new G4PhotoElectricEffect();
       pee->SetEmModel(new G4LivermorePhotoElectricModel());
-      ph->RegisterProcess(pee, particle);
 
-      G4ComptonScattering* cs = new G4ComptonScattering;
+      G4ComptonScattering* cs = new G4ComptonScattering();
       cs->SetEmModel(new G4KleinNishinaModel());
-      ph->RegisterProcess(cs,  particle);
 
-      ph->RegisterProcess(new G4GammaConversion(), particle);
-      ph->RegisterProcess(new G4RayleighScattering(), particle);
+      if(G4EmParameters::Instance()->GeneralProcessActive()) {
+        G4GammaGeneralProcess* sp = new G4GammaGeneralProcess();
+        sp->AddEmProcess(pee);
+        sp->AddEmProcess(cs);
+        sp->AddEmProcess(new G4GammaConversion());
+        sp->AddEmProcess(new G4RayleighScattering());
+        man->SetGammaGeneralProcess(sp);
+	ph->RegisterProcess(sp, particle);
+      } else {
+	ph->RegisterProcess(pee,particle);
+	ph->RegisterProcess(cs, particle);
+	ph->RegisterProcess(new G4GammaConversion(), particle);
+	ph->RegisterProcess(new G4RayleighScattering(), particle);
+      }
  
     } else if (particleName == "e-") {
 
