@@ -23,7 +23,6 @@
 // * acceptance of all terms of the Geant4 Software license.          *
 // ********************************************************************
 //
-//
 //---------------------------------------------------------------------------
 //
 // ClassName:   G4HadronDElasticPhysics
@@ -70,6 +69,8 @@
 #include "G4BGGPionElasticXS.hh"
 #include "G4NeutronElasticXS.hh"
 
+#include "G4ComponentGGHadronNucleusXsc.hh"
+#include "G4ComponentGGNuclNuclXsc.hh"
 #include "G4CrossSectionDataSetRegistry.hh"
 
 #include "G4ChipsKaonPlusElasticXS.hh"
@@ -124,6 +125,12 @@ void G4HadronDElasticPhysics::ConstructProcess()
   G4CrossSectionElastic* anucxs = 
     new G4CrossSectionElastic(anuc->GetComponentCrossSection());
 
+  G4VCrossSectionDataSet* theComponentGGHadronNucleusData = 
+    new G4CrossSectionElastic( new G4ComponentGGHadronNucleusXsc );
+
+  G4VCrossSectionDataSet* theComponentGGNuclNuclData = 
+    new G4CrossSectionElastic( new G4ComponentGGNuclNuclXsc );
+
   G4HadronElastic* lhep0 = new G4HadronElastic();
   G4HadronElastic* lhep1 = new G4HadronElastic();
   lhep1->SetMaxEnergy(10.1*MeV);
@@ -141,24 +148,24 @@ void G4HadronDElasticPhysics::ConstructProcess()
     G4ProcessManager* pmanager = particle->GetProcessManager();
     G4String pname = particle->GetParticleName();
     if(pname == "anti_lambda"  ||
-       pname == "anti_neutron" ||
        pname == "anti_omega-"  || 
        pname == "anti_sigma-"  || 
+       pname == "anti_sigma0"  || 
        pname == "anti_sigma+"  || 
-       pname == "anti_xi-"  || 
-       pname == "anti_xi0"  || 
-       pname == "lambda"    || 
-       pname == "omega-"    || 
-       pname == "sigma-"    || 
-       pname == "sigma+"    || 
-       pname == "xi-"       || 
-       pname == "alpha"     ||
-       pname == "deuteron"  ||
-       pname == "triton"    
-       ) {
+       pname == "anti_xi-"     || 
+       pname == "anti_xi0"     || 
+       pname == "lambda"       || 
+       pname == "omega-"       || 
+       pname == "sigma-"       || 
+       pname == "sigma0"       ||
+       pname == "sigma+"       || 
+       pname == "xi-"          ||       
+       pname == "xi0"
+      ) {
       
       hel = new G4HadronElasticProcess();
       hel->RegisterMe(lhep0);
+      hel->AddDataSet( theComponentGGHadronNucleusData );
       pmanager->AddDiscreteProcess(hel);
       if(verbose > 1) {
 	G4cout << "### HadronDElasticPhysics: " << hel->GetProcessName()
@@ -169,7 +176,6 @@ void G4HadronDElasticPhysics::ConstructProcess()
 
       hel = new G4HadronElasticProcess();
       hel->AddDataSet(new G4BGGNucleonElasticXS(particle));
-      //hel->AddDataSet(new G4CHIPSElasticXS());
       model = new G4DiffuseElastic();
       hel->RegisterMe(lhep1);
       hel->RegisterMe(model);
@@ -178,11 +184,10 @@ void G4HadronDElasticPhysics::ConstructProcess()
 	G4cout << "### HadronDElasticPhysics: " << hel->GetProcessName()
 	       << " added for " << particle->GetParticleName() << G4endl;
       }
-
     } else if(pname == "neutron") {   
 
       hel = new G4HadronElasticProcess();
-      hel->AddDataSet(G4CrossSectionDataSetRegistry::Instance()->GetCrossSectionDataSet(G4NeutronElasticXS::Default_Name()));
+      hel->AddDataSet(new G4NeutronElasticXS());
       model = new G4DiffuseElastic();
       hel->RegisterMe(lhep1);
       hel->RegisterMe(model);
@@ -192,7 +197,6 @@ void G4HadronDElasticPhysics::ConstructProcess()
 	       << hel->GetProcessName()
 	       << " added for " << particle->GetParticleName() << G4endl;
       }
-
     } else if (pname == "pi+" || pname == "pi-") { 
 
       hel = new G4HadronElasticProcess();
@@ -205,46 +209,38 @@ void G4HadronDElasticPhysics::ConstructProcess()
 	G4cout << "### HadronDElasticPhysics: " << hel->GetProcessName()
 	       << " added for " << particle->GetParticleName() << G4endl;
       }
-
-    } else if(pname == "kaon-") {
-      
-      hel = new G4HadronElasticProcess();
-      hel->AddDataSet(G4CrossSectionDataSetRegistry::Instance()->GetCrossSectionDataSet(G4ChipsKaonMinusElasticXS::Default_Name()));
-      model = new G4DiffuseElastic();
-      hel->RegisterMe(lhep1);
-      hel->RegisterMe(model);
-      pmanager->AddDiscreteProcess(hel);
-      if(verbose > 1) {
-	G4cout << "### HadronElasticPhysics: " << hel->GetProcessName()
-	       << " added for " << particle->GetParticleName() << G4endl;
-      }
-    } else if(pname == "kaon+") {
-      
-      hel = new G4HadronElasticProcess();
-      hel->AddDataSet(G4CrossSectionDataSetRegistry::Instance()->GetCrossSectionDataSet(G4ChipsKaonPlusElasticXS::Default_Name()));
-      model = new G4DiffuseElastic();
-      hel->RegisterMe(lhep1);
-      hel->RegisterMe(model);
-      pmanager->AddDiscreteProcess(hel);
-      if(verbose > 1) {
-	G4cout << "### HadronElasticPhysics: " << hel->GetProcessName()
-	       << " added for " << particle->GetParticleName() << G4endl;
-      }
-    } else if(pname == "kaon0S"    || 
+    } else if(pname == "kaon-"     || 
+	      pname == "kaon+"     || 
+	      pname == "kaon0S"    || 
 	      pname == "kaon0L" 
 	      ) {
       
       hel = new G4HadronElasticProcess();
-      hel->AddDataSet(G4CrossSectionDataSetRegistry::Instance()->GetCrossSectionDataSet(G4ChipsKaonZeroElasticXS::Default_Name()));
-      model = new G4DiffuseElastic();
+              model = new G4DiffuseElastic();
       hel->RegisterMe(lhep1);
       hel->RegisterMe(model);
+      hel->AddDataSet( theComponentGGHadronNucleusData );
       pmanager->AddDiscreteProcess(hel);
       if(verbose > 1) {
 	G4cout << "### HadronElasticPhysics: " << hel->GetProcessName()
 	       << " added for " << particle->GetParticleName() << G4endl;
       }
+    } else if(pname == "alpha"     ||
+              pname == "deuteron"  ||
+              pname == "triton"    ||
+              pname == "He3"
+             ) {
+      hel = new G4HadronElasticProcess();
+      hel->AddDataSet(theComponentGGNuclNuclData);
+      hel->RegisterMe(lhep0);
+      pmanager->AddDiscreteProcess(hel);
+      if(verbose > 1) {
+	G4cout << "### HadronElasticPhysics: " << hel->GetProcessName()
+	       << " added for " << particle->GetParticleName() << G4endl;
+      }
+
     } else if(
+       pname == "anti_neutron"   ||
        pname == "anti_proton"    || 
        pname == "anti_alpha"     ||
        pname == "anti_deuteron"  ||
