@@ -38,8 +38,6 @@
 #include "G4SystemOfUnits.hh"
 
 #include "G4ProcessManager.hh"
-#include "G4CrossSectionInelastic.hh"
-#include "G4ComponentGGHadronNucleusXsc.hh"
 #include "G4HadronCaptureProcess.hh"
 #include "G4NeutronRadCapture.hh"
 #include "G4NeutronCaptureXS.hh"
@@ -103,14 +101,6 @@ void G4HadronPhysicsFTFP_BERT_HP::Neutron()
 
 void G4HadronPhysicsFTFP_BERT_HP::ExtraConfiguration()
 {
-  //Modify XS for kaons
-  auto xsk = new G4ComponentGGHadronNucleusXsc();
-  G4VCrossSectionDataSet * kaonxs = new G4CrossSectionInelastic(xsk);
-  G4PhysListUtil::FindInelasticProcess(G4KaonMinus::KaonMinus())->AddDataSet(kaonxs);
-  G4PhysListUtil::FindInelasticProcess(G4KaonPlus::KaonPlus())->AddDataSet(kaonxs);
-  G4PhysListUtil::FindInelasticProcess(G4KaonZeroShort::KaonZeroShort())->AddDataSet(kaonxs);
-  G4PhysListUtil::FindInelasticProcess(G4KaonZeroLong::KaonZeroLong())->AddDataSet(kaonxs);
-
   // --- Neutrons ---
   const G4ParticleDefinition* neutron = G4Neutron::Neutron();
   G4HadronicProcess* capture = G4PhysListUtil::FindCaptureProcess(neutron);
