@@ -275,6 +275,11 @@ G4ITNavigator1::LocateGlobalPointAndSetup( const G4ThreeVector& globalPoint,
                                   &parentTouchable));
               }
               break;
+           case kExternal:
+             G4Exception("G4ITNavigator1::LocateGlobalPointAndSetup()",
+                         "GeomNav0001", FatalException,
+                         "Not applicable for external volumes.");
+             break;
           }
           fEntering = false;
           fBlockedPhysicalVolume = 0;
@@ -507,6 +512,11 @@ G4ITNavigator1::LocateGlobalPointAndSetup( const G4ThreeVector& globalPoint,
                                              localPoint);
         }
         break;
+      case kExternal:
+        G4Exception("G4ITNavigator1::LocateGlobalPointAndSetup()",
+                    "GeomNav0001", FatalException,
+                    "Not applicable for external volumes.");
+        break;
     }
 
     // LevelLocate returns true if it finds a daughter volume 
@@ -635,6 +645,11 @@ G4ITNavigator1::LocateGlobalPointWithinVolume(const G4ThreeVector& pGlobalpoint)
                      "GeomNav0001", FatalException,
                      "Not applicable for replicated volumes.");
          break;
+       case kExternal:
+         G4Exception("G4ITNavigator1::LocateGlobalPointWithinVolume()",
+                     "GeomNav0001", FatalException,
+                     "Not applicable for external volumes.");
+         break;
      }
    }
 
@@ -970,6 +985,10 @@ G4double G4ITNavigator1::ComputeStep( const G4ThreeVector &pGlobalpoint,
         G4Exception("G4ITNavigator1::ComputeStep()", "GeomNav0001",
                     FatalException, "Not applicable for replicated volumes.");
         break;
+      case kExternal:
+        G4Exception("G4ITNavigator1::ComputeStep()", "GeomNav0001",
+                    FatalException, "Not applicable for external volumes.");
+        break;
     }
   }
   else
@@ -1312,26 +1331,32 @@ void G4ITNavigator1::SetupHierarchy()
       case kReplica:
         freplicaNav.ComputeTransformation(fHistory.GetReplicaNo(i), current);
         break;
-      case kParameterised:
-        G4int replicaNo;
-        pParam = current->GetParameterisation();
-        replicaNo = fHistory.GetReplicaNo(i);
-        pSolid = pParam->ComputeSolid(replicaNo, current);
+      case kParameterised: {
+          G4int replicaNo;
+          pParam = current->GetParameterisation();
+          replicaNo = fHistory.GetReplicaNo(i);
+          pSolid = pParam->ComputeSolid(replicaNo, current);
 
-        // Set up dimensions & transform in solid/physical volume
-        //
-        pSolid->ComputeDimensions(pParam, replicaNo, current);
-        pParam->ComputeTransformation(replicaNo, current);
+          // Set up dimensions & transform in solid/physical volume
+          //
+          pSolid->ComputeDimensions(pParam, replicaNo, current);
+          pParam->ComputeTransformation(replicaNo, current);
 
-        G4TouchableHistory touchable( fHistory );
-        touchable.MoveUpHistory();  // move up to the parent level
-      
-        // Set up the correct solid and material in Logical Volume
-        //
-        G4LogicalVolume *pLogical = current->GetLogicalVolume();
-        pLogical->SetSolid( pSolid );
-        pLogical->UpdateMaterial( pParam ->
-          ComputeMaterial(replicaNo, current, &touchable) );
+          G4TouchableHistory touchable( fHistory );
+          touchable.MoveUpHistory();  // move up to the parent level
+        
+          // Set up the correct solid and material in Logical Volume
+          //
+          G4LogicalVolume *pLogical = current->GetLogicalVolume();
+          pLogical->SetSolid( pSolid );
+          pLogical->UpdateMaterial( pParam ->
+            ComputeMaterial(replicaNo, current, &touchable) );
+          break;
+      }
+      case kExternal:
+        G4Exception("G4ITNavigator1::SetupHierarchy()",
+                    "GeomNav0001", FatalException,
+                    "Not applicable for external volumes.");
         break;
     }
   }
@@ -1537,6 +1562,11 @@ G4ITNavigator1::GetMotherToDaughterTransform( G4VPhysicalVolume *pEnteringPhysVo
         pLogical->SetSolid( pSolid );
       }
       break;
+      case kExternal:
+        G4Exception("G4ITNavigator1::GetMotherToDaughterTransform()",
+                    "GeomNav0001", FatalException,
+                    "Not applicable for external volumes.");
+        break;
   }
   return G4AffineTransform(pEnteringPhysVol->GetRotation(), 
                            pEnteringPhysVol->GetTranslation()).Invert(); 
@@ -1780,6 +1810,11 @@ G4double G4ITNavigator1::ComputeSafety( const G4ThreeVector &pGlobalpoint,
           G4Exception("G4ITNavigator1::ComputeSafety()", "GeomNav0001",
                       FatalException, "Not applicable for replicated volumes.");
           break;
+        case kExternal:
+          G4Exception("G4ITNavigator1::ComputeSafety()",
+                      "GeomNav0001", FatalException,
+                      "Not applicable for external volumes.");
+         break;
       }
     }
     else
