@@ -298,6 +298,11 @@ G4ITNavigator2::LocateGlobalPointAndSetup( const G4ThreeVector& globalPoint,
                                   &parentTouchable));
               }
               break;
+           case kExternal:
+             G4Exception("G4ITNavigator2::LocateGlobalPointAndSetup()",
+                         "GeomNav0001", FatalException,
+                         "Not applicable for external volumes.");
+             break;
           }
           fEntering = false;
           fBlockedPhysicalVolume = 0;
@@ -530,6 +535,11 @@ G4ITNavigator2::LocateGlobalPointAndSetup( const G4ThreeVector& globalPoint,
                                              localPoint);
         }
         break;
+      case kExternal:
+        G4Exception("G4ITNavigator2::LocateGlobalPointAndSetup()",
+                    "GeomNav0001", FatalException,
+                    "Not applicable for external volumes.");
+        break;
     }
 
     // LevelLocate returns true if it finds a daughter volume 
@@ -672,6 +682,11 @@ G4ITNavigator2::LocateGlobalPointWithinVolume(const G4ThreeVector& pGlobalpoint)
                      "GeomNav0001", FatalException,
                      "Not applicable for replicated volumes.");
          break;
+       case kExternal:
+         G4Exception("G4ITNavigator2::LocateGlobalPointWithinVolume()",
+                     "GeomNav0001", FatalException,
+                     "Not applicable for external volumes.");
+         break;
      }
    }
 
@@ -1095,6 +1110,10 @@ G4double G4ITNavigator2::ComputeStep( const G4ThreeVector &pGlobalpoint,
         G4Exception("G4ITNavigator2::ComputeStep()", "GeomNav0001",
                     FatalException, "Not applicable for replicated volumes.");
         break;
+      case kExternal:
+        G4Exception("G4ITNavigator2::ComputeStep()", "GeomNav0001",
+                    FatalException, "Not applicable for external volumes.");
+        break;
     }
   }
   else
@@ -1449,6 +1468,7 @@ void G4ITNavigator2::SetupHierarchy()
         freplicaNav.ComputeTransformation(fHistory.GetReplicaNo(i), current);
         break;
       case kParameterised:
+      {
         G4int replicaNo;
         pParam = current->GetParameterisation();
         replicaNo = fHistory.GetReplicaNo(i);
@@ -1478,7 +1498,15 @@ void G4ITNavigator2::SetupHierarchy()
         pLogical->UpdateMaterial( pParam ->
           ComputeMaterial(replicaNo, current, pTouchable) );
         delete pTouchable;
-        break;
+      }
+      break;
+        
+      case kExternal:
+        G4Exception("G4ITNavigator2::SetupHierarchy()",
+                    "GeomNav0001", FatalException,
+                    "Not applicable for external volumes.");
+        break;        
+
     }
   }
 }
@@ -1685,6 +1713,11 @@ G4ITNavigator2::GetMotherToDaughterTransform( G4VPhysicalVolume *pEnteringPhysVo
         pLogical->SetSolid( pSolid );
       }
       break;
+      case kExternal:
+        G4Exception("G4ITNavigator2::GetMotherToDaughterTransform()",
+                    "GeomNav0001", FatalException,
+                    "Not applicable for external volumes.");
+        break;
   }
   return G4AffineTransform(pEnteringPhysVol->GetRotation(), 
                            pEnteringPhysVol->GetTranslation()).Invert(); 
@@ -2005,6 +2038,11 @@ G4double G4ITNavigator2::ComputeSafety( const G4ThreeVector &pGlobalpoint,
           G4Exception("G4ITNavigator2::ComputeSafety()", "GeomNav0001",
                       FatalException, "Not applicable for replicated volumes.");
           break;
+        case kExternal:
+          G4Exception("G4ITNavigator2::ComputeSafety()",
+                      "GeomNav0001", FatalException,
+                      "Not applicable for external volumes.");
+         break;
       }
     }
     else
