@@ -437,7 +437,7 @@ void G4DNAPTBIonisationModel::ReadDiffCSFile(const G4String& materialName,
     // To read and save the informations contained within the differential cross section files
 
     // get the path of the G4LEDATA data folder
-    char *path = getenv("G4LEDATA");
+    char *path = std::getenv("G4LEDATA");
     // if it is not found then quit and print error message
     if(!path)
     {
