@@ -541,7 +541,7 @@ G4MolecularConfiguration::~G4MolecularConfiguration()
 
 G4MolecularConfiguration*
 G4MolecularConfiguration::
-ChangeConfiguration(const G4ElectronOccupancy& newElectronOccupancy)
+ChangeConfiguration(const G4ElectronOccupancy& newElectronOccupancy) const
 {
   G4MolecularConfiguration* output =
       GetManager()->GetMolecularConfiguration(fMoleculeDefinition,
@@ -558,7 +558,7 @@ ChangeConfiguration(const G4ElectronOccupancy& newElectronOccupancy)
 //______________________________________________________________________________
 
 G4MolecularConfiguration*
-G4MolecularConfiguration::ChangeConfiguration(int charge)
+G4MolecularConfiguration::ChangeConfiguration(int charge) const
 {
   G4MolecularConfiguration* output =
       GetManager()->GetMolecularConfiguration(fMoleculeDefinition, charge);
@@ -584,7 +584,7 @@ G4MolecularConfiguration::operator=(G4MolecularConfiguration& /*right*/)
 /** Method used in Geant4-DNA to excite water molecules
  */
 G4MolecularConfiguration*
-G4MolecularConfiguration::ExciteMolecule(G4int ExcitedLevel)
+G4MolecularConfiguration::ExciteMolecule(G4int ExcitedLevel) const
 {
 //  MakeExceptionIfFinalized();
   CheckElectronOccupancy(__func__);
@@ -601,7 +601,7 @@ G4MolecularConfiguration::ExciteMolecule(G4int ExcitedLevel)
 /** Method used in Geant4-DNA to ionize water molecules
  */
 G4MolecularConfiguration*
-G4MolecularConfiguration::IonizeMolecule(G4int IonizedLevel)
+G4MolecularConfiguration::IonizeMolecule(G4int IonizedLevel) const
 {
 //  MakeExceptionIfFinalized();
   CheckElectronOccupancy(__func__);
@@ -633,7 +633,7 @@ G4MolecularConfiguration::IonizeMolecule(G4int IonizedLevel)
 //______________________________________________________________________________
 
 G4MolecularConfiguration* G4MolecularConfiguration::AddElectron(G4int orbit,
-                                                                G4int number)
+                                                                G4int number) const
 {
 //  MakeExceptionIfFinalized();
   CheckElectronOccupancy(__func__);
@@ -646,7 +646,7 @@ G4MolecularConfiguration* G4MolecularConfiguration::AddElectron(G4int orbit,
 
 G4MolecularConfiguration*
 G4MolecularConfiguration::RemoveElectron(G4int orbit,
-                                         G4int number)
+                                         G4int number) const
 {
 //  MakeExceptionIfFinalized();
   CheckElectronOccupancy(__func__);
@@ -675,7 +675,7 @@ G4MolecularConfiguration::RemoveElectron(G4int orbit,
 
 G4MolecularConfiguration*
 G4MolecularConfiguration::MoveOneElectron(G4int orbitToFree,
-                                          G4int orbitToFill)
+                                          G4int orbitToFill) const
 {
 //  MakeExceptionIfFinalized();
   CheckElectronOccupancy(__func__);
@@ -786,7 +786,7 @@ void G4MolecularConfiguration::PrintState() const
 
 // added - to be transformed in a "Decay method"
 const vector<const G4MolecularDissociationChannel*>*
-  G4MolecularConfiguration::GetDecayChannel() const
+  G4MolecularConfiguration::GetDissociationChannels() const
 {
   // if (fElectronOccupancy == 0) return 0;
   return fMoleculeDefinition->GetDecayChannels(this);
@@ -800,7 +800,7 @@ G4int G4MolecularConfiguration::GetFakeParticleID() const
   else G4Exception("G4MolecularConfiguration::GetMoleculeID",
                    "",
                    FatalErrorInArgument,
-                   "You should first enter a molecule defintion");
+                   "You should first enter a molecule definition");
 
   return INT_MAX;
 }
