@@ -37,53 +37,49 @@
 #include "G4SystemOfUnits.hh"
 #include "G4ParticleTable.hh"
 
-// ######################################################################
-// ###                         Hydrogen                               ###
-// ######################################################################
-G4H2O* G4H2O::theInstance = 0;
+G4H2O* G4H2O::fgpInstance = nullptr;
 
 G4H2O* G4H2O::Definition()
 {
-  if (theInstance != 0) return theInstance;
+    if (fgpInstance != nullptr)
+    {
+        return fgpInstance;
+    }
 
-  const G4String name = "H2O";
-  // search in particle table]
-  G4ParticleTable* pTable = G4ParticleTable::GetParticleTable();
-  G4ParticleDefinition* anInstance = pTable->FindParticle(name);
+    const G4String name = "H2O";
+    G4ParticleTable* pTable = G4ParticleTable::GetParticleTable();
+    G4ParticleDefinition* pInstance = pTable->FindParticle(name);
 
-  if (anInstance == 0)
-  {
-    const G4String formatedName = "H_{2}O";
+    if (pInstance == nullptr)
+    {
+        const G4String formatedName = "H_{2}O";
 
-    // create molecule
-    //
-    //      G4MoleculeDefinition(const G4String& name,
-    //          G4double mass,
-    //          G4double diffCoeff,
-    //          G4int    charge = 0,
-    //          G4int    electronicLevels = 0,
-    //          G4double radius = -1,
-    //          G4int    atomsNumber = -1,
-    //          G4double lifetime = -1,
-    //          G4String aType = "",
-    //          G4FakeParticleID ID = G4FakeParticleID::Create()
-    //      );
+        G4double mass = 18.0153 * g / Avogadro * c_squared;
+        pInstance = new G4MoleculeDefinition(name,
+                                              mass,
+                                              2e-5 * (cm * cm / s), // diffusion coefficient
+                                              0, // charge
+                                              8, // electronic levels
+                                              2.75 * angstrom, // radius
+                                              3, // atoms number
+                                              0 // lifetime
+        ); //picosecond set in dissociation process
 
-    G4double mass = 18.0153 * g / Avogadro * c_squared;
-    anInstance = new G4MoleculeDefinition(name, mass, 2e-5 * (cm * cm / s),
-                                          0, // charge
-                                          8, 2.75 * angstrom, 3,
-                                          0 /*lifetime*/); //picosecond set in dissociation process
+        ((G4MoleculeDefinition*) pInstance)->SetLevelOccupation(0);
+        ((G4MoleculeDefinition*) pInstance)->SetLevelOccupation(1);
+        ((G4MoleculeDefinition*) pInstance)->SetLevelOccupation(2);
+        ((G4MoleculeDefinition*) pInstance)->SetLevelOccupation(3);
+        ((G4MoleculeDefinition*) pInstance)->SetLevelOccupation(4);
+        ((G4MoleculeDefinition*) pInstance)->SetFormatedName(formatedName);
 
-    ((G4MoleculeDefinition*) anInstance)->SetLevelOccupation(0);
-    ((G4MoleculeDefinition*) anInstance)->SetLevelOccupation(1);
-    ((G4MoleculeDefinition*) anInstance)->SetLevelOccupation(2);
-    ((G4MoleculeDefinition*) anInstance)->SetLevelOccupation(3);
-    ((G4MoleculeDefinition*) anInstance)->SetLevelOccupation(4);
-    ((G4MoleculeDefinition*) anInstance)->SetFormatedName(formatedName);
-
-  }
-  theInstance = reinterpret_cast<G4H2O*>(anInstance);
-  return theInstance;
+    }
+    fgpInstance = reinterpret_cast<G4H2O*>(pInstance);
+    return fgpInstance;
 }
 
+G4H2O* G4H2O::DefinitionIfExists()
+{
+    return fgpInstance;
+}
+
+
