@@ -672,10 +672,22 @@ G4double G4DNABrownianTransportation::AlongStepGetPhysicalInteractionLength(cons
 
   }
   else
-    */
-  //{
+  {
     diffusionCoefficient = GetMolecule(track)->GetDiffusionCoefficient();
-  //}
+  }
+  */
+  
+  diffusionCoefficient = GetMolecule(track)->GetDiffusionCoefficient();
+  
+  // To avoid divide by zero of diffusionCoefficient  
+  if(diffusionCoefficient <= 0)
+  {
+    State(fGeometryLimitedStep) = false;
+    State(theInteractionTimeLeft) = DBL_MAX;
+    State(fTransportEndPosition) = track.GetPosition();
+    return 0;
+  }
+  
 
   State(fComputeLastPosition) = false;
   State(fTimeStepReachedLimit) = false;
