@@ -23,7 +23,7 @@
 // * acceptance of all terms of the Geant4 Software license.          *
 // ********************************************************************
 //
-// $Id: G4DNAElastic.cc 85423 2014-10-29 08:22:38Z gcosmo $
+// add elastic scattering processes of proton, hydrogen, helium, alpha+, alpha++
 
 #include "G4DNAElastic.hh"
 #include "G4SystemOfUnits.hh"
@@ -33,47 +33,86 @@
 
 using namespace std;
 
-G4DNAElastic::G4DNAElastic(const G4String& processName,
-  G4ProcessType type):G4VEmProcess (processName, type),
-    isInitialised(false)
+G4DNAElastic::G4DNAElastic(const G4String& processName, G4ProcessType type) :
+    G4VEmProcess(processName, type), isInitialised(false)
 {
   SetProcessSubType(51);
 }
 
 //....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......
- 
+
 G4DNAElastic::~G4DNAElastic()
-{}
+{
+}
 
 //....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo....
 
 G4bool G4DNAElastic::IsApplicable(const G4ParticleDefinition& p)
 {
-  return (&p == G4Electron::Electron() || &p == G4Positron::Positron());
+  G4DNAGenericIonsManager *instance;
+  instance = G4DNAGenericIonsManager::Instance();
+
+  return (&p == G4Electron::Electron() || &p == G4Positron::Positron()
+          || &p == G4Proton::Proton() || &p == instance->GetIon("hydrogen")
+          || &p == instance->GetIon("alpha++")
+          || &p == instance->GetIon("alpha+")
+          || &p == instance->GetIon("helium"));
+
 }
 
 //....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo....
 
-void G4DNAElastic::InitialiseProcess(const G4ParticleDefinition*)
+void G4DNAElastic::InitialiseProcess(const G4ParticleDefinition* p)
 {
-  if(!isInitialised) 
+  if(!isInitialised)
   {
     isInitialised = true;
     SetBuildTableFlag(false);
-    if(!EmModel()) SetEmModel(new G4DNAScreenedRutherfordElasticModel);
-    EmModel()->SetLowEnergyLimit(0*eV);
-    EmModel()->SetHighEnergyLimit(1.*MeV);
-    AddEmModel(1, EmModel());
-  } 
+
+    G4String name = p->GetParticleName();
+
+    if(name == "e-")
+    {
+      if(!EmModel())
+      {
+        SetEmModel(new G4DNAScreenedRutherfordElasticModel);
+        EmModel()->SetLowEnergyLimit(0 * eV);
+        EmModel()->SetHighEnergyLimit(1. * MeV);
+      }
+      AddEmModel(1, EmModel());
+    }
+
+    else if(name == "proton" || name == "hydrogen")
+    {
+      if(!EmModel())
+      {
+        SetEmModel(new G4DNAIonElasticModel);
+        EmModel()->SetLowEnergyLimit(0 * eV);
+        EmModel()->SetHighEnergyLimit(1 * MeV);
+      }
+      AddEmModel(1, EmModel());
+    }
+
+    // "alpha" must be explicitely used, not alpha++
+    else if(name == "helium" || name == "alpha" || name == "alpha+")
+    {
+      if(!EmModel())
+      {
+        SetEmModel(new G4DNAIonElasticModel);
+        EmModel()->SetLowEnergyLimit(0 * eV);
+        EmModel()->SetHighEnergyLimit(1 * MeV);
+      }
+      AddEmModel(1, EmModel());
+    }
+  }
 }
 
 //....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......
 
 void G4DNAElastic::PrintInfo()
 {
-  G4cout
-    << " Total cross sections computed from " << EmModel()->GetName() << " model"
-    << G4endl;
-}         
+  G4cout << " Total cross sections computed from " << EmModel()->GetName()
+         << " model" << G4endl;
+}
 
 //....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......
