@@ -23,7 +23,6 @@
 // * acceptance of all terms of the Geant4 Software license.          *
 // ********************************************************************
 //
-// $Id: G4hPairProduction.cc 107367 2017-11-09 10:56:09Z gcosmo $
 //
 // -------------------------------------------------------------------
 //
@@ -96,7 +95,7 @@ void G4hPairProduction::InitialiseEnergyLossProcess(
 
 void G4hPairProduction::ProcessDescription(std::ostream& out) const
 {
-  out << "<strong>Hadron pair production</strong>";
+  out << "  Hadron pair production";
   G4VEnergyLossProcess::ProcessDescription(out);
 }
 
