@@ -112,7 +112,7 @@ void G4BoldyshevTripletModel::Initialise(const G4ParticleDefinition*,
   if(IsMaster()) 
   {
     // Access to elements  
-    char* path = getenv("G4LEDATA");
+    char* path = std::getenv("G4LEDATA");
 
     G4ProductionCutsTable* theCoupleTable =
       G4ProductionCutsTable::GetProductionCutsTable();
@@ -164,7 +164,7 @@ void G4BoldyshevTripletModel::ReadData(size_t Z, const char* path)
 
   if(!datadir) 
   {
-    datadir = getenv("G4LEDATA");
+    datadir = std::getenv("G4LEDATA");
     if(!datadir) 
     {
       G4Exception("G4BoldyshevTripletModel::ReadData()",
