@@ -143,7 +143,7 @@ void G4BremsstrahlungParameters::LoadData(const G4String& name)
 
   // Read parameters
 
-  char* path = getenv("G4LEDATA");
+  char* path = std::getenv("G4LEDATA");
   if (path == 0)
     {
       G4Exception("G4BremsstrahlungParameters::LoadData",
