@@ -121,7 +121,7 @@ void G4DopplerProfile::LoadBiggsP(const G4String& fileName)
   ost << fileName << ".dat";
   G4String name(ost.str());
   
-  char* path = getenv("G4LEDATA");
+  char* path = std::getenv("G4LEDATA");
   if (!path)
     { 
       G4Exception("G4DopplerProfile::LoadBiggsP",
@@ -163,7 +163,7 @@ void G4DopplerProfile::LoadProfile(const G4String& fileName,G4int Z)
   ost << fileName << "-" << Z << ".dat";
   G4String name(ost.str());
   
-  char* path = getenv("G4LEDATA");
+  char* path = std::getenv("G4LEDATA");
   if (!path)
     { 
       G4String excep("G4LEDATA environment variable not set");
