@@ -465,7 +465,7 @@ size_t G4EMDataSet::FindLowerBound(G4double x, G4DataVector* values) const
 
 G4String G4EMDataSet::FullFileName(const G4String& name) const
 {
-  char* path = getenv("G4LEDATA");
+  char* path = std::getenv("G4LEDATA");
   if (!path) {
      G4Exception("G4EMDataSet::FullFileName",
 		    "em0006",FatalException,"G4LEDATA environment variable not set");
