@@ -120,7 +120,7 @@ void G4LivermoreComptonModel::Initialise(const G4ParticleDefinition* particle,
 
     // Access to elements
 
-    char* path = getenv("G4LEDATA");
+    char* path = std::getenv("G4LEDATA");
 
     G4ProductionCutsTable* theCoupleTable = 
       G4ProductionCutsTable::GetProductionCutsTable();
@@ -193,7 +193,7 @@ void G4LivermoreComptonModel::ReadData(size_t Z, const char* path)
   const char* datadir = path;
   if(!datadir) 
   {
-    datadir = getenv("G4LEDATA");
+    datadir = std::getenv("G4LEDATA");
     if(!datadir) 
     {
       G4Exception("G4LivermoreComptonModel::ReadData()",
