@@ -106,7 +106,7 @@ void G4LivermoreGammaConversionModelRC::Initialise(
 
     // Access to elements
   
-    char* path = getenv("G4LEDATA");
+    char* path = std::getenv("G4LEDATA");
 
     G4ProductionCutsTable* theCoupleTable =
       G4ProductionCutsTable::GetProductionCutsTable();
@@ -168,7 +168,7 @@ void G4LivermoreGammaConversionModelRC::ReadData(size_t Z, const char* path)
 
   if(!datadir) 
   {
-    datadir = getenv("G4LEDATA");
+    datadir = std::getenv("G4LEDATA");
     if(!datadir) 
     {
       G4Exception("G4LivermoreGammaConversionModelRC::ReadData()",
