@@ -103,7 +103,7 @@ void G4LivermoreNuclearGammaConversionModel::Initialise(
 
     // Access to elements
   
-    char* path = getenv("G4LEDATA");
+    char* path = std::getenv("G4LEDATA");
 
     G4ProductionCutsTable* theCoupleTable =
       G4ProductionCutsTable::GetProductionCutsTable();
@@ -166,7 +166,7 @@ void G4LivermoreNuclearGammaConversionModel::ReadData(size_t Z, const char* path
 
   if(!datadir) 
   {
-    datadir = getenv("G4LEDATA");
+    datadir = std::getenv("G4LEDATA");
     if(!datadir) 
     {
       G4Exception("G4LivermoreNuclearGammaConversionModel::ReadData()",
