@@ -109,7 +109,7 @@ void G4LivermorePolarizedGammaConversionModel::Initialise(const G4ParticleDefini
       
       // Access to elements
       
-      char* path = getenv("G4LEDATA");
+      char* path = std::getenv("G4LEDATA");
       
       G4ProductionCutsTable* theCoupleTable =
 	G4ProductionCutsTable::GetProductionCutsTable();
@@ -171,7 +171,7 @@ void G4LivermorePolarizedGammaConversionModel::ReadData(size_t Z, const char* pa
   
   if(!datadir) 
     {
-      datadir = getenv("G4LEDATA");
+      datadir = std::getenv("G4LEDATA");
       if(!datadir) 
 	{
 	  G4Exception("G4LivermorePolarizedGammaConversionModel::ReadData()",
