@@ -121,7 +121,7 @@ G4LivermorePolarizedPhotoElectricGDModel::Initialise(
     
     if(!fShellCrossSection) { fShellCrossSection = new G4ElementData(); }
     
-    char* path = getenv("G4LEDATA");
+    char* path = std::getenv("G4LEDATA");
     
     G4ProductionCutsTable* theCoupleTable =
       G4ProductionCutsTable::GetProductionCutsTable();
@@ -442,7 +442,7 @@ void G4LivermorePolarizedPhotoElectricGDModel::ReadData(G4int Z, const char* pat
   
   if(!datadir) 
     {
-      datadir = getenv("G4LEDATA");
+      datadir = std::getenv("G4LEDATA");
       if(!datadir) 
 	{
 	  G4Exception("G4LivermorePhotoElectricModel::ReadData()",
