@@ -129,7 +129,7 @@ G4LivermorePolarizedPhotoElectricModel::Initialise(const G4ParticleDefinition*,
 
     if(!fShellCrossSection) { fShellCrossSection = new G4ElementData(); }
 
-    char* path = getenv("G4LEDATA");
+    char* path = std::getenv("G4LEDATA");
 
     G4ProductionCutsTable* theCoupleTable =
       G4ProductionCutsTable::GetProductionCutsTable();
@@ -445,7 +445,7 @@ G4LivermorePolarizedPhotoElectricModel::ReadData(G4int Z, const char* path)
 
   if(!datadir) 
   {
-    datadir = getenv("G4LEDATA");
+    datadir = std::getenv("G4LEDATA");
     if(!datadir) 
     {
       G4Exception("G4LivermorePolarizedPhotoElectricModel::ReadData()",
