@@ -130,7 +130,7 @@ void G4LowEPPolarizedComptonModel::Initialise(const G4ParticleDefinition* partic
 
     // Access to elements
 
-    char* path = getenv("G4LEDATA");
+    char* path = std::getenv("G4LEDATA");
 
     G4ProductionCutsTable* theCoupleTable =
       G4ProductionCutsTable::GetProductionCutsTable();
@@ -203,7 +203,7 @@ void G4LowEPPolarizedComptonModel::ReadData(size_t Z, const char* path)
   const char* datadir = path;
   if(!datadir)
   {
-    datadir = getenv("G4LEDATA");
+    datadir = std::getenv("G4LEDATA");
     if(!datadir)
     {
       G4Exception("G4LowEPPolarizedComptonModel::ReadData()",
