@@ -69,8 +69,8 @@ void G4MicroElecElastic::InitialiseProcess(const G4ParticleDefinition*)
   {
     isInitialised = true;
     SetBuildTableFlag(false);
-    if(!EmModel(1)) SetEmModel(new G4DummyModel(), 1);
-    AddEmModel(2, EmModel(1));
+    if(!EmModel()) SetEmModel(new G4DummyModel());
+    AddEmModel(2, EmModel());
   } 
 }
 
