@@ -133,7 +133,7 @@ void G4MuElecInelasticModel::Initialise(const G4ParticleDefinition* particle,
   
   G4double scaleFactor = 1e-18 * cm *cm;
 
-  char *path = getenv("G4LEDATA");
+  char *path = std::getenv("G4LEDATA");
 
   // *** ELECTRON
     electron = electronDef->GetParticleName();
