@@ -397,7 +397,7 @@ void G4ShellEMDataSet::CleanUpComponents(void)
 
 G4String G4ShellEMDataSet::FullFileName(const G4String& fileName) const
 {
-  char* path = getenv("G4LEDATA");
+  char* path = std::getenv("G4LEDATA");
   
   if (!path)
   {
