@@ -46,7 +46,7 @@ G4ecpssrBaseLixsModel::G4ecpssrBaseLixsModel()
 
   // Storing FLi data needed for 0.2 to 3.0  velocities region
 
-  char *path = getenv("G4LEDATA");
+  char *path = std::getenv("G4LEDATA");
     
   if (!path) {
     G4Exception("G4ecpssrLCrossSection::G4ecpssrBaseLixsModel()","em0006", FatalException ,"G4LEDATA environment variable not set");
