@@ -23,7 +23,6 @@
 // * acceptance of all terms of the Geant4 Software license.          *
 // ********************************************************************
 //
-// $Id: G4MuBremsstrahlung.cc 107056 2017-11-01 14:52:32Z gcosmo $
 //
 // -------------------------------------------------------------------
 //
@@ -85,11 +84,6 @@ G4MuBremsstrahlung::G4MuBremsstrahlung(const G4String& name)
 
 //....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo....
 
-G4MuBremsstrahlung::~G4MuBremsstrahlung()
-{}
-
-//....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo....
-
 G4bool G4MuBremsstrahlung::IsApplicable(const G4ParticleDefinition& p)
 {
   return (p.GetPDGCharge() != 0.0 && p.GetPDGMass() > 10.0*MeV);
@@ -133,7 +127,7 @@ void G4MuBremsstrahlung::PrintInfo()
 
 void G4MuBremsstrahlung::ProcessDescription(std::ostream& out) const
 {
-  out << "<strong>Muon bremsstrahlung</strong>";
+  out << "  Muon bremsstrahlung";
   G4VEnergyLossProcess::ProcessDescription(out);
 }
 
