@@ -23,7 +23,6 @@
 // * acceptance of all terms of the Geant4 Software license.          *
 // ********************************************************************
 //
-// $Id$
 //
 // -------------------------------------------------------------------
 //
@@ -109,11 +108,6 @@ G4MuIonisation::G4MuIonisation(const G4String& name)
 
 //....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo....
 
-G4MuIonisation::~G4MuIonisation()
-{}
-
-//....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo....
-
 G4bool G4MuIonisation::IsApplicable(const G4ParticleDefinition& p)
 {
   return (p.GetPDGCharge() != 0.0 && p.GetPDGMass() > 10.0*MeV);
@@ -187,7 +181,7 @@ void G4MuIonisation::PrintInfo()
 
 void G4MuIonisation::ProcessDescription(std::ostream& out) const
 {
-  out << "<strong>Muon ionisation</strong>";
+  out << "  Muon ionisation";
   G4VEnergyLossProcess::ProcessDescription(out);
 }
 
