@@ -335,7 +335,7 @@ size_t G4DataSet::FindLowerBound(G4double x, G4DataVector* values) const
 
 G4String G4DataSet::FullFileName(const G4String& name) const
 {
-  char* path = getenv("G4PIIDATA");
+  char* path = std::getenv("G4PIIDATA");
   if (!path)
     G4Exception("G4DataSet::FullFileName",
 		"pii00000160",
