@@ -24,7 +24,6 @@
 // ********************************************************************
 //
 //
-// $Id$
 // 
 //
 // File name:     G4PolarizedCompton
@@ -123,7 +122,7 @@ void G4PolarizedCompton::InitialiseProcess(const G4ParticleDefinition*)
       if(!EmModel(0)) { SetEmModel(new G4KleinNishinaCompton()); }
     } else {
       emModel = new G4PolarizedComptonModel();
-      SetEmModel(emModel, 1); 
+      SetEmModel(emModel); 
     }
     G4EmParameters* param = G4EmParameters::Instance();
     EmModel(0)->SetLowEnergyLimit(param->MinKinEnergy());
