@@ -253,7 +253,7 @@ void G4GSMottCorrection::InitMCDataPerMaterials() {
 // it's called only if data has not been loaded for this element yet
 void G4GSMottCorrection::LoadMCDataElement(const G4Element *elem) {
   // allocate memory
-  G4int izet = G4lrint(elem->GetZ());
+  G4int izet = elem->GetZasInt();
   if (izet>gMaxZet) {
     izet = gMaxZet;
   }
@@ -262,7 +262,7 @@ void G4GSMottCorrection::LoadMCDataElement(const G4Element *elem) {
   fMCDataPerElement[izet]  = perElem;
   //
   // load data from file
-  char* tmppath = getenv("G4LEDATA");
+  char* tmppath = std::getenv("G4LEDATA");
   if (!tmppath) {
     G4Exception("G4GSMottCorrection::LoadMCDataElement()","em0006",
 		FatalException,
