@@ -283,7 +283,8 @@ void G4PAIPhotModel::SampleSecondaries(std::vector<G4DynamicParticle*>* vdp,
 
     if( deltaTkin > tmax) deltaTkin = tmax;
 
-    const G4Element* anElement = SelectRandomAtom(matCC,fParticle,kineticEnergy);
+    const G4Element* anElement = SelectTargetAtom(matCC,fParticle,kineticEnergy,
+                                                  dp->GetLogKineticEnergy());
     G4int Z = G4lrint(anElement->GetZ());
  
     G4DynamicParticle* deltaRay = new G4DynamicParticle(fElectron, 
