@@ -24,8 +24,6 @@
 // ********************************************************************
 //
 //
-// $Id: G4PAIxSection.cc 106442 2017-10-10 08:00:30Z gcosmo $
-// GEANT4 tag $Name: geant4-09-03-ref-06 $
 //
 // 
 // G4PAIxSection.cc -- class implementation file
@@ -596,8 +594,10 @@ G4PAIxSection::~G4PAIxSection()
   delete fMatSandiaMatrix;
 }
 
-
-
+G4double G4PAIxSection::GetLorentzFactor(G4int j) const
+{
+   return fLorentzFactor[j];
+}
 
 ////////////////////////////////////////////////////////////////////////
 //
