@@ -77,3 +77,32 @@ void G4DummyModel::SampleSecondaries(std::vector<G4DynamicParticle*>*,
 
 //....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo....
 
+G4ThreeVector& 
+G4DummyModel::SampleScattering(const G4ThreeVector&, G4double)
+{
+  return fDisplacement;
+}
+
+//....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......
+
+G4double G4DummyModel::ComputeTruePathLengthLimit(const G4Track&, G4double&)
+{
+  return DBL_MAX;
+}
+
+//....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......
+
+G4double G4DummyModel::ComputeGeomPathLength(G4double truePathLength)
+{
+  return truePathLength;
+}
+
+//....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......
+
+G4double G4DummyModel::ComputeTrueStepLength(G4double geomPathLength)
+{
+  return geomPathLength;
+}
+
+//....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo....
+
