@@ -23,7 +23,6 @@
 // * acceptance of all terms of the Geant4 Software license.          *
 // ********************************************************************
 //
-//
 // -------------------------------------------------------------------
 //
 // GEANT4 Class file
@@ -44,7 +43,7 @@
 #include "G4ComponentGGHadronNucleusXsc.hh"
 #include "G4UPiNuclearCrossSection.hh"
 #include "G4HadronNucleonXsc.hh"
-#include "G4ComponentSAIDTotalXS.hh"
+#include "G4NuclearRadii.hh"
 
 #include "G4Proton.hh"
 #include "G4PionPlus.hh"
@@ -54,32 +53,36 @@
 
 #include "G4HadronicParameters.hh"
 
+G4double G4BGGPionInelasticXS::theGlauberFacPiPlus[93] = {0.0};
+G4double G4BGGPionInelasticXS::theGlauberFacPiMinus[93] = {0.0};
+G4double G4BGGPionInelasticXS::theLowEPiPlus[93] = {0.0};
+G4double G4BGGPionInelasticXS::theLowEPiMinus[93] = {0.0};
+G4int    G4BGGPionInelasticXS::theA[93] = {0};
+
+#ifdef G4MULTITHREADED
+G4Mutex G4BGGPionInelasticXS::pionInelasticXSMutex = G4MUTEX_INITIALIZER;
+#endif
+
 G4BGGPionInelasticXS::G4BGGPionInelasticXS(const G4ParticleDefinition* p) 
- : G4VCrossSectionDataSet("Barashenkov-Glauber-Gribov")
+ : G4VCrossSectionDataSet("BarashenkovGlauberGribov")
 {
   verboseLevel = 0;
-  fGlauberEnergy = 91.*GeV;
-  fLowEnergy = 20.*MeV;
-  fSAIDHighEnergyLimit = 2.6*GeV;
+  fGlauberEnergy    = 91.*CLHEP::GeV;
+  fLowEnergy        = 20.*CLHEP::MeV;
+  fLowestEnergy     = 1.*CLHEP::MeV;
   SetMinKinEnergy(0.0);
   SetMaxKinEnergy( G4HadronicParameters::Instance()->GetMaxEnergy() );
 
-  for (G4int i = 0; i < 93; i++) {
-    theGlauberFac[i] = 0.0;
-    theCoulombFac[i] = 0.0;
-    theA[i] = 1;
-  }
   fPion = nullptr;
   fGlauber = nullptr;
   fHadron  = nullptr;
-  fSAID    = nullptr;
 
   fG4pow   = G4Pow::GetInstance();
 
-  particle = p;
-  theProton= G4Proton::Proton();
-  isPiplus = (p == G4PionPlus::PionPlus()) ? true : false;
-  isInitialized = false;
+  theProton = G4Proton::Proton();
+  thePiPlus = G4PionPlus::PionPlus();
+  isPiplus  = (p == thePiPlus);
+  isMaster  = false;
   SetForAllAtomsAndEnergies(true);
 }
 
@@ -94,7 +97,7 @@ G4BGGPionInelasticXS::~G4BGGPionInelasticXS()
 
 G4bool 
 G4BGGPionInelasticXS::IsElementApplicable(const G4DynamicParticle*, G4int,
-					  const G4Material*)
+                                          const G4Material*)
 {
   return true;
 }
@@ -102,9 +105,9 @@ G4BGGPionInelasticXS::IsElementApplicable(const G4DynamicParticle*, G4int,
 //....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......
 
 G4bool G4BGGPionInelasticXS::IsIsoApplicable(const G4DynamicParticle*, 
-					     G4int Z, G4int,  
-					     const G4Element*,
-					     const G4Material*)
+                                             G4int Z, G4int,  
+                                             const G4Element*,
+                                             const G4Material*)
 {
   return (1 == Z);
 }
@@ -113,33 +116,32 @@ G4bool G4BGGPionInelasticXS::IsIsoApplicable(const G4DynamicParticle*,
 
 G4double
 G4BGGPionInelasticXS::GetElementCrossSection(const G4DynamicParticle* dp,
-					     G4int ZZ, const G4Material*)
+                                             G4int ZZ, const G4Material*)
 {
   // this method should be called only for Z > 1
 
   G4double cross = 0.0;
-  G4double ekin = dp->GetKineticEnergy();
+  G4double ekin = std::max(dp->GetKineticEnergy(), fLowestEnergy);
   G4int Z = std::min(ZZ, 92);
+
   if(1 == Z) {
     cross = 1.0115*GetIsoCrossSection(dp,1,1);
+  } else if(ekin < fLowEnergy) {
+    cross = (isPiplus) ? theLowEPiPlus[Z]*CoulombFactorPiPlus(ekin, Z)
+      : theLowEPiMinus[Z]*FactorPiMinus(ekin);
+  } else if(ekin > fGlauberEnergy) {
+    cross = (isPiplus) ? theGlauberFacPiPlus[Z] : theGlauberFacPiMinus[Z];
+    cross *= fGlauber->GetInelasticGlauberGribov(dp, Z, theA[Z]);
   } else {
-    if(ekin <= fLowEnergy && !isPiplus) {
-      cross = theCoulombFac[Z];
-    } else if(ekin <= 2*MeV && isPiplus) {
-      cross = theCoulombFac[Z]*CoulombFactor(ekin, Z);
-    } else if(ekin > fGlauberEnergy) {
-      cross = theGlauberFac[Z]*fGlauber->GetInelasticGlauberGribov(dp, Z, theA[Z]);
-    } else {
-      cross = fPion->GetInelasticCrossSection(dp, Z, theA[Z]);
-    }
+    cross = fPion->GetInelasticCrossSection(dp, Z, theA[Z]);
   }
   if(verboseLevel > 1) {
     G4cout << "G4BGGPionInelasticXS::GetCrossSection  for "
-	   << dp->GetDefinition()->GetParticleName()
-	   << "  Ekin(GeV)= " << dp->GetKineticEnergy()
-	   << " in nucleus Z= " << Z << "  A= " << theA[Z]
-	   << " XS(b)= " << cross/barn 
-	   << G4endl;
+           << dp->GetDefinition()->GetParticleName()
+           << "  Ekin(GeV)= " << dp->GetKineticEnergy()
+           << " in nucleus Z= " << Z << "  A= " << theA[Z]
+           << " XS(b)= " << cross/barn 
+           << G4endl;
   }
   return cross;
 }
@@ -148,27 +150,23 @@ G4BGGPionInelasticXS::GetElementCrossSection(const G4DynamicParticle* dp,
 
 G4double
 G4BGGPionInelasticXS::GetIsoCrossSection(const G4DynamicParticle* dp, 
-					 G4int Z, G4int A, 
-					 const G4Isotope*,
-					 const G4Element*,
-					 const G4Material*)
+                                         G4int Z, G4int A, 
+                                         const G4Isotope*,
+                                         const G4Element*,
+                                         const G4Material*)
 {
   // this method should be called only for Z = 1
-
-  G4double cross = 0.0;
-  if(1 == Z) {
-    fHadron->GetHadronNucleonXscNS(dp, theProton);
-    cross = fHadron->GetInelasticHadronNucleonXsc();
-  }
-  cross *= A;
+  fHadron->HadronNucleonXscNS(dp->GetDefinition(), theProton, 
+                              dp->GetKineticEnergy());
+  G4double cross = A*fHadron->GetInelasticHadronNucleonXsc();
 
   if(verboseLevel > 1) {
     G4cout << "G4BGGPionInelasticXS::GetCrossSection  for "
-	   << dp->GetDefinition()->GetParticleName()
-	   << "  Ekin(GeV)= " << dp->GetKineticEnergy()
-	   << " in nucleus Z= " << Z << "  A= " << A
-	   << " XS(b)= " << cross/barn 
-	   << G4endl;
+           << dp->GetDefinition()->GetParticleName()
+           << "  Ekin(GeV)= " << dp->GetKineticEnergy()
+           << " in nucleus Z= " << Z << "  A= " << A
+           << " XS(b)= " << cross/barn 
+           << G4endl;
   }
   return cross;
 }
@@ -177,94 +175,116 @@ G4BGGPionInelasticXS::GetIsoCrossSection(const G4DynamicParticle* dp,
 
 void G4BGGPionInelasticXS::BuildPhysicsTable(const G4ParticleDefinition& p)
 {
+  if(fPion) { return; }
+  if(verboseLevel > 1) {
+    G4cout << "G4BGGPionInelasticXS::BuildPhysicsTable for " 
+           << p.GetParticleName() << G4endl;
+  } 
   if(&p == G4PionPlus::PionPlus() || &p == G4PionMinus::PionMinus()) {
-    particle = &p;
+    isPiplus = (&p == G4PionPlus::PionPlus());
   } else {
-    G4cout << "### G4BGGPionInelasticXS WARNING: is not applicable to " 
-	   << p.GetParticleName()
-	   << G4endl;
-    throw G4HadronicException(__FILE__, __LINE__,
-	  "G4BGGPionInelasticXS::BuildPhysicsTable is used for wrong particle");
+    G4ExceptionDescription ed;
+    ed << "This BGG cross section is applicable only to pions and not to " 
+       << p.GetParticleName() << G4endl; 
+    G4Exception("G4BGGPionInelasticXS::BuildPhysicsTable", "had001", 
+                FatalException, ed);
     return;
   }
 
-  if(isInitialized) { return; }
-  isInitialized = true;
-
   fPion    = new G4UPiNuclearCrossSection();
   fGlauber = new G4ComponentGGHadronNucleusXsc();
   fHadron  = new G4HadronNucleonXsc();
 
-  fPion->BuildPhysicsTable(*particle);
-  fGlauber->BuildPhysicsTable(*particle);
+  fPion->BuildPhysicsTable(p);
 
-  G4ThreeVector mom(0.0,0.0,1.0);
-  G4DynamicParticle dp(particle, mom, fGlauberEnergy);
-
-  G4NistManager* nist = G4NistManager::Instance();
-
-  G4double csup, csdn;
-
-  if(verboseLevel > 0) {
-    G4cout << "### G4BGGPionInelasticXS::Initialise for "
-	   << particle->GetParticleName()
-	   << " isPiplus: " << isPiplus
-	   << G4endl;
+  if(0 == theA[0]) { 
+#ifdef G4MULTITHREADED
+    G4MUTEXLOCK(&pionInelasticXSMutex);
+    if(0 == theA[0]) { 
+#endif
+      isMaster = true;
+#ifdef G4MULTITHREADED
+    }
+    G4MUTEXUNLOCK(&pionInelasticXSMutex);
+#endif
+  } else {
+    return;
   }
 
-  for(G4int iz=2; iz<93; ++iz) {
-    G4int A = G4lrint(nist->GetAtomicMassAmu(iz));
-    theA[iz] = A;
+  if(isMaster && 0 == theA[0]) {
 
-    csup = fGlauber->GetInelasticGlauberGribov(&dp, iz, A);
-    csdn = fPion->GetInelasticCrossSection(&dp, iz, A);
+    theA[0] = theA[1] = 1;
+    G4ThreeVector mom(0.0,0.0,1.0);
+    G4DynamicParticle dp(thePiPlus, mom, fGlauberEnergy);
+
+    G4NistManager* nist = G4NistManager::Instance();
+    G4double csup, csdn;
 
-    theGlauberFac[iz] = csdn/csup;
     if(verboseLevel > 0) {
-      G4cout << "Z= " << iz <<  "  A= " << A 
-	     << " factor= " << theGlauberFac[iz] << G4endl; 
+      G4cout << "### G4BGGPionInelasticXS::Initialise for "
+             << p.GetParticleName()
+             << " isPiplus: " << isPiplus
+             << G4endl;
     }
-  }
-  theCoulombFac[1] = 1.0;
-  G4double elim = (isPiplus) ? 2*MeV : fLowEnergy; 
-  dp.SetKineticEnergy(elim);
+    for(G4int iz=2; iz<93; ++iz) {
+      G4int A = G4lrint(nist->GetAtomicMassAmu(iz));
+      theA[iz] = A;
 
-  for(G4int iz=2; iz<93; ++iz) {
-    if(isPiplus) { 
-      theCoulombFac[iz] = fPion->GetInelasticCrossSection(&dp, iz, theA[iz])
-	/CoulombFactor(elim, iz); 
-    } else {
-      theCoulombFac[iz] = fPion->GetInelasticCrossSection(&dp, iz, theA[iz]);
+      csup = fGlauber->GetInelasticGlauberGribov(&dp, iz, A);
+      csdn = fPion->GetInelasticCrossSection(&dp, iz, A);
+      theGlauberFacPiPlus[iz] = csdn/csup;
     }
-    if(verboseLevel > 0) {
-      G4cout << "Z= " << iz <<  "  A= " << theA[iz] 
-	     << " CoulombFactor= " << theCoulombFac[iz] << G4endl; 
+
+    dp.SetDefinition(G4PionMinus::PionMinus());
+    for(G4int iz=2; iz<93; ++iz) {
+      csup = fGlauber->GetInelasticGlauberGribov(&dp, iz, theA[iz]);
+      csdn = fPion->GetInelasticCrossSection(&dp, iz, theA[iz]);
+      theGlauberFacPiMinus[iz] = csdn/csup;
+
+      if(verboseLevel > 0) {
+        G4cout << "Z= " << iz <<  "  A= " << theA[iz] 
+               << " factorPiPlus= " << theGlauberFacPiPlus[iz] 
+               << " factorPiMinus= " << theGlauberFacPiMinus[iz] 
+               << G4endl;
+      }
+    }
+
+    theLowEPiPlus[1] = theLowEPiMinus[1]= 1.0;
+    dp.SetDefinition(thePiPlus);
+    dp.SetKineticEnergy(fLowEnergy);
+    for(G4int iz=2; iz<93; ++iz) {
+      theLowEPiPlus[iz] = fPion->GetInelasticCrossSection(&dp, iz, theA[iz])
+        /CoulombFactorPiPlus(fLowEnergy, iz);
+    }
+
+    dp.SetDefinition(G4PionMinus::PionMinus());
+    for(G4int iz=2; iz<93; ++iz) {
+      theLowEPiMinus[iz] = fPion->GetInelasticCrossSection(&dp, iz, theA[iz])
+        /FactorPiMinus(fLowEnergy);
+    
+      if(verboseLevel > 0) {
+        G4cout << "Z= " << iz <<  "  A= " << theA[iz] 
+               << " LowEtorPiPlus= " << theLowEPiPlus[iz] 
+               << " LowEtorPiMinus= " << theLowEPiMinus[iz] 
+               << G4endl;
+      }
     }
   }
 }
 
 //....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......
 
-G4double G4BGGPionInelasticXS::CoulombFactor(G4double kinEnergy, G4int Z)
+G4double G4BGGPionInelasticXS::CoulombFactorPiPlus(G4double kinEnergy, G4int Z)
 {
-  G4int A = theA[Z];
-  G4double res= 0.0;
-  if(kinEnergy <= DBL_MIN) { return res; }
-  else if(A < 2) { return kinEnergy*kinEnergy; }
-  
-  G4double elog = fG4pow->log10A(6.7*kinEnergy/GeV);
-  G4double aa = A;
+  return (kinEnergy > 0.0) ? 
+    G4NuclearRadii::CoulombFactor(Z, theA[Z], thePiPlus, kinEnergy) : 0.0;
+}
 
-  // from G4ProtonInelasticCrossSection
-  G4double ff1 = 0.70 - 0.002*aa;           // slope of the drop at medium energies.
-  G4double ff2 = 1.00 + 1/aa;               // start of the slope.
-  G4double ff3 = 0.8  + 18/aa - 0.002*aa;   // stephight
-  res = 1.0 + ff3*(1.0 - (1.0/(1+fG4pow->expA(-8*ff1*(elog + 1.37*ff2)))));
+//....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......
 
-  ff1 = 1.   - 1./aa - 0.001*aa; // slope of the rise
-  ff2 = 1.17 - 2.7/aa-0.0014*aa; // start of the rise
-  res /= (1 + fG4pow->expA(-8.*ff1*(elog + 2*ff2)));
-  return res;  
+G4double G4BGGPionInelasticXS::FactorPiMinus(G4double kinEnergy)
+{
+  return 1.0/std::sqrt(kinEnergy);
 }
 
 //....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......
