@@ -116,6 +116,7 @@
 #include "G4DynamicParticle.hh"
 #include "G4HadronicException.hh"
 #include "G4InuclCollider.hh"
+#include "G4LightTargetCollider.hh"
 #include "G4InuclElementaryParticle.hh"
 #include "G4InuclNuclei.hh"
 #include "G4InuclParticle.hh"
@@ -143,11 +144,13 @@ typedef std::vector<G4InuclNuclei>::const_iterator nucleiIterator;
 // Constructor and destrutor
 
 G4CascadeInterface::G4CascadeInterface(const G4String& name)
-  : G4VIntraNuclearTransportModel(name), 
-    randomFile(G4CascadeParameters::randomFile()),
-    maximumTries(20), numberOfTries(0),
-    collider(new G4InuclCollider), balance(new G4CascadeCheckBalance(name)),
-    bullet(0), target(0), output(new G4CollisionOutput) {
+ : G4VIntraNuclearTransportModel(name), 
+   randomFile(G4CascadeParameters::randomFile()),
+   maximumTries(20), numberOfTries(0),
+   collider(new G4InuclCollider), balance(new G4CascadeCheckBalance(name)), 
+   ltcollider(new G4LightTargetCollider),
+   bullet(0), target(0), output(new G4CollisionOutput)
+{
   // Set up global objects for master thread or sequential build
   if (G4Threading::IsMasterThread()) Initialize();
 
@@ -278,55 +281,71 @@ G4CascadeInterface::ApplyYourself(const G4HadProjectile& aTrack,
     return NoInteraction(aTrack, theNucleus);
   }
 
-  // Make conversion between native Geant4 and Bertini cascade classes.
-  if (!createBullet(aTrack)) {
-    if (verboseLevel) G4cerr << " Unable to create usable bullet" << G4endl;
-    return NoInteraction(aTrack, theNucleus);
-  }
+  // If target A < 3 skip all cascade machinery and do scattering on
+  // nucleons
 
-  if (!createTarget(theNucleus)) {
-    if (verboseLevel) G4cerr << " Unable to create usable target" << G4endl;
-    return NoInteraction(aTrack, theNucleus);
-  }
-
-  // Different retry conditions for proton target vs. nucleus
-  const G4bool isHydrogen = (theNucleus.GetA_asInt() == 1);
-
-  numberOfTries = 0;
-  do {   			// we try to create inelastic interaction
-    if (verboseLevel > 1)
-      G4cout << " Generating cascade attempt " << numberOfTries << G4endl;
-    
+  if (aTrack.GetDefinition() == G4Gamma::Gamma() &&
+      theNucleus.GetA_asInt() < 3) {
     output->reset();
-    collider->collide(bullet, target, *output);
-    balance->collide(bullet, target, *output);
+    createBullet(aTrack);
+    createTarget(theNucleus);
+    // Due to binning, gamma-p cross sections between 130 MeV and the inelastic threshold
+    // (144 for pi0 p, 152 for pi+ n) are non-zero, causing energy non-conservation
+    // So, if Egamma is between 144 and 152, only pi0 p is allowed.  
+
+    // Also, inelastic gamma-p cross section from G4PhotoNuclearCrossSection seems to be
+    // non-zero below between pi0 mass (135 MeV) and threshold (144 MeV) 
+    ltcollider->collide(bullet, target, *output);
+
+  } else {
+
+    // Make conversion between native Geant4 and Bertini cascade classes.
+    if (!createBullet(aTrack)) {
+      if (verboseLevel) G4cerr << " Unable to create usable bullet" << G4endl;
+      return NoInteraction(aTrack, theNucleus);
+    }
+
+    if (!createTarget(theNucleus)) {
+      if (verboseLevel) G4cerr << " Unable to create usable target" << G4endl;
+      return NoInteraction(aTrack, theNucleus);
+    }
+
+    // Different retry conditions for proton target vs. nucleus
+    const G4bool isHydrogen = (theNucleus.GetA_asInt() == 1);
+
+    numberOfTries = 0;
+    do {   			// we try to create inelastic interaction
+      if (verboseLevel > 1)
+        G4cout << " Generating cascade attempt " << numberOfTries << G4endl;
     
-    numberOfTries++;
-    /* Loop checking 08.06.2015 MHK */
-  } while ( isHydrogen ? retryInelasticProton() : retryInelasticNucleus() );
+      output->reset();
+      collider->collide(bullet, target, *output);
+      balance->collide(bullet, target, *output);
+    
+      numberOfTries++;
+      /* Loop checking 08.06.2015 MHK */
+    } while ( isHydrogen ? retryInelasticProton() : retryInelasticNucleus() );
 
-  // Null event if unsuccessful
-  if (numberOfTries >= maximumTries) {
-    if (verboseLevel) 
-      G4cout << " Cascade aborted after trials " << numberOfTries << G4endl;
-    return NoInteraction(aTrack, theNucleus);
-  }
+    // Null event if unsuccessful
+    if (numberOfTries >= maximumTries) {
+      if (verboseLevel) 
+        G4cout << " Cascade aborted after trials " << numberOfTries << G4endl;
+      return NoInteraction(aTrack, theNucleus);
+    }
 
-  // Abort job if energy or momentum are not conserved
-  if (!balance->okay()) {
-    throwNonConservationFailure();
-    return NoInteraction(aTrack, theNucleus);
-  }
+    // Abort job if energy or momentum are not conserved
+    if (!balance->okay()) {
+      throwNonConservationFailure();
+      return NoInteraction(aTrack, theNucleus);
+    }
 
-  // Successful cascade -- clean up and return
-  if (verboseLevel) {
-    G4cout << " Cascade output after trials " << numberOfTries << G4endl;
-    if (verboseLevel > 1) output->printCollisionOutput();
-  }
+    // Successful cascade -- clean up and return
+    if (verboseLevel) {
+      G4cout << " Cascade output after trials " << numberOfTries << G4endl;
+      if (verboseLevel > 1) output->printCollisionOutput();
+    }
 
-  // Rotate event to put Z axis along original projectile direction
-  // Removed by DHW to fix bug #1990
-  // output->rotateEvent(bulletInLabFrame);
+  }  // end cascade-style collisions
 
   copyOutputToHadronicResult();
 
