@@ -84,27 +84,27 @@ const G4CascadeParameters* G4CascadeParameters::Instance() {
 //#define OLD_RADIUS_UNITS (3.3836/1.2)		// Used with NucModel params
 
 G4CascadeParameters::G4CascadeParameters()
-  : G4CASCADE_VERBOSE(getenv("G4CASCADE_VERBOSE")),
-    G4CASCADE_CHECK_ECONS(getenv("G4CASCADE_CHECK_ECONS")),
-    G4CASCADE_USE_PRECOMPOUND(getenv("G4CASCADE_USE_PRECOMPOUND")),
-    G4CASCADE_DO_COALESCENCE(getenv("G4CASCADE_DO_COALESCENCE")),
-    G4CASCADE_SHOW_HISTORY(getenv("G4CASCADE_SHOW_HISTORY")),
-    G4CASCADE_USE_3BODYMOM(getenv("G4CASCADE_USE_3BODYMOM")),
-    G4CASCADE_USE_PHASESPACE(getenv("G4CASCADE_USE_PHASESPACE")),
-    G4CASCADE_PIN_ABSORPTION(getenv("G4CASCADE_PIN_ABSORPTION")),
-    G4CASCADE_RANDOM_FILE(getenv("G4CASCADE_RANDOM_FILE")),
-    G4NUCMODEL_USE_BEST(getenv("G4NUCMODEL_USE_BEST")),
-    G4NUCMODEL_RAD_2PAR(getenv("G4NUCMODEL_RAD_2PAR")),
-    G4NUCMODEL_RAD_SCALE(getenv("G4NUCMODEL_RAD_SCALE")),
-    G4NUCMODEL_RAD_SMALL(getenv("G4NUCMODEL_RAD_SMALL")),
-    G4NUCMODEL_RAD_ALPHA(getenv("G4NUCMODEL_RAD_ALPHA")),
-    G4NUCMODEL_RAD_TRAILING(getenv("G4NUCMODEL_RAD_TRAILING")),
-    G4NUCMODEL_FERMI_SCALE(getenv("G4NUCMODEL_FERMI_SCALE")),
-    G4NUCMODEL_XSEC_SCALE(getenv("G4NUCMODEL_XSEC_SCALE")),
-    G4NUCMODEL_GAMMAQD(getenv("G4NUCMODEL_GAMMAQD")),
-    DPMAX_2CLUSTER(getenv("DPMAX_2CLUSTER")),
-    DPMAX_3CLUSTER(getenv("DPMAX_3CLUSTER")),
-    DPMAX_4CLUSTER(getenv("DPMAX_4CLUSTER")),
+  : G4CASCADE_VERBOSE(std::getenv("G4CASCADE_VERBOSE")),
+    G4CASCADE_CHECK_ECONS(std::getenv("G4CASCADE_CHECK_ECONS")),
+    G4CASCADE_USE_PRECOMPOUND(std::getenv("G4CASCADE_USE_PRECOMPOUND")),
+    G4CASCADE_DO_COALESCENCE(std::getenv("G4CASCADE_DO_COALESCENCE")),
+    G4CASCADE_SHOW_HISTORY(std::getenv("G4CASCADE_SHOW_HISTORY")),
+    G4CASCADE_USE_3BODYMOM(std::getenv("G4CASCADE_USE_3BODYMOM")),
+    G4CASCADE_USE_PHASESPACE(std::getenv("G4CASCADE_USE_PHASESPACE")),
+    G4CASCADE_PIN_ABSORPTION(std::getenv("G4CASCADE_PIN_ABSORPTION")),
+    G4CASCADE_RANDOM_FILE(std::getenv("G4CASCADE_RANDOM_FILE")),
+    G4NUCMODEL_USE_BEST(std::getenv("G4NUCMODEL_USE_BEST")),
+    G4NUCMODEL_RAD_2PAR(std::getenv("G4NUCMODEL_RAD_2PAR")),
+    G4NUCMODEL_RAD_SCALE(std::getenv("G4NUCMODEL_RAD_SCALE")),
+    G4NUCMODEL_RAD_SMALL(std::getenv("G4NUCMODEL_RAD_SMALL")),
+    G4NUCMODEL_RAD_ALPHA(std::getenv("G4NUCMODEL_RAD_ALPHA")),
+    G4NUCMODEL_RAD_TRAILING(std::getenv("G4NUCMODEL_RAD_TRAILING")),
+    G4NUCMODEL_FERMI_SCALE(std::getenv("G4NUCMODEL_FERMI_SCALE")),
+    G4NUCMODEL_XSEC_SCALE(std::getenv("G4NUCMODEL_XSEC_SCALE")),
+    G4NUCMODEL_GAMMAQD(std::getenv("G4NUCMODEL_GAMMAQD")),
+    DPMAX_2CLUSTER(std::getenv("DPMAX_2CLUSTER")),
+    DPMAX_3CLUSTER(std::getenv("DPMAX_3CLUSTER")),
+    DPMAX_4CLUSTER(std::getenv("DPMAX_4CLUSTER")),
     messenger(0) {
   messenger = new G4CascadeParamMessenger(this);
   Initialize();
