@@ -23,8 +23,6 @@
 // * acceptance of all terms of the Geant4 Software license.          *
 // ********************************************************************
 //
-// $Id: G4hhElastic.cc,v 1.5 2010-11-09 09:04:29 grichine Exp $
-// GEANT4 tag $Name: not supported by cvs2svn $
 //
 //
 // Physics model class G4hhElastic 
@@ -62,6 +60,8 @@
 
 #include "G4Pow.hh"
 
+#include "G4HadronicParameters.hh"
+
 using namespace std;
 
 
@@ -74,7 +74,7 @@ G4hhElastic::G4hhElastic()
   : G4HadronElastic("HadrHadrElastic")
 {
   SetMinEnergy( 1.*GeV );
-  SetMaxEnergy( 10000.*TeV );
+  SetMaxEnergy( G4HadronicParameters::Instance()->GetMaxEnergy() );
   verboseLevel = 0;
   lowEnergyRecoilLimit = 100.*keV;  
   lowEnergyLimitQ  = 0.0*GeV;  
@@ -115,7 +115,7 @@ G4hhElastic::G4hhElastic( G4ParticleDefinition* target, G4ParticleDefinition* pr
   : G4HadronElastic("HadrHadrElastic")
 {
   SetMinEnergy( 1.*GeV );
-  SetMaxEnergy( 10000.*TeV );
+  SetMaxEnergy( G4HadronicParameters::Instance()->GetMaxEnergy() );
   verboseLevel         = 0;
   lowEnergyRecoilLimit = 100.*keV;  
   lowEnergyLimitQ      = 0.0*GeV;  
@@ -160,7 +160,7 @@ G4hhElastic::G4hhElastic( G4ParticleDefinition* target, G4ParticleDefinition* pr
   : G4HadronElastic("HadrHadrElastic")
 {
   SetMinEnergy( 1.*GeV );
-  SetMaxEnergy( 10000.*TeV );
+  SetMaxEnergy( G4HadronicParameters::Instance()->GetMaxEnergy() );
   verboseLevel = 0;
   lowEnergyRecoilLimit = 100.*keV;  
   lowEnergyLimitQ  = 0.0*GeV;  
@@ -662,7 +662,7 @@ G4hhElastic:: GetTransfer( G4int iTkin, G4int iTransfer, G4double position )
   return randTransfer;
 }
 
-const G4double G4hhElastic::theNuclNuclData[18][6] = 
+const G4double G4hhElastic::theNuclNuclData[19][6] = 
 {
   // sqrt(fSpp) in GeV, fRA in 1/GeV, fRB in 1/GeV, fBq, fBQ, fImCof 
 
@@ -688,7 +688,8 @@ const G4double G4hhElastic::theNuclNuclData[18][6] =
 
   { 546,        7.4,	7.4,	0.013,	0.845877,	5.5  }, // pb-p 546 GeV
   { 1960,	7.8,	7.8,	0.022,	0.809062,	7.5  }, // pb-p 1960 GeV
-  { 7000,	8,	8,	0.024,	0.820441,	5.5  }  // pp TOTEM
+  { 7000,	8,	8,	0.024,	0.820441,	5.5  },  // pp TOTEM 7 TeV
+  { 13000,	8.5,	8.5,	0.03,	0.796721,	10.5  }  // pp TOTEM 13 TeV
  
 };
 
