@@ -24,7 +24,6 @@
 // ********************************************************************
 //
 //
-//
 // Hadronic Process: Nuclear De-excitations
 // by V. Lara (Oct 1998)
 //
@@ -51,6 +50,7 @@
 #include "G4SystemOfUnits.hh"
 #include "G4EvaporationFactory.hh"
 #include "G4EvaporationGEMFactory.hh"
+#include "G4EvaporationGEMFactoryVI.hh"
 #include "G4EvaporationDefaultGEMFactory.hh"
 #include "G4NistManager.hh"
 #include "G4VFermiBreakUp.hh"
@@ -59,6 +59,7 @@
 #include "G4ParticleTable.hh"
 #include "G4IonTable.hh"
 #include "G4NuclearLevelData.hh"
+#include "G4LevelManager.hh"
 #include "G4UnstableFragmentBreakUp.hh"
 #include "Randomize.hh"
 
@@ -69,13 +70,18 @@ G4Evaporation::G4Evaporation(G4VEvaporationChannel* photoEvaporation)
   if(photoEvaporation) { SetPhotonEvaporation(photoEvaporation); }
   else                 { SetPhotonEvaporation(new G4PhotonEvaporation()); }
 
-  channelType = fEvaporation;
-  theChannelFactory = new G4EvaporationFactory(thePhotonEvaporation);
-  InitialiseChannelFactory();
+  channelType = fDummy;
+  theChannelFactory = nullptr;
 
+  fLevelData = G4NuclearLevelData::GetInstance();
   theTableOfIons = G4ParticleTable::GetParticleTable()->GetIonTable();
   nist = G4NistManager::Instance();
   unstableBreakUp = new G4UnstableFragmentBreakUp();
+  /*
+    G4cout << "G4Evaporation() " << this << " thePhotonEvaporation: "
+	   << photoEvaporation << "  UnstableFragmentBreakUp: " 
+           << unstableBreakUp << G4endl;
+  */
 }
 
 G4Evaporation::~G4Evaporation()
@@ -87,13 +93,16 @@ void G4Evaporation::InitialiseChannels()
 {
   if(isInitialised) { return; }
 
-  G4DeexPrecoParameters* param = 
-    G4NuclearLevelData::GetInstance()->GetParameters(); 
+  G4DeexPrecoParameters* param = fLevelData->GetParameters(); 
   minExcitation = param->GetMinExcitation();
+  fVerbose = param->GetVerbose();
+  unstableBreakUp->SetVerbose(fVerbose);
 
   G4DeexChannelType type = param->GetDeexChannelsType();
   if(type == fCombined) { SetCombinedChannel(); }
   else if(type == fGEM) { SetGEMChannel(); }
+  else if(type == fEvaporation) { SetDefaultChannel(); }
+  else if(type == fGEMVI) { SetGEMVIChannel(); }
 
   isInitialised = true;
 }
@@ -104,7 +113,7 @@ void G4Evaporation::InitialiseChannelFactory()
   nChannels = theChannels->size();   
   probabilities.resize(nChannels, 0.0);
 
-  if(fVerbose > 0) {
+  if(fVerbose > 1) {
     G4cout << "### G4Evaporation::InitialiseChannelFactory  for " 
 	   << nChannels << " channels " << this << G4endl;
   }
@@ -118,8 +127,10 @@ void G4Evaporation::SetDefaultChannel()
 {
   if(fEvaporation != channelType) {
     channelType = fEvaporation;
-    CleanChannels();
-    delete theChannelFactory;
+    if(theChannelFactory) {
+      CleanChannels();
+      delete theChannelFactory;
+    }
     theChannelFactory = new G4EvaporationFactory(thePhotonEvaporation);
     InitialiseChannelFactory();
   }
@@ -129,20 +140,38 @@ void G4Evaporation::SetGEMChannel()
 {
   if(fGEM != channelType) {
     channelType = fCombined;
-    CleanChannels();
-    delete theChannelFactory;
+    if(theChannelFactory) {
+      CleanChannels();
+      delete theChannelFactory;
+    }
     theChannelFactory = new G4EvaporationGEMFactory(thePhotonEvaporation);
     InitialiseChannelFactory();
   }
 }
 
+void G4Evaporation::SetGEMVIChannel()
+{
+  if(fGEMVI != channelType) {
+    channelType = fGEMVI;
+    if(theChannelFactory) {
+      CleanChannels();
+      delete theChannelFactory;
+    }
+    theChannelFactory = new G4EvaporationGEMFactoryVI(thePhotonEvaporation);
+    InitialiseChannelFactory();
+  }
+}
+
 void G4Evaporation::SetCombinedChannel()
 {
   if(fCombined != channelType) {
     channelType = fCombined;
-    CleanChannels();
-    delete theChannelFactory;
-    theChannelFactory = new G4EvaporationDefaultGEMFactory(thePhotonEvaporation);
+    if(theChannelFactory) {
+      CleanChannels();
+      delete theChannelFactory;
+    }
+    theChannelFactory = 
+      new G4EvaporationDefaultGEMFactory(thePhotonEvaporation);
     InitialiseChannelFactory();
   }
 }
@@ -156,6 +185,9 @@ void G4Evaporation::BreakFragment(G4FragmentVector* theResult,
   size_t maxchannel, i;
 
   G4int Amax = theResidualNucleus->GetA_asInt();
+  if(fVerbose > 1) {
+    G4cout << "### G4Evaporation::BreakItUp loop" << G4endl;
+  }
 
   // Starts loop over evaporated particles, loop is limited by number
   // of nucleons
@@ -164,6 +196,7 @@ void G4Evaporation::BreakFragment(G4FragmentVector* theResult,
     // g,n,p and light fragments - evaporation is finished
     G4int Z = theResidualNucleus->GetZ_asInt();
     G4int A = theResidualNucleus->GetA_asInt();
+    if(A <= 1) { break; }
     G4double Eex = theResidualNucleus->GetExcitationEnergy();
 
     // stop deecitation loop if residual can be deexcited by FBU    
@@ -171,26 +204,22 @@ void G4Evaporation::BreakFragment(G4FragmentVector* theResult,
 
     // check if it is stable, then finish evaporation
     G4double abun = nist->GetIsotopeAbundance(Z, A); 
-    if(fVerbose > 0) {
-      G4cout << "### G4Evaporation::BreakItUp step " << ia << " Z= " << Z
-	     << " A= " << A << " Eex(MeV)= " 
-	     << theResidualNucleus->GetExcitationEnergy()
-	     << " aban= " << abun << G4endl;
-    }
     // stop deecitation loop in the case of a cold stable fragment 
-    if(Eex <= minExcitation && abun > 0.0) { break; }
+    if(Eex <= minExcitation && 
+       (abun > 0.0 || (A == 3 && (Z == 1 || Z == 2)))) { break; }
  
     totprob = 0.0;
     maxchannel = nChannels;
     if(fVerbose > 1) {
-      G4cout << "### Evaporation loop #" << ia 
-	     << "  Fragment: " << theResidualNucleus << G4endl;
+      G4cout << "Evaporation# " << ia << " Z= " << Z << " A= " << A 
+             << " Eex(MeV)= " << theResidualNucleus->GetExcitationEnergy()
+	     << " aban= " << abun << G4endl;
     }
     // loop over evaporation channels
     for(i=0; i<nChannels; ++i) {
       prob = (*theChannels)[i]->GetEmissionProbability(theResidualNucleus);
-      if(fVerbose > 1 && prob > 0.0) {
-	G4cout << "  Channel# " << i << "  prob= " << prob << G4endl; 
+      if(fVerbose > 2 && prob > 0.0) {
+	G4cout << "    Channel# " << i << "  prob= " << prob << G4endl; 
       }
       totprob += prob;
       probabilities[i] = totprob;
@@ -206,10 +235,10 @@ void G4Evaporation::BreakFragment(G4FragmentVector* theResult,
     }
 
     // photon evaporation in the case of no other channels available
-    // do evaporation chain and reset total probability
+    // do evaporation chain and return back ground state fragment
     if(0.0 < totprob && probabilities[0] == totprob) {
       if(fVerbose > 1) {
-	G4cout << "Start chain of gamma evaporation" << G4endl;
+	G4cout << "$$$ Start chain of gamma evaporation" << G4endl;
       }
       (*theChannels)[0]->BreakUpChain(theResult, theResidualNucleus);
       totprob = 0.0;
@@ -218,14 +247,19 @@ void G4Evaporation::BreakFragment(G4FragmentVector* theResult,
     // stable fragment - evaporation is finished
     if(0.0 == totprob) {
 
-      // if fragment is exotic, then force its decay 
-      if(0.0 == abun) {
-	if(!unstableBreakUp->BreakUpChain(theResult, theResidualNucleus))
-	  { break; }
-	if(fVerbose > 1) { G4cout << "$$$ Decay exotic fragment" << G4endl; }
-      } else {
-	break;
+      // release fragment known to DB
+      if(fLevelData->GetLevelManager(Z, A)) { break; }
+
+      // if fragment is exotic, then it forced to decay 
+      // if success, then decay product is added to results 
+      if(fVerbose > 1) { 
+	G4cout << "$$$ Decay exotic fragment" << G4endl; 
       }
+      if(unstableBreakUp->BreakUpChain(theResult, theResidualNucleus)) {
+        continue;
+      }
+      // release if it is not possible to decay
+      break;
     }
 
     // select channel
@@ -233,14 +267,12 @@ void G4Evaporation::BreakFragment(G4FragmentVector* theResult,
     // loop over evaporation channels
     for(i=0; i<maxchannel; ++i) { if(probabilities[i] >= totprob) { break; } }
 
-    if(fVerbose > 1) { G4cout << "Channel # " << i << G4endl; }
+    if(fVerbose > 1) { G4cout << "$$$ Channel # " << i << G4endl; }
     G4Fragment* frag = (*theChannels)[i]->EmittedFragment(theResidualNucleus);
-    if(fVerbose > 1 && frag) { G4cout << "   " << *frag << G4endl; }
+    if(fVerbose > 2 && frag) { G4cout << "   " << *frag << G4endl; }
 
     // normaly a fragment should be created
     if(frag) { theResult->push_back(frag); }
     else     { break; }
   }
-  // loop is stopped, residual fragment is added to the results
-  theResult->push_back(theResidualNucleus);
 }
