@@ -37,7 +37,6 @@
 #include "G4GEMChannel.hh"
 #include "G4VCoulombBarrier.hh"
 #include "G4GEMCoulombBarrier.hh"
-#include "G4NuclearLevelData.hh"
 #include "G4PairingCorrection.hh"
 #include "G4PhysicalConstants.hh"
 #include "G4SystemOfUnits.hh"
@@ -51,9 +50,9 @@ G4GEMChannel::G4GEMChannel(G4int theA, G4int theZ, const G4String & aName,
   G4VEvaporationChannel(aName),
   A(theA),
   Z(theZ),
-  theEvaporationProbabilityPtr(aEmissionStrategy),
   EmissionProbability(0.0),
-  MaximalKineticEnergy(-CLHEP::GeV)
+  MaximalKineticEnergy(-CLHEP::GeV),
+  theEvaporationProbabilityPtr(aEmissionStrategy)
 { 
   theCoulombBarrierPtr = new G4GEMCoulombBarrier(theA, theZ);
   theEvaporationProbabilityPtr->SetCoulomBarrier(theCoulombBarrierPtr);
@@ -63,8 +62,7 @@ G4GEMChannel::G4GEMChannel(G4int theA, G4int theZ, const G4String & aName,
   ResidualMass = CoulombBarrier = 0.0;
   fG4pow = G4Pow::GetInstance(); 
   ResidualZ = ResidualA = 0;
-  pairingCorrection = 
-    G4NuclearLevelData::GetInstance()->GetPairingCorrection();
+  fNucData = G4NuclearLevelData::GetInstance();
 }
 
 G4GEMChannel::~G4GEMChannel()
@@ -89,11 +87,11 @@ G4double G4GEMChannel::GetEmissionProbability(G4Fragment* fragment)
   EmissionProbability = 0.0;
 
   // Only channels which are physically allowed are taken into account 
-  if (ResidualA >= ResidualZ && ResidualZ > 0 && ResidualA >= A) {
+  if (ResidualA >= ResidualZ && ResidualZ >= 0 && ResidualA >= A) {
   
     //Effective excitation energy
     G4double ExEnergy = fragment->GetExcitationEnergy()
-      - pairingCorrection->GetPairingCorrection(anA, aZ);
+      - fNucData->GetPairingCorrection(aZ, anA);
     if(ExEnergy > 0.0) { 
       ResidualMass = G4NucleiProperties::GetNuclearMass(ResidualA, ResidualZ);
       G4double FragmentMass = fragment->GetGroundStateMass();
@@ -156,7 +154,7 @@ G4double G4GEMChannel::SampleKineticEnergy(const G4Fragment & fragment)
 
   //                       ***RESIDUAL***
   //JMQ (September 2009) the following quantities  refer to the RESIDUAL:
-  G4double delta0 = pairingCorrection->GetPairingCorrection(ResidualA,ResidualZ);
+  G4double delta0 = fNucData->GetPairingCorrection(ResidualZ,ResidualA);
   G4double Ux = (2.5 + 150.0/ResidualA)*MeV;
   G4double Ex = Ux + delta0;
   G4double InitialLevelDensity;
@@ -165,8 +163,8 @@ G4double G4GEMChannel::SampleKineticEnergy(const G4Fragment & fragment)
   //                       ***PARENT***
   //JMQ (September 2009) the following quantities   refer to the PARENT:
   
-  G4double deltaCN = pairingCorrection->GetPairingCorrection(fragment.GetA_asInt(),
-							     fragment.GetZ_asInt());
+  G4double deltaCN = fNucData->GetPairingCorrection(fragment.GetZ_asInt(),
+						    fragment.GetA_asInt());
   G4double aCN = theLevelDensityPtr->LevelDensityParameter(fragment.GetA_asInt(),
 							   fragment.GetZ_asInt(),
 							   U-deltaCN);   
@@ -191,11 +189,10 @@ G4double G4GEMChannel::SampleKineticEnergy(const G4Fragment & fragment)
   
   G4double Spin = theEvaporationProbabilityPtr->GetSpin();
   //JMQ  BIG BUG fixed: hbarc instead of hbar_Planck !!!!
-  //     it was fixed in total probability (for this channel) but remained still here!!
-  //    G4double g = (2.0*Spin+1.0)*NuclearMass/(pi2* hbar_Planck*hbar_Planck);
+  //     it was also fixed in total probability 
   G4double gg = (2.0*Spin+1.0)*EvaporatedMass/(pi2* hbarc*hbarc);
   //
-  //JMQ  fix on Rb and  geometrical cross sections according to Furihata's paper 
+  //JMQ  fix on Rb and geometrical cross sections according to Furihata's paper 
   //                      (JAERI-Data/Code 2001-105, p6)
   G4double Rb = 0.0; 
   if (A > 4) 
