@@ -62,14 +62,13 @@ G4Mutex G4PhotonEvaporation::PhotonEvaporationMutex = G4MUTEX_INITIALIZER;
 
 G4PhotonEvaporation::G4PhotonEvaporation(G4GammaTransition* p)
   : fLevelManager(nullptr), fTransition(p), fPolarization(nullptr),
-    fVerbose(0), fPoints(0), vShellNumber(-1), fIndex(0), 
+    fVerbose(1), fPoints(0), vShellNumber(-1), fIndex(0), 
     fMaxLifeTime(DBL_MAX), 
     fICM(true), fRDM(false), fSampleTime(true), 
     fCorrelatedGamma(false), isInitialised(false)
 {
   //G4cout << "### New G4PhotonEvaporation() " << this << G4endl;   
   fNuclearLevelData = G4NuclearLevelData::GetInstance(); 
-  fNucPStore = G4NuclearPolarizationStore::GetInstance();
   Tolerance = 20*CLHEP::eV;
 
   if(!fTransition) { fTransition = new G4GammaTransition(); }
@@ -91,18 +90,19 @@ void G4PhotonEvaporation::Initialise()
   if(isInitialised) { return; }
   isInitialised = true;
 
-  if(fVerbose > 0) {
-    G4cout << "### G4PhotonEvaporation is initialized " << this << G4endl;   
-  }
   G4DeexPrecoParameters* param = fNuclearLevelData->GetParameters();
   Tolerance = param->GetMinExcitation();
   fMaxLifeTime = param->GetMaxLifeTime();
   fCorrelatedGamma = param->CorrelatedGamma();
   fICM = param->GetInternalConversionFlag();
+  fVerbose = param->GetVerbose();
 
   fTransition->SetPolarizationFlag(fCorrelatedGamma);
   fTransition->SetTwoJMAX(param->GetTwoJMAX());
   fTransition->SetVerbose(fVerbose);
+  if(fVerbose > 1) {
+    G4cout << "### G4PhotonEvaporation is initialized " << this << G4endl;   
+  }
 }
 
 void G4PhotonEvaporation::InitialiseGRData()
@@ -112,7 +112,7 @@ void G4PhotonEvaporation::InitialiseGRData()
 #endif
   if(0.0f == GREnergy[1]) { 
     G4Pow* g4calc = G4Pow::GetInstance();
-    static const G4float GRWfactor = 0.3f;
+    const G4float GRWfactor = 0.3f;
     for (G4int A=1; A<MAXGRDATA; ++A) {
       GREnergy[A] = (G4float)(40.3*CLHEP::MeV/g4calc->powZ(A,0.2));
       GRWidth[A] = GRWfactor*GREnergy[A];
@@ -131,7 +131,9 @@ G4PhotonEvaporation::EmittedFragment(G4Fragment* nucleus)
 
   // potentially external code may set initial polarization
   // but only for radioactive decay nuclear polarization is considered
+  G4NuclearPolarizationStore* fNucPStore = nullptr;
   if(fCorrelatedGamma && fRDM) {
+    fNucPStore = G4NuclearPolarizationStore::GetInstance();
     if(nucleus->GetNuclearPolarization()) { 
       fNucPStore->RemoveMe(nucleus->GetNuclearPolarization());
       delete nucleus->GetNuclearPolarization(); 
@@ -141,7 +143,7 @@ G4PhotonEvaporation::EmittedFragment(G4Fragment* nucleus)
                                             nucleus->GetExcitationEnergy());
     nucleus->SetNuclearPolarization(fPolarization);
   }
-  if(fVerbose > 1) { 
+  if(fVerbose > 2) { 
     G4cout << "G4PhotonEvaporation::EmittedFragment: " 
            << *nucleus << G4endl;
     if(fPolarization) { G4cout << "NucPolar: " << fPolarization << G4endl; }
@@ -151,8 +153,8 @@ G4PhotonEvaporation::EmittedFragment(G4Fragment* nucleus)
   G4Fragment* gamma = GenerateGamma(nucleus);
 
   // remove G4NuclearPolarizaton when reach ground state
-  if(fPolarization && 0 == fIndex) {
-    if(fVerbose > 1) { 
+  if(fNucPStore && fPolarization && 0 == fIndex) {
+    if(fVerbose > 3) { 
       G4cout << "G4PhotonEvaporation::EmittedFragment: remove " 
              << fPolarization << G4endl;
     }
@@ -161,7 +163,7 @@ G4PhotonEvaporation::EmittedFragment(G4Fragment* nucleus)
     nucleus->SetNuclearPolarization(fPolarization);
   }
 
-  if(fVerbose > 1) {
+  if(fVerbose > 2) {
     G4cout << "G4PhotonEvaporation::EmittedFragment: RDM= " 
            << fRDM << " done:" << G4endl; 
     if(gamma) { G4cout << *gamma << G4endl; }
@@ -173,7 +175,7 @@ G4PhotonEvaporation::EmittedFragment(G4Fragment* nucleus)
 G4FragmentVector* 
 G4PhotonEvaporation::BreakItUp(const G4Fragment& nucleus)
 {
-  if(fVerbose > 0) {
+  if(fVerbose > 1) {
     G4cout << "G4PhotonEvaporation::BreakItUp" << G4endl;
   }
   G4Fragment* aNucleus = new G4Fragment(nucleus);
@@ -187,7 +189,7 @@ G4bool G4PhotonEvaporation::BreakUpChain(G4FragmentVector* products,
                                          G4Fragment* nucleus)
 {
   if(!isInitialised) { Initialise(); }
-  if(fVerbose > 0) {
+  if(fVerbose > 1) {
     G4cout << "G4PhotonEvaporation::BreakUpChain RDM= " << fRDM << " "
            << *nucleus << G4endl;
   }
@@ -206,7 +208,7 @@ G4bool G4PhotonEvaporation::BreakUpChain(G4FragmentVector* products,
     gamma = GenerateGamma(nucleus);
     if(gamma) { 
       products->push_back(gamma);
-      if(fVerbose > 0) {
+      if(fVerbose > 2) {
         G4cout << "G4PhotonEvaporation::BreakUpChain: "   
                << *gamma << G4endl;
         G4cout << "   Residual: " << *nucleus << G4endl;
@@ -235,7 +237,7 @@ G4PhotonEvaporation::GetEmissionProbability(G4Fragment* nucleus)
   G4int Z = nucleus->GetZ_asInt();
   G4int A = nucleus->GetA_asInt();
   fCode   = 1000*Z + A; 
-  if(fVerbose > 1) {
+  if(fVerbose > 2) {
     G4cout << "G4PhotonEvaporation::GetEmissionProbability: Z=" 
            << Z << " A=" << A << " Eexc(MeV)= " << fExcEnergy << G4endl; 
   }
@@ -264,10 +266,10 @@ G4PhotonEvaporation::GetEmissionProbability(G4Fragment* nucleus)
   if(0.0 == emax || fExcEnergy*eexcfac <= emax) { emax = fExcEnergy*eexcfac; }
 
   fStep = emax;
-  static const G4double MaxDeltaEnergy = CLHEP::MeV;
+  const G4double MaxDeltaEnergy = CLHEP::MeV;
   fPoints = std::min((G4int)(fStep/MaxDeltaEnergy) + 2, MAXDEPOINT);
   fStep /= ((G4double)(fPoints - 1));
-  if(fVerbose > 1) {
+  if(fVerbose > 2) {
     G4cout << "Emax= " << emax << " Npoints= " << fPoints 
            << "  Eex= " << fExcEnergy << G4endl;
   }
@@ -296,7 +298,7 @@ G4PhotonEvaporation::GetEmissionProbability(G4Fragment* nucleus)
       *gammaR2*gammaE2/(egdp2*egdp2 + gammaR2);
     fProbability += (p1 + p0);
     fCummProbability[i] = fProbability;
-    if(fVerbose > 2) {
+    if(fVerbose > 3) {
       G4cout << "Egamma= " << egam << "  Eex= " << fExcEnergy
              << "  p0= " << p0 << " p1= " << p1 << " sum= " 
              << fCummProbability[i] <<G4endl;
@@ -353,15 +355,18 @@ G4PhotonEvaporation::GenerateGamma(G4Fragment* nucleus)
   const G4NucLevel* level = nullptr;
   size_t ntrans = 0;
 
-  if(fVerbose > 1) {
+  if(fVerbose > 2) {
     G4cout << "GenerateGamma: " << " Eex= " << eexc
            << " Eexmax= " << fLevelEnergyMax << G4endl;
   }
   // initial discrete state
   if(fLevelManager && eexc <= fLevelEnergyMax + Tolerance) {
     fIndex = fLevelManager->NearestLevelIndex(eexc, fIndex);
+    // initial state below 1st level
+    if(0 == fIndex && eexc >= Tolerance 
+       && fLevelManager->NumberOfTransitions() > 0) { fIndex = 1; }
     isDiscrete = true; 
-    if(fVerbose > 1) {
+    if(fVerbose > 2) {
       G4cout << "              index= " << fIndex 
              << " lTime= " << fLevelManager->LifeTime(fIndex) << G4endl;
     }
@@ -384,7 +389,7 @@ G4PhotonEvaporation::GenerateGamma(G4Fragment* nucleus)
       }
     }
   }
-  if(fVerbose > 1) {
+  if(fVerbose > 2) {
     G4int prec = G4cout.precision(4);
     G4cout << "GenerateGamma: Z= " << nucleus->GetZ_asInt()
            << " A= " << nucleus->GetA_asInt() 
@@ -403,14 +408,13 @@ G4PhotonEvaporation::GenerateGamma(G4Fragment* nucleus)
     if(fCode != 1000*theZ + theA || eexc != fExcEnergy) { 
       GetEmissionProbability(nucleus); 
     }
-    //if(fProbability == 0.0) { return result; }
     if(fProbability == 0.0) { 
       fPoints = 1; 
       efinal = 0.0; 
     } else {
       G4double y = fCummProbability[fPoints-1]*G4UniformRand();
       for(G4int i=1; i<fPoints; ++i) {
-        if(fVerbose > 2) {
+        if(fVerbose > 3) {
           G4cout << "y= " << y << " cummProb= " << fCummProbability[i] 
                  << " fPoints= " << fPoints << " fStep= " << fStep << G4endl;
         }
@@ -423,7 +427,7 @@ G4PhotonEvaporation::GenerateGamma(G4Fragment* nucleus)
     }
     // final discrete level
     if(fVerbose > 2) {
-      G4cout << "Continues Efinal= " << efinal << G4endl;
+      G4cout << "Continues proposes Efinal= " << efinal << G4endl;
     }
     if(fLevelManager) {
       if(efinal < fLevelEnergyMax) {
@@ -443,32 +447,17 @@ G4PhotonEvaporation::GenerateGamma(G4Fragment* nucleus)
         fIndex = fLevelManager->NearestLevelIndex(efinal, fIndex);
       }
     }
-    if(fVerbose > 1) {
+    if(fVerbose > 2) {
       G4cout << "Continues emission efinal(MeV)= " << efinal << G4endl; 
     }
     //discrete part ground state
   } else if(0 == fIndex) {
     return result;
 
-    //discrete part no transitions defined
-  } else if(0 == ntrans) {
-    for(size_t ii=fIndex-1; ii>0; --ii) {
-      level = fLevelManager->GetLevel(ii);
-      if(level) { 
-        ntrans = level->NumberOfTransitions();
-        // transition identified
-        if(0 < ntrans) {
-          efinal = fLevelManager->LevelEnergy(ii);
-          fIndex = ii;
-          break;
-        }
-      }
-    }
-    
-    //discrete part for levels with transitions
+    //discrete part
   } else {
  
-    if(fVerbose > 1) {
+    if(fVerbose > 2) {
       G4cout << "Discrete emission from level Index= " << fIndex 
              << " Elevel= " << fLevelManager->LevelEnergy(fIndex)
              << " Ltime= " << fLevelManager->LifeTime(fIndex)
@@ -481,29 +470,39 @@ G4PhotonEvaporation::GenerateGamma(G4Fragment* nucleus)
     G4double ltime = fLevelManager->LifeTime(fIndex);
     if(ltime < 0.0 || (!fRDM && ltime > fMaxLifeTime)) { return result; }
 
-    size_t idx = 0;
-    if(1 < ntrans) {
-      idx = level->SampleGammaTransition(G4UniformRand());
-    }
-    if(fVerbose > 1) {
-      G4cout << "Ntrans= " << ntrans << " idx= " << idx
-             << " ICM= " << fICM << "  JP1= " << JP1 << G4endl;
-    }
-    G4double prob = (G4double)level->GammaProbability(idx);
-    // prob = 0 means that there is only internal conversion
-    if(fICM && prob < 1.0) {
-      G4double rndm = G4UniformRand();
-      if(rndm > prob) {
-        isGamma = false;
-        rndm = (rndm - prob)/(1.0 - prob);
-        vShellNumber = level->SampleShell(idx, rndm);
+    // no transitions: force transition to the closest level 
+    if(0 == ntrans) {
+      G4int ii = fIndex - 1;
+      for(; ii>0; --ii) {
+	const G4NucLevel* fl = fLevelManager->GetLevel(ii);
+	if(fl && 0 < fl->NumberOfTransitions()) { break; }
       }
+      fIndex = ii;
+    } else {
+      size_t idx = 0;
+      if(1 < ntrans) {
+	idx = level->SampleGammaTransition(G4UniformRand());
+      }
+      if(fVerbose > 2) {
+	G4cout << "Ntrans= " << ntrans << " idx= " << idx
+	       << " ICM= " << fICM << "  JP1= " << JP1 << G4endl;
+      }
+      G4double prob = (G4double)level->GammaProbability(idx);
+      // prob = 0 means that there is only internal conversion
+      if(fICM && prob < 1.0) {
+	G4double rndm = G4UniformRand();
+	if(rndm > prob) {
+	  isGamma = false;
+	  rndm = (rndm - prob)/(1.0 - prob);
+	  vShellNumber = level->SampleShell(idx, rndm);
+	}
+      }
+      // it is discrete transition with possible gamma correlation
+      ratio  = level->MultipolarityRatio(idx);
+      multiP = level->TransitionType(idx);
+      fIndex = level->FinalExcitationIndex(idx);
     }
-    // it is discrete transition with possible gamma correlation
-    ratio  = level->MultipolarityRatio(idx);
-    multiP = level->TransitionType(idx);
-    fIndex = level->FinalExcitationIndex(idx);
-    JP2    = fLevelManager->SpinTwo(fIndex); 
+    JP2 = fLevelManager->SpinTwo(fIndex); 
 
     // final energy and time
     efinal = fLevelManager->LevelEnergy(fIndex);
@@ -531,7 +530,7 @@ G4PhotonEvaporation::GenerateGamma(G4Fragment* nucleus)
     nucleus->SetFloatingLevelNumber(fLevelManager->FloatingLevel(fIndex));
   }
       
-  if(fVerbose > 1) { 
+  if(fVerbose > 2) { 
     G4cout << "Final level E= " << efinal << " time= " << time 
            << " idxFinal= " << fIndex << " isDiscrete: " << isDiscrete
            << " isGamma: " << isGamma << " multiP= " << multiP 
