@@ -44,6 +44,8 @@
 
 #include "globals.hh"
 #include "G4ios.hh"
+#include "G4Exp.hh"
+#include "G4Log.hh"
 #include "G4SystemOfUnits.hh"
 #include "G4XnpTotalLowE.hh"
 #include "G4KineticTrack.hh"
@@ -57,12 +59,12 @@ const G4double G4XnpTotalLowE::_lowLimit = 0.;
 const G4double G4XnpTotalLowE::_highLimit = 3.*GeV;
 
 // Low energy limit of the cross-section table (in GeV)
-// Units are assigned while filling the PhysicsVector
+// Units are assigned when filling the PhysicsVector
 const G4double G4XnpTotalLowE::_eMinTable = 1.8964808;
 const G4double G4XnpTotalLowE::_eStepLog = 0.01;
 
 // Cross-sections in mb
-// Units are assigned while filling the PhysicsVector
+// Units are assigned when filling the PhysicsVector
 const G4int G4XnpTotalLowE::_tableSize = 101;
 const G4double G4XnpTotalLowE::_sigmaTable[101] = 
 { 
@@ -88,8 +90,8 @@ G4XnpTotalLowE::G4XnpTotalLowE()
   // Cross-sections are available in the range (_eMin,_eMax)
 
   _eMin = _eMinTable * GeV;
-  _eMin = std::exp(std::log(_eMinTable)-_eStepLog)*GeV;
-  _eMax = std::exp(std::log(_eMinTable) + _tableSize * _eStepLog) * GeV;
+  _eMin = G4Exp(G4Log(_eMinTable)-_eStepLog)*GeV;
+  _eMax = G4Exp(G4Log(_eMinTable) + _tableSize * _eStepLog) * GeV;
 
   // Protections: validity limits must be compatible with available data
 //  @@GF  this ought to be _lowLimit < _eMin
