@@ -6,8 +6,6 @@
 #include <cmath>
 
 #ifdef WIN32
-//#include "erf.h"
-#include "amp_math.h"
 #define M_PI 3.141592653589793238463
 #endif
 
