@@ -79,7 +79,7 @@ G4int G4ParticleHPProduct::GetMultiplicity(G4double anEnergy )
 #else 
        if( theMultiplicityMethod == G4HPMultiPoisson ) {
 	 multi = G4Poisson ( mean ); 	 
-	 if( getenv("G4PHPTEST") )  G4cout << " MULTIPLICITY MULTIPLIED " << multi << " " << theMassCode << G4endl;
+	 if( std::getenv("G4PHPTEST") )  G4cout << " MULTIPLICITY MULTIPLIED " << multi << " " << theMassCode << G4endl;
        } else { // if( theMultiplicityMethod == G4HPMultiBetweenInts ) {
 	 G4double radnf = CLHEP::RandFlat::shoot();
 	 G4int imulti = G4int(mean);
@@ -92,7 +92,7 @@ G4int G4ParticleHPProduct::GetMultiplicity(G4double anEnergy )
 	//       if( CLHEP::RandFlat::shoot() > mean-multi ) multi++;
      }
 #ifdef G4PHPDEBUG
-     if( getenv("G4ParticleHPDebug") ) G4cout << "G4ParticleHPProduct::GetMultiplicity " << theMassCode << " " << theMass << " multi " << multi << " mean " << mean << G4endl;
+     if( std::getenv("G4ParticleHPDebug") ) G4cout << "G4ParticleHPProduct::GetMultiplicity " << theMassCode << " " << theMass << " multi " << multi << " mean " << mean << G4endl;
 #endif
   }
 
@@ -118,13 +118,13 @@ G4ReactionProductVector * G4ParticleHPProduct::Sample(G4double anEnergy, G4int m
   for(i=0;i<multi;i++)
   {
 #ifdef G4PHPDEBUG
- if( getenv("G4PHPTEST") )
-    if( getenv("G4ParticleHPDebug") && tmp != 0 )    G4cout << multi << " " << i << " @@@ G4ParticleHPProduct::Sample " << anEnergy << " Mass " << theMassCode << " " << theMass << G4endl;
+ if( std::getenv("G4PHPTEST") )
+    if( std::getenv("G4ParticleHPDebug") && tmp != 0 )    G4cout << multi << " " << i << " @@@ G4ParticleHPProduct::Sample " << anEnergy << " Mass " << theMassCode << " " << theMass << G4endl;
 #endif
     tmp = theDist->Sample(anEnergy, theMassCode, theMass);
     if(tmp != 0) { result->push_back(tmp); }
 #ifndef G4PHPDEBUG //GDEB
-    if( getenv("G4ParticleHPDebug") && tmp != 0 )   G4cout << multi << " " << i << " @@@ G4ParticleHPProduct::Sample " << tmp->GetDefinition()->GetParticleName() << " E= " << tmp->GetKineticEnergy() << G4endl; 
+    if( std::getenv("G4ParticleHPDebug") && tmp != 0 )   G4cout << multi << " " << i << " @@@ G4ParticleHPProduct::Sample " << tmp->GetDefinition()->GetParticleName() << " E= " << tmp->GetKineticEnergy() << G4endl; 
 #endif
   }
   if(multi == 0) 
