@@ -47,13 +47,13 @@ const G4VStringFragmentation & G4VStringFragmentation::operator=(const G4VString
   return *this;
 }
 
-int G4VStringFragmentation::operator==(const G4VStringFragmentation &) const
+G4bool G4VStringFragmentation::operator==(const G4VStringFragmentation &) const
 {
-  return 0;
+  return false;
 }
 
-int G4VStringFragmentation::operator!=(const G4VStringFragmentation &) const
+G4bool G4VStringFragmentation::operator!=(const G4VStringFragmentation &) const
 {
-  return 1;
+  return true;
 }
 
