@@ -24,7 +24,6 @@
 // ********************************************************************
 //
 //
-// $Id$
 // ------------------------------------------------------------
 //      GEANT 4 class implemetation file
 //
@@ -60,6 +59,11 @@
 #include "G4Log.hh"
 #include "G4Pow.hh"
 
+//============================================================================
+
+//#define debugDoubleDiffraction
+
+//============================================================================
 
 G4QGSDiffractiveExcitation::G4QGSDiffractiveExcitation()
 {
@@ -71,14 +75,20 @@ G4QGSDiffractiveExcitation::~G4QGSDiffractiveExcitation()
 
 
 G4bool G4QGSDiffractiveExcitation::
-ExciteParticipants(G4VSplitableHadron *projectile, G4VSplitableHadron *target) const
+ExciteParticipants(G4VSplitableHadron *projectile, G4VSplitableHadron *target, G4bool ) const
 {
+  #ifdef debugDoubleDiffraction
+    G4cout<<G4endl<<"G4QGSDiffractiveExcitation::ExciteParticipants - Double diffraction."<<G4endl;
+    G4cout<<"Proj Targ "<<projectile->GetDefinition()->GetParticleName()<<" "<<target->GetDefinition()->GetParticleName()<<G4endl;
+    G4cout<<"Proj 4 Mom "<<projectile->Get4Momentum()<<" "<<projectile->Get4Momentum().mag()<<G4endl;
+    G4cout<<"Targ 4 Mom "<<target->Get4Momentum()    <<" "<<target->Get4Momentum().mag()    <<G4endl;
+  #endif
+
   G4LorentzVector Pprojectile=projectile->Get4Momentum();
 
   // -------------------- Projectile parameters -----------------------------------
   G4bool PutOnMassShell=0;
 
-  //G4double M0projectile=projectile->GetDefinition()->GetPDGMass();  // With de-excitation
   G4double M0projectile = Pprojectile.mag();                        // Without de-excitation
 
   if(M0projectile < projectile->GetDefinition()->GetPDGMass())
@@ -87,37 +97,6 @@ ExciteParticipants(G4VSplitableHadron *projectile, G4VSplitableHadron *target) c
     M0projectile=projectile->GetDefinition()->GetPDGMass();
   }
 
-  G4double Mprojectile2 = M0projectile * M0projectile;
-
-  G4int    PDGcode=projectile->GetDefinition()->GetPDGEncoding();
-  G4int    absPDGcode=std::abs(PDGcode);
-  G4double ProjectileDiffCut;
-  G4double AveragePt2;
-
-  if( absPDGcode > 1000 )                        //------Projectile is baryon --------
-  {
-    ProjectileDiffCut = 1.1;                    // GeV
-    AveragePt2 = 0.3;                           // GeV^2
-  }
-  else if( absPDGcode == 211 || PDGcode ==  111) //------Projectile is Pion -----------
-  {
-    ProjectileDiffCut = 1.0;                   // GeV
-    AveragePt2 = 0.3;                          // GeV^2
-  }
-  else if( absPDGcode == 321 || PDGcode == -311) //------Projectile is Kaon -----------
-  {
-    ProjectileDiffCut = 1.1;                    // GeV
-    AveragePt2 = 0.3;                           // GeV^2
-  }
-  else                                           //------Projectile is undefined, Nucleon assumed
-  {
-    ProjectileDiffCut = 1.1;                    // GeV
-    AveragePt2 = 0.3;                           // GeV^2
-  };
-
-  ProjectileDiffCut = ProjectileDiffCut * GeV;
-  AveragePt2 = AveragePt2 * GeV*GeV;
-
   // -------------------- Target parameters ----------------------------------------------
   G4LorentzVector Ptarget=target->Get4Momentum();
 
@@ -129,18 +108,18 @@ ExciteParticipants(G4VSplitableHadron *projectile, G4VSplitableHadron *target) c
     M0target=target->GetDefinition()->GetPDGMass();
   }
 
-  G4double Mtarget2 = M0target * M0target;                      //Ptarget.mag2(); // for AA-inter.
+  G4LorentzVector Psum=Pprojectile+Ptarget;
+  G4double S=Psum.mag2();
+  G4double SqrtS=std::sqrt(S);
 
-  G4double NuclearNucleonDiffCut = 1.1*GeV;
+  if (SqrtS < M0projectile + M0target) {return false;}  // The model cannot work for pp-interactions
+	                                                // at Plab < 1.3 GeV/c.
 
-  G4double ProjectileDiffCut2 = ProjectileDiffCut * ProjectileDiffCut;
-  G4double NuclearNucleonDiffCut2 = NuclearNucleonDiffCut * NuclearNucleonDiffCut;
+  G4double Mprojectile2 = M0projectile * M0projectile;
+  G4double Mtarget2     = M0target     * M0target;    //Ptarget.mag2(); // for AA-inter.
 
   // Transform momenta to cms and then rotate parallel to z axis;
 
-  G4LorentzVector Psum;
-  Psum=Pprojectile+Ptarget;
-
   G4LorentzRotation toCms(-1*Psum.boostVector());
 
   G4LorentzVector Ptmp=toCms*Pprojectile;
@@ -160,108 +139,112 @@ ExciteParticipants(G4VSplitableHadron *projectile, G4VSplitableHadron *target) c
   Pprojectile.transform(toCms);
   Ptarget.transform(toCms);
 
-  G4double Pt2;
-  G4double ProjMassT2, ProjMassT;
-  G4double TargMassT2, TargMassT;
-  G4double PZcms2, PZcms;
-  G4double PMinusNew, TPlusNew;
+  G4double PZcms2=(S*S+Mprojectile2*Mprojectile2+Mtarget2*Mtarget2-
+  		   2*S*Mprojectile2-2*S*Mtarget2-2*Mprojectile2*Mtarget2)/4./S;
 
-  G4double S=Psum.mag2();
-  G4double SqrtS=std::sqrt(S);
+  if (PZcms2 < 0) {return false;}   // It can be in an interaction with off-shell nuclear nucleon
 
-  if(SqrtS < 2200*MeV) {return false;}   // The model cannot work for pp-interactions
-  // at Plab < 1.3 GeV/c. Uzhi
+  G4double PZcms = std::sqrt(PZcms2);
 
-  PZcms2=(S*S+Mprojectile2*Mprojectile2+Mtarget2*Mtarget2-
-	  2*S*Mprojectile2-2*S*Mtarget2-2*Mprojectile2*Mtarget2)/4./S;
-  if(PZcms2 < 0)
-  {return false;}   // It can be in an interaction with off-shell nuclear nucleon
-
-  PZcms = std::sqrt(PZcms2);
-
-  if(PutOnMassShell)
+  if (PutOnMassShell)
   {
-    if(Pprojectile.z() > 0.)
+    if (Pprojectile.z() > 0.)
     {
       Pprojectile.setPz( PZcms);
       Ptarget.setPz(    -PZcms);
-    } else
+    }
+    else
     {
       Pprojectile.setPz(-PZcms);
       Ptarget.setPz(     PZcms);
     };
 
-    Pprojectile.setE(std::sqrt(Mprojectile2+
-			       Pprojectile.x()*Pprojectile.x()+
-			       Pprojectile.y()*Pprojectile.y()+
-			       PZcms2));
-    Ptarget.setE(std::sqrt(    Mtarget2    +
-			       Ptarget.x()*Ptarget.x()+
-			       Ptarget.y()*Ptarget.y()+
-			       PZcms2));
+    Pprojectile.setE(std::sqrt(Mprojectile2+sqr(Pprojectile.x())+sqr(Pprojectile.y())+PZcms2));
+    Ptarget.setE(    std::sqrt(    Mtarget2+sqr(    Ptarget.x())+sqr(    Ptarget.y())+PZcms2));
   }
 
   G4double maxPtSquare = PZcms2;
 
-  //G4cout << "Pprojectile aft boost : " << Pprojectile << G4endl;
-  //G4cout << "Ptarget aft boost : " << Ptarget << G4endl;
-  //	   G4cout << "cms aft boost : " << (Pprojectile+ Ptarget) << G4endl;
-  //	   G4cout << " Projectile Xplus / Xminus : " <<
-  //	   	     Pprojectile.plus() << " / " << Pprojectile.minus() << G4endl;
-  //	   G4cout << " Target Xplus / Xminus : " <<
-  //	   	     Ptarget.plus() << " / " << Ptarget.minus() << G4endl;
+  #ifdef debugDoubleDiffraction
+    G4cout << "Pprojectile after boost to CMS: " << Pprojectile <<" "<<Pprojectile.mag()<<G4endl;
+    G4cout << "Ptarget     after boost to CMS: " << Ptarget     <<" "<<Ptarget.mag()    <<G4endl;
+  #endif
+
+  G4int    PrPDGcode=projectile->GetDefinition()->GetPDGEncoding();
+  G4int    absPrPDGcode=std::abs(PrPDGcode);
+  G4double MinPrDiffMass(0.);
+  G4double AveragePt2(0.);
+
+  if (M0projectile <= projectile->GetDefinition()->GetPDGMass())
+  { // Normal projectile 
+    if( absPrPDGcode > 1000 )                         //------Projectile is baryon --------
+    {
+      MinPrDiffMass = 1.16;                       // GeV
+      AveragePt2 = 0.3;                           // GeV^2
+    }
+    else if( absPrPDGcode == 211 || PrPDGcode ==  111) //------Projectile is Pion -----------
+    {
+      MinPrDiffMass = 1.0;                       // GeV
+      AveragePt2 = 0.3;                          // GeV^2
+    }
+    else if( absPrPDGcode == 321 || absPrPDGcode == 130 || absPrPDGcode == 310) //-Projectile is Kaon-
+    {
+      MinPrDiffMass = 1.1;                        // GeV
+      AveragePt2 = 0.3;                           // GeV^2
+    }
+    else                                              //------Projectile is undefined, Nucleon assumed
+    {
+      MinPrDiffMass = 1.16;                       // GeV
+      AveragePt2 = 0.3;                           // GeV^2
+    }
+  }
+  else
+  { // Excited projectile
+    MinPrDiffMass = M0projectile + 220.0*MeV;
+    AveragePt2 = 0.3; 
+  }
+
+  MinPrDiffMass = MinPrDiffMass * GeV;
+  AveragePt2 = AveragePt2 * GeV*GeV;
+  //---------------------------------------------
+  G4double MinTrDiffMass = 1.16*GeV;
+
+  if (SqrtS < MinPrDiffMass + MinTrDiffMass) {return false;}   // The model cannot work at low energy
+
+  G4double MinPrDiffMass2 = MinPrDiffMass * MinPrDiffMass;
+  G4double MinTrDiffMass2 = MinTrDiffMass * MinTrDiffMass;
+
+  G4double Pt2;
+  G4double ProjMassT2, ProjMassT;
+  G4double TargMassT2, TargMassT;
+  G4double PMinusNew, TPlusNew;
 
   G4LorentzVector Qmomentum;
   G4double Qminus, Qplus;
 
   G4int whilecount=0;
   do {
-    //  Generate pt
-
     if (whilecount++ >= 500 && (whilecount%100)==0)
-      //G4cout << "G4QGSDiffractiveExcitation::ExciteParticipants possibly looping"
-      //       << ", loop count/ maxPtSquare : "
-      //       << whilecount << " / " << maxPtSquare << G4endl;
-
-    if (whilecount > 1000 )
-    {
-      Qmomentum=G4LorentzVector(0.,0.,0.,0.);
-      return false; 	  //  Ignore this interaction
-    }
+      if (whilecount > 1000 ) {
+	Qmomentum=G4LorentzVector(0.,0.,0.,0.);
+	return false; 	  //  Ignore this interaction
+      }
 
+    //  Generate pt
     Qmomentum=G4LorentzVector(GaussianPt(AveragePt2,maxPtSquare),0);
 
-    //G4cout << "generated Pt " << Qmomentum << G4endl;
-    //G4cout << "Pprojectile with pt : " << Pprojectile+Qmomentum << G4endl;
-    //G4cout << "Ptarget with pt : " << Ptarget-Qmomentum << G4endl;
-
-    //  Momentum transfer
-    /*
-    G4double Xmin = minmass / ( Pprojectile.e() + Ptarget.e() );
-    G4double Xmax=1.;
-    G4double Xplus =ChooseX(Xmin,Xmax);
-    G4double Xminus=ChooseX(Xmin,Xmax);
-
-    //G4cout << " X-plus  " << Xplus << G4endl;
-    //G4cout << " X-minus " << Xminus << G4endl;
-
-    G4double pt2=G4ThreeVector(Qmomentum.vect()).mag2();
-    G4double Qplus =-1 * pt2 / Xminus/Ptarget.minus();
-    G4double Qminus=     pt2 / Xplus /Pprojectile.plus();
-    */
-
     Pt2=G4ThreeVector(Qmomentum.vect()).mag2();
-    ProjMassT2=Mprojectile2+Pt2;
+    ProjMassT2=MinPrDiffMass2+Pt2;
     ProjMassT =std::sqrt(ProjMassT2);
 
-    TargMassT2=Mtarget2+Pt2;
+    TargMassT2=MinTrDiffMass2+Pt2;
     TargMassT =std::sqrt(TargMassT2);
 
-    PZcms2=(S*S+ProjMassT2*ProjMassT2+
-	    TargMassT2*TargMassT2-
-	    2.*S*ProjMassT2-2.*S*TargMassT2-
-	    2.*ProjMassT2*TargMassT2)/4./S;
-    if(PZcms2 < 0 ) {PZcms2=0;};
+    if (SqrtS < ProjMassT + TargMassT) continue;
+ 
+    PZcms2=(S*S+ProjMassT2*ProjMassT2+TargMassT2*TargMassT2-
+	    2.*S*ProjMassT2-2.*S*TargMassT2-2.*ProjMassT2*TargMassT2)/4./S;
+    if (PZcms2 < 0 ) {PZcms2=0;};
     PZcms =std::sqrt(PZcms2);
 
     G4double PMinusMin=std::sqrt(ProjMassT2+PZcms2)-PZcms;
@@ -279,71 +262,22 @@ ExciteParticipants(G4VSplitableHadron *projectile, G4VSplitableHadron *target) c
     Qmomentum.setPz( (Qplus-Qminus)/2 );
     Qmomentum.setE(  (Qplus+Qminus)/2 );
 
-    //G4cout << "Qplus / Qminus " << Qplus << " / " << Qminus<<G4endl;
-    //G4cout << "pt2" << pt2 << G4endl;
-    //G4cout << "Qmomentum " << Qmomentum << G4endl;
-    //G4cout << " Masses (P/T) : " << (Pprojectile+Qmomentum).mag() <<
-    //	   		   " / " << (Ptarget-Qmomentum).mag() << G4endl;
-  /*
-  } while ( (Pprojectile+Qmomentum).mag2() <= Mprojectile2 ||
-	   	     (Ptarget-Qmomentum).mag2()     <= Mtarget2 );
-  */
-  } while (  /* Loop checking, 26.10.2015, A.Ribon */
-            ( (Pprojectile+Qmomentum).mag2() <  Mprojectile2       ||        // No without excitation
-	      (Ptarget    -Qmomentum).mag2() <  Mtarget2             ) ||  
-	      ( (Pprojectile+Qmomentum).mag2()  <  ProjectileDiffCut2 &&     // No double Diffraction
-	      (Ptarget    -Qmomentum).mag2()  <  NuclearNucleonDiffCut2) ); 
-
-  if((Ptarget-Qmomentum).mag2() < NuclearNucleonDiffCut2)         // Uzhi Projectile diffraction
-  {
-    G4double TMinusNew=SqrtS-PMinusNew;
-    Qminus=Ptarget.minus()-TMinusNew;
-    TPlusNew=TargMassT2/TMinusNew;
-    Qplus=Ptarget.plus()-TPlusNew;
-
-    Qmomentum.setPz( (Qplus-Qminus)/2 );
-    Qmomentum.setE(  (Qplus+Qminus)/2 );
-  }
-  else if((Pprojectile+Qmomentum).mag2() <  ProjectileDiffCut2)   // Uzhi Target diffraction
-  {
-    G4double PPlusNew=SqrtS-TPlusNew;
-    Qplus=PPlusNew-Pprojectile.plus();
-    PMinusNew=ProjMassT2/PPlusNew;
-    Qminus=PMinusNew-Pprojectile.minus();
-
-    Qmomentum.setPz( (Qplus-Qminus)/2 );
-    Qmomentum.setE(  (Qplus+Qminus)/2 );
-  };
+  } while ( (Pprojectile+Qmomentum).mag2() <  MinPrDiffMass2 ||
+	    (Ptarget    -Qmomentum).mag2() <  MinTrDiffMass2   ); 
 
   Pprojectile += Qmomentum;
   Ptarget     -= Qmomentum;
 
-  // Vova
-
-  /*
-  Pprojectile.setPz(0.);
-  Pprojectile.setE(SqrtS-M0target);
-  Ptarget.setPz(0.);
-  Ptarget.setE(M0target);
-  */
-
-  //G4cout << "Pprojectile with Q : " << Pprojectile << G4endl;
-  //G4cout << "Ptarget with Q : " << Ptarget << G4endl;
-  //G4cout << "Projectile back: " << toLab * Pprojectile << G4endl;
-  //G4cout << "Target back: " << toLab * Ptarget << G4endl;
-
   // Transform back and update SplitableHadron Participant.
   Pprojectile.transform(toLab);
   Ptarget.transform(toLab);
 
-  //G4cout << "Pprojectile with Q M: " << Pprojectile<<" "<<  Pprojectile.mag() << G4endl;
-  //G4cout << "Ptarget     with Q M: " << Ptarget    <<" "<<  Ptarget.mag()     << G4endl;
-  //G4cout << "Target	 mass  " <<  Ptarget.mag() << G4endl;
+  #ifdef debugDoubleDiffraction
+    G4cout << "Pprojectile after boost to Lab: " << Pprojectile <<" "<<Pprojectile.mag()<<G4endl;
+    G4cout << "Ptarget     after boost to Lab: " << Ptarget     <<" "<<Ptarget.mag()    <<G4endl;
+  #endif
 
   target->Set4Momentum(Ptarget);
-
-  //G4cout << "Projectile mass  " <<  Pprojectile.mag() << G4endl;
-
   projectile->Set4Momentum(Pprojectile);
 
   return true;
@@ -355,18 +289,19 @@ String(G4VSplitableHadron * hadron, G4bool isProjectile) const
 {
   hadron->SplitUp();
   G4Parton *start= hadron->GetNextParton();
-  if ( start==NULL) { 
-    G4cout << " G4FTFModel::String() Error:No start parton found"<< G4endl;
+  if ( start==NULL) 
+  { G4cout << " G4QGSDiffractiveExcitation::String() Error:No start parton found"<< G4endl;
     return NULL;
   }
   G4Parton *end  = hadron->GetNextParton();
-  if ( end==NULL) { 
-    G4cout << " G4FTFModel::String() Error:No end parton found"<< G4endl;
+  if ( end==NULL) 
+  { G4cout << " G4QGSDiffractiveExcitation::String() Error:No end parton found"<< G4endl;
     return NULL;
   }
 
   G4ExcitedString * string;
-  if ( isProjectile )  {
+  if ( isProjectile ) 
+  {
     string= new G4ExcitedString(end,start, +1);
   } else {
     string= new G4ExcitedString(start,end, -1);
@@ -375,14 +310,10 @@ String(G4VSplitableHadron * hadron, G4bool isProjectile) const
   string->SetPosition(hadron->GetPosition());
 
   // momenta of string ends
-  G4double ptSquared= hadron->Get4Momentum().perp2();
-  G4double transverseMassSquared= hadron->Get4Momentum().plus()
-				* hadron->Get4Momentum().minus();
 
-  G4double maxAvailMomentumSquared=
-    sqr( std::sqrt(transverseMassSquared) - std::sqrt(ptSquared) );
+  G4double maxAvailMomentumSquared=sqr(hadron->Get4Momentum().mag()/2.);
 
-  G4double widthOfPtSquare = 0.25;          // Uzhi <Pt^2>=0.25 ???
+  G4double widthOfPtSquare = 0.5*sqr(GeV);
   G4ThreeVector pt=GaussianPt(widthOfPtSquare,maxAvailMomentumSquared);
 
   G4LorentzVector Pstart(G4LorentzVector(pt,0.));
@@ -414,12 +345,12 @@ String(G4VSplitableHadron * hadron, G4bool isProjectile) const
   start->Set4Momentum(Pstart);
   end->Set4Momentum(Pend);
 
-  #ifdef G4_FTFDEBUG
-  G4cout << " generated string flavors          " << start->GetPDGcode() << " / " << end->GetPDGcode() << G4endl;
-  G4cout << " generated string momenta:   quark " << start->Get4Momentum() << "mass : " <<start->Get4Momentum().mag()<< G4endl;
-  G4cout << " generated string momenta: Diquark " << end ->Get4Momentum() << "mass : " <<end->Get4Momentum().mag()<< G4endl;
-  G4cout << " sum of ends                       " << Pstart+Pend << G4endl;
-  G4cout << " Original                          " << hadron->Get4Momentum() << G4endl;
+  #ifdef debugQGSdiffExictation
+    G4cout << " generated string flavors          " << start->GetPDGcode()   << " / " << end->GetPDGcode() << G4endl;
+    G4cout << " generated string momenta:   quark " << start->Get4Momentum() << "mass : " <<start->Get4Momentum().mag()<< G4endl;
+    G4cout << " generated string momenta: Diquark " << end ->Get4Momentum()  << "mass : " <<end->Get4Momentum().mag()<< G4endl;
+    G4cout << " sum of ends                       " << Pstart+Pend << G4endl;
+    G4cout << " Original                          " << hadron->Get4Momentum() << G4endl;
   #endif
 
   return string;	
@@ -442,27 +373,15 @@ G4double G4QGSDiffractiveExcitation::ChooseP(G4double Pmin, G4double Pmax) const
   }
 
   G4double P;
-  /*
-  do {
-    x=Xmin + G4UniformRand() * range;
-  }  while ( Xmin/x < G4UniformRand() );
-  */
-
   P=Pmin * G4Pow::GetInstance()->powA(Pmax/Pmin,G4UniformRand());
-
   //debug-hpw	cout << "DiffractiveX "<<x<<G4endl;
   return P;
 }
 
+
 G4ThreeVector G4QGSDiffractiveExcitation::GaussianPt(G4double AveragePt2, G4double maxPtSquare) const
 {            //  @@ this method is used in FTFModel as well. Should go somewhere common!
-
   G4double Pt2;
-  /*
-  do {
-    pt2=widthSquare * G4Log( G4UniformRand() );
-  } while ( pt2 > maxPtSquare);
-  */
 
   Pt2 = -AveragePt2 * G4Log(1. + G4UniformRand() * (G4Exp(-maxPtSquare/AveragePt2)-1.));
 
@@ -472,4 +391,3 @@ G4ThreeVector G4QGSDiffractiveExcitation::GaussianPt(G4double AveragePt2, G4doub
 
   return G4ThreeVector (Pt*std::cos(phi), Pt*std::sin(phi), 0.);    
 }
-
