@@ -469,14 +469,14 @@ G4KineticTrack& G4KineticTrack::operator=(const G4KineticTrack& right)
 
 
 
-G4int G4KineticTrack::operator==(const G4KineticTrack& right) const
+G4bool G4KineticTrack::operator==(const G4KineticTrack& right) const
 {
  return (this == & right);
 }
 
 
 
-G4int G4KineticTrack::operator!=(const G4KineticTrack& right) const
+G4bool G4KineticTrack::operator!=(const G4KineticTrack& right) const
 {
  return (this != & right);
 }
@@ -726,7 +726,7 @@ G4KineticTrackVector* G4KineticTrack::Decay()
          delete theDynamicParticle;
         }
      delete theDecayProducts;
-     if(getenv("DecayEnergyBalanceCheck"))
+     if(std::getenv("DecayEnergyBalanceCheck"))
        std::cout << "DEBUGGING energy balance in cms and lab, charge baryon balance : "
        	         << momentumBalanceCMS << " " 
   	         <<energyMomentumBalance << " " 
