@@ -36,8 +36,6 @@
 // Class Description:
 //
 // Intermediate class for hadronic absorption at rest using FTF/Preco.
-// Physics lists should reference the concrete subclasses for:
-// anti_proton, anti_sigma+, and all anti-nuclei.
 //
 //---------------------------------------------------------------------------
 
@@ -99,8 +97,12 @@ G4HadronicAbsorptionFritiof::~G4HadronicAbsorptionFritiof() {
 G4bool G4HadronicAbsorptionFritiof::
 IsApplicable( const G4ParticleDefinition& particle ) {
   return ( ( 0 == pdefApplicable && 
-             ( &particle == G4AntiProton::Definition() ||
-	       &particle == G4AntiSigmaPlus::Definition() ||
+             ( &particle == G4AntiProton::Definition()     ||
+               &particle == G4AntiNeutron::Definition()    ||
+               &particle == G4AntiLambda::Definition()     ||
+	       &particle == G4AntiSigmaZero::Definition()  ||
+	       &particle == G4AntiSigmaPlus::Definition()  ||
+               &particle == G4AntiXiZero::Definition()     ||
                particle.GetBaryonNumber() < -1 ) )     // Anti-nuclei
 	   || ( &particle == pdefApplicable ) );
 }
@@ -109,8 +111,9 @@ IsApplicable( const G4ParticleDefinition& particle ) {
 // Documentation of purpose
 void G4HadronicAbsorptionFritiof::
 ProcessDescription( std::ostream& os ) const {
-  os << "Stopping and absorption of anti_protons, anti_sigma+, and \n"
-     << "all anti-nuclei using Fritiof (FTF) string model.\n"
+  os << "Stopping and absorption of anti_proton, anti_neutron, anti_lambda, \n"
+     << "anti_sigma0, anti_sigma+, anti_xi0 and all anti-nuclei \n"
+     << "using  Fritiof (FTF) string model.\n"
      << "Geant4 PreCompound model is used for nuclear de-excitation."
      << std::endl;
 }
