@@ -23,7 +23,6 @@
 // * acceptance of all terms of the Geant4 Software license.          *
 // ********************************************************************
 //
-// $Id: G4MuonicAtomDecay.cc 94351 2015-11-12 15:35:32Z gcosmo $
 //
 //---------------------------------------------------------------------
 //
@@ -257,6 +256,12 @@ G4VParticleChange* G4MuonicAtomDecay::DecayIt(const G4Track& aTrack,
       }
 #endif
       products = decaychannel->DecayIt(aParticle->GetMass());
+      if(!products) {
+	G4ExceptionDescription ed;
+	ed << "No products are generated for "
+           << aParticleDef->GetParticleName();
+	G4Exception("G4MuonicAtomDecay::DecayIt","DECAY003",FatalException,ed);
+      }
 #ifdef G4VERBOSE
       if (GetVerboseLevel()>1) {
 	decaychannel->SetVerboseLevel(temp);
@@ -384,7 +389,7 @@ G4VParticleChange* G4MuonicAtomDecay::DecayIt(const G4Track& aTrack,
         result = cmptr->ApplyYourself(theMuPro, nucleus); // muon and muonic atom nucleus
         ++reentryCount;
       }
-      catch(G4HadronicException aR) {
+      catch(G4HadronicException & aR) {
         G4ExceptionDescription ed;
         ed << "Call for " << cmptr->GetModelName() << G4endl;
         ed << "  Z= "
