@@ -237,7 +237,7 @@ G4Allocator<G4ReactionProduct>*& aRPAllocator()
       return 0.0;
     } else {
       a = ( tx*px + ty*py + tz*pz ) / a;
-      if( std::fabs(a) > 1.0 ) { a<0.0 ? a=-1.0 : a=1.0; }
+      if( std::abs(a) > 1.0 ) { a<0.0 ? a=-1.0 : a=1.0; }
       return std::acos( a );
     }
   }
