@@ -98,7 +98,8 @@ void G4UserWorkerThreadInitialization::SetupRNGEngine(const CLHEP::HepRandomEngi
        retRNG= new CLHEP::RanecuEngine;
     }
     if ( dynamic_cast<const CLHEP::Ranlux64Engine*>(aNewRNG) ) {
-       retRNG= new CLHEP::Ranlux64Engine;
+       const CLHEP::Ranlux64Engine* theRNG = dynamic_cast<const CLHEP::Ranlux64Engine*>(aNewRNG);
+       retRNG= new CLHEP::Ranlux64Engine(123,theRNG->getLuxury());
     }
     if ( dynamic_cast<const CLHEP::MTwistEngine*>(aNewRNG) ) {
        retRNG= new CLHEP::MTwistEngine;
@@ -107,7 +108,8 @@ void G4UserWorkerThreadInitialization::SetupRNGEngine(const CLHEP::HepRandomEngi
        retRNG= new CLHEP::DualRand;
     }
     if ( dynamic_cast<const CLHEP::RanluxEngine*>(aNewRNG) ) {
-       retRNG= new CLHEP::RanluxEngine;
+       const CLHEP::RanluxEngine* theRNG = dynamic_cast<const CLHEP::RanluxEngine*>(aNewRNG);
+       retRNG= new CLHEP::RanluxEngine(123,theRNG->getLuxury());
     }
     if ( dynamic_cast<const CLHEP::RanshiEngine*>(aNewRNG) ) {
        retRNG= new CLHEP::RanshiEngine;
@@ -115,11 +117,14 @@ void G4UserWorkerThreadInitialization::SetupRNGEngine(const CLHEP::HepRandomEngi
     
     if( retRNG != 0 ) {
        G4Random::setTheEngine( retRNG );
-    }else{
+    }
+    else
+    {
         // Does a new method, such as aNewRng->newEngine() exist to clone it ?
         G4ExceptionDescription msg;
         msg<< " Unknown type of RNG Engine - " << G4endl
-           << " Can cope only with HepJamesRandom, MixMaxRng, Ranecu, Ranlux64, MTwistEngine, DualRand, Ranlux or Ranshi."
+           << " Can cope only with HepJamesRandom, MixMaxRng, Ranecu, Ranlux64,"
+           << " MTwistEngine, DualRand, Ranlux or Ranshi."
            << G4endl
            << " Cannot clone this type of RNG engine, as required for this thread" << G4endl
            << " Aborting " << G4endl;
