@@ -74,10 +74,10 @@ void G4WorkerRunManagerKernel::SetupShadowProcess() const
           G4cout << "G4WorkerRunManagerKernel::SetupShadowProcess() for particle <"
                  << pd->GetParticleName() << ">" << G4endl;
           G4cout << " ProcessManager : " << pm << " ProcessManagerShadow : " << pmM << G4endl;
-          for(G4int iv1=0;iv1<procs.size();iv1++)
+          for(std::size_t iv1=0;iv1<procs.size();++iv1)
           { G4cout << "  " << iv1 << " - " << procs[iv1]->GetProcessName() << G4endl; }
           G4cout << "--------------------------------------------------------------" << G4endl;
-          for(G4int iv2=0;iv2<procsM.size();iv2++)
+          for(std::size_t iv2=0;iv2<procsM.size();++iv2)
           { G4cout << "  " << iv2 << " - " << procsM[iv2]->GetProcessName() << G4endl; }
           G4cout << "--------------------------------------------------------------" << G4endl;
           G4ExceptionDescription msg;
@@ -91,7 +91,7 @@ void G4WorkerRunManagerKernel::SetupShadowProcess() const
         //process from master. Note that we rely on
         //processes being in the correct order!
         // We could use some checking using process name or type
-        for ( G4int idx = 0 ; idx < procs.size() ; ++idx )
+        for ( std::size_t idx = 0 ; idx < procs.size() ; ++idx )
         {
             procs[idx]->SetMasterProcess(procsM[idx]);
         }
