@@ -24,7 +24,6 @@
 // ********************************************************************
 //
 //
-// $Id$
 //
 // ---------------------------------------------------------------
 //
@@ -44,7 +43,11 @@
 #include "G4AttCheck.hh"
 #endif
 
-G4ThreadLocal G4Allocator<G4TrajectoryPoint> *aTrajectoryPointAllocator = 0;
+G4Allocator<G4TrajectoryPoint>*& aTrajectoryPointAllocator()
+{
+    G4ThreadLocalStatic G4Allocator<G4TrajectoryPoint>* _instance = nullptr;
+    return _instance;
+}
 
 G4TrajectoryPoint::G4TrajectoryPoint()
 {
