@@ -113,6 +113,7 @@ G4bool G4OpenGLStoredQtViewer::CompareForKernelVisit(G4ViewParameters& lastVP)
   // modifiers (fTreeItemModels, etc.).
   if (
       (lastVP.GetDrawingStyle ()    != fVP.GetDrawingStyle ())    ||
+      (lastVP.GetNumberOfCloudPoints()  != fVP.GetNumberOfCloudPoints())  ||
       (lastVP.IsAuxEdgeVisible ()   != fVP.IsAuxEdgeVisible ())   ||
       (lastVP.IsCulling ()          != fVP.IsCulling ())          ||
       (lastVP.IsCullingInvisible () != fVP.IsCullingInvisible ()) ||
@@ -153,17 +154,15 @@ G4bool G4OpenGLStoredQtViewer::CompareForKernelVisit(G4ViewParameters& lastVP)
       (lastVP.GetVisibleDensity () != fVP.GetVisibleDensity ()))
     return true;
 
-  /**************************************************************
-   Section (DCUT) implemented locally.  No need to visit kernel if
-   section plane itself changes.
-   if (lastVP.IsSection () &&
-   (lastVP.GetSectionPlane () != fVP.GetSectionPlane ()))
-   return true;
-   ***************************************************************/
+//  /**************************************************************
+//   If section (DCUT) is implemented locally, comment this out.
+  if (lastVP.IsSection () &&
+      (lastVP.GetSectionPlane () != fVP.GetSectionPlane ()))
+    return true;
+//   ***************************************************************/
 
   /**************************************************************
-   Cutaways implemented locally.  No need to visit kernel if cutaway
-   planes themselves change.
+   If cutaways are implemented locally, comment this out.
    if (lastVP.IsCutaway ()) {
    if (lastVP.GetCutawayPlanes ().size () !=
    fVP.GetCutawayPlanes ().size ()) return true;
@@ -181,7 +180,7 @@ G4bool G4OpenGLStoredQtViewer::CompareForKernelVisit(G4ViewParameters& lastVP)
   if (lastVP.IsExplode () &&
       (lastVP.GetExplodeFactor () != fVP.GetExplodeFactor ()))
     return true;
-  
+
   return false;
 }
 
