@@ -203,7 +203,7 @@ G4OpenGLViewerMessenger::G4OpenGLViewerMessenger()
   fpCommandDisplayListLimit =
     new G4UIcmdWithAnInteger("/vis/ogl/set/displayListLimit", this);
   fpCommandDisplayListLimit->SetGuidance
-    ("Set/reset display list limit (to avoid memory exhaustion).");
+    ("Set/reset display list number of primitive limit (to avoid memory exhaustion).");
   fpCommandDisplayListLimit->SetParameterName("limit", omitable = true);
   fpCommandDisplayListLimit->SetDefaultValue(50000);
   fpCommandDisplayListLimit->SetRange("limit>=10000");
@@ -277,7 +277,7 @@ G4OpenGLViewerMessenger::G4OpenGLViewerMessenger()
     new G4UIcommand("/vis/ogl/set/printSize", this);
   fpCommandPrintSize->SetGuidance ("Set print size");
   fpCommandPrintSize->SetGuidance ("Tip : -1 will mean 'print size' = 'window size'");
-  fpCommandPrintSize->SetGuidance ("       Setting size greatter than your maximum graphic card capacity , will set the size to maximum  size.");
+  fpCommandPrintSize->SetGuidance ("       Setting size greater than your maximum graphic card capacity , will set the size to maximum  size.");
   G4UIparameter* parameterPrintSize;
   parameterPrintSize = new G4UIparameter ("width", 'd', omitable = false);
   parameterPrintSize->SetDefaultValue(-1);
