@@ -158,6 +158,7 @@ G4bool G4OpenInventorViewer::CompareForKernelVisit(G4ViewParameters& vp) {
 
   if (
       (vp.GetDrawingStyle ()    != fVP.GetDrawingStyle ())    ||
+      (vp.GetNumberOfCloudPoints()  != fVP.GetNumberOfCloudPoints())  ||
       (vp.IsAuxEdgeVisible ()   != fVP.IsAuxEdgeVisible ())   ||
       (vp.IsCulling ()          != fVP.IsCulling ())          ||
       (vp.IsCullingInvisible () != fVP.IsCullingInvisible ()) ||
@@ -667,6 +668,9 @@ void G4OpenInventorViewer::SetSolid() {
     break;
   case G4ViewParameters::hlhsr:
     break;
+  case G4ViewParameters::cloud:
+    vp.SetDrawingStyle(G4ViewParameters::hsr);
+    break;
   }
   SetViewParameters(vp);
   DrawDetector();
@@ -685,6 +689,9 @@ void G4OpenInventorViewer::SetWireFrame() {
   case G4ViewParameters::hlhsr:
     vp.SetDrawingStyle(G4ViewParameters::hlr);
     break;
+  case G4ViewParameters::cloud:
+    vp.SetDrawingStyle(G4ViewParameters::wireframe);
+    break;
   }
   SetViewParameters(vp);
   DrawDetector();
@@ -710,6 +717,9 @@ void G4OpenInventorViewer::SetReducedWireFrame(bool aValue) {
   case G4ViewParameters::hlhsr:
     vp.SetDrawingStyle(G4ViewParameters::hlr);
     break;
+  case G4ViewParameters::cloud:
+    vp.SetDrawingStyle(G4ViewParameters::wireframe);
+    break;
   }
   SetViewParameters(vp);
   NeedKernelVisit(); // Just in case it was alread in wire framw.
