@@ -89,7 +89,7 @@ void G4OpenInventorXtExtendedViewer::Initialise() {
   G4String wName = fName;
   
   Widget parent = (Widget)fInteractorManager->GetParentInteractor ();
-  G4cout << "DEBUG G4OpenInventorXtExtendedViewer: parent = " << parent << G4endl;
+  // G4cout << "DEBUG G4OpenInventorXtExtendedViewer: parent = " << parent << G4endl;
   int width = 600;
   int height = 600;
 
@@ -124,7 +124,7 @@ void G4OpenInventorXtExtendedViewer::Initialise() {
 			       SoXt::getDisplay(),
 			       args,3);
     
-    G4cout << "DEBUG CREATING THE VIEWER WITH CREATED SHELL = " << fShell << G4endl;
+    // G4cout << "DEBUG CREATING THE VIEWER WITH CREATED SHELL = " << fShell << G4endl;
     fViewer = new G4OpenInventorXtExaminerViewer(fShell, wName.c_str(), TRUE);
     fViewer->addEscapeCallback(EscapeFromKeyboardCbk, (void *)this);
      
@@ -199,7 +199,7 @@ void G4OpenInventorXtExtendedViewer::Initialise() {
   } else {
     char* str = fInteractorManager->GetCreationString();
     if(str!=0) wName = str;
-    G4cout << "DEBUG CREATING THE VIEWER WITH parent = " << parent << G4endl;
+    // G4cout << "DEBUG CREATING THE VIEWER WITH parent = " << parent << G4endl;
     fViewer = new G4OpenInventorXtExaminerViewer(parent, wName.c_str(), TRUE);
   }
 
@@ -279,7 +279,7 @@ Widget G4OpenInventorXtExtendedViewer::AddMenu(
   // Cascade button :
   Arg args[2];
   XmString cps = 
-    XmStringLtoRCreate((char*)aLabel.c_str(),XmSTRING_DEFAULT_CHARSET);
+    XmStringLtoRCreate((char*)aLabel.c_str(),(char*)XmSTRING_DEFAULT_CHARSET);
   XtSetArg (args[0],XmNlabelString,cps);
   XtSetArg (args[1],XmNsubMenuId,menu);
   Widget widget = XmCreateCascadeButton(aMenuBar,(char*)aName.c_str(),args,2);
@@ -324,12 +324,28 @@ void G4OpenInventorXtExtendedViewer::EscapeFromKeyboardCbk(void* o) {
 void G4OpenInventorXtExtendedViewer::PostScriptCbk(
   Widget,XtPointer aData,XtPointer) {
   G4OpenInventorXtExtendedViewer* This = (G4OpenInventorXtExtendedViewer*)aData;
+  // FWJ Workaround: avoids empty 2nd page in file
+  SbBool superimpState =
+     This->fViewer->getSuperimpositionEnabled(This->fViewer->superimposition);
+  This->fViewer->setSuperimpositionEnabled(This->fViewer->superimposition,
+                                           FALSE);
   This->WritePostScript();
+  if (superimpState)
+     This->fViewer->setSuperimpositionEnabled(This->fViewer->superimposition,
+                                              TRUE);
 }
 void G4OpenInventorXtExtendedViewer::PDFCbk(
   Widget,XtPointer aData,XtPointer) {
   G4OpenInventorXtExtendedViewer* This = (G4OpenInventorXtExtendedViewer*)aData;
+  // FWJ Workaround: avoids empty 2nd page in file
+  SbBool superimpState =
+     This->fViewer->getSuperimpositionEnabled(This->fViewer->superimposition);
+  This->fViewer->setSuperimpositionEnabled(This->fViewer->superimposition,
+                                           FALSE);
   This->WritePDF();
+  if (superimpState)
+     This->fViewer->setSuperimpositionEnabled(This->fViewer->superimposition,
+                                              TRUE);
 }
 
 void G4OpenInventorXtExtendedViewer::PixmapPostScriptCbk(
