@@ -42,8 +42,6 @@
 #include <iomanip>
 
 #include "globals.hh"
-#include "G4PhysicalConstants.hh"
-#include "G4SystemOfUnits.hh"
 #include "G4VisManager.hh"
 
 #include "G4GMocrenFile.hh"
@@ -90,6 +88,9 @@
 #include "G4ScoringManager.hh"
 #include "G4ScoringBox.hh"
 
+#include "G4PhysicalConstants.hh"
+#include "G4SystemOfUnits.hh"
+
 //----- constants
 const char  GDD_FILE_HEADER      [] = "g4_";
 const char  DEFAULT_GDD_FILE_NAME[] = "g4_00.gdd";
@@ -155,7 +156,7 @@ G4GMocrenFileSceneHandler::G4GMocrenFileSceneHandler(G4GMocrenFile& system,
   // maximum number of g4.gdd files in the dest directory
   kMaxFileNum = FR_MAX_FILE_NUM ; // initialization
   if ( std::getenv( "G4GMocrenFile_MAX_FILE_NUM" ) != NULL ) {	
-    char * pcFileNum = getenv("G4GMocrenFile_MAX_FILE_NUM");
+    char * pcFileNum = std::getenv("G4GMocrenFile_MAX_FILE_NUM");
     char c10FileNum[10];
     std::strncpy(c10FileNum, pcFileNum, 9);
     c10FileNum[9] = '\0';
