@@ -84,18 +84,32 @@ void G4VisCommandDrawTree::SetNewValue(G4UIcommand*, G4String newValue) {
   G4Scene* keepScene = fpVisManager->GetCurrentScene();
   G4VSceneHandler* keepSceneHandler = fpVisManager->GetCurrentSceneHandler();
   G4VViewer* keepViewer = fpVisManager->GetCurrentViewer();
+  G4VisManager::Verbosity keepVisVerbosity = fpVisManager->GetVerbosity();
 
   G4UImanager* UImanager = G4UImanager::GetUIpointer();
-  G4int keepVerbose = UImanager->GetVerboseLevel();
+  G4int keepUIVerbose = UImanager->GetVerboseLevel();
   G4int newVerbose(0);
-  if (keepVerbose >= 2 ||
+  if (keepUIVerbose >= 2 ||
       fpVisManager->GetVerbosity() >= G4VisManager::confirmations)
     newVerbose = 2;
   UImanager->SetVerboseLevel(newVerbose);
+
+  G4bool keepAbleness = fpVisManager->GetConcreteInstance()? true: false;
+
   UImanager->ApplyCommand(G4String("/vis/open " + system));
   if (fErrorCode == 0) {
+    if (!keepAbleness) {  // Enable temporarily
+      fpVisManager->SetVerboseLevel("Quiet");
+      UImanager->ApplyCommand("/vis/enable");
+      fpVisManager->SetVerboseLevel(keepVisVerbosity);
+    }
     UImanager->ApplyCommand(G4String("/vis/drawVolume " + pvname));
     UImanager->ApplyCommand("/vis/viewer/flush");
+    if (!keepAbleness) {  // Disable again
+      fpVisManager->SetVerboseLevel("Quiet");
+      UImanager->ApplyCommand("/vis/disable");
+      fpVisManager->SetVerboseLevel(keepVisVerbosity);
+    }
     if (keepViewer) {
       if (fpVisManager->GetVerbosity() >= G4VisManager::warnings) {
         G4cout << "Reverting to " << keepViewer->GetName() << G4endl;
@@ -106,7 +120,7 @@ void G4VisCommandDrawTree::SetNewValue(G4UIcommand*, G4String newValue) {
       fpVisManager->SetCurrentViewer(keepViewer);
     }
   }
-  UImanager->SetVerboseLevel(keepVerbose);
+  UImanager->SetVerboseLevel(keepUIVerbose);
 }
 
 ////////////// /vis/drawView ///////////////////////////////////////
@@ -212,17 +226,9 @@ G4VisCommandDrawLogicalVolume::G4VisCommandDrawLogicalVolume() {
   const G4UIcommandTree* tree = G4UImanager::GetUIpointer()->GetTree();
   const G4UIcommand* addLogVolCmd = tree->FindPath("/vis/scene/add/logicalVolume");
   // Pick up guidance from /vis/scene/add/logicalVolume
-  G4int nGuideEntries = addLogVolCmd->GetGuidanceEntries();
-  for (G4int i = 0; i < nGuideEntries; ++i) {
-    const G4String& guidance = addLogVolCmd->GetGuidanceLine(i);
-    fpCommand->SetGuidance(guidance);
-  }
+  CopyGuidanceFrom(addLogVolCmd,fpCommand);
   // Pick up parameters from /vis/scene/add/logicalVolume
-  G4int nParEntries = addLogVolCmd->GetParameterEntries();
-  for (G4int i = 0; i < nParEntries; ++i) {
-    G4UIparameter* parameter = new G4UIparameter(*(addLogVolCmd->GetParameter(i)));
-    fpCommand->SetParameter(parameter);
-  }
+  CopyParametersFrom(addLogVolCmd,fpCommand);
 }
 
 G4VisCommandDrawLogicalVolume::~G4VisCommandDrawLogicalVolume() {
@@ -245,7 +251,8 @@ void G4VisCommandDrawLogicalVolume::SetNewValue(G4UIcommand*, G4String newValue)
   UImanager->ApplyCommand(G4String("/vis/scene/add/logicalVolume " + newValue));
   UImanager->ApplyCommand("/vis/sceneHandler/attach");
   G4ViewParameters::DrawingStyle keepDrawingStyle = currentViewParams.GetDrawingStyle();
-  if(keepDrawingStyle != G4ViewParameters::wireframe) UImanager->ApplyCommand("/vis/viewer/set/style wireframe");
+  if(keepDrawingStyle != G4ViewParameters::wireframe)
+    UImanager->ApplyCommand("/vis/viewer/set/style wireframe");
   G4bool keepMarkerNotHidden = currentViewParams.IsMarkerNotHidden();
   if (!keepMarkerNotHidden) UImanager->ApplyCommand("/vis/viewer/set/hiddenMarker false");
   if (keepAutoRefresh) UImanager->ApplyCommand("/vis/viewer/set/autoRefresh true");
@@ -264,11 +271,12 @@ void G4VisCommandDrawLogicalVolume::SetNewValue(G4UIcommand*, G4String newValue)
           style = "surface"; edge = "false"; break;
         case G4ViewParameters::hlhsr:
           style = "surface"; edge = "true"; break;
+        case G4ViewParameters::cloud:
+          style = "cloud"; edge = ""; break;
       }
-      G4cout
-      << "\n  /vis/viewer/set/style " + style
-      << "\n  /vis/viewer/set/hiddenEdge " + edge
-      << G4endl;
+      G4cout << "\n  /vis/viewer/set/style " + style;
+      if (!edge.empty()) G4cout << "\n  /vis/viewer/set/hiddenEdge " + edge;
+      G4cout << G4endl;
     }
     if (keepMarkerNotHidden != currentViewParams.IsMarkerNotHidden()) {
       G4cout
@@ -297,17 +305,9 @@ G4VisCommandDrawVolume::G4VisCommandDrawVolume() {
   const G4UIcommandTree* tree = G4UImanager::GetUIpointer()->GetTree();
   const G4UIcommand* addVolCmd = tree->FindPath("/vis/scene/add/volume");
   // Pick up guidance from /vis/scene/add/volume
-  G4int nGuideEntries = addVolCmd->GetGuidanceEntries();
-  for (G4int i = 0; i < nGuideEntries; ++i) {
-    const G4String& guidance = addVolCmd->GetGuidanceLine(i);
-    fpCommand->SetGuidance(guidance);
-  }
+  CopyGuidanceFrom(addVolCmd,fpCommand);
   // Pick up parameters from /vis/scene/add/volume
-  G4int nParEntries = addVolCmd->GetParameterEntries();
-  for (G4int i = 0; i < nParEntries; ++i) {
-    G4UIparameter* parameter = new G4UIparameter(*(addVolCmd->GetParameter(i)));
-    fpCommand->SetParameter(parameter);
-  }
+  CopyParametersFrom(addVolCmd,fpCommand);
 }
 
 G4VisCommandDrawVolume::~G4VisCommandDrawVolume() {
