@@ -40,7 +40,7 @@
 #include "G4IntersectionSolid.hh"
 #include "G4Material.hh"
 #include "G4VisAttributes.hh"
-#include "G4BoundingSphereScene.hh"
+#include "G4BoundingExtentScene.hh"
 #include "G4PhysicalVolumeSearchScene.hh"
 #include "G4TransportationManager.hh"
 #include "G4Polyhedron.hh"
@@ -54,6 +54,10 @@
 #include <sstream>
 #include <iomanip>
 
+namespace {
+  G4int volumeCount = 0;
+}
+
 G4PhysicalVolumeModel::G4PhysicalVolumeModel
 (G4VPhysicalVolume*            pVPV
  , G4int                       requestedDepth
@@ -63,7 +67,7 @@ G4PhysicalVolumeModel::G4PhysicalVolumeModel
  , const std::vector<G4PhysicalVolumeNodeID>& baseFullPVPath)
 : G4VModel           (modelTransformation,pMP)
 , fpTopPV            (pVPV)
-, fTopPVCopyNo       (0)
+, fTopPVCopyNo       (pVPV? pVPV->GetCopyNo(): 0)
 , fRequestedDepth    (requestedDepth)
 , fUseFullExtent     (useFullExtent)
 , fCurrentDepth      (0)
@@ -126,14 +130,26 @@ G4ModelingParameters::PVNameCopyNoPath G4PhysicalVolumeModel::GetPVNameCopyNoPat
 
 void G4PhysicalVolumeModel::CalculateExtent ()
 {
+  // To handle paramaterisations, set copy number and compute dimensions
+  // to get extent right
+  G4VPVParameterisation* pP = fpTopPV -> GetParameterisation ();
+  if (pP) {
+    fpTopPV -> SetCopyNo (fTopPVCopyNo);
+    G4VSolid* solid = pP -> ComputeSolid (fTopPVCopyNo, fpTopPV);
+    solid -> ComputeDimensions (pP, fTopPVCopyNo, fpTopPV);
+  }
   if (fUseFullExtent) {
     fExtent = fpTopPV -> GetLogicalVolume () -> GetSolid () -> GetExtent ();
-  }
-  else {
-    G4BoundingSphereScene bsScene(this);
+  } else {
+    // Calculate extent of *drawn* volumes, i.e., ignoring culled, e.g.,
+    // invisible volumes, by traversing the whole geometry hierarchy below
+    // this physical volume.
+    G4BoundingExtentScene beScene(this);
     const G4int tempRequestedDepth = fRequestedDepth;
-    fRequestedDepth = -1;  // Always search to all depths to define extent.
+    const G4Transform3D tempTransform = fTransform;
     const G4ModelingParameters* tempMP = fpMP;
+    fRequestedDepth = -1;  // Always search to all depths to define extent.
+    fTransform = G4Transform3D();  // Extent is in local cooridinates
     G4ModelingParameters mParams
       (0,      // No default vis attributes needed.
        G4ModelingParameters::wf,  // wireframe (not relevant for this).
@@ -144,23 +160,16 @@ void G4PhysicalVolumeModel::CalculateExtent ()
        true,   // Cull daughters of opaque mothers.
        24);    // No of sides (not relevant for this operation).
     fpMP = &mParams;
-    DescribeYourselfTo (bsScene);
-    G4double radius = bsScene.GetRadius();
-    if (radius < 0.) {  // Nothing in the scene.
-      fExtent = fpTopPV -> GetLogicalVolume () -> GetSolid () -> GetExtent ();
-    } else {
-      // Transform back to coordinates relative to the top
-      // transformation, which is in G4VModel::fTransform.  This makes
-      // it conform to all models, which are defined by a
-      // transformation and an extent relative to that
-      // transformation...
-      G4Point3D centre = bsScene.GetCentre();
-      centre.transform(fTransform.inverse());
-      fExtent = G4VisExtent(centre, radius);
-    }
+    DescribeYourselfTo (beScene);
+    fExtent = beScene.GetBoundingExtent();
     fpMP = tempMP;
+    fTransform = tempTransform;
     fRequestedDepth = tempRequestedDepth;
   }
+  G4double radius = fExtent.GetExtentRadius();
+  if (radius < 0.) {  // Nothing in the scene - revert to top extent
+    fExtent = fpTopPV -> GetLogicalVolume () -> GetSolid () -> GetExtent ();
+  }
 }
 
 void G4PhysicalVolumeModel::DescribeYourselfTo
@@ -176,12 +185,19 @@ void G4PhysicalVolumeModel::DescribeYourselfTo
 
   G4Transform3D startingTransformation = fTransform;
 
+  volumeCount = 0;
+
   VisitGeometryAndGetVisReps
     (fpTopPV,
      fRequestedDepth,
      startingTransformation,
      sceneHandler);
 
+//  G4cout
+//  << "G4PhysicalVolumeModel::DescribeYourselfTo: volume count: "
+//  << volumeCount
+//  << G4endl;
+
   // Reset or clear data...
   fCurrentDepth     = 0;
   fpCurrentPV       = fpTopPV;
@@ -245,10 +261,15 @@ void G4PhysicalVolumeModel::VisitGeometryAndGetVisReps
     G4double offset;
     G4bool consuming;
     pVPV -> GetReplicationData (axis, nReplicas, width,  offset, consuming);
-    if (fCurrentDepth == 0) nReplicas = 1;  // Just draw first
+    G4int nBegin = 0;
+    G4int nEnd = nReplicas;
+    if (fCurrentDepth == 0) { // i.e., top volume
+      nBegin = fTopPVCopyNo;  // Describe only one volume, namely the one
+      nEnd = nBegin + 1;      // specified by the given copy number.
+    }
     G4VPVParameterisation* pP = pVPV -> GetParameterisation ();
     if (pP) {  // Parametrised volume.
-      for (int n = 0; n < nReplicas; n++) {
+      for (int n = nBegin; n < nEnd; n++) {
 	pSol = pP -> ComputeSolid (n, pVPV);
 	pP -> ComputeTransformation (n, pVPV);
 	pSol -> ComputeDimensions (pP, n, pVPV);
@@ -295,7 +316,7 @@ void G4PhysicalVolumeModel::VisitGeometryAndGetVisReps
 	originalRMax = ((G4Tubs*)pSol)->GetOuterRadius();
       }
       G4bool visualisable = true;
-      for (int n = 0; n < nReplicas; n++) {
+      for (int n = nBegin; n < nEnd; n++) {
 	G4ThreeVector translation;  // Identity.
 	G4RotationMatrix rotation;  // Identity - life enough for visualizing.
 	G4RotationMatrix* pRotation = 0;
@@ -464,7 +485,7 @@ void G4PhysicalVolumeModel::DescribeAndDescend
           // Initialise it with the current vis atts and reset the pointer.
           modifiedVisAtts = *pVisAttribs;
           pVisAttribs = &modifiedVisAtts;
-                    const G4VisAttributes& transVisAtts = vam.GetVisAttributes();
+          const G4VisAttributes& transVisAtts = vam.GetVisAttributes();
           switch (vam.GetVisAttributesSignifier()) {
             case G4ModelingParameters::VASVisibility:
               modifiedVisAtts.SetVisibility(transVisAtts.IsVisible());
@@ -498,6 +519,18 @@ void G4PhysicalVolumeModel::DescribeAndDescend
                 }
               }
               break;
+            case G4ModelingParameters::VASForceCloud:
+              if (transVisAtts.IsForceDrawingStyle()) {
+                if (transVisAtts.GetForcedDrawingStyle() ==
+                    G4VisAttributes::cloud) {
+                  modifiedVisAtts.SetForceCloud(true);
+                }
+              }
+              break;
+            case G4ModelingParameters::VASForceNumberOfCloudPoints:
+              modifiedVisAtts.SetForceNumberOfCloudPoints
+              (transVisAtts.GetForcedNumberOfCloudPoints());
+              break;
             case G4ModelingParameters::VASForceAuxEdgeVisible:
               if (transVisAtts.IsForceAuxEdgeVisible()) {
                 modifiedVisAtts.SetForceAuxEdgeVisible
@@ -565,6 +598,7 @@ void G4PhysicalVolumeModel::DescribeAndDescend
       theNewAT = centering * newTranslation * oldRotation * oldScale;
     }
 
+    volumeCount++;
     DescribeSolid (theNewAT, pSol, pVisAttribs, sceneHandler);
 
   }
@@ -653,14 +687,14 @@ void G4PhysicalVolumeModel::DescribeSolid
  const G4VisAttributes* pVisAttribs,
  G4VGraphicsScene& sceneHandler)
 {
-  sceneHandler.PreAddSolid (theAT, *pVisAttribs);
-
-  G4VSolid* pSectionSolid = fpMP->GetSectionSolid();
-  G4VSolid* pCutawaySolid = fpMP->GetCutawaySolid();
+  G4DisplacedSolid* pSectionSolid = fpMP->GetSectionSolid();
+  G4DisplacedSolid* pCutawaySolid = fpMP->GetCutawaySolid();
 
   if (!fpClippingSolid && !pSectionSolid && !pCutawaySolid) {
 
+    sceneHandler.PreAddSolid (theAT, *pVisAttribs);
     pSol -> DescribeYourselfTo (sceneHandler);  // Standard treatment.
+    sceneHandler.PostAddSolid ();
 
   } else {
 
@@ -672,10 +706,10 @@ void G4PhysicalVolumeModel::DescribeSolid
 	(pVisAttribs->GetForcedLineSegmentsPerCircle());
     else
       G4Polyhedron::SetNumberOfRotationSteps(fpMP->GetNoOfSides());
-    const G4Polyhedron* pOriginal = pSol->GetPolyhedron();
+    const G4Polyhedron* pOriginalPolyhedron = pSol->GetPolyhedron();
     G4Polyhedron::ResetNumberOfRotationSteps();
 
-    if (!pOriginal) {
+    if (!pOriginalPolyhedron) {
 
       if (fpMP->IsWarning())
 	G4cout <<
@@ -687,57 +721,66 @@ void G4PhysicalVolumeModel::DescribeSolid
 
     } else {
 
-      G4Polyhedron resultant(*pOriginal);
-      G4VisAttributes resultantVisAttribs(*pVisAttribs);
-      G4VSolid* resultantSolid = 0;
+      G4VSolid* pResultantSolid = 0;
 
       if (fpClippingSolid) {
 	switch (fClippingMode) {
 	default:
 	case subtraction:
-	  resultantSolid = new G4SubtractionSolid
-	    ("resultant_solid", pSol, fpClippingSolid, theAT.inverse());
+	  pResultantSolid = new G4SubtractionSolid
+	    ("subtracted_clipped_solid", pSol, fpClippingSolid, theAT.inverse());
 	  break;
 	case intersection:
-	  resultantSolid = new G4IntersectionSolid
-	    ("resultant_solid", pSol, fpClippingSolid, theAT.inverse());
+	  pResultantSolid = new G4IntersectionSolid
+	    ("intersected_clipped_solid", pSol, fpClippingSolid, theAT.inverse());
 	  break;
 	}
       }
 
       if (pSectionSolid) {
-	resultantSolid = new G4IntersectionSolid
+	pResultantSolid = new G4IntersectionSolid
 	  ("sectioned_solid", pSol, pSectionSolid, theAT.inverse());
       }
 
       if (pCutawaySolid) {
-	resultantSolid = new G4SubtractionSolid
+        // Follow above...
+	pResultantSolid = new G4SubtractionSolid
 	  ("cutaway_solid", pSol, pCutawaySolid, theAT.inverse());
       }
 
-      G4Polyhedron* tmpResultant = resultantSolid->GetPolyhedron();
-      if (tmpResultant) resultant = *tmpResultant;
-      else {
-	if (fpMP->IsWarning())
-	  G4cout <<
-	    "WARNING: G4PhysicalVolumeModel::DescribeSolid: resultant polyhedron for"
-	    "\n  solid \"" << pSol->GetName() <<
-	    "\" not defined due to error during Boolean processing."
-	    "\n  Original will be drawn in red."
-		 << G4endl;
-	resultantVisAttribs.SetColour(G4Colour::Red());
+      const G4Polyhedron* pResultantPolyhedron = pResultantSolid->GetPolyhedron();
+      if (!pResultantPolyhedron) {
+        if (fpMP->IsWarning())
+          G4cout <<
+          "WARNING: G4PhysicalVolumeModel::DescribeSolid: resultant polyhedron for"
+          "\n  solid \"" << pSol->GetName() <<
+          "\" not defined due to error during Boolean processing."
+          << G4endl;
+      } else {
+        // It seems that if the sectioning solid does not intersect the
+        // original solid the Boolean Processor returns the original
+        // polyhedron, or a copy thereof. We do not want it.
+        // Check the number of facets, etc. If same, ignore.
+        // What we need from the Boolean Processor is a null pointer or a
+        // null polyhedron. It seems to return the original or a copy of it.
+        if (pResultantPolyhedron->GetNoFacets() == pOriginalPolyhedron->GetNoFacets())
+          // This works in most cases but I still get a box in test202 with
+          // /vis/viewer/set/sectionPlane on 0 0 0 m 0.1 0.1 1
+        {
+          pResultantPolyhedron = nullptr;
+        }
       }
 
-      delete resultantSolid;
+      if (pResultantPolyhedron) {
+        // Finally, draw polyhedron...
+        sceneHandler.BeginPrimitives(theAT);
+        sceneHandler.AddPrimitive(*pResultantPolyhedron);
+        sceneHandler.EndPrimitives();
+      }
 
-      // Finally, force polyhedron drawing...
-      resultant.SetVisAttributes(resultantVisAttribs);
-      sceneHandler.BeginPrimitives(theAT);
-      sceneHandler.AddPrimitive(resultant);
-      sceneHandler.EndPrimitives();
+      delete pResultantSolid;
     }
   }
-  sceneHandler.PostAddSolid ();
 }
 
 G4bool G4PhysicalVolumeModel::Validate (G4bool warn)
@@ -953,7 +996,7 @@ std::ostream& operator<<
 (std::ostream& os, const std::vector<G4PhysicalVolumeModel::G4PhysicalVolumeNodeID>& path)
 {
   if (path.empty()) {
-    os << " NULL PATH";
+    os << " TOP";
   } else {
     for (const auto& nodeID: path) {
       os << ' ' << nodeID;
